%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computing and plotting integrated water vapour (IWV) and transport (IVT)
% for four anomalous IWV events in NY Alesund during the ACLOUD and PASCAL campaigns
% Fig A1 in Knudsen E., et al., 2018, Meteorological conditions during the ACLOUD/PASCAL field campaigns near Svalbard in early summer 2017 
% Fig A1d: 13 June, 2017, 00UTC
% FIGURE SHOWS:
% - vertically integrated water vapor (IWV; in kg m-2; shading)
% - 700 hPa geopotential height (in m; black contours)
% - sea ice edge (defined by 15% sea ice concentration; white contours)
% - vertically integrated water vapour transport (IVT) corresponding to atmospheric rivers (IVT; in kg m-1 s-1; red arrows)
% Atmospheric rivers are defined as in Gorodetskaya et al 2014
% INPUT DATA: 
% - era_interim_06_2017_05.nc
% - era_interim_geopotential_06_2017_05.nc
% - era_interim_lanseamask_06_05.nc
% - era_interim_sci_06_2017_05.nc
% USES FUNCTIONS: 
% - func_IVT_1000to300hpa
% - func_IWV_1000to300hpa
% - func_IWVsat_1000to300hpa
% - func_IWV_higher_IWVthres
% REFERENCES:
% Gorodetskaya, I. V., M. Tsukernik, K.Claes, M. F. Ralph, W. D. Neff, and N. P. M. Van Lipzig (2014), 
% The role of atmospheric rivers in anomalous snow accumulation in East Antarctica,
% Geophys. Res. Lett., 41, 61996206, doi:10.1002/2014GL060881
% AUTHORS:
% Carolina Viceto and Irina Gorodetskaya
% Centre for Marine and Environmental Studies, Dept of Physics, University of Aveiro, Portugal
% Contact emails: carolina.viceto@ua.pt, irina.gorodetskaya@ua.pt
% November 2018
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%% CALCULATE NEEDED VARIABLES %%%%%%%%%%%%%%%%%%%%%%

% create date vector during June 2017
date=datenum({'01-Jun-2017 00:00:00';'30-June-2017 18:00:00'});
dates=datevec(date(1):1/4:date(2)); clear date
% 00 UTC June 13, 2017 - dates(49,:)

% date of the studied event
mon_txt='06';
day_txt='13';
hour_txt='00';
year_txt='2017';

%% Calculate vertically integrated water vapour (IWV)
% 1000hPa and 300hPa

% load variables - pressure (pres), specific humidity (q) - 00 UTC June 13, 2017
filename=[mon_txt '_' year_txt '_05.nc'];
filein = ['inputs/era_interim_' filename];

d.pres = ncread(filein, 'level');
d.q = ncread(filein,'q',[1 1 1 49],[Inf Inf Inf 1]);
d.lat = ncread(filein, 'latitude');
d.lon = ncread(filein, 'longitude');

% Calculate IWV - creates s structure
s = func_IWV_1000to300hpa(d, year_txt, mon_txt, day_txt, hour_txt);
% s structure contains IWV (kg m-2)

% Save data into file
datapath='IWVkgm2/';
date_txt = [year_txt mon_txt day_txt '_' hour_txt];

mfname=[datapath 'era_interim_IWVkgm2_1000to300hpa_' date_txt '.mat'];
save(mfname,'-struct','s') 

clearvars -except dates mon_txt day_txt hour_txt year_txt

%% Calculate vertically integrated saturated water vapour (IWVsat)
% 1000hPa and 300hPa

% load variables - pressure (pres), specific humidity (q) - 00 UTC June 13, 2017
filename=[mon_txt '_' year_txt '_05.nc'];
filein = ['inputs/era_interim_' filename];

d.pres = ncread(filein, 'level');
d.q = ncread(filein,'q',[1 1 1 49],[Inf Inf Inf 1]);
d.lat = ncread(filein, 'latitude');
d.lon = ncread(filein, 'longitude');
d.t = ncread(filein,'t',[1 1 1 49],[Inf Inf Inf 1]);

% Calculate IWVsat - creates s structure
s = func_IWVsat_1000to300hpa(d, year_txt, mon_txt, day_txt, hour_txt);
% s structure contains IWVsat (kg m-2)

% Save data into file
datapath='IWVsat/';
date_txt = [year_txt mon_txt day_txt '_' hour_txt];

mfname=[datapath 'era_interim_IWVsat_1000to300hpa_' date_txt '.mat'];
save(mfname,'-struct','s')   

clearvars -except dates mon_txt day_txt hour_txt year_txt

%% Calculate vertically integrated vapour transport (IVT)
% 1000hPa and 300hPa

% load variables - pressure (pres), specific humidity (q),
% zonal wind component (u), meridional wind component (v)
% 00 UTC June 13, 2017 
filename=[mon_txt '_' year_txt '_05.nc'];
filein = ['inputs/era_interim_' filename];

d.pres = ncread(filein, 'level');
d.q = ncread(filein,'q',[1 1 1 49],[Inf Inf Inf 1]);
d.u = ncread(filein,'u',[1 1 1 49],[Inf Inf Inf 1]);
d.v = ncread(filein,'v',[1 1 1 49],[Inf Inf Inf 1]);
d.lat = ncread(filein, 'latitude');
d.lon = ncread(filein, 'longitude');
d.lev = ncread(filein, 'level');

% Calculate IWV - creates s structure
s = func_IVT_1000to300hpa(d, year_txt, mon_txt, day_txt, hour_txt);
% s structure contains IVT (kg m-1 s-1)

% Save data into file
datapath='IVT/';
date_txt = [year_txt mon_txt day_txt '_' hour_txt];

mfname=[datapath 'era_interim_IVT_1000to300hpa_' date_txt '.mat'];
save(mfname,'-struct','s') 

clearvars -except dates mon_txt day_txt hour_txt year_txt

%% Identify regions where IWV is higher or equal than a threshold (IWVthres)

% load variables - pressure (pres), specific humidity (q)
% 00 UTC June 13, 2017

% Load IWV
datapath='IWVkgm2/';
var='IWVkgm2';
date_txt = [year_txt mon_txt day_txt '_' hour_txt];
filename=[datapath '/era_interim_' var '_1000to300hpa_' date_txt];
load(filename)
clear datapath var filename day hour mon

% Load IWVsat
datapath='IWVsat/';
var='IWVsat';
filename=[datapath '/era_interim_' var '_1000to300hpa_' date_txt];
load(filename)
clear datapath var filename day hour mon

d.iwv = iwvkgm2;
d.iwvsat = iwv_sat;
d.lat = lat;
d.lon = lon;

% Calculate IWVsat - creates s structure
s = func_IWV_higher_IWVthres(d, year_txt, mon_txt, day_txt, hour_txt);
% s structure contains IWVsat (kg m-2)

% Save data into file
datapath='IWV_higher_IWVthres/';
date_txt = [year_txt mon_txt day_txt '_' hour_txt];

mfname=[datapath 'era_interim_IWV_higher_IWVthres_' date_txt '.mat'];
save(mfname,'-struct','s')   

clear all

%%%%%%%%%%%%%%%%%%%%% LOAD VARIABLES FOR FIGURE %%%%%%%%%%%%%%%%%%%%%%%%%%

mon_txt='06';
day_txt='13';
hour_txt='00';
year_txt='2017';

date_txt = [year_txt mon_txt day_txt '_' hour_txt];

% Load sea-ice cover
filename=[mon_txt '_' year_txt '_05.nc'];
filein = ['inputs/era_interim_sci_' filename];
ci=ncread(filein,'ci');
ci=ci(:,:,49); % 00 UTC June 13, 2017

% Add one longitude
ci=[ci;ci(720,:)];

% Load geopotential at 700 hPa
filename=[mon_txt '_' year_txt '_05.nc'];
filein = ['inputs/era_interim_geopotential_' filename];
geopt=ncread(filein,'z',[1 1 49],[Inf Inf 1]);

% Calculate geopotential height
g=9.8; 
geopth=geopt/g; clear geopt

% Add one longitude
geopth=[geopth;geopth(720,:)];

% Load Integrated Vapour Transport (IVT) - zonal (ivtx), meridional (ivty)
filename=['IVT/era_interim_IVT_1000to300hpa_' date_txt];
load(filename)

% Load Integrated Water Vapour (IWV)
filename=['IWVkgm2/era_interim_IWVkgm2_1000to300hpa_' date_txt];
load(filename)

% Add one longitude
iwvkgm2=[iwvkgm2 iwvkgm2(:,720)];

% Load IWV higher or equal than IWVthres
filename=['IWV_higher_IWVthres/era_interim_IWV_higher_IWVthres_' date_txt];
load(filename)

% Add longitude
iwvthres=[iwvthres;iwvthres(720,:)];

% Latitude, longitude
latitude=double(lat);
longitude=double(lon);

% Add one longitude
longitude=[longitude;360];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PLOT FIGURE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

FigHandle = figure('color','w','Visible','on'); 
axesm('lambert')
setm(gca,'Origin',[0 40],'MapLonLimit',[-30 110],'MapLatLimit',[50 85],'MLabelLocation',[-45 -30 -15 0 15 30 45 60 75 90 105],'PLabelLocation',[50 55 60 65 70 75 80 85],'MLineLocation',15,'PLineLocation',5,'LabelRotation','on','Fontsize',12)
framem on
plabel on
mlabel on
gridm on
axis off
 
% Add colormap tables
addpath(genpath('kakearney-cptcmap-pkg-845bf83/'))
cptcmap('seminf-haxby');

% Plot IWV - shading
pcolorm(latitude,longitude,iwvkgm2)

c=colorbar('south','XAxisLocation','bottom','position',[0.25 0.06 0.5 0.02]);
set(get(c,'xlabel'),'string','Integrated water vapour [kg m^{-2}]','Fontweight','bold','position',[20 -5.5]);
caxis([-1e-10 40])
set(c,'Xtick',[0 5 10 15 20 25 30 35 40])    

% Plot coastline - grey line
load coast
plotm(lat,long,'color',[0.502 0.502 0.502],'linewidth',2) 

% Plot ny-alesund location - yellow dot
plotm(78.9230,11.9210,'xy','Linewidth',3,'Markersize',5);

tightmap
    
% Load land-sea mask
filename=[mon_txt '_05.nc'];
filein = ['inputs/era_interim_landseamask_' filename];
lsm=ncread(filein,'lsm');

% Add one longitude
lsm=[lsm;lsm(720,:)];
    
% Remove grid points where sea-ice cover intercepts the coastline 
for i=1:size(longitude,1)
    for j=1:size(latitude,1)
      
        m=lsm(i,j);

        if m==1
            ci(i,j)=NaN;
        end
    end
end
    
% Plot sea-ice cover using a 15% threshold - white line
contourm(latitude,longitude,ci',[0.15 0.15],'linecolor','w','Linewidth',2); 

% Remove gridpoints of IVT where IWV<IWVthres

% Add one longitude
ivtx=[ivtx;ivtx(720,:)];
ivty=[ivty;ivty(720,:)];

for i=1:size(longitude,1)
    for j=1:size(latitude,1)
            
        if iwvthres(i,j)==-9999
            ivtx(i,j)=0;
            ivty(i,j)=0;
        end
    end
end
    
% Plot geopotential height - black line
[cg,h]=contourm(latitude,longitude,geopth','k','Linewidth',1.5,'levelstep',50);
q=clabelm(cg,h,'LabelSpacing',10000);
set(q,'Edgecolor','none','backgroundcolor','none','Fontsize',12,'color','k')

% Change latitude from 90 to -90 -> -90 to 90
latitude=flip(latitude);
ivtx=flip(ivtx,2);
ivty=flip(ivty,2);

% Create lat x lon matrix
[lati,loni]=meshgrid(latitude,longitude);

% Plot IVT arrows where IWV >= IWVthres - red arrows
% Different spacing for latitudes higher than 60N
quivermc(lati(1:12:end,331:2:end),loni(1:12:end,331:2:end),ivtx(1:12:end,331:2:end),ivty(1:12:end,331:2:end),'density',100,'color','r','reference',200,'arrowstyle','tail','linewidth',1.5);
quivermc(lati(1:7:end,311:3:330),loni(1:7:end,311:3:330),ivtx(1:7:end,311:3:330),ivty(1:7:end,311:3:330),'density',100,'color','r','reference',200,'arrowstyle','tail','linewidth',1.5);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% FUNCTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Function to calculate integrated vapour transport (IVT)(kg m-1 s-1)
% from 1000 hPa to 3000 hPa 

function [s] = func_IVT_1000to300hpa(d, year_txt, mon_txt, day_txt, hour_txt);

    % Constants
    g=9.8;

    % Save to folder
    datapath = 'IVT/';

    if exist(datapath, 'dir')~=7
        mkdir(datapath)
    end

    % Calculate zonal water vapour transport (qu)
    qu=d.q.*d.u;

    % Calculate zonal water vapour transport (qv)
    qv=d.q.*d.v;

    % Calculate qu (ivtx) and qv (ivty) at each pressure level
    for n=1:size(d.lev)-1;
        dp=(d.lev(n+1)-d.lev(n))*100; % hpa -> pa
        qu_l=qu(:,:,n+1)+qu(:,:,n);
        qv_l=qv(:,:,n+1)+qv(:,:,n);
        ivtx(:,:,n)=(qu_l/2)*double(dp);
        ivty(:,:,n)=(qv_l/2)*double(dp);
    end 

    % Calculate vertical integral
    ivtx=(1/g).*nansum(ivtx,3); clear ivtx_l
    ivty=(1/g).*nansum(ivty,3); clear ivty_l

    s.ivtx=ivtx;
    s.ivty=ivty;

end

%% Function to calculate integrated water vapour (IWV) (kg m-2)
% from 1000 hPa to 3000 hPa

function [s] = func_IWV_1000to300hpa(d, year_txt, mon_txt, day_txt, hour_txt)

    % Constants
    g = 9.8; % graviational acceleration, m s-2

    % Date
    date_txt = [year_txt mon_txt day_txt];

    % Save to folder
    datapath = 'IWVkgm2/';

    if exist(datapath, 'dir')~=7 %create folder 
        mkdir(datapath) 
    end

    % Find pressure levels from 1000 hPa to 300 hPa
    all.p = d.pres.*100; % hPa->Pa; 
    indp1 = find(all.p==30000); % find level 300 hPa
    indp2 = find(all.p==100000); % find level 1000 hPa

    % Limit pressure (p) and specific humidity(q) to 1000 hPa to 300 hPa
    a.p = all.p(indp1:indp2);
    a.q = d.q(:,:,indp1:indp2); clear indp1 indp2
    pres = a.p';
    presdif = abs(diff(a.p))'; % pressure difference between levels

    % Calculate IWV

    % dimensions
    dim.lon = [1:size(a.q,1)];
    dim.lat = [1:size(a.q,2)];

    % create 3d pressure matrix
    [lon3d, lat3d, pres3d] = ndgrid(dim.lon, dim.lat, pres);

    % create 3d pressure difference matrix
    [lon3d, lat3d, presdif3d] = ndgrid(dim.lon, dim.lat, presdif);  clear presdif

    a1 = presdif3d; clear presdif3d

    % Calculate IWV from q at each pressure level
    a2=(a.q(:,:,1:end-1)+a.q(:,:,2:end))/2;

    % Calculate vertical integral
    iwv_kgm2 = (1/g).*nansum(double(a1).*double(a2),3); % kg m-2
    IWVkgm2 = iwv_kgm2; clear a1 a2

    % New structure to save
    s.iwvkgm2=IWVkgm2';
    s.pres = a.p;
    s.lon = d.lon;
    s.lat = d.lat;
    s.year = year_txt;
    s.mon = mon_txt;
    s.day = day_txt;
    s.hour= hour_txt;

end

%% Function to calculate saturated integrated water vapour IWV (IWVsat) (kg m-2)
% from 1000 hPa to 3000 hPa 

function [s] = func_IWVsat_1000to300hpa(d, year_txt, mon_txt, day_txt, hour_txt);

    % Constants
    g = 9.8; % graviational acceleration, m s-2
    epsilon = 0.622;  % Rd/Rv
    Rv = 461;  % J kg-1 K-1, gas constant for vapor
    Lv = 2.5e6; % J kg-1, latent heat of vaporization at 0C
    T0 = 273.16; % K, T at triple point
    es0 = 611;  % Pa, vapor pressure at triple point

    % Date
    date_txt = [year_txt mon_txt day_txt];

    datapath = 'IWVsat/';

    if exist(datapath, 'dir')~=7
        mkdir(datapath)
    end

    % Find pressure levels from 1000 hPa to 300 hPa
    all.p = d.pres.*100; % hPa->Pa; 
    indp1 = find(all.p==30000); % find level 300 hPa
    indp2 = find(all.p==100000); % find level 1000 hPa

    % Limit pressure (p) and specific humidity(q) to 1000 hPa to 300 hPa
    a.p = all.p(indp1:indp2);
    a.t = d.t(:,:,indp1:indp2); clear indp1 indp2
    pres = a.p';
    presdif = abs(diff(a.p))'; % pressure difference between levels

    % Calculate SATURATED IWV

    % saturation vapour pressure of water vapour
    es = es0.*exp(-Lv/Rv.*(1./a.t-1/T0));

    % dimensions
    dim.lon = [1:size(a.t,1)];
    dim.lat = [1:size(a.t,2)];

    % create 3d pressure matrix
    [lon3d, lat3d, pres3d] = ndgrid(dim.lon, dim.lat, pres);

    % create 3d pressure difference matrix
    [lon3d, lat3d, presdif3d] = ndgrid(dim.lon, dim.lat, presdif); clear presdif

    a1 = double(presdif3d); clear presdif3d

    % Saturated specific humidity
    qs = epsilon.*es./double(pres3d); clear es pres3d

    % Calculate sat IWV from qs at each pressure level
    a2=(qs(:,:,1:end-1)+qs(:,:,2:end))/2; clear qs

    % Calculate vertical integral
    iwv_kgm2 = (1/g).*sum(a1.*a2,3); % kg m-2
    IWVkgm2 = iwv_kgm2; clear a1 a2

    % New structure to save
    s.iwv_sat = IWVkgm2';
    s.pres = a.p;
    s.lon = d.lon;
    s.lat = d.lat;
    s.year = year_txt;
    s.mon = mon_txt;
    s.day = day_txt;
    s.hour= hour_txt;
end

%% Function to identify regions where IWV is higher than a threshold (IWVthres)

% Calculate threshold on IWV (IWVthresh) using Clausius-Clapeyron relation 
% IWV >= IWVthres
% IWVthres = IWVsat_mean+ARcoef*(IWVsat_max-IWVsat_mean), where:
%    - IWVsat_mean is a zonal mean IWVsat along each latitude
%    - ARcoef = 0.2, is a coefficient determining relative strength of an AR
%    - IWVsat_max is the maximum value of IWVsat along the same latitude

function [s] = func_IWV_higher_IWVthres(d, year_txt, mon_txt, day_txt, hour_txt);

    % Constants
    g=9.8;

    datapath = 'IWV_higher_IWVthres/';

    if exist(datapath, 'dir')~=7
        mkdir(datapath)
    end

    % Load IWV
    datapath='IWVkgm2/';
    var='IWVkgm2';
    date_txt = [year_txt mon_txt day_txt '_' hour_txt];
    filename=[datapath '/era_interim_' var '_1000to300hpa_' date_txt];
    load(filename)
    clear datapath var filename day hour mon

    % Load IWVsat
    datapath='IWVsat/';
    var='IWVsat';
    filename=[datapath '/era_interim_' var '_1000to300hpa_' date_txt];
    load(filename)
    clear datapath var filename day hour mon

    % Define Atmospheric rivers

    % Studying sector:
    sector_lon1 = -30; % 30W  
    sector_lon2 = 110; % 110E

    % AR strength coefficient
    ARcoef = 0.2;  

    % Average over longitudes (zonal mean)
    z.IWVsat_mean = mean(iwv_sat, 2); % vector: one value per latitude

    % maximum of IWVsat along each latitude:
    numlat = size(z.IWVsat_mean);

    for ilat = 1:numlat
       IWVsat_max(ilat) = max(iwv_sat(ilat,:));
    end

    z.IWVsat_max = IWVsat_max';  % vector: one value per latitude

    % Threshold for ARs

    % Threshold based on CC relation: one value for each latitude
    z.IWV_ARthreshCC = z.IWVsat_mean + ARcoef .* (z.IWVsat_max - z.IWVsat_mean);  

    z.lat = lat; % latitudes
    z.lon = lon; % longitudes

    % create 2d IWVthresh matrix (extend threshold per latitude to all longitudes):
    [lon2d, IWVthresh_2d] = ndgrid(z.lon, z.IWV_ARthreshCC);

    z.IWVthresh_2d = IWVthresh_2d';

    % indices for ARs:
    indAR = (abs(iwvkgm2) >= z.IWVthresh_2d);  %   1 if AR, 0 if non-AR 

    z.indAR = double(indAR);  % convert logical 0/1 to numeric

    % define IWV > threshold at each latitude/longitude:
    z.IWVthres = iwvkgm2;
    z.IWVthres(indAR==0) = -9999;  % values of IWV<IWVr become NaNs


    % New structure to save
    s.iwvthres = z.IWVthres';
    s.lon = d.lon;
    s.lat = d.lat;
    s.year = year_txt;
    s.mon = mon_txt;
    s.day = day_txt;
    s.hour= hour_txt;
end
