; Description:
;  Performing EOF analysis to optain Arctic Dipole (AD) and
;  Arctic Oscillation (AO) indices
;
;  Knudsen, E., et al., 2018, Meteorological conditions
;  during the ACLOUD/PASCAL field campaign near Svalbard
;  in early summer 2017 - Fig. 12 and A2
;
;  NCL script based on sample script eof_4_640.ncl (see below)
;
; Use method:
;  ncl calc_eof_day_RnW.ncl
;
; Author: 
;  Bernd Heinold, TROPOS
;  04318 Leipzig, Germany
;
; History:
;  October 2017
;
;==============================================================
; eof_4_640.ncl
;==============================================================
; Match the AAO pattern at: 
;   http://www.cpc.ncep.noaa.gov/products/precip/CWlink/daily_ao_index/aao/aao.loading.shtml
;
; Use method: 
;   http://www.cpc.ncep.noaa.gov/products/precip/CWlink/daily_ao_index/aao/aao.shtml
;==============================================================
; Data source was Reanalysis-2 geopotential height.
;  http://www.esrl.noaa.gov/psd/data/gridded/data.ncep.reanalysis2.pressure.html 
;==============================================================
; This script uses functions eofunc_n_Wrap and 
; eofunc_ts_n_Wrap, which were added in NCL V6.4.0
;==============================================================
; These files are loaded by default in NCL V6.2.0 and newer
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
  load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/stdDayTLL.ncl"

; ==============================================================
; User defined parameters that specify region of globe and
; ==============================================================
  latN   =  90.
  latS   =  20. 
  plev   = 1000

; yrStrt = 1979
; yrLast = 1991

; yrStrt = 1992
; yrLast = 2004

  yrStrt = 2005
  yrLast = 2017

  var    = "var129"
  title  = str_upper(var)+": "+plev+"hPa "

  ymStrt = yrStrt*100 +  1
  ymLast = yrLast*100 + 12

  neof   = 3                                  ; Leading EOF only
  optEOF = True       
  optETS = False

; ==============================================================
; Open the file: Read only the user specified period and level
; ==============================================================
  f      = addfile ("/INPUT_DIRECTORY/1000mb.hgt.day.mean.nc", "r")

  TIME   = f->time
  YYYY   = cd_calendar(TIME,-1)/100                 ; entire file
  iYYYY  = ind(YYYY.ge.yrStrt .and. YYYY.le.yrLast)

  TIM     = cd_calendar(TIME, 0)          ; type float 
  year    = toint( TIM(iYYYY,0) )
  month   = toint( TIM(iYYYY,1) )
  day     = toint( TIM(iYYYY,2) ) 
  ddd     = day_of_year(year, month, day) 
  yyyyddd = year*1000 + ddd 

  iMM = ind(month.ge.5 .and. month.le.7 .and. year.eq.2004)

  x      = short2flt( f->$var$(iYYYY,0,{latS:latN},:) )
 printVarSummary(x)                                ; (time, lat,lon)

; ==============================================================
; compute climatology and Anomalies
; ==============================================================
  xClm   = clmDayTLL(x,yyyyddd)                    ; (366,lat,lon)
; xClm   = smthClmDayTLL(x, 2)                     ; (366,lat,lon) smooth

  xAnom  = calcDayAnomTLL ( x, yyyyddd, xClm)                ; (time, lat,lon)
; printVarSummary(xAnom)         
; printMinMax(xAnom, True)

; =================================================================
; create weights:  sqrt(cos(lat))   [or sqrt(gw) ]
; =================================================================
  rad    = get_d2r("float")
  clat   = xAnom&lat            
  clat   = sqrt( cos(rad*clat) )                 ; gw for gaussian grid

; =================================================================
; weight all observations 
; =================================================================
  xw     = xAnom*conform(xAnom, clat, 1)
  copy_VarMeta(x, xw)
  xw@long_name = "Wgt: "+x@long_name

; =================================================================
; Reorder (lat,lon,time) the *weighted* input data
; Compute EOFs & Standardize time series
; =================================================================
  eof    = eofunc_n_Wrap(xw, neof, optEOF, 0)      
; eof    = -1*eof                                ; *special* match sign of CPC

  eof_ts = eofunc_ts_n_Wrap (xw, eof, optETS, 0)

  eof_ts = dim_standardize_n( eof_ts, 0, 1)      ; normalize

  eof_ts_1 = eof_ts( 0, :)      ; 1st primary component
  eof_ts_2 = eof_ts( 1, :)      ; 2nd primary component
  eof_ts_3 = eof_ts( 2, :)      ; 3rd primary component
  eof_ts_1TLL = conform(x, eof_ts_1, 0)  
  eof_ts_2TLL = conform(x, eof_ts_2, 0)  
  eof_ts_3TLL = conform(x, eof_ts_3, 0)  
  copy_VarMeta(x, eof_ts_1TLL)
  copy_VarMeta(x, eof_ts_2TLL)
  copy_VarMeta(x, eof_ts_3TLL)

; =================================================================
; netcdf output
; =================================================================
 fname =  "eof_ts_II.nc"
 rmcmd = "'rm' " + fname
 system(rmcmd)                           ; remove any pre-existing file
 ncdf = addfile(fname,"c")               ; open output netCDF file

; make time an UNLIMITED dimension       ; recommended  for most applications
 filedimdef(ncdf,"time",-1,True)

; output variables directly
 ncdf->eof_ts1 = eof_ts_1TLL
 ncdf->eof_ts2 = eof_ts_2TLL
 ncdf->eof_ts3 = eof_ts_3TLL

; =================================================================
; compute time mean
; =================================================================
; eof_ts_1Clm    = clmDayTLL(eof_ts_1TLL,yyyyddd)                    ; (366,lat,lon)
; eof_ts_1ClmStd = stdDayTLL(eof_ts_1TLL,yyyyddd)

; iplotDDD = toint( yyyyddd(iMM)-2004000-1 )
; sub_eof_ts_1Clm = eof_ts_1Clm(iplotDDD,0,0)

; data_ts      = new((/2,dimsizes(iplotDDD)/),double)
; data_ts(0,:) = eof_ts_1(iMM)
; data_ts(1,:) = sub_eof_ts_1Clm

; =================================================================
; Regress
; =================================================================

  eof_regres = eof                               ; create an array w meta data
  do ne=0,neof-1
     eof_regres(ne,:,:) = (/ regCoef_n(eof_ts(ne,:), xAnom, 0, 0) /)
  end do
; printVarSummary(eof_regres)

