; Description:
;  Plotting time series of Arctic Oscillation (AO) index
;
;  Knudsen, E., et al., 2018, Meteorological conditions
;  during the ACLOUD/PASCAL field campaign near Svalbard
;  in early summer 2017 - Fig. 12
;
; Use method:
;  Apply after scripts
;  icalc_eof_day_RnW.ncl and prep_eof_ts_clim4ncl_2.sh
;  ncl plot_ts_ao_clim.ncl
;
; Author:
;  Bernd Heinold, TROPOS
;  04318 Leipzig, Germany
;
; History:
;  October 2017
;
;------------------------------------------------------------------------------
; These files are loaded by default in NCL V6.2.0 and newer
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;
; This file still has to be loaded manually
load "$NCARG_ROOT/lib/ncarg/nclscripts/contrib/time_axis_labels.ncl"

begin
; Open the file
  inFileName1 = "outn_cp_ao_all.nc"
  inFileName2 = "outn_wp_ao_all.nc"
  inFileName3 = "outn_np_ao_all.nc"
  inFileName4 = "outn_np_ao_all.nc"
  inFileName5 = "outn_np_ao_all.nc"
  inFileName6 = "outn_np_ao_all.nc"

  inFile1 = addfile( inFileName1, "r" )
  inFile2 = addfile( inFileName2, "r" )
  inFile3 = addfile( inFileName3, "r" )
  inFile4 = addfile( inFileName4, "r" )
  inFile5 = addfile( inFileName5, "r" )
  inFile6 = addfile( inFileName6, "r" )

; lon = 480 ;
; lat = 94 ;
; time = UNLIMITED ; // (92 currently)
; double eof_ts1(time, lat, lon)
; double time(time); units = "hours since 1979-1-1 00:00:00"
;                    calendar = "proleptic_gregorian"

; Get the time units and set the first and last times that we want
  timeUnits = inFile1->time@units
  startDate = cd_inv_calendar( 1998, 06, 01, 00, 0, 0, timeUnits, 0 )
  endDate   = cd_inv_calendar( 2017, 06, 01, 00, 0, 0, timeUnits, 0 )

  inData    = inFile1->eof_ts1({startDate:endDate},0,0)

  data      = new((/6,dimsizes(inData)/),"double")
  data(0,:) = inFile1->eof_ts1({startDate:endDate},0,0)
  data(1,:) = inFile2->eof_ts1({startDate:endDate},0,0)
  data(2,:) = inFile3->eof_ts1({startDate:endDate},0,0)
  data(3,:) = inFile4->eof_ts1({startDate:endDate},0,0)
  data(4,:) = inFile5->eof_ts1({startDate:endDate},0,0)
  data(5,:) = inFile6->eof_ts1({startDate:endDate},0,0)

  timeUnits = "days since 1800-01-01 00:00:00"
  data&time = ut_convert( data&time, timeUnits )
  
  TIM     = cd_calendar(data&time, 0)          ; type float
  year    = toint( TIM(:,0) )

; Set workspace
  wks = gsn_open_wks("eps", "eof1_clim_1979-2017_15_20N" ) ; send graphics to PNG file

;; Set resources for the line plot
;  res                    = True              ; plot mods desired
;  res@gsnDraw            = True             ; don't draw yet
;  res@gsnFrame           = False             ; don't advance frame yet
;
;  res@vpHeightF          = 0.40              ; change aspect ratio
;  res@vpWidthF           = 0.70
;  res@vpXF               = 0.15              ; change start locations
;  res@vpYF               = 0.75              ; 
;  res@gsnXYBarChartBarWidth = 0.15           ; change bar widths
;
;; res@trYMinF            = -3.0  ;-7.0
;; res@trYMaxF            =  3.0  ; 7.0
;  res@trYMinF            = -2.0  ;-5.0
;  res@trYMaxF            =  2.0  ; 5.0
;
;  res@gsnYRefLine            = 0.0               ; create a reference line
;  res@gsnYRefLineDashPattern = 14           
;  res@gsnXYBarChart          = True            ; create bar chart 
;  res@gsnAboveYRefLineColor  = "red"           ; above ref line fill red
;  res@gsnBelowYRefLineColor  = "blue"          ; below ref line fill blue
;
;; res@tiMainString       = "Arctic Oscillation (AO) index"  ; add title
;; res@tiYAxisString	 = "AO index"        ; add an axis title    
;  res@tiMainString       = "Arctic Dipole (AD) index"  ; add title
;  res@tiYAxisString	 = "AD index"        ; add an axis title    
;  res@txFontHeightF	 = 0.0195            ; change title font heights
;  res@tmXBLabelAngleF    = -45               ; tilt the XB labels 45 degrees
;  res@tmXBLabelDeltaF    = 1.25              ; push the XB labels down from plot
;
;; Set special resources for the time axis
;  resTick                = True
;; resTick@ttmFormat      = "%d %c"
;  resTick@ttmFormat      = "%Y"
;  resTick@ttmAxis        = "XB"
;  resTick@ttmMajorStride = 5
;
;; Set resources necessary to customize X axis labels
;; time_axis_labels( data&time, res, resTick )
;  
;; Create main line plot
;  top_plot = gsn_csm_xy (wks,data&time+5,data(0:1,:),res)       ; create line plot
;
;; Make panel plot       
;  maximize_output(wks,True)

     sres = True
     sres@gsnDraw            = False
     sres@gsnFrame           = False
     sres@vpHeightF          = 0.40              ; change aspect ratio
     sres@vpWidthF           = 0.70
     sres@vpXF               = 0.15              ; change start locations
     sres@vpYF               = 0.75              ; 

     sres@gsnPaperOrientation = "auto"          
     sres@gsnMaximize         = True

     sres@trXMinF            = 0.
     sres@trXMaxF            = dimsizes(year)+1.
     sres@trYMinF            = -2.
     sres@trYMaxF            =  2.

     sresTick                = True
     sresTick@ttmMajorStride = 5
     sresTick@ttmFormat      = "%Y"
     sresTick@ttmAxis        = "XB"

     sres@gsnXYBarChart      = True
     sres@gsnXYBarChartBarWidth = 0.20           ; change bar widths

     sres@gsnYRefLine            = 0.0               ; create a reference line
  ;  sres@gsnYRefLineDashPattern = 14           
     sres@gsnXYBarChart          = True            ; create bar chart 
    ;sres@gsnAboveYRefLineColor  = "red"           ; above ref line fill red
    ;sres@gsnBelowYRefLineColor  = "blue"          ; below ref line fill blue

     sres@tmXBMode             = "Explicit"         ; explicit labels
     sres@tmXBValues           = fspan(1,dimsizes(year),dimsizes(year))
     sres@tmXBLabels           = year 
     sres@tmXBLabelFontHeightF = 0.01
     sres@tmYLLabelFontHeightF = 0.01
     sres@tiMainFontHeightF    = 0.025
     sres@tiMainFont           = "helvetica"
     sres@tiMainString         = "Arctic Oscillation (AO) index"  ; add title
     sres@tiYAxisString        = "AO index"        ; add an axis title    
     sres@gsnRightString       = ""
        
     sres@gsnAboveYRefLineColor  = (/0.94,0.5,0.5/)           ; above ref line fill red
     sres@gsnBelowYRefLineColor  = (/0.53,0.81,0.98/)           ; above ref line fill red
    ;sres@gsnXYBarChartColors    = (/0.,0.,1./)
     plot1 = gsn_csm_xy(wks,fspan(0.8,dimsizes(year)-0.20,dimsizes(year)),data(0,:),sres)		; draw each time series
     sres@gsnAboveYRefLineColor  = (/1.,0.,0./)           ; above ref line fill red
     sres@gsnBelowYRefLineColor  = (/0.,0.,1./)           ; above ref line fill red
    ;sres@gsnXYBarChartColors    = (/1.,0.,0./)
     plot2 = gsn_csm_xy(wks,fspan(1,dimsizes(year),dimsizes(year)),data(1,:),sres)		; advancing the frame
     sres@gsnAboveYRefLineColor  = (/0.5,0.,0./)           ; above ref line fill red
     sres@gsnBelowYRefLineColor  = (/0.,0.,0.5/)           ; above ref line fill red
    ;sres@gsnXYBarChartColors    = (/0.,0.5,0./)
     plot3 = gsn_csm_xy(wks,fspan(1.2,dimsizes(year)+0.20,dimsizes(year)),data(2,:),sres)		; each time series is
   ; sres@gsnAboveYRefLineColor  = (/0.5,0.5,0./)           ; above ref line fill red
   ; sres@gsnBelowYRefLineColor  = (/0.,0.5,0.5/)           ; above ref line fill red
     sres@gsnXYBarChart          = False            ; create bar chart 
     sres@xyLineThicknesses	 = (/6./)         ; line thicknesses
   delete([/sres@gsnAboveYRefLineColor,sres@gsnBelowYRefLineColor/])
     plot4 = gsn_csm_xy(wks,fspan(1,dimsizes(year),dimsizes(year)),(data(0,:)+data(2,:)+data(1,:))/3.,sres)		; each time series is

     lbres                    = False ;True          ; labelbar only resources
     lbres@vpWidthF           = 0.3           ; labelbar width
     lbres@vpHeightF          = 0.1           ; labelbar height
     lbres@lbBoxMajorExtentF  = 0.36          ; puts space between color boxes
     lbres@lbFillColors       = (/"green","blue"/)
     lbres@lbMonoFillPattern  = True          ; Solid fill pattern
     lbres@lbLabelFontHeightF = 0.035         ; font height. default is small
     lbres@lbLabelJust        = "CenterLeft"  ; left justify labels
     lbres@lbPerimOn          = False
     lbres@lgPerimColor     = "white"
     labels = (/"CP (light blue/red)","WP (blue/red)"/)
     gsn_labelbar_ndc(wks,2,labels,0.52,0.23,lbres)	; draw right labelbar column
	
     lbres@lbFillColors       = (/"lightblue","red"/)
     labels = (/"NP (dark blue/red)","         "/)
     gsn_labelbar_ndc(wks,2,labels,0.17,0.23,lbres)	; draw left labelbar column
;    frame(wks) 
  maximize_output(wks,True)
end
