; Description:
;  Analyzing time series of Marine Cold Air Outbreak (MCAO) index
;  for MCAO events following Kolstad, E. W. (2017), QJ, doi:10.1002/qj.3068 
;
;  Preparing histogram with MCAO intensity and duration 
;
;  Knudsen, E., et al., 2018, Meteorological conditions
;  during the ACLOUD/PASCAL field campaign near Svalbard
;  in early summer 2017 - Fig. 14
;
; Use method:
;  Apply after ksh scripts
;  calc_mcao.sh and prep_mcao_ts_stat4ncl.sh
;  ncl calc_ts_stat_mcao.ncl
;
; Author:
;  Bernd Heinold, TROPOS
;  04318 Leipzig, Germany
;
; History:
;  October 2017
;
;------------------------------------------------------------------------------
; These files are loaded by default in NCL V6.2.0 and newer
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;
; This file still has to be loaded manually
load "$NCARG_ROOT/lib/ncarg/nclscripts/contrib/time_axis_labels.ncl"

begin
; Open the file
  inFileName1 = "mcao_ei_mjj1979-2017_small.nc"
; inFileName1 = "mcao_ei_mjj1979-2017_daysmall.nc"
; inFileName1 = "mcao_ei_mjj2017_daysmall.nc"
; inFileName1 = "mcao_ei_acloud1979-2017_daysmall.nc"
; inFileName1 = "mcao_ei_acloud2017_daysmall.nc"
  inFile1 = addfile( inFileName1, "r" )

; lon = 480 ;
; lat = 94 ;
; time = UNLIMITED ; // (92 currently)
; double eof_ts2(time, lat, lon)
; double time(time); units = "hours since 1979-1-1 00:00:00"
;                    calendar = "proleptic_gregorian"

; Get the time units and set the first and last times that we want
  timeUnits = inFile1->time@units
  startDate = cd_inv_calendar( 1979, 05,  1, 00, 0, 0, timeUnits, 0 )
  endDate   = cd_inv_calendar( 2017, 07, 31, 00, 0, 0, timeUnits, 0 )

  inData    = inFile1->var151({startDate:endDate},0,0)

  data      = new((/3,dimsizes(inData)/),"double")
  data(0,:) = inFile1->var151({startDate:endDate},0,0)
  data(1,:) = 0.  ; num_rcd
  data(2,:) = 0.  ; max_rcd

  timeUnits = "days since 1800-01-01 00:00:00"
  data&time = ut_convert( data&time, timeUnits )

  nn = 0.d
  mx = 0.d
  do t=1,dimsizes(data&time)-1
    if(data(0,t).gt.0.d) then
      nn = nn + 0.25d
      if(data(0,t).gt.mx) then
        mx = data(0,t)
      end if
    else
      data(1,t-1) = nn
      data(2,t-1) = mx
      nn = 0.d
      mx = 0.d
    end if
  end do

  data(1,:) = where(data(1,:).gt.0.5d.AND.data(2,:).ge.1.d,data(1,:),0.d) 
  data(2,:) = where(data(1,:).gt.0.5d.AND.data(2,:).ge.1.d,data(2,:),0.d) 

  data_sca  = new ( (/dimsizes(inData),2/), "double") ; (row,col)
  data_sca(:,0) = (/ data(2,:) /)
  data_sca(:,1) = (/ data(1,:) /)

  mcao_nnTLL = conform(inData, data(1,:), 0)
  mcao_mxTLL = conform(inData, data(2,:), 0)
  copy_VarMeta(inData, mcao_nnTLL)
  copy_VarMeta(inData, mcao_mxTLL)

; =================================================================
; netcdf output
; =================================================================
 fname =  "mcao_stat.nc"
 rmcmd = "'rm' " + fname
 system(rmcmd)                           ; remove any pre-existing file
 ncdf = addfile(fname,"c")               ; open output netCDF file

; make time an UNLIMITED dimension       ; recommended  for most applications
 filedimdef(ncdf,"time",-1,True)

; output variables directly
 ncdf->mcao    = inData
 ncdf->mcao_nn = mcao_nnTLL
 ncdf->mcao_mx = mcao_mxTLL
 ncdf->mcao_sc = data_sca

; =================================================================
; plot bivariate (joint) pdf
; =================================================================
 x = data(1,:)
 y = data(2,:)
;x = where(x.eq.0,x@_FillValue,x)
;y = where(y.eq.0,y@_FillValue,y)

 opt          = True
 opt@binx_min = 2      ; minimum value for the x bin boundary.
 opt@binx_max = 16      ; maximum value for the x bin boundary.
 opt@biny_min = 3      ; minimum value for the y bin boundary.
 opt@biny_max = 8      ; maximum value for the y bin boundary. 
 opt@bin_nice = True
;opt@binx_nice = True
;opt@biny_nice = True

 pdf2 = pdfxy(x, y, 7, 5, opt) 
;printVarSummary(pdf2)
 print(pdf2)

 pdf2 = where(pdf2.eq.0,pdf2@_FillValue,pdf2)

;plot   = new ( nSea, "graphic")
 wks    = gsn_open_wks("png","mcaopdf")

 res    = True
 res@gsnDraw              = False    ; do not draw picture
 res@gsnFrame             = False    ; do not advance frame
 res@cnFillOn             = True     ; turn on color fill
 res@cnFillPalette        = "amwg"   ; set color map
 res@cnFillMode           = "RasterFill"       ; Raster Mode
 res@cnLinesOn            = False    ; no contour lines
 res@cnLineLabelsOn       = False    ; no contour line labels
 res@cnInfoLabelOn        = False
;res@cnLabelBarEndStyle   = "ExcludeOuterBoxes"
;res@tiXAxisString        = awnc@varName
;res@tiYAxisString        = arel@varName
 res@tiXAxisOffsetYF      = 0.105

 res@gsnCenterString      = "  "
 plot = plt_pdfxy (wks, pdf2, res)
 maximize_output(wks,True)

end
