; Description:
;  Plotting time series of Arctic Oscillation (AO) or
;  Arctic Dipole (AD) index
;
;  Knudsen, E., et al., 2018, Meteorological conditions
;  during the ACLOUD/PASCAL field campaign near Svalbard
;  in early summer 2017 - Fig. A2
;
; Use method:
;  Apply after scripts
;  icalc_eof_day_RnW.ncl and prep_eof_ts_clim4ncl_2.sh
;  ncl plot_ts_ao_clim.ncl
;
; Author:
;  Bernd Heinold, TROPOS
;  04318 Leipzig, Germany
;
; History:
;  October 2017
;
;------------------------------------------------------------------------------
; These files are loaded by default in NCL V6.2.0 and newer
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;
; This file still has to be loaded manually
load "$NCARG_ROOT/lib/ncarg/nclscripts/contrib/time_axis_labels.ncl"

begin
; Open the file
  inFileName1 = "outn_all.nc"
; inFileName2 = "outn_50.nc"
; inFileName3 = "outn_25.nc"
; inFileName4 = "outn_75.nc"
; inFileName5 = "outn_05.nc"
; inFileName6 = "outn_95.nc"
  inFileName2 = "outn_all.nc"
  inFileName3 = "outn_all.nc"
  inFileName4 = "outn_all.nc"
  inFileName5 = "outn_all.nc"
  inFileName6 = "outn_all.nc"
  inFile1 = addfile( inFileName1, "r" )
  inFile2 = addfile( inFileName2, "r" )
  inFile3 = addfile( inFileName3, "r" )
  inFile4 = addfile( inFileName4, "r" )
  inFile5 = addfile( inFileName5, "r" )
  inFile6 = addfile( inFileName6, "r" )

; lon = 480 ;
; lat = 94 ;
; time = UNLIMITED ; // (92 currently)
; double eof_ts2(time, lat, lon)
; double time(time); units = "hours since 1979-1-1 00:00:00"
;                    calendar = "proleptic_gregorian"

; Get the time units and set the first and last times that we want
  timeUnits = inFile1->time@units
  startDate = cd_inv_calendar( 2017, 05, 9, 00, 0, 0, timeUnits, 0 )
  endDate   = cd_inv_calendar( 2017, 07, 1, 00, 0, 0, timeUnits, 0 )

  inData    = inFile1->eof_ts2({startDate:endDate},0,0)

  data      = new((/6,dimsizes(inData)/),"double")
  data(0,:) = inFile1->eof_ts2({startDate:endDate},0,0)
  data(1,:) = inFile2->eof_ts2({startDate:endDate},0,0)
  data(2,:) = inFile3->eof_ts2({startDate:endDate},0,0)
  data(3,:) = inFile4->eof_ts2({startDate:endDate},0,0)
  data(4,:) = inFile5->eof_ts2({startDate:endDate},0,0)
  data(5,:) = inFile6->eof_ts2({startDate:endDate},0,0)

  timeUnits = "days since 1800-01-01 00:00:00"
  data&time = ut_convert( data&time, timeUnits )

; Set workspace
; wks = gsn_open_wks("eps", "eof1_time_1979-2017_15" ) ; send graphics to PNG file
; wks = gsn_open_wks("eps", "eof2_time_1979-2017_15_20N" ) ; send graphics to PNG file
  wks = gsn_open_wks("eps", "eof2_time_1979-2017_15_20N_dstd" ) ; send graphics to PNG file
; wks = gsn_open_wks("eps", "eof2_time_1988-2017_15" ) ; send graphics to PNG file
; wks = gsn_open_wks("eps", "eof1_time_1988-2017_07" ) ; send graphics to PNG file

; Set resources for the line plot
  res                    = True              ; plot mods desired
  res@gsnDraw            = False             ; don't draw yet
  res@gsnFrame           = False             ; don't advance frame yet

  res@vpHeightF          = 0.40              ; change aspect ratio
  res@vpWidthF           = 0.70
  res@vpXF               = 0.15              ; change start locations
  res@vpYF               = 0.75              ; 

; res@trYMinF            = -3.0  ;-7.0
; res@trYMaxF            =  3.0  ; 7.0
  res@trYMinF            = -3.0  ;-5.0
  res@trYMaxF            =  3.0  ; 5.0

  res@gsnYRefLine        = 0.0               ; create a reference line
  res@gsnYRefLineDashPattern = 14           
  res@xyMonoLineColor    = False             ; want colored lines
  res@xyLineColors       = (/"Red","grey58"/) ; colors chosen
  res@xyLineThicknesses	 = (/6.,3./)         ; line thicknesses
  res@xyDashPatterns	 = (/0.,0./)         ; make all lines solid

; res@tiMainString       = "Arctic Oscillation (AO) index"  ; add title
; res@tiYAxisString	 = "AO index"        ; add an axis title    
  res@tiMainString       = "Arctic Dipole (AD) index"  ; add title
  res@tiYAxisString	 = "AD index"        ; add an axis title    
  res@txFontHeightF	 = 0.0195            ; change title font heights
  res@tmXBLabelAngleF    = -45               ; tilt the XB labels 45 degrees
  res@tmXBLabelDeltaF    = 1.25              ; push the XB labels down from plot

; Set special resources for the time axis
  resTick                = True
  resTick@ttmFormat      = "%d %c"
  resTick@ttmAxis        = "XB"
  resTick@ttmMajorStride = 7

; Set resources necessary to customize X axis labels
  time_axis_labels( data&time, res, resTick )
  
; Create main line plot
  top_plot = gsn_csm_xy (wks,data&time,data(0:1,:),res)       ; create line plot

; Create a plot with the area between both curves filled in blue.
  delete(res@xyLineColors)
  res@gsnXYFillColors = "grey85"
  res@xyLineColor     = -1                           ; We don't want the line, so make it transparent.
  mid_plot  = gsn_csm_xy (wks,data&time,data(2:3,:),res)  ; Create filled XY plot.

; Create a plot with the area between both curves filled in blue.
  delete(res@xyLineColors)
  res@gsnXYFillColors = "grey95"
  res@xyLineColor     = -1                           ; We don't want the line, so make it transparent.
  bot_plot  = gsn_csm_xy (wks,data&time,data(4:5,:),res)  ; Create filled XY plot.

; Overlay the top and mid plots on the bottom plot.
  overlay(mid_plot,top_plot)
  overlay(bot_plot,mid_plot)

; Create legend
lgres                    = True
lgres@lgLineColors       = (/"red","grey58","grey85","grey95"/)
lgres@lgLineThicknessF   = (/6,3,20,20/) 
lgres@lgLabelFontHeightF = .08            ; set the legend label font thickness
lgres@vpWidthF           = 0.15           ; width of legend (NDC)
lgres@vpHeightF          = 0.1            ; height of legend (NDC)
lgres@lgMonoDashIndex    = True   
lgres@lgPerimOn          = True          ; draw the box perimeter in orange
lgres@lgPerimFill        = "SolidFill"      ; Fill legend box w/white
lgres@lgPerimFillColor   = "white"          ; so it masks XY curves
labels = " " + (/"2017","Median","25-75 Percentile","5-95 Percentile"/)
lbid = gsn_create_legend(wks,4,labels,lgres)

; Add legend to bottom right corner of last plot
amres                  = True
amres@amJust           = "BottomRight"  ; Corner of plot for positioning
amres@amOrthogonalPosF =  -0.22   ;  0.5 is the bottom edge of the plot.
amres@amParallelPosF   =  0.1   ;  0.5 is the right edge of the plot.
annoid = gsn_add_annotation(bot_plot, lbid, amres)


; Make panel plot       
  maximize_output(wks,True)
end
