% PURPOSE
% Load and store every minute and 6-hourly atmospheric data from the 
% Alfred-Wegener-Institut (AWI) and the Institut polaire français 
% Paul-Émile-Victor (IPEV) merged research base (AWIPEV) and daily surface 
% data from the Norwegian Meteorological Institute (NMI) for Ny-Ålesund 
% (NAa) and 3-hourly atmospheric data from AWI for Polarstern (PS) over 
% chosen date and time interval in order to study the synoptic situation 
% during the Arctic CLoud Observations Using airborne measurements during 
% polar Day (ACLOUD) and Physical feedback of Arctic planetary boundary 
% layer, Sea ice, Cloud and AerosoL (PASCAL) field campaigns 
% May 23 - June 26 and June 6-16, 2017, respectively, on/near Spitsbergen.
%
% The data set choices are:
%   AWIPEV  : Alfred-Wegener-Institut/Paul-Émile-Victor
%   NMI     : Norwegian Meteorological Institute
%   AWI     : Alfred-Wegener-Institut
%
% The parameter choices are:
%   ps          : Surface pressure (p_{s}) - AWIPEV - Every minute
%   p16m        : 16-m pressure (p_{16m}) - AWI - 3-hourly
%   wnddir925hPa: 925-hPa wind direction (wnd_{dir,925hPa}) - AWIPEV - 
%                 6-hourly
%   wnddir850hPa: 850-hPa wind direction (wnd_{dir,850hPa}) - AWIPEV - 
%                 6-hourly
%   wndspd925hPa: 925-hPa wind speed (wnd_{spd,925hPa}) - AWIPEV - 6-hourly
%   wndspd850hPa: 850-hPa wind speed (wnd_{spd,850hPa}) - AWIPEV - 6-hourly
%   T2m         : 2-m temperature (T_{2m}) - AWIPEV - Every minute
%   T10m        : 10-m temperature (T_{10m}) - AWIPEV - Every minute
%   T29m        : 29-m temperature (T_{29m}) - AWI - 3-hourly
%   IWV         : Integrated water vapor - AWIPEV - 6-hourly
%   P           : Precipitation - NMI - Daily
%   snwdpt      : Snow depth (snw_{dpt}) - NMI - Daily
%   snwcvr      : Snow cover (snw_{cvr}) - NMI - Daily
%
% The region choices are:
%   Spb : Spitsbergen
%
% The station choices are:
%   99910   : Ny-Ålesund (1993-2017 for AWIPEV, 1975-2017 for NMI;
%                         78.92 deg N, 11.93 deg E; 8 masl.)
%   106.1   : Polarstern (2017; 82.00 deg N, 11.00 deg E; 25 masl.)
%
% NB! Time period start given as 1st year with whole calendar year data.
%
% CHOICES
%   mod_name        : Data set names and time period
%                     [Data set number : File name : MATLAB name : ...
%                      Abbreviated name : Full name : Time period]
%   param_name      : Parameter names and unit of field campaign data
%                     [Parameter number : General name : File name : ...
%                      Data name : MATLAB name : Full name : Unit : ...
%                      Start date : End date]
%   stat_name       : Station names
%                     [Abbreviated name : MATLAB name : Full name : ...
%                      Latitude : Longitude : Altitude : Code]
%   path_MATLAB     : MATLAB path
%   path_data       : Data path
%   yr_bnd          : Boundary of chosen year(s) of ACLOUD and PASCAL data
%   month_ACLOUD_bnd: Boundary of chosen month(s) of ACLOUD data
%   month_PASCAL_bnd: Boundary of chosen month(s) of PASCAL data
%   day_ACLOUD_bnd  : Boundary of chosen day(s) of ACLOUD data
%   day_PASCAL_bnd  : Boundary of chosen day(s) of PASCAL data
%   hr_bnd          : Boundary of chosen hour(s) of ACLOUD and PASCAL data
%   mod_indx        : Index(es) of chosen data set(s)
%   param_indx      : Index(es) of chosen parameter(s) of field campaign 
%                     data
%   stat_indx       : Index(es) of chosen station(s)
%   plot_no         : Number of open plots
%   plot_typename   : MATLAB name of figure type(s) to be plotted
%
% USES
%   IWV_calc.m
%   plot_ACLOUD_AWIPEV_NMI_AWI.m
%
% ABBREVIATIONS
%   STD : Standard deviation
%
% MATLAB REQUIREMENTS
%   Charles R. Denham's NetCDF Toolbox
%       (http://crusty.er.usgs.gov/~cdenham/MexCDF/)
%   CSIRO MATLAB/NetCDF Interface
%       (http://www.marine.csiro.au/sw/matlab-netcdf.html)
%
%
% AUTHOR
%   Erlend Moster Knudsen
%   PostDoc
%   Institute for Geophysics and Meteorology, University of Cologne
%   eknudsen@uni-koeln.de
%   October 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% Basic settings %%%%%
%%% Time properties %%%
% Time interval names
tint_name = ...
    [{''} {'Every minute'} {'3-hourly'} {'6-hourly'} {'Day'} ...
    {'Month'} {'Season'} {'Year'} {'Time section'}; ...
    {'n.'} {'min'} {'3hr'} {'6hr'} {'day'} ...
    {'month'} {'seas'} {'yr'} {'tsec'}; ...
    {'adj./adv.'} {'everymin'} {'3hourly'} {'6hourly'} {'daily'} ...
    {'monthly'} {'seasonal'} {'annual'} {'time_sectional'}];

% Month names and day numbers
month_name = {'Number' 'Name' 'Abbreviation' 'Initial'};
    % Header of month names table
month_name_full = ...
    {'January'; 'February'; 'March'; 'April'; 'May'; 'June'; ...
    'July'; 'August'; 'September'; 'October'; 'November'; 'December'};
    % Name of all months
for m = 1:size(month_name_full) % m = 1:12 - Loop over number of months
    % Temporary variable
    month_name_tmp = char(month_name_full(m));
    
    % Month names table
    month_name(m+1,:) = ...
        [num2cell(m) month_name_tmp cellstr(month_name_tmp(1:3)) cellstr(month_name_tmp(1))];
end
month_dayno = [31 29 31 30 31 30 31 31 30 31 30 31];
    % Number of days per month, February given as a leap-year
month_daysum = cumsum(month_dayno,2);
    % Number of cumulative days up to the end day per month
    % NB! February given as a leap-year
clear m month_name_* % Delete unnecessary variable(s)

%%% Data sets and variables %%%
% Data set names
mod_name = ...
    [{'      '} {'File name'} {'MATLAB name'} {'Abbreviation'} ...
    {'Full name'} {'Time period'}; ...
    {'Mod 1'} {'AWIPEV'} {'AWIPEV'} {'AWIPEV'} ...
    {'Alfred-Wegener-Institut/Paul-Émile-Victor'} {'1993-2017'}; ...
    {'Mod 2'} {'NMI'} {'NMI'} {'NMI'} ...
    {'Norwegian Meteorological Institute'} {'1975-2017'}; ...
    {'Mod 3'} {'AWI'} {'AWI'} {'AWI'} ...
    {'Alfred-Wegener-Institut'} {'2017'}];
    % [Data set number : File name : MATLAB name : Abbreviated name : ...
    %  Full name : Time period]
    
% Parameter names
param_name = ...
    [{'      '} {'General name'} {'File name'} {'Data name'} {'MATLAB name'} ...
    {'Full name'} {'Unit'} {'Start date'} {'End date'}; ...
    {'Param 1'} {'p'} {'p-T'} {'NYA_stationlevelpressure'} {'ps'} ...
    {'Surface pressure'} {'hPa'} {'20170501'} {'20170630'}; ...
    {'Param 2'} {'p'} {'SYNOP'} {'PPPP'} {'p16m'} ...
    {'16-m pressure'} {'hPa'} {'20170525'} {'20170620'}; ...
    {'Param 3'} {'wind'} {'wind'} {'WDir_925hPa'} {'wnddir925hPa'} ...
    {'925-hPa wind direction'} {'^{\circ}'} {'20170501'} {'20170630'}; ...
    {'Param 4'} {'wind'} {'wind'} {'WDir_850hPa'} {'wnddir850hPa'} ...
    {'850-hPa wind direction'} {'^{\circ}'} {'20170501'} {'20170630'}; ...
    {'Param 5'} {'wind'} {'wind'} {'WSpeed_925hPa'} {'wndspd925hPa'} ...
    {'925-hPa wind speed'} {'m s^{-1}'} {'20170501'} {'20170630'}; ...
    {'Param 6'} {'wind'} {'wind'} {'WSpeed_850hPa'} {'wndspd850hPa'} ...
    {'850-hPa wind speed'} {'m s^{-1}'} {'20170501'} {'20170630'}; ...
    {'Param 7'} {'T'} {'p-T'} {'NYA_temperature_2m'} {'T2m'} ...
    {'2-m temperature'} {'^{\circ}C'} {'20170501'} {'20170630'}; ...
    {'Param 8'} {'T'} {'p-T'} {'NYA_temperature_10m'} {'T10m'} ...
    {'10-m temperature'} {'^{\circ}C'} {'20170501'} {'20170630'}; ...
    {'Param 9'} {'T'} {'SYNOP'} {'TTT'} {'T29m'} ...
    {'29-m temperature'} {'^{\circ}C'} {'20170525'} {'20170620'}; ...
    {'Param 10'} {'humid'} {'humid'} {'IWV'} {'IWV'} ...
    {'Integrated water vapor'} {'kg m^{-2}'} {'20170501'} {'20170630'};
    {'Param 11'} {'P'} {'P'} {'RR'} {'P'} ...
    {'Precipitation'} {'mm day^{-1}'} {'20170501'} {'20170630'}; ...
    {'Param 12'} {'P'} {'P'} {'SA'} {'snwdpt'} ...
    {'Snow depth'} {'cm'} {'20170501'} {'20170630'}; ...
    {'Param 13'} {'P'} {'P'} {'SD'} {'snwcvr'} ...
    {'Snow cover'} {'1-3 = partly snow-covered, 4 = fully snow-covered'} ...
    {'20170501'} {'20170630'}];
    % [Parameter number : General name : File name : Data name : ...
    %  MATLAB name : Full name : Unit : Start date : End date]

%%% Regions and stations %%%
% Region names
reg_name = ...
    [{'     '} {'Abbreviated name'} {'Full name'}; ...
    {'Reg 1'} {'Spb'} {'Spitsbergen'}];
    % [Region number : Abbreviated name : Full name]

% Station names
stat_name = ...
    [{'      '} {'Abbreviated name'} {'Full name'} {'Time period'} ...
    {'Latitude'} {'Longitude'} {'Elevation'} {'Code'}; ...
    {'Stat 1'} {'NAa'} {['Ny-' char(197) 'lesund']} {'1993-2017'} ...
    {'78.92'} {'11.93'} {'8'} {'99910'}; ...
    {'Stat 2'} {'PS'} {'Polarstern'} {'2017'} ...
    {'81.83'} {'10.68'} {'25'} {'106.1'}];
    % [Station number : Abbreviated name : Full name : Time period : ...
    %  Latitude (deg N) : Longitude (deg E) : Altitude (masl.) : Code]
    % NB! Polarstern location is given as average over PASCAL (ice-locked) 
    %     dates

%%% Paths %%%
% MATLAB path
path_MATLAB = '/home/eknudsen/MATLAB/ACLOUD/';
    % '/Users/erlendmosterknudsen/Documents/MATLAB/ACLOUD/'
    %       = Mac hard drive path
    % '/home/eknudsen/MATLAB/ACLOUD/'
    %       = Linux hard drive path
    % '/media/backup/eknudsen/Dokumenter/Skole/Geofysikk/
    %   Data/Tools/MATLAB/ACLOUD/'
    %       = UzK hard drive path
    % '/Volumes/UIB-USB/Dokumenter/Skole/Geofysikk/
    %   Data/Tools/MATLAB/ACLOUD/'
    %       = External hard drive path
    
% Data path
path_data = '/media/backup/eknudsen/Dokumenter/Skole/Geofysikk/Data/';
    % '/Users/erlendmosterknudsen/Dokumenter/Skole/Geofysikk/Data/'
    %       = Mac hard drive path
    % '/media/backup/eknudsen/Dokumenter/Skole/Geofysikk/Data/'
    %       = UzK hard drive path
    % '/Volumes/UIB-USB/Dokumenter/Skole/Geofysikk/Data/'
    %       = External hard drive path
    
% Figure path
path_fig = [path_data 'Tools/MATLAB/Figures/AWIPEV-NMI-AWI-ERA_INT/'];

%%%%% Chosen settings %%%%%
% Chosen year(s) boundary, vector, number and name of field campaign data
yr_bnd = [2017 2017]; % Boundary, [Start : End]
    % NB! Equal for ACLOUD and PASCAL campaigns
yr_vec = [yr_bnd(1):yr_bnd(2)]'; % Vector, [Yr]
yr_no = length(yr_vec); % Number
if yr_no == 1 % Only 1 year
    % Name
    yr_name = num2str(yr_bnd(1));
else % Several years
    % Name
    yr_name = [num2str(yr_bnd(1)) '-' num2str(yr_bnd(2))];
end

% Chosen month(s) boundary, vector, number and name of field campaign data
month_ACLOUD_bnd = [5 6]; % Boundary - ACLOUD, [Start : End]
month_PASCAL_bnd = [5 6]; % Boundary - PASCAL, [Start : End]
month_ACLOUD_vec = month_ACLOUD_bnd(1):month_ACLOUD_bnd(2);
    % Vector - ACLOUD, [Month_ACLOUD]
month_PASCAL_vec = month_PASCAL_bnd(1):month_PASCAL_bnd(2);
    % Vector - PASCAL, [Month_PASCAL]
month_ACLOUD_no = length(month_ACLOUD_vec); % Number - ACLOUD
month_PASCAL_no = length(month_PASCAL_vec); % Number - PASCAL
month_ACLOUD_abbr = permute(char(month_name(month_ACLOUD_vec+1,4)),[2 1]);
    % Name - ACLOUD
month_PASCAL_abbr = permute(char(month_name(month_PASCAL_vec+1,4)),[2 1]);
    % Name - PASCAL

% Chosen day(s) boundary, vector and number of field campaign data
day_ACLOUD_bnd = [143 177]; % Boundary - ACLOUD, [Start : End]
    % NB! Must account for leap-year possibility
day_PASCAL_bnd = [148 169]; % Boundary - PASCAL, [Start : End]
    % NB! Must account for leap-year possibility
day_ACLOUD_vec = [day_ACLOUD_bnd(1):day_ACLOUD_bnd(2)]'; % Vector - ACLOUD
    % [Day_ACLOUD]
day_PASCAL_vec = [day_PASCAL_bnd(1):day_PASCAL_bnd(2)]'; % Vector - PASCAL
    % [Day_PASCAL]
day_ACLOUD_no = length(day_ACLOUD_vec); % Number - ACLOUD
day_PASCAL_no = length(day_PASCAL_vec); % Number - PASCAL

% Chosen 6-hour(s) boundary, vectors and number of field campaign data
hr_bnd = [0 18]; % Boundary, [Start : End]
    % NB! Equal for ACLOUD and PASCAL campaigns
hr_vec = [hr_bnd(1):24/4:hr_bnd(2)]'; % Vector, [Hr]
hr_no = length(hr_vec); % Number

% Chosen time period boundary names of field campaign data
tper_ACLOUD_txt = ...
    [datestr([yr_bnd(1),month_ACLOUD_bnd(1),...
    day_ACLOUD_bnd(1)-month_daysum(month_ACLOUD_bnd(1)-1)+1,0,0,0]) ...
    ' - ' ...
    datestr([yr_bnd(2),month_ACLOUD_bnd(2),...
    day_ACLOUD_bnd(2)-month_daysum(month_ACLOUD_bnd(2)-1)+1,0,0,0])];
    % Text - ACLOUD
tper_PASCAL_txt = ...
    [datestr([yr_bnd(1),month_PASCAL_bnd(1),...
    day_PASCAL_bnd(1)-month_daysum(month_PASCAL_bnd(1)-1)+1,0,0,0]) ...
    ' - ' ...
    datestr([yr_bnd(2),month_PASCAL_bnd(2),...
    day_PASCAL_bnd(2)-month_daysum(month_PASCAL_bnd(2)-1)+1,0,0,0])];
    % Text - PASCAL
tper_ACLOUD_num = ....
    [datestr([yr_bnd(1),month_ACLOUD_bnd(1),...
    day_ACLOUD_bnd(1)-month_daysum(month_ACLOUD_bnd(1)-1)+1,0,0,0],'yyyymmdd') ...
    '-' ...
    datestr([yr_bnd(2),month_ACLOUD_bnd(2),...
    day_ACLOUD_bnd(2)-month_daysum(month_ACLOUD_bnd(2)-1)+1,0,0,0],'yyyymmdd')];
    % Numerical - ACLOUD
tper_PASCAL_num = ....
    [datestr([yr_bnd(1),month_PASCAL_bnd(1),...
    day_PASCAL_bnd(1)-month_daysum(month_PASCAL_bnd(1)-1)+1,0,0,0],'yyyymmdd') ...
    '-' ...
    datestr([yr_bnd(2),month_PASCAL_bnd(2),...
    day_PASCAL_bnd(2)-month_daysum(month_PASCAL_bnd(2)-1)+1,0,0,0],'yyyymmdd')];
    % Numerical - PASCAL

% Display chosen time properties of field campaign data
disp(['load_ACLOUD_AWIPEV_NMI_AWI: ACLOUD time period = ' tper_ACLOUD_txt])
disp(['load_ACLOUD_AWIPEV_NMI_AWI: PASCAL time period = ' tper_PASCAL_txt])

%%% Region(s) %%%
% Index, abbreviated, MATLAB and full name of chosen station(s)
reg_indx = 1; % Index
    % 1 : Spitsbergen
reg_abbr = char(reg_name(reg_indx+1,2)); % Abbreviated name(s)
reg_full = char(reg_name(reg_indx+1,3)); % Full name(s)

%%% Station(s) %%%
% Index and number of chosen station(s)
stat_indx = [1 2]; % Index
    % 1 : Ny-Ålesund (1993-2017 for AWIPEV, 1975-2017 for NMI;
    %                 78.92 deg N, 11.93 deg E, 8 masl.)
    % 2 : Polarstern (2017; 82.00 deg N, 11.00 deg E; 25 masl.)
    % NB! Must reflect choice of parameter(s) in 'param_indx'
stat_no = length(stat_indx); % Number
    
% Names of chosen station(s)
stat_abbr = char(stat_name(stat_indx+1,2)); % Abbreviated, [Stat]
stat_full = char(stat_name(stat_indx+1,3)); % Full, [Stat]

% Time period of chosen station(s)
stat_tper = char(stat_name(stat_indx+1,4)); % [Stat]

% Latitude, longitude, altitude and code of chosen station(s)
for st = 1:stat_no % Loop over number of chosen stations
    % Latitude
    stat_lat(st) = str2double(char(stat_name(stat_indx(st)+1,5)));
        % [deg N], [Stat]
    
    % Longitude
    stat_lon(st) = str2double(char(stat_name(stat_indx(st)+1,6)));
        % [deg E], [Stat]
        
    % Altitude
    stat_alt(st) = str2double(char(stat_name(stat_indx(st)+1,7)));
        % [masl], [Stat]
    
    % Code
    stat_code(st) = str2double(char(stat_name(stat_indx(st)+1,8)));
        % [Stat]
    
    % Display properties of chosen station
    disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
        'Chosen station = ' stat_full(st,:) ' (' ...
        num2str(stat_lat(st)) char(176) 'N, ' ...
        num2str(stat_lon(st)) char(176) 'E)'])
end
clear st % Delete unnecessary variable(s)

%%% Data sets and parameters %%%
% Index(es) and number of chosen parameter(s) in field campaign data
param_indx = [1 2 4 6]; % Index(es)
    %  1 = p_{s}
    %  2 = p_{16m}
    %  3 = wnd_{dir,925hPa}
    %  4 = wnd_{dir,850hPa}
    %  5 = wnd_{spd,925hPa}
    %  6 = wnd_{spd,850hPa}
    %  7 = T_{2m}
    %  8 = T_{10m}
    %  9 = T_{29m}
    % 10 = IWV
    % 11 = P
    % 12 = snw_{dpt}
    % 13 = snw_{cvr}
param_no = length(param_indx); % Number

% Index(es) and number of corresponding data set(s)
if sum(ismember([1 3:8],param_indx)) > 0 % AWIPEV data
    % Index
    %   1 = AWIPEV
    mod_indx = 1;
    
    % Loop over data set parameters and display chosen parameter and 
    % corresponding data set
    for i = [1 3:8] % Loop over index(es) of AWIPEV parameters
        % Current data set index logical
        param_log = ismember(i,param_indx);
        
        % Display chosen parameter and corresponding data set
        if param_log == 1
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Chosen parameter = ' lower(char(param_name(i+1,6))) ', ' ...
                'chosen data set = ' char(mod_name(1+1,3))])
        end
    end
end
if sum(ismember(11:13,param_indx)) > 0 % NMI data
    % Index
    %   2 = NMI
    if exist('mod_indx','var') % Variable existent
        % Unsorted
        mod_indx = [mod_indx 2];
        
        % Sorted
        mod_indx = sort(mod_indx);
    else % Variable non-existent
        mod_indx = 2;
    end
    
    % Loop over data set parameters and display chosen parameter and 
    % corresponding data set
    for i = 11:13 % Loop over index(es) of NMI parameters
        % Current data set index logical
        param_log = ismember(i,param_indx);
        
        % Display chosen parameter and corresponding data set
        if param_log == 1
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Chosen parameter = ' lower(char(param_name(i+1,6))) ', ' ...
                'chosen data set = ' char(mod_name(2+1,3))])
        end
    end
end
if sum(ismember([2 9],param_indx)) > 0 % AWI data
    % Index
    %   3 = AWI
    mod_indx = 3;
    
    % Loop over data set parameters and display chosen parameter and 
    % corresponding data set
    for i = [2 9 10] % Loop over index(es) of AWI parameters
        % Current data set index logical
        param_log = ismember(i,param_indx);
        
        % Display chosen parameter and corresponding data set
        if param_log == 1
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Chosen parameter = ' lower(char(param_name(i+1,6))) ', ' ...
                'chosen data set = ' char(mod_name(3+1,3))])
        end
    end
end
if sum(ismember(10,param_indx)) > 0 % IWV data
    if sum(ismember(1,stat_indx)) == length(stat_indx)
            % Ny-Ålesund data only
        % Index
        %   1 = AWIPEV
        if exist('mod_indx','var') % Variable existent
            % Unsorted - All indexes
            mod_indx = [mod_indx 1];
            
            % Unsorted - Unique indexes
            mod_indx = unique(mod_indx);
            
            % Sorted
            mod_indx = sort(mod_indx);
        else % Variable non-existent
            mod_indx = 1;
        end
    elseif sum(ismember(2,stat_indx)) == length(stat_indx)
            % Polarstern data only
        % Index
        %   3 = AWI
        if exist('mod_indx','var') % Variable existent
            % Unsorted - All indexes
            mod_indx = [mod_indx 3];
            
            % Unsorted - Unique indexes
            mod_indx = unique(mod_indx);
            
            % Sorted
            mod_indx = sort(mod_indx);
        else % Variable non-existent
            mod_indx = 3;
        end
    elseif sum(ismember([1 2],stat_indx)) == length(stat_indx)
            % Both Ny-Ålesund and Polarstern data
        % Index
        %   1 = AWIPEV
        %   3 = AWI
        if exist('mod_indx','var') % Variable existent
            % Unsorted - All indexes
            mod_indx = [mod_indx 1 3];
            
            % Unsorted - Unique indexes
            mod_indx = unique(mod_indx);
            
            % Sorted
            mod_indx = sort(mod_indx);
        else % Variable non-existent
            mod_indx = [1 3];
        end
    end
    
    % Loop over stations and display chosen parameter and corresponding 
    % data set
    for i = mod_indx % Loop over index(es) of data set(s)
        % Current data set index logical
        mod_log = ismember(i,mod_indx);
        
        % Display chosen parameter and corresponding data set
        if mod_log == 1
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Chosen parameter = ' lower(char(param_name(10+1,6))) ', ' ...
                'chosen data set = ' char(mod_name(i+1,3))])
        end
    end
end
mod_no = length(mod_indx); % Number
clear i param_log mod_log % Delete unnecessary variable(s)

%%%%% Store basic data %%%%%
%%% Store basic variables %%%
% Data set MATLAB names
mod_MATLAB = char(mod_name(1+1,3)); % 1st data set
for s = 2:size(mod_name,1) - 1 % Loop over number of data sets
    % Other data sets
    mod_MATLAB = [mod_MATLAB '-' char(mod_name(s+1,3))];
end
clear s % Delete unnecessary variable(s)

% Parameter path and file names
param_path = char(param_name(1+1,2)); % 1st parameter, path
param_file = param_path; % 1st parameter, file
for p = 2:size(param_name,1) - 1 % Loop over number of parameters
    % Other parameters
    if isempty(strfind(param_path,char(param_name(p+1,2))))
            % General name non-existent
        % Path
        param_path = [param_path '_' char(param_name(p+1,2))];
        
        % File
        param_file = [param_file '-' char(param_name(p+1,2))];
    end
end
clear p % Delete unnecessary variable(s)

% Path and file name for variable storage
path_store = [path_MATLAB param_path '_data/']; % Path
file_store = [param_file '_' mod_MATLAB '_' yr_name '.mat']; % File

% Store basic variables
save([path_store file_store],...
    'tint_name','yr_*','month_*','day_*','hr_*',...
    'path_*','mod_*','param_*','reg_name','stat_name','stat_indx')

%%% Delete data %%%
% Delete unnecessary variable(s)
clear file_store
%%
%%%%%%%% Load data %%%%%%%%
%%%%% p data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
p_name_all = param_name(1+1:2+1,5); % Name(s)
p_indx_all = ...
    [find(strcmp(param_name(2:end,5),p_name_all(1))); ...
    find(strcmp(param_name(2:end,5),p_name_all(2)))];
    % Index(es)

% Load p data only if chosen
if sum(ismember(p_indx_all,param_indx)) > 0 % p data chosen
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    p_name_chos = p_name_all(ismember(p_indx_all,param_indx)); % Name(s)
    p_indx_chos = p_indx_all(ismember(p_indx_all,param_indx)); % Index(es)
    p_no_chos = length(p_indx_chos); % Number
    
    % Loop over chosen p variables and load p data
    for p = 1:p_no_chos % Loop over number of chosen p parameters
        %%% Parameter and data set names %%%
        % Extract current chosen parameter names
        crp_name_gen = char(param_name(p_indx_chos(p)+1,2));
            % General
        crp_name_file = char(param_name(p_indx_chos(p)+1,3));
            % File
        crp_name_data = char(param_name(p_indx_chos(p)+1,4));
            % Data
        crp_name_MATLAB = char(param_name(p_indx_chos(p)+1,5));
            % MATLAB
        crp_name_full = char(param_name(p_indx_chos(p)+1,6));
            % Full
            
        % Extract current chosen parameter unit
        crp_unit = char(param_name(p_indx_chos(p)+1,7));
        
        % Extract current chosen parameter data set names
        if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
            crp_set_file = char(mod_name(1+1,2)); % File
            crp_set_MATLAB = char(mod_name(1+1,3)); % MATLAB
            crp_set_tper = char(mod_name(1+1,6)); % Time period
        elseif strcmp(crp_name_MATLAB,'p16m') % 16-m pressure data
            crp_set_file = char(mod_name(3+1,2)); % File
            crp_set_MATLAB = char(mod_name(3+1,3)); % MATLAB
            crp_set_tper = char(mod_name(3+1,6)); % Time period
        end
        
        %%% Time period names and dates %%%
        % Set campaign time step names
        crp_tstep_cpgn_abbr = char(tint_name(1+1,1+1)); % Abbreviated
        crp_tstep_cpgn_full = char(tint_name(2+1,1+1)); % Full
        
        % Set climatology time step names
        if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
            crp_tstep_clim_abbr = char(tint_name(1+1,4+1)); % Abbreviated
            crp_tstep_clim_full = char(tint_name(2+1,4+1)); % Full
        end
        
        % Extract current chosen parameter campaign boundary dates
        crp_date_yrmonthday_srt = ...
            char(param_name(p_indx_chos(p)+1,8));
            % Start
        crp_date_yrmonthday_end = ...
            char(param_name(p_indx_chos(p)+1,9));
            % End
        
        % Extract current chosen parameter climatology boundary years
        if strcmp(crp_set_MATLAB,'AWIPEV') % AWIPEV data
            % Start
            crp_date_yr_srt = ...
                num2str(str2double(crp_set_tper(1:strfind(crp_set_tper,'-')-1)) + 1);
                % NB! Exclude 1st year (measurements from August only)
                
            % End
            crp_date_yr_end = ...
                num2str(str2double(crp_set_tper(strfind(crp_set_tper,'-')+1:end)) - 1);
                % NB! Exclude campaign year
        elseif strcmp(crp_set_MATLAB,'AWI') % AWI data
            % Start
            crp_date_yr_srt = crp_set_tper;
                
            % End
            crp_date_yr_end = crp_set_tper;
        end
        
        % Set current chosen parameter storage path and file names
        crp_store_path = path_store; % Path
        if strcmp(crp_set_MATLAB,'AWIPEV') % AWIPEV data
            % File
            crp_store_file = ...
                [crp_name_MATLAB '_NAa_' ...
                month_ACLOUD_abbr '_' yr_name '_' crp_set_MATLAB '.mat'];
        elseif strcmp(crp_set_MATLAB,'AWI') % AWI data
            % File
            crp_store_file = ...
                [crp_name_MATLAB '_PS_' ...
                month_PASCAL_abbr '_' yr_name '_' crp_set_MATLAB '.mat'];
        end
            
        % Display current chosen parameter loading conditions
        disp(['load_ACLOUD_AWIPEV_NMI_AWI: Loading ' crp_name_MATLAB ...
            ' data from the ' crp_set_MATLAB ' data set'])
        
        %%% Variables in storage file %%%
        % Set current chosen parameter time variables names
        crp_store_t_name = ...
            [{[crp_name_MATLAB '_date_minhrdaymonth_' crp_set_MATLAB]}; ...
            {[crp_name_MATLAB '_date_daymonth_' crp_set_MATLAB]}];
            % [Every minute date matrix; ...
            %  Daily date matrix]
        
        % Set current chosen parameter campaign variable names
        crp_store_cpgn_name = ...
            [{[crp_name_MATLAB '_cpgn_minhrdaymonth_' crp_set_MATLAB]}; ...
            {[crp_name_MATLAB '_cpgn_daymonth_minhr_' crp_set_MATLAB]}; ...
            {[crp_name_MATLAB '_cpgn_daymonth_' crp_set_MATLAB]}];
            % [Every minute over time period; ...
            %  Every minute per day over time period; ...
            %  Daily averaged daily over time period]
            
        % Set current chosen parameter climatology variable names
        if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
            crp_store_clim_name = ...
                [{[crp_name_MATLAB '_clim_mean_daymonth_' crp_set_MATLAB]}; ...
                {[crp_name_MATLAB '_clim_STD_daymonth_' crp_set_MATLAB]}];
                % [Daily averaged annually over time period; ...
                %  Daily standard-deviated annually over time period]
        end
        
        %%% Variables to load from storage files %%%
        % Check existence of current chosen parameter variable in storage 
        % file
        if exist([crp_store_path crp_store_file],'file')
                % File existent
            % Find current chosen parameter file variable names
            crp_store_var_file = ...
                whos('-file',[crp_store_path crp_store_file]);
            
            % Check existence of current chosen parameter variables in 
            % storage file
            crp_store_cpgn_exist = ...
                ismember(crp_store_cpgn_name,{crp_store_var_file.name});
                % Campaign variables
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                % Climatology variables
                crp_store_clim_exist = ...
                    ismember(crp_store_clim_name,{crp_store_var_file.name});
            else % Other pressure data
                % Climatology variables
                % NB! Set to one even though no climatology variables exist
                crp_store_clim_exist = 1;
            end
        else % File non-existent
            % Set current chosen parameter logical variable to zero
            crp_store_cpgn_exist = 0; % Campaign variables
            crp_store_clim_exist = 0; % Climatology variables
        end
        
        % Load current chosen parameter data only if variables are 
        % non-existent
        if sum(crp_store_cpgn_exist) == length(crp_store_cpgn_exist) && ...
                sum(crp_store_clim_exist) == length(crp_store_clim_exist)
                % Variables existent
            disp('load_ACLOUD_AWIPEV_NMI_AWI: Existent variables:')
            disp(crp_store_t_name)
            disp(crp_store_cpgn_name)
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                disp(crp_store_clim_name)
            end
            
            %%% Load data %%%
            % Load current chosen parameter data from .mat file
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                load([crp_store_path crp_store_file],...
                    crp_store_t_name{:},crp_store_cpgn_name{:},...
                    crp_store_clim_name{:})
            else % Other pressure data
                load([crp_store_path crp_store_file],...
                    crp_store_t_name{:},crp_store_cpgn_name{:})
            end
            
            %%% Rename data %%%
            % Rename current chosen parameter time variables
            crp_date_minhrdaymonth = eval(char(crp_store_t_name(1)));
                % Every minute date matrix
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec] /
                %   [Min*Hr*Day_PASCAL*Month_PASCAL;
                %    Yr : Month : Day : Hr : Min : Sec]
            crp_date_daymonth = eval(char(crp_store_t_name(2)));
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] / 
                %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
            
            % Rename current chosen parameter campaign variables
            crp_cpgn_minhrdaymonth = eval(char(crp_store_cpgn_name(1)));
                % [hPa]
                % Every minute over time period
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL]
            crp_cpgn_daymonth_minhr = eval(char(crp_store_cpgn_name(2)));
                % [hPa]
                % Every minute per day over time period
                % [Day_ACLOUD*Month_ACLOUD; Min*Hr]/ 
                %   [Day_PASCAL*Month_PASCAL; Min*Hr]
            crp_cpgn_daymonth = eval(char(crp_store_cpgn_name(3)));
                % [hPa]
                % Daily averaged daily over time period
                % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
                
            % Rename current chosen parameter climatology variables
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                % Daily averaged annually over time period
                crp_clim_mean_daymonth = ...
                    eval(char(crp_store_clim_name(1)));
                    % [hPa], [Day_ACLOUD*Month_ACLOUD]
                    
                % Daily standard-deviated annually over time period
                crp_clim_STD_daymonth = eval(char(crp_store_clim_name(2)));
                    % [hPa], [Day_ACLOUD*Month_ACLOUD]
            end
        else % File non-existent
            disp('load_ACLOUD_AWIPEV_NMI_AWI: Loading variables:')
            disp(crp_store_t_name)
            disp(crp_store_cpgn_name)
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                disp(crp_store_clim_name)
            end
            
            %%% Load campaign data %%%
            % Set current chosen campaign parameter loading path, file and 
            % data names
            crp_load_cpgn_path = ...
                [path_data 'Observations/' upper(crp_tstep_cpgn_full) '/'];
                % Path
            if strcmp(crp_set_MATLAB,'AWIPEV') % AWIPEV data
                % File
                crp_load_cpgn_file = ...
                    [crp_set_file '_' crp_name_file '_NAa_' ...
                    crp_tstep_cpgn_full '_' crp_date_yrmonthday_srt '-' ...
                    crp_date_yrmonthday_end '.mat'];
            elseif strcmp(crp_set_MATLAB,'AWI') % AWI data
                % File
                crp_load_cpgn_file = ...
                    [crp_set_file '_' crp_name_file '_PS_' ...
                    crp_tstep_cpgn_full '_' crp_date_yrmonthday_srt '-' ...
                    crp_date_yrmonthday_end '.txt'];
            end
            crp_load_cpgn_data = crp_name_data;
                % Data
            
            % Load current chosen campaign parameter time and variable data
            if strcmp(crp_set_MATLAB,'AWIPEV') % AWIPEV data
                % Load current chosen campaign parameter time data
                crp_date_minhrdaymonth = ...
                    load([crp_load_cpgn_path crp_load_cpgn_file],...
                    'NYA_timestamp');
                    % Structure format
                    % [1].mat
                crp_date_minhrdaymonth = ...
                    crp_date_minhrdaymonth.NYA_timestamp;
                    % Vector format
                    % [Min_All*Hr_All*Day_All*Month_All]
                crp_date_minhrdaymonth = datevec(crp_date_minhrdaymonth);
                    % Matrix format
                    % [Min_All*Hr_All*Day_All*Month_All; ...
                    %  Yr : Month : Day : Hr : Min : Sec]
                
                % Load current chosen campaign parameter variable data
                crp_cpgn_var = ...
                    load([crp_load_cpgn_path crp_load_cpgn_file],...
                    crp_load_cpgn_data);
                    % [hPa], structure format
                    % [1].mat
                crp_cpgn_minhrdaymonth = ...
                    eval(['crp_cpgn_var.' crp_name_data ';']);
                    % [hPa], vector format
                    % [Min_All*Hr_All*Day_All*Month_All]
                    
                % Replace current chosen campaign parameter negative 
                % (missing) values by NaN
                crp_cpgn_minhrdaymonth(crp_cpgn_minhrdaymonth < 0) = NaN;
                    % [hPa], [Min_All*Hr_All*Day_All*Month_All]
            elseif strcmp(crp_set_MATLAB,'AWI') % AWI data
                % Set current chosen parameter loading format
                crp_load_cpgn_frmt = ...
                    '%s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f';
                
                % Open, store content of and close current chosen campaign 
                % parameter file
                crp_load_cpgn_open = ...
                    fopen([crp_load_cpgn_path crp_load_cpgn_file],'r');
                    % Open file
                crp_load_cpgn_hdln = ...
                    textscan(crp_load_cpgn_open,'%s',3+13*2);
                    % Store file headlines in cell matrix
                    % NB! Account for headline format, which contains units
                    %     in square brackets for all 16 variable parameters
                crp_load_cpgn_cont = ...
                    textscan(crp_load_cpgn_open,crp_load_cpgn_frmt,...
                    'delimiter','\t','headerlines',1);
                    % Store file content in cell matrix
                crp_load_cpgn_clse = fclose(crp_load_cpgn_open);
                    % Close file
                
                % Extract current chosen campaign parameter headerlines
                crp_load_cpgn_hdln = crp_load_cpgn_hdln{1,1};
                    % Vector format, including units
                crp_load_cpgn_hdln = ...
                    [crp_load_cpgn_hdln(1:3); crp_load_cpgn_hdln(4:2:end)];
                    % Vector format, excluding units
                
                % Find current chosen campaign parameter time data indexes 
                % in file
                crp_load_cpgn_indx = ...
                    find(strcmp(crp_load_cpgn_hdln,crp_load_cpgn_data));
                
                % Extract current chosen campaign parameter time data
                crp_date_minhrdaymonth_cell = crp_load_cpgn_cont{1,1};
                    % Every minute date vector on cell format
                    % [Min_All*Hr_All*Day_All*Month_All]
                for mn = 1:length(crp_date_minhrdaymonth_cell)
                        % Loop over number of minutes
                    % Every minute date matrix on integer format
                    crp_date_minhrdaymonth_mat(mn,:) = ...
                        datevec(datenum(...
                        [crp_date_minhrdaymonth_cell{mn,1}(1:10) ' ' ...
                        crp_date_minhrdaymonth_cell{mn,1}(12:16)]));
                        % [Min_All*Hr_All*Day_All*Month_All; ...
                        %  Yr : Month : Day : Hr : Min : Sec]
                end
                
                % Extract current chosen campaign parameter campaign data
                crp_cpgn_minhrdaymonth = ...
                    crp_load_cpgn_cont{1,crp_load_cpgn_indx};
                    % [hPa]
                	% [Min_All*Hr_All*Day_All*Month_All]
                
                % Replace current chosen campaign parameter missing and 
                % negative values by NaN
                crp_cpgn_minhrdaymonth(crp_cpgn_minhrdaymonth == -9999) = NaN;
                    % [hPa], missing values
                    % [Min_All*Hr_All*Day_All*Month_All]
                crp_cpgn_minhrdaymonth(crp_cpgn_minhrdaymonth < 0) = NaN;
                    % [hPa], negative values
                    % [Min_All*Hr_All*Day_All*Month_All]
                    
                % Rename current chosen campaign parameter time data
                crp_date_minhrdaymonth = crp_date_minhrdaymonth_mat;
                    % Every minute date matrix
                    % [Min_All*Hr_All*Day_All*Month_All; ...
                    %  Yr : Month : Day : Hr : Min : Sec]
                    
                % Delete unnecessary variable(s)
                clear crp_load_cpgn_* crp_date_minhrdaymonth_*
            end
            
            %%% Load climatology data %%%
            % Set current chosen climatology parameter loading path, file 
            % and data names
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                % Path
                crp_load_clim_path = ...
                    [path_data 'Observations/' ...
                    upper(crp_tstep_clim_full) '/'];
                
                % File
                crp_load_clim_file = ...
                    [crp_set_file '_' crp_name_gen '_NAa_' ...
                    crp_tstep_clim_full '_JFMAMJJASOND_' ...
                    crp_date_yr_srt '-' crp_date_yr_end '.mat'];
                
                % Data
                crp_load_clim_data = ...
                    [{'longterm_daymean_p'}; {'longterm_stddev_p'}];
            end
            
            % Load current chosen climatology parameter mean and STD data
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                % Structure format
                crp_clim_mean_STD = ...
                    load([crp_load_clim_path crp_load_clim_file],...
                    char(crp_load_clim_data(1)),...
                    char(crp_load_clim_data(2)));
                    % [hPa], [1].mat
                    
                % Vector format
                crp_clim_mean_daymonth = ...
                    eval(['crp_clim_mean_STD.' char(crp_load_clim_data(1)) ';']);
                    % [hPa], mean, [Day_All*Month_All]
                crp_clim_STD_daymonth = ...
                    eval(['crp_clim_mean_STD.' char(crp_load_clim_data(2)) ';']);
                    % [hPa], STD, [Day_All*Month_All]
            end
                
            % Rearrange current chosen climatology parameter mean and STD 
            % data from horizontal to vertical vectors
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                % Mean
                crp_clim_mean_daymonth = crp_clim_mean_daymonth';
                    % [hPa], [Day_All*Month_All]
                    
                % STD
                crp_clim_STD_daymonth = crp_clim_STD_daymonth';
                    % [hPa], [Day_All*Month_All]
            end
            
            % Replace current chosen climatology parameter negative 
            % (missing) values by NaN
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                % Mean
                crp_clim_mean_daymonth(crp_clim_mean_daymonth < 0) = NaN;
                    % [hPa], [Day_All*Month_All]
                    
                % STD
                crp_clim_STD_daymonth(crp_clim_STD_daymonth < 0) = NaN;
                    % [hPa], [Day_All*Month_All]
            end
            
            % Delete unnecessary variable(s)
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                clear crp_cpgn_var crp_clim_mean_STD
            end
            
            %%% Find boundary data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Extracting ' crp_set_MATLAB ' ' crp_name_MATLAB ...
                ' data over chosen time period'])
            
            % Find current chosen campaign parameter chosen time period 
            % boundary indexes in campaign data
            if strcmp(crp_set_MATLAB,'AWIPEV') % AWIPEV data
                % Start
                crp_date_minhrdaymonth_srt = ...
                    find(datenum(crp_date_minhrdaymonth(:,1:3)) == ...
                    datenum(tper_ACLOUD_num(1:8),'yyyymmdd'),1,'first');
                
                % End
                crp_date_minhrdaymonth_end = ...
                    find(datenum(crp_date_minhrdaymonth(:,1:3)) == ...
                    datenum(tper_ACLOUD_num(10:end),'yyyymmdd'),1,'last');
            elseif strcmp(crp_set_MATLAB,'AWI') % AWI data
                % Start
                crp_date_minhrdaymonth_srt = ...
                    find(datenum(crp_date_minhrdaymonth(:,1:3)) == ...
                    datenum(tper_PASCAL_num(1:8),'yyyymmdd'),1,'first');
                
                % End
                crp_date_minhrdaymonth_end = ...
                    find(datenum(crp_date_minhrdaymonth(:,1:3)) == ...
                    datenum(tper_PASCAL_num(10:end),'yyyymmdd'),1,'last');
            end
            
            % Merge current chosen campaign parameter chosen time period 
            % boundary indexes
            crp_date_minhrdaymonth_bnd = ...
                [crp_date_minhrdaymonth_srt crp_date_minhrdaymonth_end];
                % [Start : End]
                
            % Rename current chosen climatology parameter chosen time 
            % period boundary indexes
            if strcmp(crp_set_MATLAB,'AWIPEV') % AWIPEV data
                crp_date_daymonth_bnd = day_ACLOUD_bnd; % [Start : End]
            elseif strcmp(crp_set_MATLAB,'AWI') % AWI data
                crp_date_daymonth_bnd = day_PASCAL_bnd; % [Start : End]
            end
                
            % Delete unnecessary variable(s)
            clear crp_date_minhrdaymonth_srt crp_date_minhrdaymonth_end
            
            %%% Extract data %%%
            % Extract current chosen parameter every minute time data over 
            % chosen time period
            crp_date_minhrdaymonth = ...
                crp_date_minhrdaymonth(...
                crp_date_minhrdaymonth_bnd(1):crp_date_minhrdaymonth_bnd(2),:);
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL;
                %    Yr : Month : Day : Hr : Min : Sec]
            
            % Extract current chosen parameter daily time data over chosen 
            % time period
            crp_date_daymonth = crp_date_minhrdaymonth(1:60*24:end,1:3);
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] / 
                %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
            
            % Extract current chosen parameter campaign data over chosen 
            % time period
            crp_cpgn_minhrdaymonth = ...
                crp_cpgn_minhrdaymonth(...
                crp_date_minhrdaymonth_bnd(1):crp_date_minhrdaymonth_bnd(2));
                % [hPa]
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL]
            
            % Extract current chosen parameter climatology mean and STD 
            % data over chosen time period
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                % Mean
                crp_clim_mean_daymonth = ...
                    crp_clim_mean_daymonth(...
                    crp_date_daymonth_bnd(1):crp_date_daymonth_bnd(2));
                    % [hPa], [Day_ACLOUD*Month_ACLOUD]
                    
                % STD
                crp_clim_STD_daymonth = ...
                    crp_clim_STD_daymonth(...
                    crp_date_daymonth_bnd(1):crp_date_daymonth_bnd(2));
                    % [hPa], [Day_ACLOUD*Month_ACLOUD]
            end
            
            %%% Rearrange data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Rearranging ' crp_set_MATLAB ' ' crp_name_MATLAB ...
                ' data over chosen time period'])
            
            % Rearrange current chosen parameter campaign data from 1D to 
            % 2D
            if strcmp(crp_set_MATLAB,'AWIPEV') % AWIPEV data
                crp_cpgn_minhr_daymonth = ...
                    reshape(crp_cpgn_minhrdaymonth,60*24,day_ACLOUD_no);
                    % [hPa], [Min*Hr; Day_ACLOUD*Month_ACLOUD]
            elseif strcmp(crp_set_MATLAB,'AWI') % AWI data
                crp_cpgn_minhr_daymonth = ...
                    reshape(crp_cpgn_minhrdaymonth,60*24,day_PASCAL_no);
                    % [hPa], [Min*Hr; Day_PASCAL*Month_PASCAL]
            end
            crp_cpgn_daymonth_minhr = ...
                permute(crp_cpgn_minhr_daymonth,[2,1]);
                % [hPa]
                % [Day_ACLOUD*Month_ACLOUD; Min*Hr] / 
                %   [Day_PASCAL*Month_PASCAL; Min*Hr]
            
            % Delete unnecessary variable(s)
            clear crp_cpgn_minhr_daymonth
            
            %%% Calculate data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Calculating ' crp_set_MATLAB ' ' crp_name_MATLAB ...
                ' average data'])
            
            % Calculate current chosen parameter daily means over time 
            % period
            crp_cpgn_daymonth = nanmean(crp_cpgn_daymonth_minhr,2); % [hPa]
                % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
            
            %%% Rename data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Renaming ' crp_set_MATLAB ' ' crp_name_MATLAB ' data'])
            
            % Rename current chosen parameter time variables
            eval([char(crp_store_t_name(1)) ' = crp_date_minhrdaymonth;'])
                % Every minute date matrix
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL;
                %    Yr : Month : Day : Hr : Min : Sec]
            eval([char(crp_store_t_name(2)) ' = crp_date_daymonth;'])
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] /
                %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
            
            % Rename current chosen parameter campaign variables
            eval([char(crp_store_cpgn_name(1)) ' = ' ...
                'crp_cpgn_minhrdaymonth;']);
                % [hPa]
                % Every minute over time period
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL]
            eval([char(crp_store_cpgn_name(2)) ' = ' ...
                'crp_cpgn_daymonth_minhr;']);
                % [hPa]
                % Every minute per day over time period
                % [Day_ACLOUD*Month_ACLOUD; Min*Hr] / 
                %   [Day_PASCAL*Month_PASCAL; Min*Hr]
            eval([char(crp_store_cpgn_name(3)) ' = ' ...
                'crp_cpgn_daymonth;']);
                % [hPa]
                % Daily averaged daily over time period
                % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
                
            % Rename current chosen parameter climatology variables
            if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
                % Daily averaged annually over time period
                eval([char(crp_store_clim_name(1)) ' = ' ...
                    'crp_clim_mean_daymonth;']);
                    % [hPa], [Day_ACLOUD*Month_ACLOUD]
                
                % Daily standard-deviated annually over time period
                eval([char(crp_store_clim_name(2)) ' = ' ...
                    'crp_clim_STD_daymonth;']);
                    % [hPa], [Day_ACLOUD*Month_ACLOUD]
            end
            
            %%% Store data %%%
            % Store current chosen parameter time and campaign data
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Storing ' crp_set_MATLAB ' ' crp_name_MATLAB ' data'])
            save([crp_store_path crp_store_file],...
                [crp_name_MATLAB '_*_' crp_set_MATLAB])
                % Store time and campaign variables
        end
        
        %%% Rename data %%%
        % Rename current chosen parameter time variables
        eval([crp_name_MATLAB '_date_minhrdaymonth = ' ...
            'crp_date_minhrdaymonth;'])
            % Every minute date matrix
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
            %  Yr : Month : Day : Hr : Min : Sec] / 
            % [Min*Hr*Day_PASCAL*Month_PASCAL;
            %  Yr : Month : Day : Hr : Min : Sec]
        eval([crp_name_MATLAB '_date_daymonth = ' ...
            'crp_date_daymonth;'])
            % Daily date matrix
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] /
            %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
        
        % Rename current chosen parameter campaign variables
        eval([crp_name_MATLAB '_cpgn_minhrdaymonth = ' ...
            'crp_cpgn_minhrdaymonth;']);
            % [hPa]
            % Every minute over time period
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
            %   [Min*Hr*Day_PASCAL*Month_PASCAL]
        eval([crp_name_MATLAB '_cpgn_daymonth_minhr = ' ...
            'crp_cpgn_daymonth_minhr;']);
            % [hPa]
            % Every minute per day over time period
            % [Day_ACLOUD*Month_ACLOUD; Min*Hr] / 
            %   [Day_PASCAL*Month_PASCA; Min*Hr]
        eval([crp_name_MATLAB '_cpgn_daymonth = ' ...
            'crp_cpgn_daymonth;']);
            % [hPa]
            % Daily averaged daily over time period
            % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
            
        % Rename current chosen parameter climatology variables
        if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
            % Daily averaged annually over time period
            eval([crp_name_MATLAB '_clim_mean_daymonth = ' ...
                'crp_clim_mean_daymonth;']);
                % [hPa], [Day_ACLOUD*Month_ACLOUD]
            
            % Daily standard-deviated annually over time period
            eval([crp_name_MATLAB '_clim_STD_daymonth = ' ...
                'crp_clim_STD_daymonth;']);
                % [hPa], [Day_ACLOUD*Month_ACLOUD]
        end
        
        %%% Delete data %%%
        % Delete unnecessary variable(s)
        if strcmp(crp_name_MATLAB,'ps') % Surface pressure data
            clear(crp_store_t_name{:},...
                crp_store_cpgn_name{:},crp_store_clim_name{:})
        else % Other pressure data
            clear(crp_store_t_name{:},crp_store_cpgn_name{:})
        end
        
        % Delete current chosen parameter data
        clear crp_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars p p_*
else % p data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear p_name_all p_indx_all
end
%%
%%%%% wind data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
wind_name_all = param_name(3+1:6+1,5); % Name(s)
wind_indx_all = ...
    [find(strcmp(param_name(2:end,5),wind_name_all(1))) ...
    find(strcmp(param_name(2:end,5),wind_name_all(2))) ...
    find(strcmp(param_name(2:end,5),wind_name_all(3))) ...
    find(strcmp(param_name(2:end,5),wind_name_all(4)))];
    % Index(es)

% Load wind data only if chosen
if sum(ismember(wind_indx_all,param_indx)) > 0 % wind data chosen
    %%% Basic parameter settings %%%
    % Set time step names
    wind_tstep_abbr = char(tint_name(1+1,3+1)); % Abbreviated
    wind_tstep_full = char(tint_name(2+1,3+1)); % Full
    
    % Set data set names
    wind_set_file = char(mod_name(1+1,2)); % File
    wind_set_MATLAB = char(mod_name(1+1,3)); % MATLAB
    wind_set_tper = char(mod_name(1+1,6)); % Time period
    
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    wind_name_chos = wind_name_all(ismember(wind_indx_all,param_indx));
        % Name(s)
    wind_indx_chos = wind_indx_all(ismember(wind_indx_all,param_indx));
        % Index(es)
    wind_no_chos = length(wind_indx_chos); % Number
    
    % Loop over chosen wind variables and load wind data
    for p = 1:wind_no_chos % Loop over number of chosen wind parameters
        %%% Parameter and data set names %%%
        % Extract current chosen parameter names
        crwind_name_gen = char(param_name(wind_indx_chos(p)+1,2));
            % General
        crwind_name_file = char(param_name(wind_indx_chos(p)+1,3));
            % File
        crwind_name_data = char(param_name(wind_indx_chos(p)+1,4));
            % Data
        crwind_name_MATLAB = char(param_name(wind_indx_chos(p)+1,5));
            % MATLAB
        crwind_name_full = char(param_name(wind_indx_chos(p)+1,6));
            % Full
            
        % Extract current chosen parameter unit
        crwind_unit = char(param_name(wind_indx_chos(p)+1,7));
        
        % Extract current chosen parameter campaign boundary dates
        crwind_date_yrmonthday_srt = ...
            char(param_name(wind_indx_chos(p)+1,8));
            % Start
        crwind_date_yrmonthday_end = ...
            char(param_name(wind_indx_chos(p)+1,9));
            % End
            
        % Extract current chosen parameter climatology boundary years
        crwind_date_yr_srt = wind_set_tper(1:strfind(wind_set_tper,'-')-1);
            % Start
        crwind_date_yr_end = ...
            num2str(str2double(wind_set_tper(strfind(wind_set_tper,'-')+1:end)) - 1);
            % End
            % NB! Exclude campaign year
        
        % Set current chosen parameter storage path and file names
        crwind_store_path = path_store; % Path
        crwind_store_file = ...
            [crwind_name_MATLAB '_NAa_' ...
            month_ACLOUD_abbr '_' yr_name '_' wind_set_MATLAB '.mat'];
            % File
            
        % Display current chosen parameter loading conditions
        disp(['load_ACLOUD_AWIPEV_NMI_AWI: Loading ' crwind_name_MATLAB ...
            ' data from the ' wind_set_MATLAB ' data set'])
        
        %%% Variables in storage file %%%
        % Set current chosen parameter time variables names
        crwind_store_t_name = ...
            [{[crwind_name_MATLAB '_date_6hrdaymonth_' wind_set_MATLAB]}; ...
            {[crwind_name_MATLAB '_date_daymonth_' wind_set_MATLAB]}];
            % [6-hourly date matrix; ...
            %  Daily date matrix]
        
        % Set current chosen parameter campaign variable names
        crwind_store_cpgn_name = ...
            [{[crwind_name_MATLAB '_cpgn_6hrdaymonth_' wind_set_MATLAB]}; ...
            {[crwind_name_MATLAB '_cpgn_daymonth_6hr_' wind_set_MATLAB]}; ...
            {[crwind_name_MATLAB '_cpgn_daymonth_' wind_set_MATLAB]}];
            % [6-hourly over time period; ...
            %  6-hourly per day over time period; ...
            %  Daily averaged daily over time period]
        
        %%% Variables to load from storage files %%%
        % Check existence of current chosen parameter variable in storage 
        % file
        if exist([crwind_store_path crwind_store_file],'file')
                % File existent
            % Find current chosen parameter file variable names
            crwind_store_var_file = ...
                whos('-file',[crwind_store_path crwind_store_file]);
            
            % Check existence of current chosen parameter variables in 
            % storage file
            crwind_store_cpgn_exist = ...
                ismember(crwind_store_cpgn_name,...
                {crwind_store_var_file.name});
                % Campaign variables
        else % File non-existent
            % Set current chosen parameter logical variable to zero
            crwind_store_cpgn_exist = 0; % Campaign variables
        end
        
        % Load current chosen parameter data only if variables are 
        % non-existent
        if sum(crwind_store_cpgn_exist) == length(crwind_store_cpgn_exist)
                % Variables existent
            disp('load_ACLOUD_AWIPEV_NMI_AWI: Existent variables:')
            disp(crwind_store_t_name)
            disp(crwind_store_cpgn_name)
            
            %%% Load data %%%
            % Load current chosen parameter data from .mat file
            load([crwind_store_path crwind_store_file],...
                crwind_store_t_name{:},crwind_store_cpgn_name{:})
            
            %%% Rename data %%%
            % Rename current chosen parameter time variables
            crwind_date_6hrdaymonth = eval(char(crwind_store_t_name(1)));
                % 6-hourly date matrix
                % [6hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec]
            crwind_date_daymonth = eval(char(crwind_store_t_name(2)));
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            
            % Rename current chosen parameter campaign variables
            crwind_cpgn_6hrdaymonth = ...
                eval(char(crwind_store_cpgn_name(1)));
                % [deg] / [m/s]
                % 6-hourly over time period
                % [6hr*Day_ACLOUD*Month_ACLOUD]
            crwind_cpgn_daymonth_6hr = ...
                eval(char(crwind_store_cpgn_name(2)));
                % [deg] / [m/s]
                % 6-hourly per day over time period
                % [Day_ACLOUD*Month_ACLOUD; 6hr]
            crwind_cpgn_daymonth = ...
                eval(char(crwind_store_cpgn_name(3)));
                % [deg] / [m/s]
                % Daily averaged daily over time period
                % [Day_ACLOUD*Month_ACLOUD]
        else % File non-existent
            disp('load_ACLOUD_AWIPEV_NMI_AWI: Loading variables:')
            disp(crwind_store_t_name)
            disp(crwind_store_cpgn_name)
            
            %%% Load data %%%
            % Set current chosen parameter loading path, file and data 
            % names
            crwind_load_path = ...
                [path_data 'Observations/' upper(wind_tstep_full) '/'];
                % Path
            crwind_load_file = ...
                [wind_set_file '_' crwind_name_file '_NAa_' ...
                wind_tstep_full '_' crwind_date_yrmonthday_srt '-' ...
                crwind_date_yrmonthday_end '.mat'];
                % File
            crwind_load_data = crwind_name_data;
                % Data
            
            % Load current chosen parameter time data
            crwind_date_6hrdaymonth = ...
                load([crwind_load_path crwind_load_file],...
                'sonde_launchtime');
                % Structure format
                % [1].mat
            crwind_date_6hrdaymonth = ...
                crwind_date_6hrdaymonth.sonde_launchtime;
                % Vector format
                % [6hr_All*Day_All*Month_All]
            crwind_date_6hrdaymonth = datevec(crwind_date_6hrdaymonth);
                % Matrix format
                % [6hr_All*Day_All*Month_All; ...
                %  Yr : Month : Day : Hr : Min : Sec]
            
            % Load current chosen parameter campaign data
            crwind_cpgn_6hrdaymonth = ...
                load([crwind_load_path crwind_load_file],crwind_load_data);
                % [deg] / [m/s], structure format, [1].mat
            crwind_cpgn_6hrdaymonth = ...
                eval(['crwind_cpgn_6hrdaymonth.' crwind_name_data ';']);
                % [deg] / [m/s], vector format, [6hr_All*Day_All*Month_All]
                
            % Replace current chosen parameter negative (missing) values by
            % NaN
            crwind_cpgn_6hrdaymonth(crwind_cpgn_6hrdaymonth < 0) = NaN;
                % [deg] / [m/s], [6hr_All*Day_All*Month_All]
            
            % Rearrange current chosen parameter data from horizontal to
            % vertical vector
            crwind_cpgn_6hrdaymonth = crwind_cpgn_6hrdaymonth';
                % [deg] / [m/s], [6hr_All*Day_All*Month_All]
            
            %%% Find boundary data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Extracting ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' data over chosen time period'])
            
            % Find current chosen parameter chosen time period boundary 
            % indexes in campaign data
            crwind_date_6hrdaymonth_srt = ...
                find(datenum(crwind_date_6hrdaymonth(:,1:3)) == ...
                datenum(tper_ACLOUD_num(1:8),'yyyymmdd'),1,'first');
                % Start
            crwind_date_6hrdaymonth_end = ...
                find(datenum(crwind_date_6hrdaymonth(:,1:3)) == ...
                datenum(tper_ACLOUD_num(10:end),'yyyymmdd'),1,'last');
                % End
                
            % Merge current chosen campaign parameter chosen time period 
            % boundary indexes
            crwind_date_6hrdaymonth_bnd = ...
                [crwind_date_6hrdaymonth_srt crwind_date_6hrdaymonth_end];
                % [Start : End]
                
            % Delete unnecessary variable(s)
            clear crwind_date_6hrdaymonth_srt crwind_date_6hrdaymonth_end
            
            %%% Extract data %%%
            % Extract current chosen parameter 6-hourly time data over 
            % chosen time period
            crwind_date_6hrdaymonth = ...
                crwind_date_6hrdaymonth(...
                crwind_date_6hrdaymonth_bnd(1):crwind_date_6hrdaymonth_bnd(2),:);
                % [6hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec]
            
            % Find current chosen parameter daily time data step indexes
            % over chosen time period
            [~,crwind_date_daymonth_indx,~] = ...
                unique(datenum(crwind_date_6hrdaymonth(:,1:3)));
            
            % Extract current chosen parameter daily time data over chosen 
            % time period
            if size(crwind_date_6hrdaymonth,1) == hr_no*day_ACLOUD_no
                    % All 6-hourly data existent
                crwind_date_daymonth = ...
                    crwind_date_6hrdaymonth(1:hr_no:end,1:3);
                    % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            else % Some 6-hourly data non-existent
                crwind_date_daymonth = ...
                    crwind_date_6hrdaymonth(crwind_date_daymonth_indx,1:3);
                    % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            end
            
            % Extract current chosen parameter campaign data over chosen 
            % time period
            crwind_cpgn_6hrdaymonth = ...
                crwind_cpgn_6hrdaymonth(...
                crwind_date_6hrdaymonth_bnd(1):crwind_date_6hrdaymonth_bnd(2));
                % [deg] / [m/s], [6hr*Day_ACLOUD*Month_ACLOUD]
            
            %%% Rearrange data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Rearranging ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' data over chosen time period'])
            
            % Rearrange current chosen parameter campaign data from 1D to 
            % 2D
            if size(crwind_date_6hrdaymonth,1) == hr_no*day_ACLOUD_no
                    % All 6-hourly data existent
                % 6-hourly per day over time period
                crwind_cpgn_6hr_daymonth = ...
                    reshape(crwind_cpgn_6hrdaymonth,hr_no,day_ACLOUD_no);
                    % [deg] / [m/s], [6hr; Day_ACLOUD*Month_ACLOUD]
                crwind_cpgn_daymonth_6hr = ...
                    permute(crwind_cpgn_6hr_daymonth,[2,1]);
                    % [deg] / [m/s], [Day_ACLOUD*Month_ACLOUD; 6hr]
                
                % Delete unnecessary variable(s)
                clear crwind_cpgn_6hr_daymonth
            else % Some 6-hourly data non-existent
                % Set 6-hourly campaign data per day over time period to
                % dummy variable of desired format
                crwind_cpgn_daymonth_6hr = NaN(day_ACLOUD_no,hr_no);
                    % [Day_ACLOUD*Month_ACLOUD; 6hr]
                
                % Loop over time period days and add existing measurements 
                % to dummy variable
                for d = 1:day_ACLOUD_no % Loop over number of ACLOUD days
                    % Extract current time period day 6-hours date(s)
                    if d < day_ACLOUD_no % 1st - 2nd last day
                        crwind_crdaymonth_date_6hr = ...
                            crwind_date_6hrdaymonth(...
                            crwind_date_daymonth_indx(d):...
                            crwind_date_daymonth_indx(d+1)-1,:);
                            % [6hr_CrDayMonth; ...
                            %  Yr : Month : Day : Hr : Min : Sec]
                    else % Last day
                        crwind_crdaymonth_date_6hr = ...
                            crwind_date_6hrdaymonth(...
                            crwind_date_daymonth_indx(d):...
                            crwind_date_daymonth_indx(end),:);
                            % [6hr_CrDayMonth; ...
                            %  Yr : Month : Day : Hr : Min : Sec]
                    end
                    
                    % Calculate number of current time period day 6-hours
                    crwind_crdaymonth_6hr_no = ...
                        size(crwind_crdaymonth_date_6hr,1);
                    
                    % Loop over current time period day 6-hours and add
                    % existing measurements to dummy variable
                    for h = 1:crwind_crdaymonth_6hr_no
                            % Loop over number of current time period day 
                            % 6-hours
                        % Find current time period day current 6-hours date 
                        % index(es)
                        % NB! Treating all measurements not 
                        %     00, 06, 12 and 18 UTC as missing values
                        crwind_crdaymonth_cr6hr_date_indx = ...
                            find(crwind_crdaymonth_date_6hr(h,4) == [5 11 17 23]);
                            % [6hr_CrDayMonth]
                        
                        % Add existing current time period day 6-hours  
                        % measurements to dummy variable
                        crwind_cpgn_daymonth_6hr(d,crwind_crdaymonth_cr6hr_date_indx) = ...
                            crwind_cpgn_6hrdaymonth(crwind_date_daymonth_indx(d)+h-1);
                            % [deg] / [m/s], [Day_ACLOUD*Month_ACLOUD; 6hr]
                        
                        % Delete current time period day current 6-hours
                        % data
                        clear crwind_crdaymonth_cr6hr_*
                    end
                    
                    % Delete current time period day data
                    clear h crwind_crdaymonth_*
                end
                
                % Delete unnecessary variable(s)
                clear d
            end
            
            %%% Calculate data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Calculating ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' average data'])
            
            % Calculate current chosen parameter daily means over time 
            % period
            if size(crwind_date_6hrdaymonth,1) == hr_no*day_ACLOUD_no
                    % All 6-hourly data existent
                % Calculate daily means over all 6-hours
                crwind_cpgn_daymonth = nanmean(crwind_cpgn_daymonth_6hr,2);
                    % [deg] / [m/s], [Day_ACLOUD*Month_ACLOUD]
            else % Some 6-hourly data non-existent
                % Loop over time period days and calculate daily means over
                % existing 6-hours
                % NB! Averaging over all measurements and not only 
                %     00, 06, 12 and 18 UTC measurements
                for d = 1:day_ACLOUD_no % Loop over number of ACLOUD days
                    if d < day_ACLOUD_no % 1st - 2nd last day
                        crwind_cpgn_daymonth(d,:) = ...
                            nanmean(crwind_cpgn_6hrdaymonth(...
                            crwind_date_daymonth_indx(d):...
                            crwind_date_daymonth_indx(d+1)-1));
                            % [deg] / [m/s], [Day_ACLOUD*Month_ACLOUD]
                    else % Last day
                        crwind_cpgn_daymonth(d,:) = ...
                            nanmean(crwind_cpgn_6hrdaymonth(...
                            crwind_date_daymonth_indx(d):...
                            crwind_date_daymonth_indx(end)));
                            % [deg] / [m/s], [Day_ACLOUD*Month_ACLOUD]
                    end
                end
                
                % Delete unnecessary variable(s)
                clear d
            end
            
            %%% Rename data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Renaming ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' data'])
            
            % Rename current chosen parameter time variables
            eval([char(crwind_store_t_name(1)) ' = ' ...
                'crwind_date_6hrdaymonth;'])
                % 6-hourly date matrix
                % [6hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec]
            eval([char(crwind_store_t_name(2)) ' = ' ...
                'crwind_date_daymonth;'])
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            
            % Rename current chosen parameter campaign variables
            eval([char(crwind_store_cpgn_name(1)) ' = ' ...
                'crwind_cpgn_6hrdaymonth;']);
                % [deg] / [m/s]
                % 6-hourly over time period
                % [6hr*Day_ACLOUD*Month_ACLOUD]
            eval([char(crwind_store_cpgn_name(2)) ' = ' ...
                'crwind_cpgn_daymonth_6hr;']);
                % [deg] / [m/s]
                % 6-hourly per day over time period
                % [Day_ACLOUD*Month_ACLOUD; 6hr]
            eval([char(crwind_store_cpgn_name(3)) ' = ' ...
                'crwind_cpgn_daymonth;']);
                % [deg] / [m/s]
                % Daily averaged daily over time period
                % [Day_ACLOUD*Month_ACLOUD]
            
            %%% Store data %%%
            % Store current chosen parameter time and campaign data
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Storing ' wind_set_MATLAB ' ' crwind_name_MATLAB ' data'])
            save([crwind_store_path crwind_store_file],...
                [crwind_name_MATLAB '_*_' wind_set_MATLAB])
                % Store time and campaign variables
        end
        
        %%% Rename data %%%
        % Rename current chosen parameter time variables
        eval([crwind_name_MATLAB '_date_6hrdaymonth = ' ...
            'crwind_date_6hrdaymonth;'])
            % 6-hourly date matrix
            % [6hr*Day_ACLOUD*Month_ACLOUD;
            %  Yr : Month : Day : Hr : Min : Sec]
        eval([crwind_name_MATLAB '_date_daymonth = ' ...
            'crwind_date_daymonth;'])
            % Daily date matrix
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        
        % Rename current chosen parameter campaign variables
        eval([crwind_name_MATLAB '_cpgn_6hrdaymonth = ' ...
            'crwind_cpgn_6hrdaymonth;']);
            % [deg] / [m/s]
            % 6-hourly over time period
            % [6hr*Day_ACLOUD*Month_ACLOUD]
        eval([crwind_name_MATLAB '_cpgn_daymonth_6hr = ' ...
            'crwind_cpgn_daymonth_6hr;']);
            % [deg] / [m/s]
            % 6-hourly per day over time period
            % [Day_ACLOUD*Month_ACLOUD; 6hr]
        eval([crwind_name_MATLAB '_cpgn_daymonth = ' ...
            'crwind_cpgn_daymonth;']);
            % [deg] / [m/s]
            % Daily averaged daily over time period
            % [Day_ACLOUD*Month_ACLOUD]
        
        %%% Delete data %%%
        % Delete unnecessary variable(s)
        clear(crwind_store_t_name{:},crwind_store_cpgn_name{:})
        
        % Delete current chosen parameter data
        clear crwind_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars p wind_*
else % wind data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear wind_name_all wind_indx_all
end
%%
%%%%% T data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
T_name_all = param_name(7+1:9+1,5); % Name(s)
T_indx_all = ...
    [find(strcmp(param_name(2:end,5),T_name_all(1))) ...
    find(strcmp(param_name(2:end,5),T_name_all(2))) ...
    find(strcmp(param_name(2:end,5),T_name_all(3)))];
    % Index(es)

% Load T data only if chosen
if sum(ismember(T_indx_all,param_indx)) > 0 % T data chosen
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    T_name_chos = T_name_all(ismember(T_indx_all,param_indx)); % Name(s)
    T_indx_chos = T_indx_all(ismember(T_indx_all,param_indx)); % Index(es)
    T_no_chos = length(T_indx_chos); % Number
    
    % Loop over chosen T variables and load T data
    for p = 1:T_no_chos % Loop over number of chosen T parameters
        %%% Parameter and data set names %%%
        % Extract current chosen parameter names
        crT_name_gen = char(param_name(T_indx_chos(p)+1,2));
            % General
        crT_name_file = char(param_name(T_indx_chos(p)+1,3));
            % File
        crT_name_data = char(param_name(T_indx_chos(p)+1,4));
            % Data
        crT_name_MATLAB = char(param_name(T_indx_chos(p)+1,5));
            % MATLAB
        crT_name_full = char(param_name(T_indx_chos(p)+1,6));
            % Full
            
        % Extract current chosen parameter unit
        crT_unit = char(param_name(T_indx_chos(p)+1,7));
        
        % Extract current chosen parameter data set names
        if strcmp(crT_name_MATLAB,'T2m') || strcmp(crT_name_MATLAB,'T10m')
                % 2-m or 10-m temperature data
            crT_set_file = char(mod_name(1+1,2)); % File
            crT_set_MATLAB = char(mod_name(1+1,3)); % MATLAB
            crT_set_tper = char(mod_name(1+1,6)); % Time period
        elseif strcmp(crT_name_MATLAB,'T29m') % 29-m pressure data
            crT_set_file = char(mod_name(3+1,2)); % File
            crT_set_MATLAB = char(mod_name(3+1,3)); % MATLAB
            crT_set_tper = char(mod_name(3+1,6)); % Time period
        end
        
        %%% Time period names and dates %%%
        % Set campaign time step names
        crT_tstep_cpgn_abbr = char(tint_name(1+1,1+1)); % Abbreviated
        crT_tstep_cpgn_full = char(tint_name(2+1,1+1)); % Full
        
        % Set climatology time step names
        if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
            crT_tstep_clim_abbr = char(tint_name(1+1,4+1)); % Abbreviated
            crT_tstep_clim_full = char(tint_name(2+1,4+1)); % Full
        end
        
        % Extract current chosen parameter campaign boundary dates
        crT_date_yrmonthday_srt = ...
            char(param_name(T_indx_chos(p)+1,8));
            % Start
        crT_date_yrmonthday_end = ...
            char(param_name(T_indx_chos(p)+1,9));
            % End
            
        % Extract current chosen parameter climatology boundary years
        if strcmp(crT_set_MATLAB,'AWIPEV') % AWIPEV data
            % Start
            crT_date_yr_srt = ...
                num2str(str2double(crT_set_tper(1:strfind(crT_set_tper,'-')-1)) + 1);
                % NB! Exclude 1st year (measurements from August only)
                
            % End
            crT_date_yr_end = ...
                num2str(str2double(crT_set_tper(strfind(crT_set_tper,'-')+1:end)) - 1);
                % NB! Exclude campaign year
        elseif strcmp(crT_set_MATLAB,'AWI') % AWI data
            % Start
            crT_date_yr_srt = crT_set_tper;
                
            % End
            crT_date_yr_end = crT_set_tper;
        end
        
        % Set current chosen parameter storage path and file names
        crT_store_path = path_store; % Path
        if strcmp(crT_set_MATLAB,'AWIPEV') % AWIPEV data
            % File
            crT_store_file = ...
                [crT_name_MATLAB '_NAa_' ...
                month_ACLOUD_abbr '_' yr_name '_' crT_set_MATLAB '.mat'];
        elseif strcmp(crT_set_MATLAB,'AWI') % AWI data
            % File
            crT_store_file = ...
                [crT_name_MATLAB '_PS_' ...
                month_PASCAL_abbr '_' yr_name '_' crT_set_MATLAB '.mat'];
        end
            
        % Display current chosen parameter loading conditions
        disp(['load_ACLOUD_AWIPEV_NMI_AWI: Loading ' crT_name_MATLAB ...
            ' data from the ' crT_set_MATLAB ' data set'])
        
        %%% Variables in storage file %%%
        % Set current chosen parameter time variables names
        crT_store_t_name = ...
            [{[crT_name_MATLAB '_date_minhrdaymonth_' crT_set_MATLAB]}; ...
            {[crT_name_MATLAB '_date_daymonth_' crT_set_MATLAB]}];
            % [Every minute date matrix; ...
            %  Daily date matrix]
        
        % Set current chosen parameter campaign variable names
        crT_store_cpgn_name = ...
            [{[crT_name_MATLAB '_cpgn_minhrdaymonth_' crT_set_MATLAB]}; ...
            {[crT_name_MATLAB '_cpgn_daymonth_minhr_' crT_set_MATLAB]}; ...
            {[crT_name_MATLAB '_cpgn_daymonth_' crT_set_MATLAB]}];
            % [Every minute over time period; ...
            %  Every minute per day over time period; ...
            %  Daily averaged daily over time period]
        
        % Set current chosen parameter climatology variable names
        if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
            crT_store_clim_name = ...
                [{[crT_name_MATLAB '_clim_mean_daymonth_' crT_set_MATLAB]}; ...
                {[crT_name_MATLAB '_clim_STD_daymonth_' crT_set_MATLAB]}];
                % [Daily averaged annually over time period; ...
                %  Daily standard-deviated annually over time period]
        end
        
        %%% Variables to load from storage files %%%
        % Check existence of current chosen parameter variable in storage 
        % file
        if exist([crT_store_path crT_store_file],'file')
                % File existent
            % Find current chosen parameter file variable names
            crT_store_var_file = ...
                whos('-file',[crT_store_path crT_store_file]);
            
            % Check existence of current chosen parameter variables in 
            % storage file
            crT_store_cpgn_exist = ...
                ismember(crT_store_cpgn_name,{crT_store_var_file.name});
                % Campaign variables
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                % Climatology variables
                crT_store_clim_exist = ...
                    ismember(crT_store_clim_name,{crT_store_var_file.name});
            else % Other temperature data
                % Climatology variables
                % NB! Set to one even though no climatology variables exist
                crT_store_clim_exist = 1;
            end
        else % File non-existent
            % Set current chosen parameter logical variable to zero
            crT_store_cpgn_exist = 0; % Campaign variables
            crT_store_clim_exist = 0; % Climatology variables
        end
        
        % Load current chosen parameter data only if variables are 
        % non-existent
        if sum(crT_store_cpgn_exist) == length(crT_store_cpgn_exist) && ...
                sum(crT_store_clim_exist) == length(crT_store_clim_exist)
                % Variables existent
            disp('load_ACLOUD_AWIPEV_NMI_AWI: Existent variables:')
            disp(crT_store_t_name)
            disp(crT_store_cpgn_name)
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                disp(crT_store_clim_name)
            end
            
            %%% Load data %%%
            % Load current chosen parameter data from .mat file
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                load([crT_store_path crT_store_file],...
                    crT_store_t_name{:},crT_store_cpgn_name{:},...
                    crT_store_clim_name{:})
            else % Other temperature data
                load([crT_store_path crT_store_file],...
                    crT_store_t_name{:},crT_store_cpgn_name{:})
            end
            
            %%% Rename data %%%
            % Rename current chosen parameter time variables
            crT_date_minhrdaymonth = eval(char(crT_store_t_name(1)));
                % Every minute date matrix
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL;
                %    Yr : Month : Day : Hr : Min : Sec]
            crT_date_daymonth = eval(char(crT_store_t_name(2)));
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] / 
                %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
            
            % Rename current chosen parameter campaign variables
            crT_cpgn_minhrdaymonth = eval(char(crT_store_cpgn_name(1)));
                % [deg C]
                % Every minute over time period
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL]
            crT_cpgn_daymonth_minhr = eval(char(crT_store_cpgn_name(2)));
                % [deg C]
                % Every minute per day over time period
                % [Day_ACLOUD*Month_ACLOUD; Min*Hr] / 
                %   [Day_PASCAL*Month_PASCAL; Min*Hr]
            crT_cpgn_daymonth = eval(char(crT_store_cpgn_name(3)));
                % [deg C]
                % Daily averaged daily over time period
                % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
                
            % Rename current chosen parameter climatology variables
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                % Daily averaged annually over time period
                crT_clim_mean_daymonth = ...
                    eval(char(crT_store_clim_name(1)));
                    % [deg C], [Day_ACLOUD*Month_ACLOUD]
                
                % Daily standard-deviated annually over time period
                crT_clim_STD_daymonth = ...
                    eval(char(crT_store_clim_name(2)));
                    % [deg C], [Day_ACLOUD*Month_ACLOUD]
            end
        else % File non-existent
            disp('load_ACLOUD_AWIPEV_NMI_AWI: Loading variables:')
            disp(crT_store_t_name)
            disp(crT_store_cpgn_name)
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                disp(crT_store_clim_name)
            end
            
            %%% Load campaign data %%%
            % Set current chosen campaign parameter loading path, file and 
            % data names
            crT_load_cpgn_path = ...
                [path_data 'Observations/' upper(crT_tstep_cpgn_full) '/'];
                % Path
            if strcmp(crT_set_MATLAB,'AWIPEV') % AWIPEV data
                % File
                crT_load_cpgn_file = ...
                    [crT_set_file '_' crT_name_file '_NAa_' ...
                    crT_tstep_cpgn_full '_' crT_date_yrmonthday_srt '-' ...
                    crT_date_yrmonthday_end '.mat'];
            elseif strcmp(crT_set_MATLAB,'AWI') % AWI data
                % File
                crT_load_cpgn_file = ...
                    [crT_set_file '_' crT_name_file '_PS_' ...
                    crT_tstep_cpgn_full '_' crT_date_yrmonthday_srt '-' ...
                    crT_date_yrmonthday_end '.txt'];
            end
            crT_load_cpgn_data = crT_name_data;
                % Data
            
            % Load current chosen campaign parameter time and variable data
            if strcmp(crT_set_MATLAB,'AWIPEV') % AWIPEV data
                % Load current chosen campaign parameter time data
                crT_date_minhrdaymonth = ...
                    load([crT_load_cpgn_path crT_load_cpgn_file],...
                    'NYA_timestamp');
                    % Structure format
                    % [1].mat
                crT_date_minhrdaymonth = ...
                    crT_date_minhrdaymonth.NYA_timestamp;
                    % Vector format
                    % [Min_All*Hr_All*Day_All*Month_All]
                crT_date_minhrdaymonth = datevec(crT_date_minhrdaymonth);
                    % Matrix format
                    % [Min_All*Hr_All*Day_All*Month_All; ...
                    %  Yr : Month : Day : Hr : Min : Sec]
                
                % Load current chosen parameter campaign data
                crT_cpgn_minhrdaymonth = ...
                    load([crT_load_cpgn_path crT_load_cpgn_file],...
                    crT_load_cpgn_data);
                    % [deg C], structure format
                    % [1].mat
                crT_cpgn_minhrdaymonth = ...
                    eval(['crT_cpgn_minhrdaymonth.' crT_name_data ';']);
                    % [deg C], vector format
                    % [Min_All*Hr_All*Day_All*Month_All]
            elseif strcmp(crT_set_MATLAB,'AWI') % AWI data
                % Set current chosen parameter loading format
                crT_load_cpgn_frmt = ...
                    '%s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f';
                
                % Open, store content of and close current chosen campaign 
                % parameter file
                crT_load_cpgn_open = ...
                    fopen([crT_load_cpgn_path crT_load_cpgn_file],'r');
                    % Open file
                crT_load_cpgn_hdln = ...
                    textscan(crT_load_cpgn_open,'%s',3+13*2);
                    % Store file headlines in cell matrix
                    % NB! Account for headline format, which contains units
                    %     in square brackets for all 37 variable parameters
                crT_load_cpgn_cont = ...
                    textscan(crT_load_cpgn_open,crT_load_cpgn_frmt,...
                    'delimiter','\t','headerlines',1);
                    % Store file content in cell matrix
                crT_load_cpgn_clse = fclose(crT_load_cpgn_open);
                    % Close file
                
                % Extract current chosen campaign parameter headerlines
                crT_load_cpgn_hdln = crT_load_cpgn_hdln{1,1};
                    % Vector format, including units
                crT_load_cpgn_hdln = ...
                    [crT_load_cpgn_hdln(1:3); crT_load_cpgn_hdln(4:2:end)];
                    % Vector format, excluding units
                
                % Find current chosen campaign parameter time data indexes 
                % in file
                crT_load_cpgn_indx = ...
                    find(strcmp(crT_load_cpgn_hdln,crT_load_cpgn_data));
                
                % Extract current chosen campaign parameter time data
                crT_date_minhrdaymonth_cell = crT_load_cpgn_cont{1,1};
                    % Every minute date vector on cell format
                    % [Min_All*Hr_All*Day_All*Month_All]
                for mn = 1:length(crT_date_minhrdaymonth_cell)
                        % Loop over number of minutes
                    % Every minute date matrix on integer format
                    crT_date_minhrdaymonth_mat(mn,:) = ...
                        datevec(datenum(...
                        [crT_date_minhrdaymonth_cell{mn,1}(1:10) ' ' ...
                        crT_date_minhrdaymonth_cell{mn,1}(12:16)]));
                        % [Min_All*Hr_All*Day_All*Month_All; ...
                        %  Yr : Month : Day : Hr : Min : Sec]
                end
                
                % Extract current chosen campaign parameter campaign data
                crT_cpgn_minhrdaymonth = ...
                    crT_load_cpgn_cont{1,crT_load_cpgn_indx};
                    % [hPa]
                	% [Min_All*Hr_All*Day_All*Month_All]
                
                % Replace current chosen campaign parameter missing and 
                % negative values by NaN
                crT_cpgn_minhrdaymonth(crT_cpgn_minhrdaymonth == -9999) = NaN;
                    % [hPa], missing values
                    % [Min_All*Hr_All*Day_All*Month_All]
                    
                % Rename current chosen campaign parameter time data
                crT_date_minhrdaymonth = crT_date_minhrdaymonth_mat;
                    % Every minute date matrix
                    % [Min_All*Hr_All*Day_All*Month_All; ...
                    %  Yr : Month : Day : Hr : Min : Sec]
                    
                % Delete unnecessary variable(s)
                clear crT_load_cpgn_* crT_date_minhrdaymonth_*
            end
            
            %%% Load climatology data %%%
            % Set current chosen climatology parameter loading path, file 
            % and data names
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                % Path
                crT_load_clim_path = ...
                    [path_data 'Observations/' ...
                    upper(crT_tstep_clim_full) '/'];
                
                % File
                crT_load_clim_file = ...
                    [crT_set_file '_' crT_name_gen '_NAa_' ...
                    crT_tstep_clim_full '_JFMAMJJASOND_' ...
                    crT_date_yr_srt '-' crT_date_yr_end '.mat'];
                
                % Data
                crT_load_clim_data = ...
                    [{'longterm_daymean_T'}; {'longterm_stddev_T'}];
            end
            
            % Load current chosen climatology parameter mean and STD data
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                % Structure format
                crT_clim_mean_STD = ...
                    load([crT_load_clim_path crT_load_clim_file],...
                    char(crT_load_clim_data(1)),char(crT_load_clim_data(2)));
                    % [deg C], [1].mat
                
                % Vector format
                crT_clim_mean_daymonth = ...
                    eval(['crT_clim_mean_STD.' char(crT_load_clim_data(1)) ';']);
                    % [deg C], mean, [Day_All*Month_All]
                crT_clim_STD_daymonth = ...
                    eval(['crT_clim_mean_STD.' char(crT_load_clim_data(2)) ';']);
                    % [deg C], STD, [Day_All*Month_All]
            end
                
            % Rearrange current chosen climatology parameter mean and STD 
            % data from horizontal to vertical vectors
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                % Mean
                crT_clim_mean_daymonth = crT_clim_mean_daymonth';
                    % [deg C], [Day_All*Month_All]
                
                % STD
                crT_clim_STD_daymonth = crT_clim_STD_daymonth';
                    % [deg C], [Day_All*Month_All]
            end
            
            % Delete unnecessary variable(s)
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                clear crT_cpgn_var crT_clim_mean_STD
            end
            
            %%% Find boundary data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Extracting ' crT_set_MATLAB ' ' crT_name_MATLAB ...
                ' data over chosen time period'])
            
            % Find current chosen parameter chosen time period boundary 
            % indexes in campaign data
            if strcmp(crT_set_MATLAB,'AWIPEV') % AWIPEV data
                % Start
                crT_date_minhrdaymonth_srt = ...
                    find(datenum(crT_date_minhrdaymonth(:,1:3)) == ...
                    datenum(tper_ACLOUD_num(1:8),'yyyymmdd'),1,'first');
                
                % End
                crT_date_minhrdaymonth_end = ...
                    find(datenum(crT_date_minhrdaymonth(:,1:3)) == ...
                    datenum(tper_ACLOUD_num(10:end),'yyyymmdd'),1,'last');
            elseif strcmp(crT_set_MATLAB,'AWI') % AWI data
                % Start
                crT_date_minhrdaymonth_srt = ...
                    find(datenum(crT_date_minhrdaymonth(:,1:3)) == ...
                    datenum(tper_PASCAL_num(1:8),'yyyymmdd'),1,'first');
                
                % End
                crT_date_minhrdaymonth_end = ...
                    find(datenum(crT_date_minhrdaymonth(:,1:3)) == ...
                    datenum(tper_PASCAL_num(10:end),'yyyymmdd'),1,'last');
            end
                
            % Merge current chosen campaign parameter chosen time period 
            % boundary indexes
            crT_date_minhrdaymonth_bnd = ...
                [crT_date_minhrdaymonth_srt crT_date_minhrdaymonth_end];
                % [Start : End]
                
            % Rename current chosen climatology parameter chosen time 
            % period boundary indexes
            if strcmp(crT_set_MATLAB,'AWIPEV') % AWIPEV data
                crT_date_daymonth_bnd = day_ACLOUD_bnd; % [Start : End]
            elseif strcmp(crT_set_MATLAB,'AWI') % AWI data
                crT_date_daymonth_bnd = day_PASCAL_bnd; % [Start : End]
            end
                
            % Delete unnecessary variable(s)
            clear crT_date_minhrdaymonth_srt crT_date_minhrdaymonth_end
            
            %%% Extract data %%%
            % Extract current chosen parameter every minute time data over 
            % chosen time period
            crT_date_minhrdaymonth = ...
                crT_date_minhrdaymonth(...
                crT_date_minhrdaymonth_bnd(1):crT_date_minhrdaymonth_bnd(2),:);
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec] / 
                %   [Min*Hr*Day_ACLOUD*Month_ACLOUD;
                %    Yr : Month : Day : Hr : Min : Sec]
            
            % Extract current chosen parameter daily time data over chosen 
            % time period
            crT_date_daymonth = crT_date_minhrdaymonth(1:60*24:end,1:3);
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] / 
                %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
                
            % Extract current chosen parameter campaign data over chosen 
            % time period
            crT_cpgn_minhrdaymonth = ...
                crT_cpgn_minhrdaymonth(...
                crT_date_minhrdaymonth_bnd(1):crT_date_minhrdaymonth_bnd(2));
                % [deg C]
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL]
                
            % Extract current chosen parameter climatology mean and STD 
            % data over chosen time period
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                % Mean
                crT_clim_mean_daymonth = ...
                    crT_clim_mean_daymonth(...
                    crT_date_daymonth_bnd(1):crT_date_daymonth_bnd(2));
                    % [deg C], [Day_ACLOUD*Month_ACLOUD]
                
                % STD
                crT_clim_STD_daymonth = ...
                    crT_clim_STD_daymonth(...
                    crT_date_daymonth_bnd(1):crT_date_daymonth_bnd(2));
                    % [deg C], [Day_ACLOUD*Month_ACLOUD]
            end
            
            %%% Rearrange data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Rearranging ' crT_set_MATLAB ' ' crT_name_MATLAB ...
                ' data over chosen time period'])
            
            % Rearrange current chosen parameter campaign data from 1D to 
            % 2D
            if strcmp(crT_set_MATLAB,'AWIPEV') % AWIPEV data
                crT_cpgn_minhr_daymonth = ...
                    reshape(crT_cpgn_minhrdaymonth,60*24,day_ACLOUD_no);
                    % [deg C], [Min*Hr; Day_ACLOUD*Month_ACLOUD]
            elseif strcmp(crT_set_MATLAB,'AWI') % AWI data
                crT_cpgn_minhr_daymonth = ...
                    reshape(crT_cpgn_minhrdaymonth,60*24,day_PASCAL_no);
                    % [deg C], [Min*Hr; Day_PASCAL*Month_PASCAL]
            end
            crT_cpgn_daymonth_minhr = ...
                permute(crT_cpgn_minhr_daymonth,[2,1]);
                % [deg C]
                % [Day_ACLOUD*Month_ACLOUD; Min*Hr] / 
                %   [Day_PASCAL*Month_PASCAL; Min*Hr]
                
            % Delete unnecessary variable(s)
            clear crT_cpgn_minhr_daymonth
            
            %%% Calculate data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Calculating ' crT_set_MATLAB ' ' crT_name_MATLAB ...
                ' average data'])
            
            % Calculate current chosen parameter daily means over time 
            % period
            crT_cpgn_daymonth = nanmean(crT_cpgn_daymonth_minhr,2);
                % [deg C]
                % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
            
            %%% Rename data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Renaming ' crT_set_MATLAB ' ' crT_name_MATLAB ' data'])
            
            % Rename current chosen parameter time variables
            eval([char(crT_store_t_name(1)) ' = crT_date_minhrdaymonth;'])
                % Every minute date matrix
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL;
                %    Yr : Month : Day : Hr : Min : Sec]
            eval([char(crT_store_t_name(2)) ' = crT_date_daymonth;'])
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] /
                %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
            
            % Rename current chosen parameter campaign variables
            eval([char(crT_store_cpgn_name(1)) ' = ' ...
                'crT_cpgn_minhrdaymonth;']);
                % [deg C]
                % Every minute over time period
                % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
                %   [Min*Hr*Day_PASCAL*Month_PASCAL]
            eval([char(crT_store_cpgn_name(2)) ' = ' ...
                'crT_cpgn_daymonth_minhr;']);
                % [deg C]
                % Every minute per day over time period
                % [Day_ACLOUD*Month_ACLOUD; Min*Hr] / 
                %   [Day_PASCAL*Month_PASCAL; Min*Hr]
            eval([char(crT_store_cpgn_name(3)) ' = ' ...
                'crT_cpgn_daymonth;']);
                % [deg C]
                % Daily averaged daily over time period
                % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
                
            % Rename current chosen parameter climatology variables
            if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
                % Daily averaged annually over time period
                eval([char(crT_store_clim_name(1)) ' = ' ...
                    'crT_clim_mean_daymonth;']);
                    % [deg C], [Day_ACLOUD*Month_ACLOUD]
                
                % Daily standard-deviated annually over time period
                eval([char(crT_store_clim_name(2)) ' = ' ...
                    'crT_clim_STD_daymonth;']);
                    % [deg C], [Day_ACLOUD*Month_ACLOUD]
            end
            
            %%% Store data %%%
            % Store current chosen parameter time and campaign data
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Storing ' crT_set_MATLAB ' ' crT_name_MATLAB ' data'])
            save([crT_store_path crT_store_file],...
                [crT_name_MATLAB '_*_' crT_set_MATLAB])
                % Store time and campaign variables
        end
        
        %%% Rename data %%%
        % Rename current chosen parameter time variables
        eval([crT_name_MATLAB '_date_minhrdaymonth = ' ...
            'crT_date_minhrdaymonth;'])
            % Every minute date matrix
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
            %  Yr : Month : Day : Hr : Min : Sec] /
            % [Min*Hr*Day_PASCAL*Month_PASCAL;
            %  Yr : Month : Day : Hr : Min : Sec]
        eval([crT_name_MATLAB '_date_daymonth = ' ...
            'crT_date_daymonth;'])
            % Daily date matrix
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] /
            %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
        
        % Rename current chosen parameter campaign variables
        eval([crT_name_MATLAB '_cpgn_minhrdaymonth = ' ...
            'crT_cpgn_minhrdaymonth;']);
            % [deg C]
            % Every minute over time period
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
            %   [Min*Hr*Day_PASCAL*Month_PASCAL]
        eval([crT_name_MATLAB '_cpgn_daymonth_minhr = ' ...
            'crT_cpgn_daymonth_minhr;']);
            % [deg C]
            % Every minute per day over time period
            % [Day_ACLOUD*Month_ACLOUD; Min*Hr] / 
            %   [Day_PASCAL*Month_PASCA; Min*Hr]
        eval([crT_name_MATLAB '_cpgn_daymonth = ' ...
            'crT_cpgn_daymonth;']);
            % [deg C]
            % Daily averaged daily over time period
            % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
            
        % Rename current chosen parameter climatology variables
        if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
            % Daily averaged annually over time period
            eval([crT_name_MATLAB '_clim_mean_daymonth = ' ...
                'crT_clim_mean_daymonth;']);
                % [deg C], [Day_ACLOUD*Month_ACLOUD]
            
            % Daily standard-deviated annually over time period
            eval([crT_name_MATLAB '_clim_STD_daymonth = ' ...
                'crT_clim_STD_daymonth;']);
                % [deg C], [Day_ACLOUD*Month_ACLOUD]
        end
        
        %%% Delete data %%%
        % Delete unnecessary variable(s)
        if strcmp(crT_name_MATLAB,'T2m') % 2-m temperature data
            clear(crT_store_t_name{:},...
                crT_store_cpgn_name{:},crT_store_clim_name{:})
        else % Other pressure data
            clear(crT_store_t_name{:},crT_store_cpgn_name{:})
        end
        
        % Delete current chosen parameter data
        clear crT_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars p T_*
else % T data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear T_name_all T_indx_all
end
%%
%%%%% humid data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
humid_name_all = param_name(10+1,5); % Name(s)
humid_indx_all = find(strcmp(param_name(2:end,5),humid_name_all(1)));
    % Index(es)

% Load humid data only if chosen
if sum(ismember(humid_indx_all,param_indx)) > 0 % humid data chosen
    %%% Basic parameter settings %%%
    % Set campaign time step names
    humid_tstep_cpgn_abbr = char(tint_name(1+1,3+1)); % Abbreviated
    humid_tstep_cpgn_full = char(tint_name(2+1,3+1)); % Full
    
    % Set climatology time step names
    if cell2mat(strfind(humid_name_all,'IWV')) > 0
            % Integrated water vapor data included
        humid_tstep_clim_abbr = char(tint_name(1+1,4+1)); % Abbreviated
        humid_tstep_clim_full = char(tint_name(2+1,4+1)); % Full
    end
    
    % Set data set names
    if length(stat_indx) == 1 % One station
        if strcmp(stat_abbr,'NAa') % Ny-Ålesund data
            humid_set_file = mod_name(1+1,2); % File
            humid_set_MATLAB = mod_name(1+1,3); % MATLAB
            humid_set_tper = mod_name(1+1,6); % Time period
        elseif strcmp(stat_abbr,'PS') % Polarstern data
            humid_set_file = mod_name(3+1,2); % File
            humid_set_MATLAB = mod_name(3+1,3); % MATLAB
            humid_set_tper = mod_name(3+1,6); % Time period
        end
    elseif length(stat_indx) == 2 % Two stations
        humid_set_file = mod_name([1+1 3+1],2); % File
        humid_set_MATLAB = mod_name([1+1 3+1],3); % MATLAB
        humid_set_tper = mod_name([1+1 3+1],6); % Time period
    end
    
    % Calculate data set number
    humid_set_no = length(stat_indx);
    
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    humid_name_chos = humid_name_all(ismember(humid_indx_all,param_indx));
        % Name(s)
    humid_indx_chos = humid_indx_all(ismember(humid_indx_all,param_indx));
        % Index(es)
    humid_no_chos = length(humid_indx_chos); % Number
    
    % Loop over data sets and load humid data
    for s = 1:humid_set_no % Loop over number of data sets
        %%% Data set names %%%
        % Extract current data set names
        crset_humid_file = char(humid_set_file(s)); % File
        crset_humid_MATLAB = char(humid_set_MATLAB(s)); % MATLAB
        crset_humid_tper = char(humid_set_tper(s)); % Time period
        
        %%% Station names %%%
        % Extract current data set station abbreviated name
        if strcmp(crset_humid_MATLAB,'AWIPEV') % AWIPEV data
            crset_humid_stat = char(stat_name(1+1,2));
        elseif strcmp(crset_humid_MATLAB,'AWI') % AWI data
            crset_humid_stat = char(stat_name(2+1,2));
        end
        
        % Loop over chosen humid variables and load humid data
        for p = 1:humid_no_chos
                % Loop over number of chosen humid parameters
            %%% Parameter and data set names %%%
            % Extract current chosen parameter names
            crhumid_name_gen = char(param_name(humid_indx_chos(p)+1,2));
                % General
            crhumid_name_file = char(param_name(humid_indx_chos(p)+1,3));
                % File
            crhumid_name_data = char(param_name(humid_indx_chos(p)+1,4));
                % Data
            crhumid_name_MATLAB = ...
                char(param_name(humid_indx_chos(p)+1,5));
                % MATLAB
            crhumid_name_full = char(param_name(humid_indx_chos(p)+1,6));
                % Full
            
            % Extract current chosen parameter unit
            crhumid_unit = char(param_name(humid_indx_chos(p)+1,7));
            
            % Extract current data set current chosen parameter campaign 
            % boundary dates
            if strcmp(crset_humid_MATLAB,'AWIPEV') % AWIPEV data
                % Start
                crset_crhumid_date_yrmonthday_srt = ...
                    char(param_name(humid_indx_chos(p)+1,8));
                
                % End
                crset_crhumid_date_yrmonthday_end = ...
                    char(param_name(humid_indx_chos(p)+1,9));
            elseif strcmp(crset_humid_MATLAB,'AWI') % AWI data
                % Start
                crset_crhumid_date_yrmonthday_srt = ...
                    tper_PASCAL_num(1:8);
                
                % End
                crset_crhumid_date_yrmonthday_end = ...
                    tper_PASCAL_num(10:end);
            end
            
            % Extract current data set current chosen parameter climatology
            % boundary years
            if strcmp(crset_humid_MATLAB,'AWIPEV') % AWIPEV data
                % Start
                crset_crhumid_date_yr_srt = ...
                    crset_humid_tper(1:strfind(crset_humid_tper,'-')-1);
                
                % End
                % NB! Exclude campaign year
                crset_crhumid_date_yr_end = ...
                    num2str(str2double(crset_humid_tper(strfind(crset_humid_tper,'-')+1:end)) - 1);
            end
            
            % Set current chosen parameter storage path and file names
            crhumid_store_path = path_store; % Path
            crhumid_store_file = ...
                [crhumid_name_MATLAB '_' crset_humid_stat '_' ...
                month_ACLOUD_abbr '_' yr_name '_' crset_humid_MATLAB ...
                '.mat'];
                % File
            
            % Display current data set current chosen parameter loading 
            % conditions
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: Loading ' ...
                crhumid_name_MATLAB ' data from the ' ...
                crset_humid_MATLAB ' data set'])
            
            %%% Variables in storage file %%%
            % Set current data set current chosen parameter time variables 
            % names
            crset_crhumid_store_t_name = ...
                [{[crhumid_name_MATLAB '_date_6hrdaymonth_' crset_humid_MATLAB]}; ...
                {[crhumid_name_MATLAB '_date_daymonth_' crset_humid_MATLAB]}];
                % [6-hourly date matrix; ...
                %  Daily date matrix]
            
            % Set current data set current chosen parameter campaign 
            % variable names
            crset_crhumid_store_cpgn_name = ...
                [{[crhumid_name_MATLAB '_cpgn_6hrdaymonth_' crset_humid_MATLAB]}; ...
                {[crhumid_name_MATLAB '_cpgn_daymonth_6hr_' crset_humid_MATLAB]}; ...
                {[crhumid_name_MATLAB '_cpgn_daymonth_' crset_humid_MATLAB]}];
                % [6-hourly over time period; ...
                %  6-hourly per day over time period; ...
                %  Daily averaged daily over time period]
            
            % Set current data set current chosen parameter climatology 
            % variable names
            if strcmp(crhumid_name_MATLAB,'IWV') && ...
                    strcmp(crset_humid_MATLAB,'AWIPEV')
                    % Integrated water vapor AWIPEV data
                crset_crhumid_store_clim_name = ...
                    [{[crhumid_name_MATLAB '_clim_mean_daymonth_' crset_humid_MATLAB]}; ...
                    {[crhumid_name_MATLAB '_clim_STD_daymonth_' crset_humid_MATLAB]}];
                    % [Daily averaged annually over time period; ...
                    %  Daily standard-deviated annually over time period]
            end
            
            %%% Variables to load from storage files %%%
            % Check existence of current data set current chosen parameter 
            % variable in storage file
            if exist([crhumid_store_path crhumid_store_file],'file')
                    % File existent
                % Find current chosen parameter file variable names
                crhumid_store_var_file = ...
                    whos('-file',[crhumid_store_path crhumid_store_file]);
                
                % Check existence of current data set current chosen 
                % parameter variables in storage file
                crset_crhumid_store_cpgn_exist = ...
                    ismember(crset_crhumid_store_cpgn_name,...
                    {crhumid_store_var_file.name});
                    % Campaign variables
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Climatology variables
                    crset_crhumid_store_clim_exist = ...
                        ismember(crset_crhumid_store_clim_name,...
                        {crhumid_store_var_file.name});
                elseif strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWI')
                        % Integrated water vapor AWIPEV data
                    % Climatology variables
                    % NB! Set to one even though no climatology variables 
                    %     exist
                    crset_crhumid_store_clim_exist = 1;
                end
            else % File non-existent
                % Set current data set current chosen parameter logical 
                % variable to zero
                crset_crhumid_store_cpgn_exist = 0; % Campaign variables
                crset_crhumid_store_clim_exist = 0; % Climatology variables
            end
            
            % Load current data set current chosen parameter data only if 
            % variables are non-existent
            if sum(crset_crhumid_store_cpgn_exist) == ...
                    length(crset_crhumid_store_cpgn_exist) && ...
                    sum(crset_crhumid_store_clim_exist) == ...
                    length(crset_crhumid_store_clim_exist)
                    % Variables existent
                disp('load_ACLOUD_AWIPEV_NMI_AWI: Existent variables:')
                disp(crset_crhumid_store_t_name)
                disp(crset_crhumid_store_cpgn_name)
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    disp(crset_crhumid_store_clim_name)
                end
                
                %%% Load data %%%
                % Load current data set current chosen parameter data from 
                % .mat file
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    load([crhumid_store_path crhumid_store_file],...
                        crset_crhumid_store_t_name{:},...
                        crset_crhumid_store_cpgn_name{:},...
                        crset_crhumid_store_clim_name{:})
                else % Other humidity data
                    load([crhumid_store_path crhumid_store_file],...
                        crset_crhumid_store_t_name{:},...
                        crset_crhumid_store_cpgn_name{:})
                end
                
                %%% Rename data %%%
                % Rename current data set current chosen parameter time 
                % variables
                crset_crhumid_date_6hrdaymonth = ...
                    eval(char(crset_crhumid_store_t_name(1)));
                    % 6-hourly date matrix
                    % [6hr*Day_ACLOUD*Month_ACLOUD;
                    %  Yr : Month : Day : Hr : Min : Sec] / 
                    %   [6hr*Day_PASCAL*Month_PASCAL;
                    %    Yr : Month : Day : Hr : Min : Sec]
                crset_crhumid_date_daymonth = ...
                    eval(char(crset_crhumid_store_t_name(2)));
                    % Daily date matrix
                    % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] / 
                    %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
                
                % Rename current data set current chosen parameter campaign
                % variables
                crset_crhumid_cpgn_6hrdaymonth = ...
                    eval(char(crset_crhumid_store_cpgn_name(1)));
                    % [kg/m^2]
                    % 6-hourly over time period
                    % [6hr*Day_ACLOUD*Month_ACLOUD] /
                    %   [6hr*Day_PASCAL*Month_PASCAL]
                crset_crhumid_cpgn_daymonth_6hr = ...
                    eval(char(crset_crhumid_store_cpgn_name(2)));
                    % [kg/m^2]
                    % 6-hourly per day over time period
                    % [Day_ACLOUD*Month_ACLOUD; 6hr] / 
                    %   [Day_PASCAL*Month_PASCAL; 6hr]
                crset_crhumid_cpgn_daymonth = ...
                    eval(char(crset_crhumid_store_cpgn_name(3)));
                    % [kg/m^2]
                    % Daily averaged daily over time period
                    % [Day_ACLOUD*Month_ACLOUD] / [Day_PASCAL*Month_PASCAL]
                
                % Rename current data set current chosen parameter 
                % climatology variables
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Daily averaged annually over time period
                    crset_crhumid_clim_mean_daymonth = ...
                        eval(char(crset_crhumid_store_clim_name(1)));
                        % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                    
                    % Daily standard-deviated annually over time period
                    crset_crhumid_clim_STD_daymonth = ...
                        eval(char(crset_crhumid_store_clim_name(2)));
                        % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                end
            else % File non-existent
                disp('load_ACLOUD_AWIPEV_NMI_AWI: Loading variables:')
                disp(crset_crhumid_store_t_name)
                disp(crset_crhumid_store_cpgn_name)
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    disp(crset_crhumid_store_clim_name)
                end
                
                %%% Load campaign data %%%
                % Set current data set current data set current chosen 
                % parameter loading path, file and data names
                crset_crhumid_load_path = ...
                    [path_data 'Observations/' ...
                    upper(humid_tstep_cpgn_full) '/'];
                    % Path
                if strcmp(crset_humid_MATLAB,'AWIPEV') % AWIPEV data
                    % File
                    crset_crhumid_load_file = ...
                        [crset_humid_file '_' crhumid_name_file '_' ...
                        crset_humid_stat '_' humid_tstep_cpgn_full '_' ...
                        crset_crhumid_date_yrmonthday_srt '-' ...
                        crset_crhumid_date_yrmonthday_end '.mat'];
                    
                    % Data
                    crset_crhumid_load_data = crhumid_name_data;
                elseif strcmp(crset_humid_MATLAB,'AWI') % AWI data
                    % File
                    crset_crhumid_load_file = ...
                        [crset_humid_file '_RAOBS_' ...
                        crset_humid_stat '_' humid_tstep_cpgn_full '_' ...
                        '<YYYYMMDD>_<HrMn>.txt'];
                    
                    % Data
                    crset_crhumid_load_data = ...
                        [{'Altitude'}; {'TTT'}; {'RH'}];
                end
                
                % Load current data set current chosen parameter time and 
                % campaign data
                if strcmp(crset_humid_MATLAB,'AWIPEV') % AWIPEV data
                    % Load time data
                    crset_crhumid_date_6hrdaymonth = ...
                        load(...
                        [crset_crhumid_load_path crset_crhumid_load_file],...
                        'sonde_launchtime');
                        % Structure format
                        % [1].mat
                    crset_crhumid_date_6hrdaymonth = ...
                        crset_crhumid_date_6hrdaymonth.sonde_launchtime;
                        % Vector format
                        % [6hr_All*Day_All*Month_All]
                    crset_crhumid_date_6hrdaymonth = ...
                        datevec(crset_crhumid_date_6hrdaymonth);
                        % Matrix format
                        % [6hr_All*Day_All*Month_All; ...
                        %  Yr : Month : Day : Hr : Min : Sec]
                    
                    % Load campaign data
                    crset_crhumid_cpgn_6hrdaymonth = ...
                        load(...
                        [crset_crhumid_load_path crset_crhumid_load_file],...
                        crset_crhumid_load_data);
                        % [kg/m^2], structure format
                        % [1].mat
                    crset_crhumid_cpgn_6hrdaymonth = ...
                        eval(['crset_crhumid_cpgn_6hrdaymonth.' crset_crhumid_load_data ';']);
                        % [kg/m^2], vector format
                        % [6hr_All*Day_All*Month_All]
                    
                    % Replace negative (missing) values by NaN
                    crset_crhumid_cpgn_6hrdaymonth(crset_crhumid_cpgn_6hrdaymonth < 0) = ...
                        NaN;
                        % [kg/m^2], [6hr_All*Day_All*Month_All]
                    
                    % Rearrange campaign data from horizontal to vertical 
                    % vector
                    crset_crhumid_cpgn_6hrdaymonth = ...
                        crset_crhumid_cpgn_6hrdaymonth';
                        % [kg/m^2], [6hr_All*Day_All*Month_All]
                elseif strcmp(crset_humid_MATLAB,'AWI') % AWI data
                    % Set loading format
                    crset_crhumid_load_frmt = '%f %f %f %f %f %f';
                    
                    % Set loading time intervals
                    crset_crhumid_load_tint = ...
                        [0000 0600 1200 1800; 0559 1159 1759 2359];
                    
                    % Set loading dummy variables
                    crset_crhumid_date_6hrdaymonth = ...
                        NaN(day_PASCAL_no*hr_no,6);
                        % 6-hourly date matrix
                    crset_crhumid_cpgn_6hrdaymonth = ...
                        NaN(day_PASCAL_no*hr_no,1);
                        % 6-hourly campaign data over time period
                    
                    % Loop over time period days and load campaign data
                    for d = 1:day_PASCAL_no
                            % Loop over number of time period days
                        % Extract current time period day name
                        crday_name = ...
                            datestr(datenum(tper_PASCAL_txt(1:11)) + d - 1,...
                            'yyyymmdd');
                        
                        % Extract current time period month and day indexes
                        crday_indx_month = str2double(crday_name(5:6));
                            % Month
                        crday_indx_day = str2double(crday_name(7:8));
                            % Day
                        
                        % Find current time period day loading file names
                        crset_crhumid_crday_load_file = ...
                            ls([crset_crhumid_load_path ...
                            crset_crhumid_load_file(1:21) crday_name '_*']);
                        
                        % Find current time period day loading file indexes
                        crset_crhumid_crday_load_indx = ...
                            strfind(crset_crhumid_crday_load_file,'.txt');
                        
                        % Find current time period day loading file number
                        crset_crhumid_crday_load_no = ...
                            length(crset_crhumid_crday_load_indx);
                        
                        % Loop over time period 6-hours and load campaign 
                        % data
                        for h = 1:crset_crhumid_crday_load_no
                                % Loop over number of current time period 
                                % day 6-hours
                            % Extract current time period day current 
                            % 6-hour data file name
                            crset_crhumid_crday_crhr_load_file = ...
                                crset_crhumid_crday_load_file(...
                                (length(crset_crhumid_crday_load_file)/...
                                crset_crhumid_crday_load_no)*(h-1)+1:...
                                (length(crset_crhumid_crday_load_file)/...
                                crset_crhumid_crday_load_no)*h-1);
                            
                            % Extract current time period day current 
                            % 6-hour hours and minutes
                            crset_crhumid_crday_crhr_hrmin = ...
                                crset_crhumid_crday_crhr_load_file(end-4-3:end-4);
                                % [HrMin]
                                
                            % Find current time period day current 6-hour 
                            % time interval index
                            crset_crhumid_crday_crhr_tint_indx = ...
                                find(...
                                crset_crhumid_load_tint >= ...
                                str2double(crset_crhumid_crday_crhr_hrmin),...
                                1,'first')/2;
                            
                            % Store current time period day current 6-hour 
                            % time data in a 6-hourly date matrix
                            crset_crhumid_date_6hrdaymonth(...
                                (d-1)*hr_no+crset_crhumid_crday_crhr_tint_indx,:) = ...
                                [yr_vec crday_indx_month crday_indx_day ...
                                str2double(crset_crhumid_crday_crhr_hrmin(1:2)) ...
                                str2double(crset_crhumid_crday_crhr_hrmin(3:4)) ...
                                0];
                                % [6hr*Day_PASCAL*Month_PASCAL; ...
                                %  Yr : Month : Day : Hr : Min : Sec]
                            
                            % Open, store content of and close current time
                            % period day current 6-hour file
                            crset_crhumid_crday_crhr_load_open = ...
                                fopen(crset_crhumid_crday_crhr_load_file,'r');
                                % Open file
                            crset_crhumid_crday_crhr_load_hdln = ...
                                textscan(crset_crhumid_crday_crhr_load_open,'%s',6*2);
                                % Store file headlines in cell matrix
                                % NB! Account for headline format, which 
                                %     contains units in square brackets for
                                %     all 6 variable parameters
                            crset_crhumid_crday_crhr_load_cont = ...
                                textscan(crset_crhumid_crday_crhr_load_open,...
                                crset_crhumid_load_frmt,...
                                'delimiter','\t','headerlines',1);
                                % Store file content in cell matrix
                            crset_crhumid_crday_crhr_load_clse = ...
                                fclose(crset_crhumid_crday_crhr_load_open);
                                % Close file
                            
                            % Extract current time period day current 
                            % 6-hour headerlines
                            crset_crhumid_crday_crhr_load_hdln = ...
                                crset_crhumid_crday_crhr_load_hdln{1,1};
                                % Vector format, including units
                            crset_crhumid_crday_crhr_load_hdln = ...
                                crset_crhumid_crday_crhr_load_hdln(1:2:end);
                                % Vector format, excluding units
                            
                            % Find campaign data indexes in current time 
                            % period day current 6-hour file
                            crset_crhumid_crday_crhr_load_cpgn_indx(1) = ...
                                find(strcmp(crset_crhumid_crday_crhr_load_hdln,...
                                char(crset_crhumid_load_data(1))));
                                % Height
                            crset_crhumid_crday_crhr_load_cpgn_indx(2) = ...
                                find(strcmp(crset_crhumid_crday_crhr_load_hdln,...
                                char(crset_crhumid_load_data(2))));
                                % Temperature
                            crset_crhumid_crday_crhr_load_cpgn_indx(3) = ...
                                find(strcmp(crset_crhumid_crday_crhr_load_hdln,...
                                char(crset_crhumid_load_data(3))));
                                % Relative humidity
                            
                            % Extract current time period day current 
                            % 6-hour campaign data
                            crset_crhumid_crday_crhr_load_cpgn_h = ...
                                crset_crhumid_crday_crhr_load_cont{1,...
                                crset_crhumid_crday_crhr_load_cpgn_indx(1)};
                                % [m], height
                            crset_crhumid_crday_crhr_load_cpgn_T = ...
                                crset_crhumid_crday_crhr_load_cont{1,...
                                crset_crhumid_crday_crhr_load_cpgn_indx(2)};
                                % [deg C], temperature
                            crset_crhumid_crday_crhr_load_cpgn_RH = ...
                                crset_crhumid_crday_crhr_load_cont{1,...
                                crset_crhumid_crday_crhr_load_cpgn_indx(3)};
                                % [%], relative humidity
                            
                            % Calculate current time period day current 
                            % 6-hour IWV data using IWV_calc.m
                            % NB! Temperature must be given in K
                            [crset_crhumid_crday_crhr_load_cpgn_IWV,~,~,~,~,~,~,~] = ...
                                IWV_calc(crset_crhumid_crday_crhr_load_cpgn_h,...
                                crset_crhumid_crday_crhr_load_cpgn_T+273.15,...
                                crset_crhumid_crday_crhr_load_cpgn_RH);
                                % [kg/m^2]
                                
                            % Store current time period day current 6-hour 
                            % campaign data in a 6-hourly vector
                            crset_crhumid_cpgn_6hrdaymonth(...
                                (d-1)*hr_no+crset_crhumid_crday_crhr_tint_indx,:) = ...
                                crset_crhumid_crday_crhr_load_cpgn_IWV;
                                % [kg/m^2]
                                % [6hr*Day_PASCAL*Month_PASCAL]
                                
                            % Delete current time period day current 6-hour
                            % data
                            clear crset_crhumid_crday_crhr_*
                        end
                        
                        % Delete current time period day data
                        clear h crset_crhumid_crday_* crday_*
                    end
                    
                    % Delete unnecessary variable(s)
                    clear d crset_crhumid_load_frmt
                end
                
                %%% Load climatology data %%%
                % Set current data set current chosen climatology parameter
                % loading path, file and data names
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Path
                    crset_crhumid_load_clim_path = ...
                        [path_data 'Observations/' ...
                        upper(humid_tstep_clim_full) '/'];
                    
                    % File
                    crset_crhumid_load_clim_file = ...
                        [crset_humid_file '_' crhumid_name_gen '_NAa_' ...
                        humid_tstep_clim_full '_JFMAMJJASOND_' ...
                        crset_crhumid_date_yr_srt '-' ...
                        crset_crhumid_date_yr_end '.mat'];
                    
                    % Data
                    crset_crhumid_load_clim_data = ...
                        [{'longtermIWV'}; {'longtermIWV_stdev'}];
                end
                
                % Load current data set current chosen climatology 
                % parameter mean and STD data
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Structure format
                    crset_crhumid_clim_mean_STD = ...
                        load([crset_crhumid_load_clim_path ...
                        crset_crhumid_load_clim_file],...
                        char(crset_crhumid_load_clim_data(1)),...
                        char(crset_crhumid_load_clim_data(2)));
                        % [kg/m^2], [1].mat
                    
                    % Vector format
                    crset_crhumid_clim_mean_daymonth = ...
                        eval(['crset_crhumid_clim_mean_STD.' ...
                        char(crset_crhumid_load_clim_data(1)) ';']);
                        % [kg/m^2], mean, [Day_All*Month_All]
                    crset_crhumid_clim_STD_daymonth = ...
                        eval(['crset_crhumid_clim_mean_STD.' ...
                        char(crset_crhumid_load_clim_data(2)) ';']);
                        % [kg/m^2], STD, [Day_All*Month_All]
                end
                
                % Rearrange current data set current chosen climatology 
                % parameter mean and STD data from horizontal to vertical
                % vectors
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Mean
                    crset_crhumid_clim_mean_daymonth = ...
                        crset_crhumid_clim_mean_daymonth';
                        % [kg/m^2], [Day_All*Month_All]
                    
                    % STD
                    crset_crhumid_clim_STD_daymonth = ...
                        crset_crhumid_clim_STD_daymonth';
                        % [kg/m^2], [Day_All*Month_All]
                end
                
                % Replace current data set current chosen climatology 
                % parameter negative (missing) values by NaN
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Mean
                    crset_crhumid_clim_mean_daymonth(...
                        crset_crhumid_clim_mean_daymonth < 0) = ...
                        NaN;
                        % [kg/m^2], [Day_All*Month_All]
                    
                    % STD
                    crset_crhumid_clim_STD_daymonth(...
                    crset_crhumid_clim_STD_daymonth < 0) = ...
                        NaN;
                        % [kg/m^2], [Day_All*Month_All]
                end
                
                % Delete unnecessary variable(s)
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    clear crset_crhumid_cpgn_var ...
                        crset_crhumid_clim_mean_STD
                end
                
                %%% Find boundary data %%%
                disp(['load_ACLOUD_AWIPEV_NMI_AWI: Extracting ' ...
                    crset_humid_MATLAB ' ' crhumid_name_MATLAB ...
                    ' data over chosen time period'])
                
                % Find current data set current chosen parameter chosen 
                % time period boundary indexes in campaign data
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Start
                    crset_crhumid_date_6hrdaymonth_srt = ...
                        find(datenum(crset_crhumid_date_6hrdaymonth(:,1:3)) == ...
                        datenum(tper_ACLOUD_num(1:8),'yyyymmdd'),1,'first');
                    
                    % End
                    crset_crhumid_date_6hrdaymonth_end = ...
                        find(datenum(crset_crhumid_date_6hrdaymonth(:,1:3)) == ...
                        datenum(tper_ACLOUD_num(10:end),'yyyymmdd'),1,'last');
                end
                
                % Merge current data set current chosen campaign parameter 
                % chosen time period boundary indexes
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    crset_crhumid_date_6hrdaymonth_bnd = ...
                        [crset_crhumid_date_6hrdaymonth_srt ...
                        crset_crhumid_date_6hrdaymonth_end];
                        % [Start : End]
                end
                
                % Rename current data set current chosen climatology 
                % parameter chosen time period boundary indexes
                % NB! Subtract 1 day as the climatology data is set for
                %     leap-years
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    crset_crhumid_date_daymonth_bnd = day_ACLOUD_bnd - 1;
                        % [Start : End]
                elseif strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWI')
                        % Integrated water vapor AWI data
                    crset_crhumid_date_daymonth_bnd = day_PASCAL_bnd - 1;
                        % [Start : End]
                end
                
                % Delete unnecessary variable(s)
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    clear crset_crhumid_date_6hrdaymonth_srt ...
                        crset_crhumid_date_6hrdaymonth_end
                end
                
                %%% Extract data %%%
                % Extract current data set current chosen parameter 
                % 6-hourly time data over chosen time period
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    crset_crhumid_date_6hrdaymonth = ...
                        crset_crhumid_date_6hrdaymonth(...
                        crset_crhumid_date_6hrdaymonth_bnd(1):...
                        crset_crhumid_date_6hrdaymonth_bnd(2),:);
                        % [6hr*Day_ACLOUD*Month_ACLOUD;
                        %  Yr : Month : Day : Hr : Min : Sec]
                elseif strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWI')
                        % Integrated water vapor AWI data
                    disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                        crset_humid_MATLAB ' ' crhumid_name_MATLAB ...
                        ' data already given over chosen time period'])
                end
                
                % Find current data set current chosen parameter daily time
                % data step indexes over chosen time period
                [~,crset_crhumid_date_daymonth_indx,~] = ...
                    unique(datenum(crset_crhumid_date_6hrdaymonth(:,1:3)));
                
                % Extract current data set current chosen parameter daily 
                % time data over chosen time period
                if size(crset_crhumid_date_6hrdaymonth,1) == ...
                        hr_no*day_ACLOUD_no
                        % All 6-hourly data existent
                    crset_crhumid_date_daymonth = ...
                        crset_crhumid_date_6hrdaymonth(1:hr_no:end,1:3);
                        % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] /
                        %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
                else % Some 6-hourly data non-existent
                    crset_crhumid_date_daymonth = ...
                        crset_crhumid_date_6hrdaymonth(...
                        crset_crhumid_date_daymonth_indx,1:3);
                        % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] / 
                        %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
                end
                
                % Extract current data set current chosen parameter 
                % campaign data over chosen time period
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    crset_crhumid_cpgn_6hrdaymonth = ...
                        crset_crhumid_cpgn_6hrdaymonth(...
                        crset_crhumid_date_6hrdaymonth_bnd(1):...
                        crset_crhumid_date_6hrdaymonth_bnd(2));
                        % [kg/m^2], [6hr*Day_ACLOUD*Month_ACLOUD]
                elseif strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWI')
                        % Integrated water vapor AWI data
                    disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                        crset_humid_MATLAB ' ' crhumid_name_MATLAB ...
                        ' data already given over chosen time period'])
                end
                
                % Extract current data set current chosen parameter 
                % climatology mean and STD data over chosen time period
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Mean
                    crset_crhumid_clim_mean_daymonth = ...
                        crset_crhumid_clim_mean_daymonth(...
                        crset_crhumid_date_daymonth_bnd(1):...
                        crset_crhumid_date_daymonth_bnd(2));
                        % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                    
                    % STD
                    crset_crhumid_clim_STD_daymonth = ...
                        crset_crhumid_clim_STD_daymonth(...
                        crset_crhumid_date_daymonth_bnd(1):...
                        crset_crhumid_date_daymonth_bnd(2));
                        % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                end
                
                %%% Rearrange data %%%
                disp(['load_ACLOUD_AWIPEV_NMI_AWI: Rearranging ' ...
                    crset_humid_MATLAB ' ' crhumid_name_MATLAB ...
                    ' data over chosen time period'])
                
                % Rearrange current data set current chosen parameter 
                % campaign data from 1D to 2D
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    if size(crset_crhumid_date_6hrdaymonth,1) == ...
                            hr_no*day_ACLOUD_no
                            % All 6-hourly data existent
                        % 6-hourly per day over time period
                        crset_crhumid_cpgn_6hr_daymonth = ...
                            reshape(crset_crhumid_cpgn_6hrdaymonth,...
                            hr_no,day_ACLOUD_no);
                            % [kg/m^2], [6hr; Day_ACLOUD*Month_ACLOUD]
                        crset_crhumid_cpgn_daymonth_6hr = ...
                            permute(crset_crhumid_cpgn_6hr_daymonth,[2,1]);
                            % [kg/m^2], [Day_ACLOUD*Month_ACLOUD; 6hr]
                        
                        % Delete unnecessary variable(s)
                        clear crset_crhumid_cpgn_6hr_daymonth
                    else % Some 6-hourly data non-existent
                        % Set 6-hourly campaign data per day over time 
                        % period to dummy variable of desired format
                        crset_crhumid_cpgn_daymonth_6hr = ...
                            NaN(day_ACLOUD_no,hr_no);
                            % [Day_ACLOUD*Month_ACLOUD; 6hr]
                        
                        % Loop over time period days and add existing
                        % measurements to dummy variable
                        for d = 1:day_ACLOUD_no
                                % Loop over number of ACLOUD days
                            % Extract current time period day 6-hours 
                            % date(s)
                            if d < day_ACLOUD_no % 1st - 2nd last day
                                crset_crhumid_crdaymonth_date_6hr = ...
                                    crset_crhumid_date_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d):...
                                    crset_crhumid_date_daymonth_indx(d+1)-1,:);
                                    % [6hr_CrDayMonth; ...
                                    %  Yr : Month : Day : Hr : Min : Sec]
                            else % Last day
                                crset_crhumid_crdaymonth_date_6hr = ...
                                    crset_crhumid_date_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d):...
                                    crset_crhumid_date_daymonth_indx(end),:);
                                    % [6hr_CrDayMonth; ...
                                    %  Yr : Month : Day : Hr : Min : Sec]
                            end
                            
                            % Calculate number of current time period day
                            % 6-hours
                            crset_crhumid_crdaymonth_6hr_no = ...
                                size(crset_crhumid_crdaymonth_date_6hr,1);
                            
                            % Loop over current time period day 6-hours and
                            % add existing measurements to dummy variable
                            for h = 1:crset_crhumid_crdaymonth_6hr_no
                                    % Loop over number of current time 
                                    % period day 6-hours
                                % Find current time period day current 
                                % 6-hours date index(es)
                                % NB! Treating all measurements not
                                %     00, 06, 12 and 18 UTC as missing 
                                %     values
                                crset_crhumid_crdaymonth_cr6hr_date_indx = ...
                                    find(crset_crhumid_crdaymonth_date_6hr(h,4) == ...
                                    [5 11 17 23]);
                                    % [6hr_CrDayMonth]
                                
                                % Add existing current time period day 
                                % 6-hours measurements to dummy variable
                                crset_crhumid_cpgn_daymonth_6hr(d,...
                                    crset_crhumid_crdaymonth_cr6hr_date_indx) = ...
                                    crset_crhumid_cpgn_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d)+h-1);
                                    % [kg/m^2]
                                    % [Day_ACLOUD*Month_ACLOUD; 6hr]
                                
                                % Delete current time period day current
                                % 6-hours data
                                clear crset_crhumid_crdaymonth_cr6hr_*
                            end
                            
                            % Delete current time period day data
                            clear h crset_crhumid_crdaymonth_*
                        end
                        
                        % Delete unnecessary variable(s)
                        clear d
                    end
                elseif strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWI')
                        % Integrated water vapor AWI data
                    if size(crset_crhumid_date_6hrdaymonth,1) == ...
                            hr_no*day_PASCAL_no
                            % All 6-hourly data existent
                        % 6-hourly per day over time period
                        crset_crhumid_cpgn_6hr_daymonth = ...
                            reshape(crset_crhumid_cpgn_6hrdaymonth,...
                            hr_no,day_PASCAL_no);
                            % [kg/m^2], [6hr; Day_PASCAL*Month_PASCAL]
                        crset_crhumid_cpgn_daymonth_6hr = ...
                            permute(crset_crhumid_cpgn_6hr_daymonth,[2,1]);
                            % [kg/m^2], [Day_PASCAL*Month_PASCAL; 6hr]
                        
                        % Delete unnecessary variable(s)
                        clear crset_crhumid_cpgn_6hr_daymonth
                    else % Some 6-hourly data non-existent
                        % Set 6-hourly campaign data per day over time 
                        % period to dummy variable of desired format
                        crset_crhumid_cpgn_daymonth_6hr = ...
                            NaN(day_PASCAL_no,hr_no);
                            % [Day_PASCAL*Month_PASCAL; 6hr]
                        
                        % Loop over time period days and add existing
                        % measurements to dummy variable
                        for d = 1:day_PASCAL_no
                                % Loop over number of PASCAL days
                            % Extract current time period day 6-hours 
                            % date(s)
                            if d < day_PASCAL_no % 1st - 2nd last day
                                crset_crhumid_crdaymonth_date_6hr = ...
                                    crset_crhumid_date_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d):...
                                    crset_crhumid_date_daymonth_indx(d+1)-1,:);
                                    % [6hr_CrDayMonth; ...
                                    %  Yr : Month : Day : Hr : Min : Sec]
                            else % Last day
                                crset_crhumid_crdaymonth_date_6hr = ...
                                    crset_crhumid_date_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d):...
                                    crset_crhumid_date_daymonth_indx(end),:);
                                    % [6hr_CrDayMonth; ...
                                    %  Yr : Month : Day : Hr : Min : Sec]
                            end
                            
                            % Calculate number of current time period day
                            % 6-hours
                            crset_crhumid_crdaymonth_6hr_no = ...
                                size(crset_crhumid_crdaymonth_date_6hr,1);
                            
                            % Loop over current time period day 6-hours and
                            % add existing measurements to dummy variable
                            for h = 1:crset_crhumid_crdaymonth_6hr_no
                                    % Loop over number of current time 
                                    % period day 6-hours
                                % Find current time period day current 
                                % 6-hours date index(es)
                                % NB! Treating all measurements not
                                %     00, 06, 12 and 18 UTC as missing 
                                %     values
                                crset_crhumid_crdaymonth_cr6hr_date_indx = ...
                                    find(crset_crhumid_crdaymonth_date_6hr(h,4) == ...
                                    [5 11 17 23]);
                                    % [6hr_CrDayMonth]
                                
                                % Add existing current time period day 
                                % 6-hours measurements to dummy variable
                                crset_crhumid_cpgn_daymonth_6hr(d,...
                                    crset_crhumid_crdaymonth_cr6hr_date_indx) = ...
                                    crset_crhumid_cpgn_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d)+h-1);
                                    % [kg/m^2]
                                    % [Day_PASCAL*Month_PASCAL; 6hr]
                                
                                % Delete current time period day current
                                % 6-hours data
                                clear crset_crhumid_crdaymonth_cr6hr_*
                            end
                            
                            % Delete current time period day data
                            clear h crset_crhumid_crdaymonth_*
                        end
                        
                        % Delete unnecessary variable(s)
                        clear d
                    end
                end
                
                %%% Calculate data %%%
                disp(['load_ACLOUD_AWIPEV_NMI_AWI: Calculating ' ...
                    crset_humid_MATLAB ' ' crhumid_name_MATLAB ...
                    ' average data'])
                
                % Calculate current data set current chosen parameter daily
                % means over time period
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    if size(crset_crhumid_date_6hrdaymonth,1) == ...
                            hr_no*day_ACLOUD_no
                            % All 6-hourly data existent
                        % Calculate daily means over all 6-hours
                        crset_crhumid_cpgn_daymonth = ...
                            nanmean(crset_crhumid_cpgn_daymonth_6hr,2);
                            % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                    else % Some 6-hourly data non-existent
                        % Loop over time period days and calculate daily 
                        % means over existing 6-hours
                        % NB! Averaging over all measurements and not only
                        %     00, 06, 12 and 18 UTC measurements
                        for d = 1:day_ACLOUD_no
                                % Loop over number of ACLOUD days
                            if d < day_ACLOUD_no % 1st - 2nd last day
                                crset_crhumid_cpgn_daymonth(d,:) = ...
                                    nanmean(crset_crhumid_cpgn_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d):...
                                    crset_crhumid_date_daymonth_indx(d+1)-1));
                                    % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                            else % Last day
                                crset_crhumid_cpgn_daymonth(d,:) = ...
                                    nanmean(crset_crhumid_cpgn_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d):...
                                    crset_crhumid_date_daymonth_indx(end)));
                                    % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                            end
                        end
                        
                        % Delete unnecessary variable(s)
                        clear d
                    end
                elseif strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWI')
                        % Integrated water vapor AWI data
                    if size(crset_crhumid_date_6hrdaymonth,1) == ...
                            hr_no*day_PASCAL_no
                            % All 6-hourly data existent
                        % Calculate daily means over all 6-hours
                        crset_crhumid_cpgn_daymonth = ...
                            nanmean(crset_crhumid_cpgn_daymonth_6hr,2);
                            % [kg/m^2], [Day_PASCAL*Month_PASCAL]
                    else % Some 6-hourly data non-existent
                        % Loop over time period days and calculate daily 
                        % means over existing 6-hours
                        % NB! Averaging over all measurements and not only
                        %     00, 06, 12 and 18 UTC measurements
                        for d = 1:day_PASCAL_no
                                % Loop over number of PASCAL days
                            if d < day_ACLOUD_no % 1st - 2nd last day
                                crset_crhumid_cpgn_daymonth(d,:) = ...
                                    nanmean(crset_crhumid_cpgn_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d):...
                                    crset_crhumid_date_daymonth_indx(d+1)-1));
                                    % [kg/m^2], [Day_PASCAL*Month_PASCAL]
                            else % Last day
                                crset_crhumid_cpgn_daymonth(d,:) = ...
                                    nanmean(crset_crhumid_cpgn_6hrdaymonth(...
                                    crset_crhumid_date_daymonth_indx(d):...
                                    crset_crhumid_date_daymonth_indx(end)));
                                    % [kg/m^2], [Day_PASCAL*Month_PASCAL]
                            end
                        end
                        
                        % Delete unnecessary variable(s)
                        clear d
                    end
                end
                
                %%% Rename data %%%
                disp(['load_ACLOUD_AWIPEV_NMI_AWI: Renaming ' ...
                    crset_humid_MATLAB ' ' crhumid_name_MATLAB ' data'])
                
                % Rename current data set current chosen parameter time 
                % variables
                eval([char(crset_crhumid_store_t_name(1)) ' = ' ...
                    'crset_crhumid_date_6hrdaymonth;'])
                    % 6-hourly date matrix
                    % [6hr*Day_ACLOUD*Month_ACLOUD;
                    %  Yr : Month : Day : Hr : Min : Sec] / 
                    %   [6hr*Day_PASCAL*Month_PASCAL;
                    %    Yr : Month : Day : Hr : Min : Sec]
                eval([char(crset_crhumid_store_t_name(2)) ' = ' ...
                    'crset_crhumid_date_daymonth;'])
                    % Daily date matrix
                    % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] /
                    %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
                
                % Rename current data set current chosen parameter campaign
                % variables
                eval([char(crset_crhumid_store_cpgn_name(1)) ' = ' ...
                    'crset_crhumid_cpgn_6hrdaymonth;']);
                    % [kg/m^2]
                    % 6-hourly over time period
                    % [6hr*Day_ACLOUD*Month_ACLOUD] /
                    %   [6hr*Day_PASCAL*Month_PASCAL]
                eval([char(crset_crhumid_store_cpgn_name(2)) ' = ' ...
                    'crset_crhumid_cpgn_daymonth_6hr;']);
                    % [kg/m^2]
                    % 6-hourly per day over time period
                    % [Day_ACLOUD*Month_ACLOUD; 6hr] /
                    %   [Day_PASCAL*Month_PASCAL; 6hr]
                eval([char(crset_crhumid_store_cpgn_name(3)) ' = ' ...
                    'crset_crhumid_cpgn_daymonth;']);
                    % [kg/m^2]
                    % Daily averaged daily over time period
                    % [Day_ACLOUD*Month_ACLOUD] /
                    %   [Day_PASCAL*Month_PASCAL]
                
                % Rename current data set current chosen parameter 
                % climatology variables
                if strcmp(crhumid_name_MATLAB,'IWV') && ...
                        strcmp(crset_humid_MATLAB,'AWIPEV')
                        % Integrated water vapor AWIPEV data
                    % Daily averaged annually over time period
                    eval([char(crset_crhumid_store_clim_name(1)) ' = ' ...
                        'crset_crhumid_clim_mean_daymonth;']);
                        % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                    
                    % Daily standard-deviated annually over time period
                    eval([char(crset_crhumid_store_clim_name(2)) ' = ' ...
                        'crset_crhumid_clim_STD_daymonth;']);
                        % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                end
                
                %%% Store data %%%
                % Store current data set current chosen parameter time and 
                % campaign data
                disp(['load_ACLOUD_AWIPEV_NMI_AWI: Storing ' ...
                    crset_humid_MATLAB ' ' crhumid_name_MATLAB ' data'])
                save([crhumid_store_path crhumid_store_file],...
                    [crhumid_name_MATLAB '_*_' crset_humid_MATLAB])
                    % Store time and campaign variables
            end
            
            %%% Rename data %%%
            % Rename current data set current chosen parameter time 
            % variables
            eval([crhumid_name_MATLAB '_date_6hrdaymonth_' crset_humid_stat ' = ' ...
                'crset_crhumid_date_6hrdaymonth;'])
                % 6-hourly date matrix
                % [6hr*Day_ACLOUD*Month_ACLOUD;
                %  Yr : Month : Day : Hr : Min : Sec] /
                %   [6hr*Day_PASCAL*Month_PASCAL;
                %    Yr : Month : Day : Hr : Min : Sec]
            eval([crhumid_name_MATLAB '_date_daymonth_' crset_humid_stat ' = ' ...
                'crset_crhumid_date_daymonth;'])
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day] /
                %   [Day_PASCAL*Month_PASCAL; Yr : Month : Day]
            
            % Rename current data set current chosen parameter campaign 
            % variables
            eval([crhumid_name_MATLAB '_cpgn_6hrdaymonth_' crset_humid_stat ' = ' ...
                'crset_crhumid_cpgn_6hrdaymonth;']);
                % [kg/m^2]
                % 6-hourly over time period
                % [6hr*Day_ACLOUD*Month_ACLOUD] / 
                %   [6hr*Day_PASCAL*Month_PASCAL]
            eval([crhumid_name_MATLAB '_cpgn_daymonth_6hr_' crset_humid_stat ' = ' ...
                'crset_crhumid_cpgn_daymonth_6hr;']);
                % [kg/m^2]
                % 6-hourly per day over time period
                % [Day_ACLOUD*Month_ACLOUD; 6hr] /
                %   [Day_PASCAL*Month_PASCAL; 6hr]
            eval([crhumid_name_MATLAB '_cpgn_daymonth_' crset_humid_stat ' = ' ...
                'crset_crhumid_cpgn_daymonth;']);
                % [kg/m^2]
                % Daily averaged daily over time period
                % [Day_ACLOUD*Month_ACLOUD] /
                %   [Day_PASCAL*Month_PASCAL]
            
            % Rename current data set current chosen parameter climatology 
            % variables
            if strcmp(crhumid_name_MATLAB,'IWV') && ...
                    strcmp(crset_humid_MATLAB,'AWIPEV')
                    % Integrated water vapor AWIPEV data
                % Daily averaged annually over time period
                eval([crhumid_name_MATLAB '_clim_mean_daymonth_' crset_humid_stat ' = ' ...
                    'crset_crhumid_clim_mean_daymonth;']);
                    % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
                
                % Daily standard-deviated annually over time period
                eval([crhumid_name_MATLAB '_clim_STD_daymonth_' crset_humid_stat ' = ' ...
                    'crset_crhumid_clim_STD_daymonth;']);
                    % [kg/m^2], [Day_ACLOUD*Month_ACLOUD]
            end
            
            %%% Delete data %%%
            % Delete unnecessary variable(s)
            if strcmp(crhumid_name_MATLAB,'IWV') && ...
                    strcmp(crset_humid_MATLAB,'AWIPEV')
                    % Integrated water vapor AWIPEV data
                clear(crset_crhumid_store_t_name{:},...
                    crset_crhumid_store_cpgn_name{:},...
                    crset_crhumid_store_clim_name{:})
            elseif strcmp(crhumid_name_MATLAB,'IWV') && ...
                    strcmp(crset_humid_MATLAB,'AWI')
                    % Integrated water vapor AWI data
                clear(crset_crhumid_store_t_name{:},...
                    crset_crhumid_store_cpgn_name{:})
            end
        
            % Delete current data set current chosen parameter data
            clear crset_crhumid_* crhumid_*
        end
        
        %%% Delete data %%%
        % Delete current data set data
        clear p crset_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars s humid_*
else % humid data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear humid_name_all humid_indx_all
end
%%
%%%%% P data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
P_name_all = param_name(11+1:13+1,5); % Name(s)
P_indx_all = ...
    [find(strcmp(param_name(2:end,5),P_name_all(1))) ...
    find(strcmp(param_name(2:end,5),P_name_all(2))) ...
    find(strcmp(param_name(2:end,5),P_name_all(3)))];
    % Index(es)

% Load P data only if chosen
if sum(ismember(P_indx_all,param_indx)) > 0 % P data chosen
    %%% Basic parameter settings %%%
    % Set time step names
    P_tstep_abbr = char(tint_name(1+1,4+1)); % Abbreviated
    P_tstep_full = char(tint_name(2+1,4+1)); % Full
    
    % Set data set names
    P_set_file = char(mod_name(2+1,2)); % File
    P_set_MATLAB = char(mod_name(2+1,3)); % MATLAB
    P_set_tper = char(mod_name(2+1,6)); % Time period
    
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    P_name_chos = P_name_all(ismember(P_indx_all,param_indx)); % Name(s)
    P_indx_chos = P_indx_all(ismember(P_indx_all,param_indx)); % Index(es)
    P_no_chos = length(P_indx_chos); % Number
    
    % Loop over chosen P variables and load P data
    for p = 1:P_no_chos % Loop over number of chosen P parameters
        %%% Parameter and data set names %%%
        % Extract current chosen parameter names
        crP_name_gen = char(param_name(P_indx_chos(p)+1,2));
            % General
        crP_name_file = char(param_name(P_indx_chos(p)+1,3));
            % File
        crP_name_data = char(param_name(P_indx_chos(p)+1,4));
            % Data
        crP_name_MATLAB = char(param_name(P_indx_chos(p)+1,5));
            % MATLAB
        crP_name_full = char(param_name(P_indx_chos(p)+1,6));
            % Full
            
        % Extract current chosen parameter unit
        crP_unit = char(param_name(P_indx_chos(p)+1,7));
        
        % Extract current chosen parameter campaign boundary dates
        crP_date_yrmonthday_srt = ...
            char(param_name(P_indx_chos(p)+1,8));
            % Start
        crP_date_yrmonthday_end = ...
            char(param_name(P_indx_chos(p)+1,9));
            % End
            
        % Extract current chosen parameter climatology boundary years
        crP_date_yr_srt = P_set_tper(1:strfind(P_set_tper,'-')-1);
            % Start
        crP_date_yr_end = ...
            num2str(str2double(P_set_tper(strfind(P_set_tper,'-')+1:end)) - 1);
            % End
            % NB! Exclude campaign year
        
        % Set current chosen parameter storage path and file names
        crP_store_path = path_store; % Path
        crP_store_file = ...
            [crP_name_MATLAB '_NAa_' ...
            month_ACLOUD_abbr '_' yr_name '_' P_set_MATLAB '.mat'];
            % File
            
        % Display current chosen parameter loading conditions
        disp(['load_ACLOUD_AWIPEV_NMI_AWI: Loading ' crP_name_MATLAB ...
            ' data from the ' P_set_MATLAB ' data set'])
        
        %%% Variables in storage file %%%
        % Set current chosen parameter time variables names
        crP_store_t_name = ...
            {[crP_name_MATLAB '_date_daymonth_' P_set_MATLAB]};
            % [Daily date matrix]
        
        % Set current chosen parameter campaign variable names
        crP_store_cpgn_name = ...
            {[crP_name_MATLAB '_cpgn_daymonth_' P_set_MATLAB]};
            % [Daily over time period]
        
        %%% Variables to load from storage files %%%
        % Check existence of current chosen parameter variable in storage 
        % file
        if exist([crP_store_path crP_store_file],'file')
                % File existent
            % Find current chosen parameter file variable names
            crP_store_var_file = ...
                whos('-file',[crP_store_path crP_store_file]);
            
            % Check existence of current chosen parameter variables in 
            % storage file
            crP_store_cpgn_exist = ...
                ismember(crP_store_cpgn_name,{crP_store_var_file.name});
                % Campaign variables
        else % File non-existent
            % Set current chosen parameter logical variable to zero
            crP_store_cpgn_exist = 0; % Campaign variables
        end
        
        % Load current chosen parameter data only if variables are 
        % non-existent
        if sum(crP_store_cpgn_exist) == length(crP_store_cpgn_exist)
                % Variables existent
            disp('load_ACLOUD_AWIPEV_NMI_AWI: Existent variables:')
            disp(crP_store_t_name)
            disp(crP_store_cpgn_name)
            
            %%% Load data %%%
            % Load current chosen parameter data from .mat file
            load([crP_store_path crP_store_file],...
                crP_store_t_name{:},crP_store_cpgn_name{:})
            
            %%% Rename data %%%
            % Rename current chosen parameter time variables
            crP_date_daymonth = eval(char(crP_store_t_name(1)));
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            
            % Rename current chosen parameter campaign variables
            crP_cpgn_daymonth = eval(char(crP_store_cpgn_name(1)));
                % [mm] / [cm] / [1,4]
                % Daily over time period
                % [Day_ACLOUD*Month_ACLOUD]
        else % File non-existent
            disp('load_ACLOUD_AWIPEV_NMI_AWI: Loading variables:')
            disp(crP_store_t_name)
            disp(crP_store_cpgn_name)
            
            %%% Load data %%%
            % Set current chosen parameter loading path, file and data 
            % names
            crP_load_path = ...
                [path_data 'Observations/' upper(P_tstep_full) '/'];
                % Path
            crP_load_file = ...
                [P_set_file '_' crP_name_file '_NAa_' ...
                P_tstep_full '_' month_ACLOUD_abbr '_' yr_name '.txt'];
                % File
            crP_load_data = crP_name_data;
                % Data
                
            % Set current chosen parameter loading format
            crP_load_frmt = '%d %d %d %f %f %f';
            
            % Open, store content and close current chosen parameter file
            crP_load_open = fopen([crP_load_path crP_load_file],'r');
                % Open file
            crP_load_hdln = textscan(crP_load_open,'%s',6);
                % Store file headlines in cell matrix
            crP_load_cont = ...
                textscan(crP_load_open,crP_load_frmt,...
                'delimiter','\t','headerlines',1);
            	% Store file content in cell matrix
            crP_load_clse = fclose(crP_load_open); % Close file
            
            % Extract current chosen parameter headerlines
            crP_hdln = permute(crP_load_hdln{1,1},[2,1]);
            
            % Find current chosen parameter time data indexes in file
            crP_load_indx = find(strcmp(crP_hdln,crP_load_data));
            
            % Extract current chosen parameter time data
            crP_date_daymonth = ...
                double([crP_load_cont{1,1} crP_load_cont{1,2} crP_load_cont{1,3}]);
                % Daily date matrix, [Day_All*Month_All; Yr : Month : Day]
                
            % Extract current chosen parameter campaign data
            crP_cpgn_daymonth = crP_load_cont{1,crP_load_indx};
                % [mm] / [cm] / [1,4], daily over time period
                % [Day_All*Month_All]
                
            % Replace current chosen parameter missing and negative values 
            % by NaN
            crP_cpgn_daymonth(crP_cpgn_daymonth == -9999) = NaN;
                % [mm] / [cm] / [1,4], missing values, [Day_All*Month_All]
            crP_cpgn_daymonth(crP_cpgn_daymonth < 0) = NaN;
                % [mm] / [cm] / [1,4], negative values, [Day_All*Month_All]
            
            % Delete unnecessary variable(s)
            clear crP_load_*
            
            %%% Find boundary data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Extracting ' P_set_MATLAB ' ' crP_name_MATLAB ...
                ' data over chosen time period'])
            
            % Find current chosen parameter chosen time period boundary 
            % indexes in campaign data
            crP_date_daymonth_srt = ...
                find(datenum(crP_date_daymonth) == ...
                datenum(tper_ACLOUD_num(1:8),'yyyymmdd'),1,'first');
                % Start
            crP_date_daymonth_end = ...
                find(datenum(crP_date_daymonth) == ...
                datenum(tper_ACLOUD_num(10:end),'yyyymmdd'),1,'last');
                % End
                
            % Merge current chosen campaign parameter chosen time period 
            % boundary indexes
            crP_date_daymonth_ACLOUD_bnd = ...
                [crP_date_daymonth_srt crP_date_daymonth_end];
                % [Start : End]
                
            % Delete unnecessary variable(s)
            clear crP_date_daymonth_srt crP_date_daymonth_end
            
            %%% Extract data %%%
            % Extract current chosen parameter daily time data over chosen 
            % time period
            crP_date_daymonth = ...
                crP_date_daymonth(...
                crP_date_daymonth_ACLOUD_bnd(1):crP_date_daymonth_ACLOUD_bnd(2),:);
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
                
            % Extract current chosen parameter campaign data over chosen 
            % time period
            crP_cpgn_daymonth = ...
                crP_cpgn_daymonth(...
                crP_date_daymonth_ACLOUD_bnd(1):crP_date_daymonth_ACLOUD_bnd(2));
                % [mm] / [cm] / [1,4], [Day_ACLOUD*Month_ACLOUD]
            
            %%% Rename data %%%
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Renaming ' P_set_MATLAB ' ' crP_name_MATLAB ' data'])
            
            % Rename current chosen parameter time variables
            eval([char(crP_store_t_name(1)) ' = crP_date_daymonth;'])
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            
            % Rename current chosen parameter campaign variables
            eval([char(crP_store_cpgn_name(1)) ' = crP_cpgn_daymonth;']);
                % [mm] / [cm] / [1,4]
                % Daily averaged daily over time period
                % [Day_ACLOUD*Month_ACLOUD]
            
            %%% Store data %%%
            % Store current chosen parameter time and campaign data
            disp(['load_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'Storing ' P_set_MATLAB ' ' crP_name_MATLAB ' data'])
            save([crP_store_path crP_store_file],...
                [crP_name_MATLAB '_*_' P_set_MATLAB])
                % Store time and campaign variables
        end
        
        %%% Rename data %%%
        % Rename current chosen parameter time variables
        eval([crP_name_MATLAB '_date_daymonth = crP_date_daymonth;'])
            % Daily date matrix
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        
        % Rename current chosen parameter campaign variables
        eval([crP_name_MATLAB '_cpgn_daymonth = crP_cpgn_daymonth;']);
            % [mm] / [cm] / [1,4]
            % Daily averaged daily over time period
            % [Day_ACLOUD*Month_ACLOUD]
        
        %%% Delete data %%%
        % Delete unnecessary variable(s)
        clear(crP_store_t_name{:},crP_store_cpgn_name{:})
        
        % Delete current chosen parameter data
        clear crP_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars('p','P_*','-except','P_date_daymonth','P_cpgn_daymonth')
else % P data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear P_name_all P_indx_all
end
%%
%%%%%%%% Plot data %%%%%%%%
%%%%% Atmospheric and surface data %%%%%
%%% Figure properties %%%
% Set number of open plots
plot_no = 0;

%%% Set variable properties %%%
% Set MATLAB name of figure type(s) to be plotted
plot_typename = [{'ts-pns_wnd850hPa'}];
    % 'tseries'          = Time series
    % 'ts-pns_wnd850hPa' = Time series of near-surface pressure with 
    %                      850-hPa wind direction and speed
    % 'ts-Tns_mlt'       = Time series of near-surface temperature with 
    %                      melt period
    % 'ts-IWV_P'         = Time series of integrated water vapor with 
    %                      precipitation

% Extract names, unit(s), index(es) and variable data of figure type(s) to 
% be plotted
plot_varname = [{'MATLAB name'} {'Title name'} {'Unit'}];
    % Headlines for variable name(s)
for t = 1:length(plot_typename) % Loop over number of plot types
    % Extract current plot type name
    crtype_name = char(plot_typename(t));
    
    % Extract current plot type variable names, unit(s) and data
    if strcmp(crtype_name,'tseries') % Time series
        disp('load_ACLOUD_AWIPEV_NMI_AWI: Time series chosen for plotting')
        
        %%% Set and calculate variable properties %%%
        % Loop over chosen parameters and extract current plot type MATLAB 
        % and title names and unit(s)
        for p = 1:param_no % Loop over number of chosen parameters
            plot_varname = ...
                [plot_varname; ...
                param_name(param_indx(p)+1,5) ...
                param_name(param_indx(p)+1,6) ...
                param_name(param_indx(p)+1,7)];
        end
        
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge time data %%%
        % Loop over chosen parameters and merge current plot type time data
        % in a structure
        for p = 1:param_no % Loop over number of chosen parameters
            % Extract current parameter names
            crparam_name_gen = char(param_name(param_indx(p)+1,2));
                % General
            crparam_name_MATLAB = char(param_name(param_indx(p)+1,5));
                % MATLAB
            
            % Merge current plot type current parameter campaign time data 
            % in a structure
            if strcmp(crparam_name_gen,'p') || strcmp(crparam_name_gen,'T')
                    % Pressure or temperature data
                % Every minute date matrix
                plot_t(plot_var_no+p,1).mat = ...
                    eval([crparam_name_MATLAB '_date_minhrdaymonth;']);
                    % [Min*Hr*Day_ACLOUD*Month_ACLOUD; 
                    %  Yr : Month : Day : Hr : Min : Sec] / 
                    %   [Min*Hr*Day_PASCAL*Month_PASCAL; 
                    %    Yr : Month : Day : Hr : Min : Sec]
            elseif strcmp(crparam_name_gen,'wind') || ...
                    strcmp(crparam_name_gen,'humid')
                    % Wind or humidity data
                % 6-hourly date matrix
                plot_t(plot_var_no+p,1).mat = ...
                    eval([crparam_name_MATLAB '_date_6hrdaymonth;']);
                    % [6hr*Day_ACLOUD*Month_ACLOUD; 
                    %  Yr : Month : Day : Hr : Min : Sec] /
                    %   [6hr*Day_PASCAL*Month_PASCAL; 
                    %    Yr : Month : Day : Hr : Min : Sec]
            elseif strcmp(crparam_name_gen,'P') % Precipiation data
                % Daily date matrix
                plot_t(plot_var_no+p,1).mat = ...
                    eval([crparam_name_MATLAB '_date_daymonth;']);
                    % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            end
            
            % Merge current plot type current parameter climatology time 
            % data in a structure
            if strcmp(crparam_name_MATLAB,'ps') || ...
                    strcmp(crparam_name_MATLAB,'T2m') || ...
                    strcmp(crparam_name_MATLAB,'IWV')
                    % Surface pressure, 2-m temperature or integrated water 
                    % vapor data
                % Daily date matrix
                plot_t(plot_var_no+p,2).mat = ...
                    eval([crparam_name_MATLAB '_date_daymonth;']);
                    % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            end
        end
        
        %%% Merge variable data %%%
        % Loop over chosen parameters and merge current plot type variable  
        % data in a structure
        for p = 1:param_no % Loop over number of chosen parameters
            % Extract current parameter names
            crparam_name_gen = char(param_name(param_indx(p)+1,2));
                % General
            crparam_name_MATLAB = char(param_name(param_indx(p)+1,5));
                % MATLAB
            
            % Merge current plot type current parameter campaign variable 
            % data in a structure
            if strcmp(crparam_name_gen,'p') || strcmp(crparam_name_gen,'T')
                    % Pressure or temperature data
                % Every minute over time period
                plot_var(plot_var_no+p,1).mat = ...
                    eval([crparam_name_MATLAB '_cpgn_minhrdaymonth;']);
                    % [hPa] / [deg C]
                    % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
                    %   [Min*Hr*Day_PASCAL*Month_PASCAL]
            elseif strcmp(crparam_name_gen,'wind') || ...
                    strcmp(crparam_name_gen,'humid')
                    % Wind or humidity data
                % 6-hourly over time period
                plot_var(plot_var_no+p).mat = ...
                    eval([crparam_name_MATLAB '_cpgn_6hrdaymonth;']);
                    % [m/s] / [deg] / [kg/m^2]
                    % [6hr*Day_ACLOUD*Month_ACLOUD] /
                    %   [6hr*Day_PASCAL*Month_PASCAL]
            elseif strcmp(crparam_name_gen,'P') % Precipiation data
                % Daily over time period
                plot_var(plot_var_no+p).mat = ...
                    eval([crparam_name_MATLAB '_cpgn_daymonth;']);
                    % [mm] / [cm] / [1,4]
                    % [Day_ACLOUD*Month_ACLOUD]
            end
            
            % Merge current plot type current parameter climatology 
            % variable data in a structure
            if strcmp(crparam_name_MATLAB,'ps') || ...
                    strcmp(crparam_name_MATLAB,'T2m') || ...
                    strcmp(crparam_name_MATLAB,'IWV')
                    % Surface pressure, 2-m temperature or integrated water 
                    % vapor data
                % Daily averaged annually over time period
                plot_var(plot_var_no+p,2).mat = ...
                    eval([crparam_name_MATLAB '_clim_mean_daymonth;']);
                    % [hPa] / [deg C] / [kg/m^2]
                    % [Day_ACLOUD*Month_ACLOUD]
                    
                % Daily standard-deviated annually over time period
                plot_var(plot_var_no+p,3).mat = ...
                    eval([crparam_name_MATLAB '_clim_STD_daymonth;']);
                    % [hPa] / [deg C] / [kg/m^2]
                    % [Day_ACLOUD*Month_ACLOUD]
            end
            
            % Delete current parameter data
            clear crparam_*
        end
    elseif strcmp(crtype_name,'ts-pns_wnd850hPa')
            % Time series of near-surface pressure with 850-hPa wind 
            % direction and speed
        disp(['load_ACLOUD_AWIPEV_NMI_AWI: Time series of ' ...
            'near-surface pressure with 850-hPa wind chosen for plotting'])
        
        %%% Set, find and calculate variable properties %%%
        % Set current plot type parameter names
        crtype_paramname = ...
            [{'ps'}; {'p16m'}; {'wnddir850hPa'}; {'wndspd850hPa'}];
        
        % Calculate number of current plot type parameters
        crtype_paramno = length(crtype_paramname);
        
        % Loop over current plot type parameters and find parameter indexes
        for p = 1:crtype_paramno % Loop over current plot type parameters
            crtype_paramindx(p) = ...
                find(strcmp(param_name(2:end,5),...
                char(crtype_paramname(p))));
        end
        
        % Extract current plot type MATLAB and title names and unit(s)
        plot_varname = ...
            [plot_varname; ...
            param_name(crtype_paramindx+1,5) ...
            param_name(crtype_paramindx+1,6) ...
            param_name(crtype_paramindx+1,7)];
        
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge time data %%%
        % Merge current plot type time data in a structure
        plot_t(plot_var_no+1,1).mat = ps_date_minhrdaymonth;
            % Surface pressure campaign data - Every minute date matrix
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD; 
            %  Yr : Month : Day : Hr : Min : Sec]
        plot_t(plot_var_no+1,2).mat = ps_date_daymonth;
            % Surface pressure climatology data - Daily date matrix
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        plot_t(plot_var_no+1,3).mat = p16m_date_minhrdaymonth;
            % 16-m pressure campaign data - Every minute date matrix
            % [Min*Hr*Day_PASCAL*Month_PASCAL; 
            %  Yr : Month : Day : Hr : Min : Sec]
        plot_t(plot_var_no+1,4).mat = wnddir850hPa_date_daymonth;
            % 850-hPa wind campaign data - Daily date matrix
            % NB! Equal for direction and speed
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            
        %%% Merge variable data %%%
        % Merge current plot type variable data in a structure
        plot_var(plot_var_no+1,1).mat = ps_cpgn_minhrdaymonth;
            % [hPa]
            % Surface pressure campaign data -
            %   Every minute over time period
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,2).mat = ps_clim_mean_daymonth;
            % [hPa]
            % Surface pressure climatology data -
            %   Daily averaged annually over time period
            % [Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,3).mat = ps_clim_STD_daymonth;
            % [hPa]
            % Surface pressure climatology data -
            %   Daily standard-deviated annually over time period
            % [Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,4).mat = p16m_cpgn_minhrdaymonth;
            % [hPa]
            % 16-m pressure campaign data -
            %   Every minute over time period
            % [Min*Hr*Day_PASCAL*Month_PASCAL]
        plot_var(plot_var_no+1,5).mat = wnddir850hPa_cpgn_daymonth;
            % [deg]
            % 850-hPa wind direction campaign data -
            %   Daily averaged daily over time period
            % [Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,6).mat = wndspd850hPa_cpgn_daymonth;
            % [m/s]
            % 850-hPa wind speed campaign data -
            %   Daily averaged daily over time period
            % [Day_ACLOUD*Month_ACLOUD]
    elseif strcmp(crtype_name,'ts-Tns_mlt')
            % Time series of near-surface temperature with melt season
        disp(['load_ACLOUD_AWIPEV_NMI_AWI: Time series of ' ...
            'near-surface temperature with melt season ' ...
            'chosen for plotting'])
        
        %%% Set, find and calculate variable properties %%%
        % Set current plot type parameter names
        crtype_paramname = [{'T2m'}; {'T29m'}];
        
        % Calculate number of current plot type parameters
        crtype_paramno = length(crtype_paramname);
        
        % Loop over current plot type parameters and find parameter indexes
        for p = 1:crtype_paramno % Loop over current plot type parameters
            crtype_paramindx(p) = ...
                find(strcmp(param_name(2:end,5),...
                char(crtype_paramname(p))));
        end
        
        % Extract current plot type MATLAB and title names and unit(s)
        plot_varname = ...
            [plot_varname; ...
            param_name(crtype_paramindx+1,5) ...
            param_name(crtype_paramindx+1,6) ...
            param_name(crtype_paramindx+1,7)];
        
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge time data %%%
        % Merge current plot type time data in a structure
        plot_t(plot_var_no+1,1).mat = T2m_date_minhrdaymonth;
            % 2-m temperature campaign data - Every minute date matrix
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD;
            %  Yr : Month : Day : Hr : Min : Sec]
        plot_t(plot_var_no+1,2).mat = T2m_date_daymonth;
            % 2-m temperature climatology data - Daily date matrix
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        plot_t(plot_var_no+1,3).mat = T29m_date_minhrdaymonth;
            % 29-m temperature campaign data - Every minute date matrix
            % [Min*Hr*Day_PASCAL*Month_PASCAL;
            %  Yr : Month : Day : Hr : Min : Sec]
        plot_t(plot_var_no+1,4).mat = [2017 5 29; 2017 6 14];
            % Melt period campaign data - Start and end dates matrix
            % [Start : End; Yr : Month : Day]
            
        %%% Merge variable data %%%
        % Merge current plot type variable data in a structure
        plot_var(plot_var_no+1,1).mat = T2m_cpgn_minhrdaymonth;
            % [deg C]
            % 2-m temperature campaign data -
            %   Every minute over time period
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,2).mat = T2m_clim_mean_daymonth;
            % [deg C]
            % 2-m temperature climatology data -
            %   Daily averaged annually over time period
            % [Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,3).mat = T2m_clim_STD_daymonth;
            % [deg C]
            % 2-m temperature climatology data -
            %   Daily standard-deviated annually over time period
            % [Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,4).mat = T29m_cpgn_minhrdaymonth;
            % [deg C]
            % 29-m temperature campaign data -
            %   Every minute over time period
            % [Min*Hr*Day_PASCAL*Month_PASCAL]
    elseif strcmp(crtype_name,'ts-IWV_P')
            % Time series of integrated water vapor with precipitation
        disp(['load_ACLOUD_AWIPEV_NMI_AWI: Time series of integrated ' ...
            'water vapor with precipitation chosen for plotting'])
        
        %%% Set and calculate variable properties %%%
        % Set current plot type parameter names
        crtype_paramname = [{'IWV'}; {'P'}];
        
        % Calculate number of current plot type parameters
        crtype_paramno = length(crtype_paramname);
        
        % Loop over current plot type parameters and find parameter indexes
        for p = 1:crtype_paramno % Loop over current plot type parameters
            crtype_paramindx(p) = ...
                find(strcmp(param_name(2:end,5),...
                char(crtype_paramname(p))));
        end
        
        % Extract current plot type MATLAB and title names and unit(s)
        plot_varname = ...
            [plot_varname; ...
            param_name(crtype_paramindx+1,5) ...
            param_name(crtype_paramindx+1,6) ...
            param_name(crtype_paramindx+1,7)];
        
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge time data %%%
        % Merge current plot type time data in a structure
        plot_t(plot_var_no+1,1).mat = IWV_date_6hrdaymonth_NAa;
            % Integrated water vapor ACLOUD campaign data -
            %   6-hourly date matrix
            % [6hr*Day_ACLOUD*Month_ACLOUD;
            %  Yr : Month : Day : Hr : Min : Sec]
        plot_t(plot_var_no+1,2).mat = IWV_date_daymonth_NAa;
            % Integrated water vapor ACLOUD climatology data -
            %   Daily date matrix
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        plot_t(plot_var_no+1,3).mat = IWV_date_6hrdaymonth_PS;
            % Integrated water vapor PASCAL campaign data -
            %   6-hourly date matrix
            % [6hr*Day_PASCAL*Month_PASCAL;
            %  Yr : Month : Day : Hr : Min : Sec]
        plot_t(plot_var_no+1,4).mat = P_date_daymonth;
            % Precipitation ACLOUD campaign data - 
            %   Daily date matrix
            % NB! Equal for direction and speed
            % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
            
        %%% Merge variable data %%%
        % Merge current plot type variable data in a structure
        plot_var(plot_var_no+1,1).mat = IWV_cpgn_6hrdaymonth_NAa;
            % [kg/m^2]
            % Integrated water vapor ACLOUD campaign data -
            %   6-hourly over time period
            % [6hr*Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,2).mat = IWV_clim_mean_daymonth_NAa;
            % [kg/m^2]
            % Integrated water vapor ACLOUD climatology data -
            %   Daily averaged annually over time period
            % [Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,3).mat = IWV_clim_STD_daymonth_NAa;
            % [kg/m^2]
            % Integrated water vapor ACLOUD climatology data -
            %   Daily standard-deviated annually over time period
            % [Day_ACLOUD*Month_ACLOUD]
        plot_var(plot_var_no+1,4).mat = IWV_cpgn_6hrdaymonth_PS;
            % [kg/m^2]
            % Integrated water vapor PASCAL campaign data -
            %   6-hourly over time period
            % [6hr*Day_PASCAL*Month_PASCAL]
        plot_var(plot_var_no+1,5).mat = P_cpgn_daymonth;
            % [mm]
            % Precipitation ACLOUD campaign data -
            %   Daily over time period
            % [Day_ACLOUD*Month_ACLOUD]
    end
    
    % Delete current plot type data
    clear p crtype_*
end

% Delete unnecessary variable(s)
clear t plot_var_no
%%
%%% Plot variable data %%%
% Plotatmospheric and surface data using plot_ACLOUD_NMI.m
plot_ACLOUD_AWIPEV_NMI_AWI(path_fig,yr_name,...
    month_ACLOUD_abbr,day_ACLOUD_no,day_PASCAL_no,...
    mod_name,param_name,param_indx,param_no,...
    stat_abbr,stat_full,stat_tper,...
    plot_no,plot_typename,plot_varname,plot_t,plot_var)