function plot_ACLOUD_AWIPEV_NMI_AWI(path_fig,yr_name,...
    month_ACLOUD_abbr,day_ACLOUD_no,day_PASCAL_no,...
    mod_name,param_name,param_indx,param_no,...
    stat_abbr,stat_full,stat_tper,...
    plot_no,plot_typename,plot_varname,plot_t,plot_var)

% PURPOSE
% Plot and store every minute and 6-hourly atmospheric data from the 
% Alfred-Wegener-Institut (AWI) and the Institut polaire français 
% Paul-Émile-Victor (IPEV) merged research base (AWIPEV) and daily surface 
% data from the Norwegian Meteorological Institute (NMI) for Ny-Ålesund 
% (NAa) and 3-hourly atmospheric data from AWI for Polarstern (PS) over 
% chosen date and time interval in order to study the synoptic situation 
% during the Arctic CLoud Observations Using airborne measurements during 
% polar Day (ACLOUD) and Physical feedback of Arctic planetary boundary 
% layer, Sea ice, Cloud and AerosoL (PASCAL) field campaigns 
% May 23 - June 26 and June 6-16, 2017, respectively, on/near Spitsbergen.
%
% The data set choices are:
%   AWIPEV  : Alfred-Wegener-Institut/Paul-Émile-Victor
%   NMI     : Norwegian Meteorological Institute
%   AWI     : Alfred-Wegener-Institut
%
% The parameter choices are:
%   ps          : Surface pressure (p_{s}) - AWIPEV - Every minute
%   p16m        : 16-m pressure (p_{16m}) - AWI - 3-hourly
%   wnddir925hPa: 925-hPa wind direction (wnd_{dir,925hPa}) - AWIPEV - 
%                 6-hourly
%   wnddir850hPa: 850-hPa wind direction (wnd_{dir,850hPa}) - AWIPEV - 
%                 6-hourly
%   wndspd925hPa: 925-hPa wind speed (wnd_{spd,925hPa}) - AWIPEV - 6-hourly
%   wndspd850hPa: 850-hPa wind speed (wnd_{spd,850hPa}) - AWIPEV - 6-hourly
%   T2m         : 2-m temperature (T_{2m}) - AWIPEV - Every minute
%   T10m        : 10-m temperature (T_{10m}) - AWIPEV - Every minute
%   T29m        : 29-m temperature (T_{29m}) - AWI - 3-hourly
%   IWV         : Integrated water vapor - AWIPEV - 6-hourly
%   P           : Precipitation - NMI - Daily
%   snwdpt      : Snow depth (snw_{dpt}) - NMI - Daily
%   snwcvr      : Snow cover (snw_{cvr}) - NMI - Daily
%
% The region choices are:
%   Spb : Spitsbergen
%
% The station choices are:
%   99910   : Ny-Ålesund (1993-2017 for AWIPEV, 1975-2017 for NMI;
%                         78.92 deg N, 11.93 deg E; 8 masl.)
%   106.1   : Polarstern (2017; 82.00 deg N, 11.00 deg E; 25 masl.)
%
% INPUT
%   path_fig            : Figure path
%   yr_name             : Name of chosen year(s)
%   month_ACLOUD_abbr   : Abbreviated name of ACLOUD month(s)
%   day_ACLOUD_no       : Number of ACLOUD days
%   day_PASCAL_no       : Number of PASCAL days
%   mod_name            : Data set names and time period
%                         [Data set number : File name : MATLAB name : ...
%                         Abbreviated name : Full name : Time period]
%   param_name          : Parameter names and unit of field campaign data
%                         [Parameter number : General name : ...
%                          File name : Data name : MATLAB name : ...
%                          Full name : Unit : Start date : End date]
%   param_indx          : Index(es) and number of chosen parameter(s)
%   param_no            : Number of chosen parameter(s)
%   stat_abbr           : Abbreviated name of chosen station(s)
%   stat_full           : Full name of chosen station(s)
%   stat_tper           : Time period of chosen station(s)
%   plot_no             : Number of open plots
%   plot_typename       : MATLAB name of figure type(s) to be plotted
%   plot_varname        : Names and unit(s) of figure type(s) to be plotted
%                         [MATLAB name : Title name : Unit]
%   plot_t              : Time data to be plotted merged in a structure
%   plot_var            : Variable data to be plotted merged in a structure
%
% CHOICES
%   plot_line_width     : Line width used in plotting
%   plot_font_name      : Font name used in plotting
%   plot_font_weight    : Font weight used in plotting
%   plot_size_label     : Label font size used in plotting
%   plot_size_legend    : Legend font size used in plotting
%   plot_ver            : Figure file versions used in plotting
%   plot_rend           : Figure render names used in plotting
%   plot_paper_type     : Figure paper type name used in plotting
%   plot_paper_orient   : Figure paper orientation name used in plotting
%   plot_paper_pos      : Figure paper position used in plotting
%
% USES
%   calc_axis_extr.m
%   windbarb_Sandro.m
%
%
% AUTHOR
%   Erlend Moster Knudsen
%   PostDoc
%   Institute for Geophysics and Meteorology, University of Cologne
%   eknudsen@uni-koeln.de
%   October 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% Plot settings %%%%%
%%% Figure properties %%%
% Plot line, font and size properties
plot_line_width = 2; % Line width
plot_font_name = 'Helvetica'; % Font name
plot_font_weight = 'bold'; % Font weight
plot_size_label = 16; % Label font size
plot_size_legend = 12; % Legend font size

% Plot figure file versions and renderer names
plot_ver = [{'fig'}; {'eps'}; {'pdf'}]; % Figure file versions
    % 'fig' = MATLAB file
    % 'eps' = Article file
    % 'pdf' = View file
plot_rend = [{'OpenGL'}; {'OpenGL'}; {'OpenGL'}]; % Renderer names
    % NB! Referes to distribution given by 'plot_ver'
    % 'OpenGL'   = Draws figures using bitmap graphics -> .fig files
    %              NB! Default
    % 'zbuffer'  = Draws figures using bitmap graphics -> .fig files
    %              NB! No longer available from MATLAB R2014b
    % 'none'     = Draws no figures -> display files
    %              NB! No longer available from MATLAB R2014b
    % 'painters' = Sorts graphic objects by child order (2D) or front to
    %               back order (3D)
    %              NB! Available from MATLAB R2014b
    
% Plot paper properties
plot_paper_type = 'A4'; % Type
plot_paper_orient = 'landscape'; % Orientation
    % 'landscape' = longer horizontally than vertically
    % 'portrait'  = longer vertically than horizontally
plot_paper_pos = [-2.0 -0.9 33 22]; % Paper position
    % [Left Top Width Height]
%%
%%%%% Plot data %%%%%
%%% Plot time series data %%%
% Only plot if asked to
if sum(cell2mat(strfind(plot_typename,'tseries'))) > 0 % Time series
    disp('plot_ACLOUD_AWIPEV_NMI_AWI: Plotting time series data')
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'tseries'));
    
    %%% Plot variable data %%%
    % Loop over chosen parameters and plot time series data
    for p = 1:param_no % Loop over number of chosen parameters
        %%% Parameter names, unit and indexes %%%
        % Extract current parameter MATLAB and title names and unit
        p_crparam_MATLAB = char(plot_varname(p_type_indx+p,1)); % MATLAB name
        p_crparam_title = char(plot_varname(p_type_indx+p,2)); % Title name
        p_crparam_unit = char(plot_varname(p_type_indx+p,3)); % Unit
        
        % Find current parameter variable indexes
        p_crparam_indx = param_indx(p);
        
        % Extract current parameter general name
        p_crparam_gen = char(param_name(p_crparam_indx+1,2));
        
        %%% Data set index and name %%%
        % Extract current parameter data set name
        if strcmp(p_crparam_MATLAB,'ps') || ...
                strcmp(p_crparam_gen,'wind') || ...
                strcmp(p_crparam_MATLAB,'T2m') || ...
                strcmp(p_crparam_MATLAB,'T10m') || ...
                strcmp(p_crparam_gen,'humid')
                % Surface pressure, wind, 2-m or 10-m temperature or
                % humidity data
            p_crparam_set = char(mod_name(1+1,3));
        elseif strcmp(p_crparam_gen,'P') % Precipiation data
            p_crparam_set = char(mod_name(2+1,3));
        elseif strcmp(p_crparam_MATLAB,'p16m') || ...
                strcmp(p_crparam_MATLAB,'T29m')
                % 16-m pressure or 29-m temperature data
            p_crparam_set = char(mod_name(3+1,3));
        end
        
        % Diplay current parameter plotting choices
        disp(['plot_ACLOUD_AWIPEV_NMI_AWI: ' ...
            'Plotting ' p_crparam_set ' ' lower(p_crparam_title) ...
            ' data from ' stat_full])
        
        %%% Figure names %%%
        % Set current parameter figure path, file and title names
        p_crparam_path = [path_fig p_crparam_MATLAB '/'];
            % Path
        p_crparam_file = ...
            [p_crparam_MATLAB '_' stat_abbr '_' ...
            month_abbr '_' yr_name '_' p_crparam_set];
            % File
        p_crparam_title = ...
            [p_crparam_title ' during ACLOUD in ' stat_full ' from ' ...
            p_crparam_set];
            % Title
        
        %%% Time data %%%
        % Extract current parameter time data
        p_crparam_cpgn_date = plot_t(p_type_indx+p-1,1).mat; % Campaign
            % Every minute / 6-hourly / daily date matrix
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD; 
            %  Yr : Month : Day : Hr : Min : Sec] / 
            %   [Min*Hr*Day_PASCAL*Month_PASCAL; 
            %    Yr : Month : Day : Hr : Min : Sec] / 
            %   [6hr*Day_ACLOUD*Month_ACLOUD; 
            %    Yr : Month : Day : Hr : Min : Sec] / 
            %   [6hr*Day_PASCAL*Month_PASCAL; 
            %    Yr : Month : Day : Hr : Min : Sec] / 
            %   [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        if strcmp(p_crparam_MATLAB,'ps') || ...
                strcmp(p_crparam_MATLAB,'T2m') || ...
                strcmp(p_crparam_MATLAB,'IWV') 
                % Surface pressure, 2-m temperature or integrated water 
                % vapor data
            % Climatology
            p_crparam_clim_date = plot_t(p_type_indx+p-1,2).mat;
                % Daily date matrix
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        end
        
        % Convert current parameter time data
        p_crparam_cpgn_t = datenum(p_crparam_cpgn_date); % Campaign
            % From date matrix to numerical vector
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
            %   [Min*Hr*Day_PASCAL*Month_PASCAL] / 
            %   [6hr*Day_ACLOUD*Month_ACLOUD] / 
            %   [6hr*Day_PASCAL*Month_PASCAL] / 
            %   [Day_ACLOUD*Month_ACLOUD]
        if strcmp(p_crparam_MATLAB,'ps') || ...
                strcmp(p_crparam_MATLAB,'T2m') || ...
                strcmp(p_crparam_MATLAB,'IWV') 
                % Surface pressure, 2-m temperature or integrated water 
                % vapor data
            p_crparam_clim_t = datenum(p_crparam_clim_date);
                % From date matrix to numerical vector
                % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        end
        
        %%% Variable data %%%
        % Extract current parameter variable data
        p_crparam_cpgn = plot_var(p_type_indx+p-1,1).mat; % Campaign
            % Every minute / 6-hourly / daily over campaign time period
            % [Min*Hr*Day_ACLOUD*Month_ACLOUD] / 
            %   [Min*Hr*Day_PASCAL*Month_PASCAL] / 
            %   [6hr*Day_ACLOUD*Month_ACLOUD] / 
            %   [6hr*Day_PASCAL*Month_PASCAL] / 
            %   [Day_ACLOUD*Month_ACLOUD]
        if strcmp(p_crparam_MATLAB,'ps') || ...
                strcmp(p_crparam_MATLAB,'T2m') || ...
                strcmp(p_crparam_MATLAB,'IWV') 
                % Surface pressure, 2-m temperature or integrated water 
                % vapor data
            % Climatology
            p_crparam_mean = plot_var(p_type_indx+p-1,2).mat;
                % Daily averaged annually over time period
                % [Day_ACLOUD*Month_ACLOUD]
            p_crparam_STD = plot_var(p_type_indx+p-1,3).mat;
                % Daily standard-devaited annually over time period
                % [Day_ACLOUD*Month_ACLOUD]
        end
        
        % Calculate current parameter variable data extremes using 
        % calc_axis_extr.m
        [p_crparam_min,p_crparam_max,p_crparam_step,~] = ...
            calc_axis_extr(p_crparam_cpgn);
        
        % Calculate current parameter variable data range
        p_crparam_range = range([p_crparam_min p_crparam_max]);
        
        %%% Plot variable data %%%
        % Plot time series data only if more than half days are finite
        if sum(isfinite(p_crparam_cpgn)) > ceil(day_no/2)
                % More than half days are finite
            %%% Plot variable data %%%
            % Loop over file versions and plot time series data
            for ver = 1:length(plot_ver)
                    % Loop over number of file versions
                %%% File version names %%%
                % Extract current file version and corresponding renderer 
                % names
                p_crver_name = char(plot_ver(ver)); % File version
                p_crver_rend = char(plot_rend(ver)); % Renderer
                
                %%% Figure names %%%
                % Set current parameter current file version figure path 
                % name
                p_crparam_crver_path = [p_crparam_path p_crver_name '/'];
                
                %%% Plot set-up and data %%%
                % Set figure number and renderer
                figure(plot_no+1) % Number
                set(gcf,'Renderer',p_crver_rend) % Renderer
                if isempty(strfind(p_crparam_MATLAB,'wnddir'))
                        % Not wind direction data
                    % Hold figure open for several plots
                    hold on
                end
                
                % Plot current parameter campaign data as a solid blue 
                % graph, rose blue or filled blue bars
                if strcmp(p_crparam_gen,'p') || ...
                        strcmp(p_crparam_gen,'wind') || ...
                        strcmp(p_crparam_gen,'T') || ...
                        strcmp(p_crparam_gen,'humid')
                        % Pressure, wind, temperature or humidity data
                    if isempty(strfind(p_crparam_MATLAB,'wnddir')) == 0
                            % Wind direction data
                        % Rose blue histogram
                        p_crparam_crver_cpgn = ...
                            rose(permute(degtorad(p_crparam_cpgn),[2 1]),12);
                    else % All other data
                        % Solid blue graph
                        p_crparam_crver_cpgn = ...
                            plot(p_crparam_cpgn_t,p_crparam_cpgn,'-b');
                    end
                elseif strcmp(p_crparam_gen,'P') % Precipitation data
                    % Filled blue bars
                    p_crparam_crver_cpgn = ...
                        bar(p_crparam_cpgn_t,p_crparam_cpgn,'b');
                end
                
                % Plot current parameter climatology data as filled blue 
                % circles and vertical blue lines
                if strcmp(p_crparam_MATLAB,'ps') || ...
                        strcmp(p_crparam_MATLAB,'T2m') || ...
                        strcmp(p_crparam_MATLAB,'IWV')
                        % Surface pressure, 2-m temperature or integrated 
                        % water vapor data
                    % Open blue circles and vertical blue lines
                    p_crparam_crver_clim = ...
                        errorbar(p_crparam_clim_t,...
                        p_crparam_mean,p_crparam_STD,...
                        'o','MarkerSize',3, 'MarkerEdgeColor','b',...
                        'MarkerFaceColor','b');
                end
                
                % Set current parameter graph size
                if isempty(strfind(p_crparam_MATLAB,'wnddir')) && ...
                        strcmp(p_crparam_gen,'P') == 0
                        % Surface pressure, 925-hPa or 850-hPa wind speed,
                        % 2-m or 10-m temperature or integrated water vapor
                        % data
                    set(p_crparam_crver_cpgn,'LineWidth',plot_line_width);
                end
                
                % Set current parameter axes extremes
                if isempty(strfind(p_crparam_MATLAB,'wnddir'))
                        % Not wind direction data
                    axis([p_crparam_cpgn_t(1) p_crparam_cpgn_t(end) ...
                        p_crparam_min p_crparam_max])
                end
                
                % Set current parameter x-axis ticks to weekly
                if isempty(strfind(p_crparam_MATLAB,'wnddir'))
                        % Not wind direction data
                    % Get axes handle
                    p_crparam_crver_axes = gca;
                    
                    % Set x-axis ticks
                    p_crparam_crver_axes.XTick = ...
                        p_crparam_cpgn_t(1):7:p_crparam_cpgn_t(end);
                end
                
                % Set current parameter x-axis to date format
                if isempty(strfind(p_crparam_MATLAB,'wnddir'))
                        % Not wind direction data
                    datetick('x','dd/mm','keeplimits','keepticks')
                end
                
                %%% Plot labels %%%
%                 % Set current parameter current station current file
%                 % version legend label properties
%                 if strcmp(p_crparam_MATLAB,'ps') || ...
%                         strcmp(p_crparam_MATLAB,'wndspd925hPa') || ...
%                         strcmp(p_crparam_MATLAB,'wndspd850hPa') || ...
%                         strcmp(p_crparam_MATLAB,'T2m') || ...
%                         strcmp(p_crparam_MATLAB,'T10m') || ...
%                         strcmp(p_crparam_MATLAB,'IWV') || ...
%                         strcmp(p_crparam_MATLAB,'P')
%                         % Surface pressure, 925-hPa or 850-hPa wind speed,
%                         % 2-m or 10-m temperature, integrated water vapor
%                         % or precipitation data
%                     % Text
%                     p_crparam_crver_lgnd = ...
%                         legend(yr_name,stat_tper,'Location','Best');
%                     
%                     % Font
%                     set(p_crparam_crver_lgnd,...
%                         'FontName',plot_font_name,...
%                         'FontSize',plot_size_label,...
%                         'FontWeight',plot_font_weight)
%                 end
                
                % Set current parameter current file version title and axes
                % label properties
                if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                        % MATLAB or view file
                    % Title label text
                    p_crparam_crver_ttl = title(p_crparam_title);
                    
                    % Title label font
                    set(p_crparam_crver_ttl,...
                        'FontName',plot_font_name,...
                        'FontSize',plot_size_label+4,...
                        'FontWeight',plot_font_weight)
                end
                if isempty(strfind(p_crparam_MATLAB,'wnddir'))
                        % Not wind direction data
                    % x-axis label text
                    p_crparam_crver_x = xlabel('Dates');
                    
                    % y-axis label text
                    p_crparam_crver_y = ylabel(p_crparam_unit);
                    
                    % Axes label font
                    set([p_crparam_crver_x,p_crparam_crver_y],...
                        'FontName',plot_font_name,...
                        'FontSize',plot_size_legend+2,...
                        'FontWeight',plot_font_weight)
                end
                
                %%% Save figure %%%
                % Save current parameter current file version figure
                if strcmp(p_crver_name,'fig') % MATLAB file
                    % Save MATLAB figure file
                    saveas(gcf,...
                        [p_crparam_crver_path p_crparam_file],'fig')
                elseif strcmp(p_crver_name,'eps') % Article file
                    % Save article figure file
                    print(gcf,'-depsc',...
                        [p_crparam_crver_path p_crparam_file])
                elseif strcmp(p_crver_name,'pdf') % View file
                    % Set file paper properties
                    set(gcf,'PaperType',plot_paper_type,...
                        'PaperOrientation',plot_paper_orient,...
                        'PaperUnits','centimeters',...
                        'PaperPosition',plot_paper_pos);
                    
                    % Save view figure file
                    print(gcf,'-dpdf',...
                        [p_crparam_crver_path p_crparam_file])
                end
                
                % Update number of open figures
                p_crver_fig = gcf;
                    % Get current file version figure handle
                plot_no = p_crver_fig.Number;
                    % Get current file version figure number
                
                %%% Delete data %%%
                % Delete current parameter current file version data
                clear p_crparam_crver_* p_crver_*
            end
        else % At least half days are infinite
            disp(['plot_ACLOUD_AWIPEV_NMI_AWI: ' ...
                'ERROR - ' p_crparam_set ' ' lower(p_crparam_title) ...
                ' data from ' stat_full ' missing'])
        end
        
        %%% Delete data %%%
        % Delete current parameter data
        clear ver p_crparam_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear p
end
%%
%%% Plot time series of near-surface pressure with 850-hPa wind data %%%
% Only plot if asked to
if sum(cell2mat(strfind(plot_typename,'ts-pns_wnd850hPa'))) > 0
        % Time series of near-surface pressure with 850-hPa wind
    disp(['plot_ACLOUD_AWIPEV_NMI_AWI: Plotting time series of ' ...
        'near-surface pressure with 850-hPa wind data'])
    
    %%% Plot type index %%%
    % Find plot type index
    p_type_indx = find(strcmp(plot_typename,'ts-pns_wnd850hPa'));
    
    %%% Parameter names and unit %%%
    % Set parameter MATLAB and title names and unit
    p_param_MATLAB = 'pns-wnd850hPa'; % MATLAB name
    p_param_title = 'Near-surface pressure with 850-hPa wind'; % Title name
    p_param_unit = char(plot_varname(p_type_indx+1,3)); % Unit
    
    %%% Data set name %%%
    % Set data set MATLAB and title names
    p_set_MATLAB = [char(mod_name(1+1,3)) '-' char(mod_name(3+1,3))];
        % MATLAB
    p_set_title = [char(mod_name(1+1,4)) '/' char(mod_name(3+1,4))];
        % Title
        
    %%% Station names %%%
    % Set station names
    p_stat_abbr = [stat_abbr(1,:) '-' stat_abbr(2,1:2)]; % Abbreviated
    p_stat_full = [stat_full(1,:) ' and ' stat_full(2,:)]; % Full
    
    % Diplay plotting choices
    disp(['plot_ACLOUD_AWIPEV_NMI_AWI: ' ...
        'Plotting ' p_set_title ' ' lower(p_param_title) ...
        ' data from ' p_stat_full])
    
    %%% Figure names %%%
    % Set figure path, file and title names
    p_fig_path = [path_fig p_param_MATLAB '/'];
        % Path
    p_fig_file = ...
        [p_param_MATLAB '_' p_stat_abbr '_' ...
        month_ACLOUD_abbr '_' yr_name '_' p_set_MATLAB];
        % File
    p_fig_title = ...
        [{[p_param_title ' during ']}; ...
        {['ACLOUD and PASCAL over ' p_stat_full ' from ' p_set_title]}];
        % Title
    
    %%% Time data %%%
    % Extract surface pressure time data
    p_ps_cpgn_date = plot_t(p_type_indx,1).mat; % Campaign
        % Every minute date matrix
        % [Min*Hr*Day_ACLOUD*Month_ACLOUD; 
        %  Yr : Month : Day : Hr : Min : Sec]
    p_ps_clim_date = plot_t(p_type_indx,2).mat; % Climatology
        % Daily date matrix
        % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        
    % Extract 16-m pressure time data
    p_p16m_cpgn_date = plot_t(p_type_indx,3).mat; % Campaign
        % Every minute date matrix
        % [Min*Hr*Day_PASCAL*Month_PASCAL; 
        %  Yr : Month : Day : Hr : Min : Sec]
    
    % Extract 850-hPa wind time data
    % NB! Equal for direction and speed, and also for 925-hPa wind
    p_wnd_cpgn_date = plot_t(p_type_indx,4).mat; % Campaign
        % Daily date matrix
        % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        
    % Set Polarstern ice-locked time data
    p_PSi_cpgn_date = [2017 6 6; 2017 6 16];
        % [Start : End; Yr : Month : Day]
    
    % Convert time data from date matrixes to numerical vectors
    p_ps_cpgn_t = datenum(p_ps_cpgn_date);
        % Surface pressure - Campaign
        % [Min*Hr*Day_ACLOUD*Month_ACLOUD]
    p_ps_clim_t = datenum(p_ps_clim_date);
        % Surface pressure - Climatology
        % [Day_ACLOUD*Month_ACLOUD]
    p_p16m_cpgn_t = datenum(p_p16m_cpgn_date);
        % 16-m pressure - Campaign
        % [Min*Hr*Day_PASCAL*Month_PASCAL]
    p_wnd_cpgn_t = datenum(p_wnd_cpgn_date);
        % 850-hPa wind - Campaign
        % [Day_ACLOUD*Month_ACLOUD]
    p_PSi_cpgn_t = datenum(p_PSi_cpgn_date);
        % Polarstern ice-lock - Campaign
        % [Start : End]
    
    %%% Variable data %%%
    % Extract surface pressure variable data
    p_ps_cpgn = plot_var(p_type_indx,1).mat; % [hPa], campaign
        % Every minute over campaign time period
        % [Min*Hr*Day_ACLOUD*Month_ACLOUD]
    p_ps_mean = plot_var(p_type_indx,2).mat; % [hPa], climatology
        % Daily averaged annually over time period
        % [Day_ACLOUD*Month_ACLOUD]
    p_ps_STD = plot_var(p_type_indx,3).mat; % [hPa], climatology
        % Daily standard-devaited annually over time period
        % [Day_ACLOUD*Month_ACLOUD]
        
    % Extract 16-m pressure variable data
    p_p16m_cpgn = plot_var(p_type_indx,4).mat; % [hPa], campaign
        % Every minute over campaign time period
        % [Min*Hr*Day_PASCAL*Month_PASCAL]
        
    % Extract 850-hPa wind variable data
    p_wnddir_cpgn = plot_var(p_type_indx,5).mat; % [deg], campaign
        % Direction - Daily averaged daily over time period
        % [Day_ACLOUD*Month_ACLOUD]
    p_wndspd_cpgn = plot_var(p_type_indx,6).mat; % [m/s], campaign
        % Speed - Daily averaged daily over time period
        % [Day_ACLOUD*Month_ACLOUD]
    
    % Calculate 850-hPa wind vector data
    p_wndu_cpgn = cos(p_wnddir_cpgn).*p_wndspd_cpgn; % Zonal wind
        % [Day_ACLOUD*Month_ACLOUD]
    p_wndv_cpgn = sin(p_wnddir_cpgn).*p_wndspd_cpgn; % Meridional wind
        % [Day_ACLOUD*Month_ACLOUD]
    
    % Calculate surface pressure variable data extremes using
    % calc_axis_extr.m
    [p_ps_min,p_ps_max,~,~] = calc_axis_extr(p_ps_cpgn);
        % [hPa], minimum and maximum
        
    % Calculate 16-m pressure variable data extremes using
    % calc_axis_extr.m
    [p_p16m_min,p_p16m_max,~,~] = calc_axis_extr(p_p16m_cpgn);
        % [hPa], minimum and maximum
    
    % Calculate 850-hPa wind speed variable data extremes using
    % calc_axis_extr.m
    [p_wndspd_min,p_wndspd_max,p_wndspd_step,~] = ...
        calc_axis_extr(p_wndspd_cpgn);
        % [m/s], minimum and maximum
        
    % Calculate pressure variable data extremes from surface and 16-m
    % pressure extremes
    p_p_min = min([p_ps_min p_p16m_min]); % [hPa], minimum
    p_p_max = max([p_ps_max p_p16m_max]); % [hPa], maximum
    p_p_range = range([p_p_min p_p_max]); % [hPa], range
    p_p_step = p_p_range/10; % [hPa], step
    
    % Adjust pressure variable steps depending on their initial size
    if p_p_step >= 80
        p_p_step = round(p_p_step*1e-2)*1e2; % [hPa]
    elseif p_p_step > 20 && p_p_step < 80
        p_p_step = 50; % [hPa]
    elseif p_p_step > 5 && p_p_step <= 20
        p_p_step = round(p_p_step/10)*10; % [hPa]
    elseif p_p_step >= 1 && p_p_step <= 5
        p_p_step = floor(p_p_step); % [hPa]
    elseif p_p_step > 0.25 && p_p_step < 1
        p_p_step = 0.5; % [hPa]
    elseif p_p_step >= 0.15 && p_p_step <= 0.25
        p_p_step = 0.2; % [hPa]
    elseif p_p_step >= 0.05 && p_p_step <= 0.15
        p_p_step = 0.1; % [hPa]
    else % p_p_step < 0.05
        p_p_step = 0.05; % [hPa]
    end
    
    % Set and calculate 850-hPa wind direction variable data
    p_wnddir_cpgn_x = p_wnd_cpgn_t;
        % x-component
    p_wnddir_cpgn_y = repmat(p_p_min + 2.5*p_p_step,day_ACLOUD_no,1);
        % y-component
    p_wnddir_cpgn_u = p_wndu_cpgn./sqrt(p_wndu_cpgn.^2+p_wndv_cpgn.^2);
        % u-component
    p_wnddir_cpgn_v = p_wndv_cpgn./sqrt(p_wndu_cpgn.^2+p_wndv_cpgn.^2);
        % v-component
    
    % Delete unnecessary variable(s)
    clear p_ps_min p_ps_max p_p16m_min p_p16m_max
    
    %%% Plot variable data %%%
    % Plot time series data only if more than half days are finite
    if sum(isfinite(p_ps_cpgn)) > ceil(day_ACLOUD_no/2) && ...
            sum(isfinite(p_p16m_cpgn)) > ceil(day_PASCAL_no/2)
            % More than half days are finite
        %%% Plot variable data %%%
        % Loop over file versions and plot time series data
        for ver = 1:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
            p_crver_name = char(plot_ver(ver)); % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current file version figure path name
            p_crver_fig_path = [p_fig_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
            % Plot surface pressure campaign data as a solid blue graph
%             p_crver_ps_cpgn = plot(p_ps_cpgn_t,p_ps_cpgn,'-b');
            [p_crver_ax,p_crver_ps_cpgn_l,p_crver_ps_cpgn_r] = ...
                plotyy(p_ps_cpgn_t,p_ps_cpgn,p_ps_cpgn_t,p_ps_cpgn,...
                'plot','plot');
            
%             % Plot surface pressure campaign data as a solid graph and
%             % 850-hPa wind speed campaign data as filled bars
%             [p_crver_ax,p_crver_ps_cpgn,p_crver_wndspd_cpgn] = ...
%                 plotyy(p_ps_cpgn_t,p_ps_cpgn,p_wnd_cpgn_t,p_wndspd_cpgn,...
%                 'plot','bar');
            
            % Plot surface pressure climatology data as filled blue circles
            % and vertical blue lines
            p_crver_ps_clim = ...
                errorbar(p_ps_clim_t,p_ps_mean,p_ps_STD,...
                'o','MarkerSize',3, 'MarkerEdgeColor','b',...
                'MarkerFaceColor','b');
            
            % Plot 16-m pressure campaign data as a solid red graph
            p_crver_p16m_cpgn = plot(p_p16m_cpgn_t,p_p16m_cpgn,'-r');
            
            % Loop over ACLOUD days and plot 850-hPa wind direction and 
            % speed data as black wind barbs using windbarb_Sandro.m
            for d = 1:day_ACLOUD_no % Loop over number of ACLOUD days
                windbarb_Sandro(p_wnd_cpgn_t(d),p_p_min+2*p_p_step,...
                    p_wndspd_cpgn(d),p_wnddir_cpgn(d),0.03,1,'k');
            end
            
            % Plot 850-hPa wind direction campaign data as a tilted black 
            % vectors of equal length
%             p_crver_wnddir_cpgn = ...
%                 quiver(p_wnddir_cpgn_x,p_wnddir_cpgn_y,...
%                 p_wnddir_cpgn_u,p_wnddir_cpgn_v,...
%                 0.25,'Color','k','LineWidth',2);
%             p_crver_wnddir_cpgn = ...
%                 quiver(p_wnddir_cpgn_x,p_wnddir_cpgn_y,...
%                 p_wnddir_cpgn_u,p_wnddir_cpgn_v,...
%                 0.35,'Color','k','LineWidth',1.5);
%             for d = 1:day_ACLOUD_no % Loop over number of ACLOUD days
%                 if p_wnddir_cpgn_u(d) >= 0 && p_wnddir_cpgn_v(d) >= 0 
%                         % Southwesterly wind
%                     % Plot on 1st y-axis level
%                     p_crver_wnddir_cpgn(d) = ...
%                         quiver(p_wnddir_cpgn_x(d),p_wnddir_cpgn_y(d)+1,...
%                         p_wnddir_cpgn_u(d),p_wnddir_cpgn_v(d),...
%                         2,'Color','k','LineWidth',2);
%                 elseif p_wnddir_cpgn_u(d) >= 0 && p_wnddir_cpgn_v(d) < 0
%                         % Southeasterly wind
%                     % Plot on 2nd y-axis level
%                     p_crver_wnddir_cpgn(d) = ...
%                         quiver(p_wnddir_cpgn_x(d),p_wnddir_cpgn_y(d),...
%                         p_wnddir_cpgn_u(d),p_wnddir_cpgn_v(d),...
%                         2,'Color','k','LineWidth',2);
%                 elseif p_wnddir_cpgn_u(d) < 0 && p_wnddir_cpgn_v(d) >= 0
%                         % Northwesterly wind
%                     % Plot on 3rd y-axis level
%                     p_crver_wnddir_cpgn(d) = ...
%                         quiver(p_wnddir_cpgn_x(d),p_wnddir_cpgn_y(d)-1,...
%                         p_wnddir_cpgn_u(d),p_wnddir_cpgn_v(d),...
%                         2,'Color','k','LineWidth',2);
%                 elseif p_wnddir_cpgn_u(d) < 0 && p_wnddir_cpgn_v(d) < 0
%                         % Northeasterly wind
%                     % Plot on 3rd y-axis level
%                     p_crver_wnddir_cpgn(d) = ...
%                         quiver(p_wnddir_cpgn_x(d),p_wnddir_cpgn_y(d)-2,...
%                         p_wnddir_cpgn_u(d),p_wnddir_cpgn_v(d),...
%                         2,'Color','k','LineWidth',2);
%                 end
%             end
            
            % Set surface pressure campaign graph and climatology circles 
            % and lines to blue and 850-hPa wind speed campaign bars to 
            % black
%             set(p_crver_ps_cpgn,'Color','b')
%                 % Surface pressure campaign graph
            set(p_crver_ps_cpgn_l,'Color','b')
                % Left surface pressure campaign graph
            set(p_crver_ps_cpgn_r,'Color','b')
                % Right surface pressure campaign graph
            set(p_crver_ps_clim,'Color','b')
                % Surface pressure climatology circles and lines
%             set(p_crver_wndspd_cpgn,'FaceColor','k')
%                 % 850-hPa wind speed campaign bars
            
            % Plot Polarstern ice-locked period as vertical gray lines
            p_crver_PSisrt_cpgn = ...
                line([p_PSi_cpgn_t(1) p_PSi_cpgn_t(1)],[0 p_p_max],...
                'LineStyle','--','Color',[.5 .5 .5]);
                % Start
            p_crver_PSiend_cpgn = ...
                line([p_PSi_cpgn_t(2) p_PSi_cpgn_t(2)],[0 p_p_max],...
                'LineStyle','--','Color',[.5 .5 .5]);
                % End
            
%             % Set 850-hPa wind direction campaign vector heads
%             for d = 1:day_ACLOUD_no % Loop over number of ACLOUD days
%                 p_crver_wnddir_cpgn_anno = ...
%                     annotation('arrow','HeadStyle','cback1',...
%                     'HeadLength',80,'HeadWidth',5);
%                 set(p_crver_wnddir_cpgn_anno,'Parent',gca);
%                 set(p_crver_wnddir_cpgn_anno,'Position',...
%                     [p_wnddir_cpgn_x(d) p_wnddir_cpgn_y(d) ...
%                     p_wnddir_cpgn_u(d) p_crver_wnddir_cpgn_v(d)]);
%             end
            
%             % Set pressure y-axis to purple and wind y-axis to black
%             p_crver_ax(1).YColor = [.5 0 .5]; % Pressure y-axis
%             p_crver_ax(2).YColor = [0 0 0]; % Wind y-axis
            
            % Set y-axes to purple
            p_crver_ax(1).YColor = [.5 0 .5]; % Left
            p_crver_ax(2).YColor = [.5 0 .5]; % Right
            
            % Set surface and 16-m pressure graph sizes
%             set(p_crver_ps_cpgn,'LineWidth',plot_line_width);
%                 % Surface pressure graph
            set(p_crver_ps_cpgn_l,'LineWidth',plot_line_width);
                % Left surface pressure graph
            set(p_crver_ps_cpgn_r,'LineWidth',plot_line_width);
                % Right surface pressure graph
            set(p_crver_p16m_cpgn,'LineWidth',plot_line_width);
                % 16-m pressure graph
            
            % Set x-axis ratio to 2.5 of y-axis
%             pbaspect(p_crver_ax(1),[2.5 1 1]) % Pressure y-axis
%             pbaspect(p_crver_ax(2),[2.5 1 1]) % Wind y-axis
            pbaspect(p_crver_ax(1),[2.5 1 1]) % Left y-axis
            pbaspect(p_crver_ax(2),[2.5 1 1]) % Right y-axis
            
            % Set axes extremes
%             p_crver_ax(1).XLim = [p_ps_cpgn_t(1)-1 p_ps_cpgn_t(end)+1];
%                 % Pressure x-axis
%             p_crver_ax(2).XLim = [p_ps_cpgn_t(1)-1 p_ps_cpgn_t(end)+1];
%                 % Wind x-axis
%             p_crver_ax(1).YLim = [floor(p_p_min/20)*20 p_p_max];
%                 % Pressure y-axis
%             p_crver_ax(2).YLim = [0 ceil(p_wndspd_max/40)*40];
%                 % Wind y-axis
            p_crver_ax(1).XLim = [p_ps_cpgn_t(1)-1 p_ps_cpgn_t(end)+1];
                % Bottom x-axis
            p_crver_ax(2).XLim = [p_ps_cpgn_t(1)-1 p_ps_cpgn_t(end)+1];
                % Top x-axis
            p_crver_ax(1).YLim = [p_p_min+p_p_step p_p_max];
                % Left y-axis
            p_crver_ax(2).YLim = [p_p_min+p_p_step p_p_max];
                % Right y-axis
            
            % Set x-axis ticks to daily
            p_crver_ax(1).XTick = p_ps_cpgn_t(1):1:p_ps_cpgn_t(end)+1;
                % Bottom x-axis
            p_crver_ax(2).XTick = p_ps_cpgn_t(1):1:p_ps_cpgn_t(end)+1;
                % Top x-axis
            
            % Set x-axis tick labels to weekly
            p_crver_ax(1).XTickLabel = repmat({''},day_ACLOUD_no+1,1);
                % Remove labels
            p_crver_ax(1).XTickLabel(1:7:end) = ...
                cellstr(datestr(p_ps_cpgn_t(1):7:p_ps_cpgn_t(end)+1,'dd/mm'));
                % Every 7th tick
                
            % Set y-axis ticks according to pressure data
            p_crver_ax(1).YTick = 995:5:1030;
                % Left
            p_crver_ax(2).YTickLabel = repmat({''},1,length(995:5:1030));
                % Right
            
            %%% Plot labels %%%
            % Set current file version legend label properties
%             p_crver_lgnd_p_h = ...
%                 legend(p_crver_ax(1),...
%                 [p_crver_ps_cpgn p_crver_p16m_cpgn],...
%                 'NYA sfc','PS 16 m',...
%                 'Location','NorthEast');
            p_crver_lgnd_p_h = ...
                legend(p_crver_ax(1),...
                [p_crver_ps_cpgn_l p_crver_p16m_cpgn],...
                'NYA sfc','PS 16 m',...
                'Location','North');
                % Pressure axes text and position
            p_crver_lgnd_p_pos = get(p_crver_lgnd_p_h,'Position');
            set(p_crver_lgnd_p_h,'Position',...
                [p_crver_lgnd_p_pos(1)+0.22 p_crver_lgnd_p_pos(2)+0.01 ...
                p_crver_lgnd_p_pos(3) p_crver_lgnd_p_pos(4)])
                % Pressure axes position
%             p_crver_lgnd_wnd_h = ...
%                 legend(p_crver_ax(2),...
%                 [p_crver_wnddir_cpgn p_crver_wndspd_cpgn],...
%                 'NYA dir','NYA spd',...
%                 'Location','Best');
%                 % Wind axes text
            windbarb_Sandro(p_ps_cpgn_t(end)-0.5,p_p_max-5.75*p_p_step,1,90,0.03,1,'k')
            p_crver_lgnd_wnd1_h = ...
                text(p_ps_cpgn_t(end)+1.5,p_p_max-5.75*p_p_step,'<2 m s^{-1}');
            windbarb_Sandro(p_ps_cpgn_t(end)-0.5,p_p_max-5*p_p_step,2,90,0.03,1,'k')
            p_crver_lgnd_wnd2_h = ...
                text(p_ps_cpgn_t(end)+1.5,p_p_max-5*p_p_step,'2 m s^{-1}');
            windbarb_Sandro(p_ps_cpgn_t(end)-0.5,p_p_max-4.25*p_p_step,4,90,0.03,1,'k')
            p_crver_lgnd_wnd4_h = ...
                text(p_ps_cpgn_t(end)+1.5,p_p_max-4.25*p_p_step,'4 m s^{-1}');
            windbarb_Sandro(p_ps_cpgn_t(end)-0.5,p_p_max-3.5*p_p_step,6,90,0.03,1,'k')
            p_crver_lgnd_wnd6_h = ...
                text(p_ps_cpgn_t(end)+1.5,p_p_max-3.5*p_p_step,'6 m s^{-1}');
            windbarb_Sandro(p_ps_cpgn_t(end)-0.5,p_p_max-2.75*p_p_step,8,90,0.03,1,'k')
            p_crver_lgnd_wnd8_h = ...
                text(p_ps_cpgn_t(end)+1.5,p_p_max-2.75*p_p_step,'8 m s^{-1}');
            windbarb_Sandro(p_ps_cpgn_t(end)-0.5,p_p_max-2*p_p_step,10,90,0.03,1,'k')
            p_crver_lgnd_wnd10_h = ...
                text(p_ps_cpgn_t(end)+1.5,p_p_max-2*p_p_step,'10 m s^{-1}');
            windbarb_Sandro(p_ps_cpgn_t(end)-0.5,p_p_max-1.25*p_p_step,12,90,0.03,1,'k')
            p_crver_lgnd_wnd12_h = ...
                text(p_ps_cpgn_t(end)+1.5,p_p_max-1.25*p_p_step,'12 m s^{-1}');
            windbarb_Sandro(p_ps_cpgn_t(end)-0.5,p_p_max-0.5*p_p_step,14,90,0.03,1,'k')
            p_crver_lgnd_wnd14_h = ...
                text(p_ps_cpgn_t(end)+1.5,p_p_max-0.5*p_p_step,'14 m s^{-1}');
                % Wind barbs text
%             p_crver_lgnd_wnd_pos = get(p_crver_lgnd_wnd_h,'Position');
%             set(p_crver_lgnd_wnd_h,'Position',...
%                 [p_crver_lgnd_wnd_pos(1)-0.125 p_crver_lgnd_wnd_pos(2)-0.465 ...
%                 p_crver_lgnd_wnd_pos(3) p_crver_lgnd_wnd_pos(4)])
%                 % Wind axes position
%             set([p_crver_lgnd_p_h,p_crver_lgnd_wnd_h],...
%                 'FontName',plot_font_name,'FontSize',plot_size_legend-6)
%                 % Pressure and wind axes font
            set([p_crver_lgnd_p_h,...
                p_crver_lgnd_wnd1_h,p_crver_lgnd_wnd2_h,...
                p_crver_lgnd_wnd4_h,p_crver_lgnd_wnd6_h,...
                p_crver_lgnd_wnd8_h,p_crver_lgnd_wnd10_h,...
                p_crver_lgnd_wnd12_h,p_crver_lgnd_wnd14_h],...
                'FontName',plot_font_name,'FontSize',plot_size_legend-4)
                % Pressure axis and wind barbs font
            
            % Set current file version title and axes label properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crver_ttl = title(p_fig_title);
                
                % Title label font
                set(p_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
            end
%             p_crver_x = xlabel('Dates'); % x-axis label text
            p_crver_y_p = ...
                ylabel(p_crver_ax(1),...
                ['Near-surface pressure [' p_param_unit ']']);
                % Pressure y-axis label text
            p_crver_y_wnd = ...
                ylabel(p_crver_ax(2),{'850-hPa wind'; '[m s^{-1}]'});
                % Wind y-axis label text
            p_crver_y_p_pos = get(p_crver_y_p,'Position');
                % Pressure y-axis label position
            set(p_crver_y_p,'Position',...
                [p_crver_y_p_pos(1) p_crver_y_p_pos(2)+0.5*p_p_step p_crver_y_p_pos(3)])
                % Pressure y-axis label position
            p_crver_y_wnd_pos = get(p_crver_y_wnd,'Position');
                % Wind y-axis label position
%             set(p_crver_y_wnd,'Rotation',270,'Position',...
%                 [p_crver_y_wnd_pos(1)+1 p_crver_y_wnd_pos(2)-8*p_wndspd_step p_crver_y_wnd_pos(3)])
%                 % Wind y-axis label position
            set(p_crver_y_wnd,'Rotation',270,'Position',...
                [p_crver_y_wnd_pos(1)+2 p_crver_y_wnd_pos(2)-3.5*p_p_step p_crver_y_wnd_pos(3)],...
                'Color','k')
                % Wind y-axis label position and color
%             set([p_crver_x,p_crver_y_p,p_crver_y_wnd],...
%                 'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
%                 'FontWeight',plot_font_weight)
            set([p_crver_y_p,p_crver_y_wnd],...
                'FontName',plot_font_name,'FontSize',plot_size_legend-3,...
                'FontWeight',plot_font_weight)
                % Axes label font
            p_crver_ax(1).FontSize = plot_size_legend;
                % Pressure axes ticks size
            p_crver_ax(2).FontSize = plot_size_legend;
                % Wind axes ticks size
            
            %%% Save figure %%%
            % Save current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crver_fig_path p_fig_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',[p_crver_fig_path p_fig_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view figure file
                print(gcf,'-dpdf',[p_crver_fig_path p_fig_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current file version data
            clear p_crver_*
        end
    else % At least half days are infinite
        disp(['plot_ACLOUD_AWIPEV_NMI_AWI: ' ...
            'ERROR - ' p_set_title ' ' lower(p_fig_title) ...
            ' data from ' stat_full ' missing'])
    end
        
    %%% Delete data %%%
    % Delete unnecessary data
    clear ver p_*
end
%%
%%% Plot time series of temperature with melt season data %%%
% Only plot if asked to
if sum(cell2mat(strfind(plot_typename,'ts-Tns_mlt'))) > 0
        % Time series of near-surface temperature with melt season
    disp(['plot_ACLOUD_AWIPEV_NMI_AWI: Plotting time series of ' ...
        'near-surface temperature with melt season data'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'ts-Tns_mlt'));
    
    %%% Parameter names and unit %%%
    % Extract parameter MATLAB and title names and unit
    p_param_MATLAB = 'Tns-mlt';
        % MATLAB name
    p_param_title = 'Near-surface temperature with snow melt season';
        % Title name
    p_param_unit = char(plot_varname(p_type_indx+1,3));
        % Unit
    
    %%% Data set name %%%
    % Extract data set MATLAB and title names
    p_set_MATLAB = [char(mod_name(1+1,3)) '-' char(mod_name(3+1,3))];
        % MATLAB
    p_set_title = [char(mod_name(1+1,4)) '/' char(mod_name(3+1,4))];
        % Title
        
    %%% Station names %%%
    % Set station names
    p_stat_abbr = [stat_abbr(1,:) '-' stat_abbr(2,1:2)]; % Abbreviated
    p_stat_full = [stat_full(1,:) ' and ' stat_full(2,:)]; % Full
    
    % Diplay plotting choices
    disp(['plot_ACLOUD_AWIPEV_NMI_AWI: ' ...
        'Plotting ' p_set_title ' ' lower(p_param_title) ...
        ' data from ' p_stat_full])
    
    %%% Figure names %%%
    % Set figure path, file and title names
    p_fig_path = [path_fig p_param_MATLAB '/'];
        % Path
    p_fig_file = ...
        [p_param_MATLAB '_' p_stat_abbr '_' ...
        month_ACLOUD_abbr '_' yr_name '_' p_set_MATLAB];
        % File
    p_fig_title = ...
        [{[p_param_title ' during ']}; ...
        {['ACLOUD and PASCAL over ' p_stat_full ' from ' p_set_title]}];
        % Title
    
    %%% Time data %%%
    % Extract 2-m temperature time data
    p_T2m_cpgn_date = plot_t(p_type_indx,1).mat; % Campaign
        % Every minute date matrix
        % [Min*Hr*Day_ACLOUD*Month_ACLOUD; 
        %  Yr : Month : Day : Hr : Min : Sec]
    p_T2m_clim_date = plot_t(p_type_indx,2).mat; % Climatology
        % Daily date matrix
        % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        
    % Extract 29-m temperature time data
    p_T29m_cpgn_date = plot_t(p_type_indx,3).mat; % Campaign
        % Every minute date matrix
        % [Min*Hr*Day_PASCAL*Month_PASCAL;
        %  Yr : Month : Day : Hr : Min : Sec]
    
    % Extract melt season time data
    p_mlt_cpgn_date = plot_t(p_type_indx,4).mat; % Campaign
        % Start and end dates matrix
        % [Start : End; Yr : Month : Day]
        
    % Set Polarstern ice-locked time data
    p_PSi_cpgn_date = [2017 6 6; 2017 6 16];
        % [Start : End; Yr : Month : Day]
    
    % Convert time data from date matrixes to numerical vectors
    p_T2m_cpgn_t = datenum(p_T2m_cpgn_date);
        % 2-m temperature - Campaign
        % [Min*Hr*Day_ACLOUD*Month_ACLOUD]
    p_T2m_clim_t = datenum(p_T2m_clim_date);
        % 2-m temperature - Climatology
        % [Day_ACLOUD*Month_ACLOUD]
    p_T29m_cpgn_t = datenum(p_T29m_cpgn_date);
        % 2-m temperature - Campaign
        % [Min*Hr*Day_PASCAL*Month_PASCAL]
    p_mlt_cpgn_t = datenum(p_mlt_cpgn_date);
        % Melt season - Campaign
        % [Start : End]
    p_PSi_cpgn_t = datenum(p_PSi_cpgn_date);
        % Polarstern ice-lock - Campaign
        % [Start : End]
    
    %%% Variable data %%%
    % Extract 2-m temperature variable data
    p_T2m_cpgn = plot_var(p_type_indx,1).mat; % [deg C], campaign
        % Every minute over campaign time period
        % [Min*Hr*Day_ACLOUD*Month_ACLOUD]
    p_T2m_mean = plot_var(p_type_indx,2).mat; % [deg C], climatology
        % Daily averaged annually over time period
        % [Day_ACLOUD*Month_ACLOUD]
    p_T2m_STD = plot_var(p_type_indx,3).mat; % [deg C], climatology
        % Daily standard-devaited annually over time period
        % [Day_ACLOUD*Month_ACLOUD]
        
    % Extract 29-m temperature variable data
    p_T29m_cpgn = plot_var(p_type_indx,4).mat; % [deg C], campaign
        % Every minute over time period
        % [Min*Hr*Day_PASCAL*Month_PASCAL]
    
    % Calculate 2-m temperature variable data extremes using
    % calc_axis_extr.m
    [p_T2m_min,p_T2m_max,~,~] = calc_axis_extr(p_T2m_cpgn);
        % [deg C], minimum and maximum
        
    % Calculate 29-m temperature variable data extremes using
    % calc_axis_extr.m
    [p_T29m_min,p_T29m_max,~,~] = calc_axis_extr(p_T29m_cpgn);
        % [deg C], minimum and maximum
        
    % Calculate temperature variable data extremes from 2-m and 29-m
    % temperature extremes
    p_T_min = min([p_T2m_min p_T29m_min]); % [deg C], minimum
    p_T_max = max([p_T2m_max p_T29m_max]); % [deg C], maximum
    p_T_range = range([p_T_min p_T_max]); % [deg C], range
    p_T_step = p_T_range/10; % [deg C], step
    
    % Adjust temperature variable steps depending on their initial size
    if p_T_step >= 80
        p_T_step = round(p_T_step*1e-2)*1e2; % [deg C]
    elseif p_T_step > 20 && p_T_step < 80
        p_T_step = 50; % [deg C]
    elseif p_T_step > 5 && p_T_step <= 20
        p_T_step = round(p_T_step/10)*10; % [deg C]
    elseif p_T_step >= 1 && p_T_step <= 5
        p_T_step = floor(p_T_step); % [deg C]
    elseif p_T_step > 0.25 && p_T_step < 1
        p_T_step = 0.5; % [deg C]
    elseif p_T_step >= 0.15 && p_T_step <= 0.25
        p_T_step = 0.2; % [deg C]
    elseif p_T_step >= 0.05 && p_T_step <= 0.15
        p_T_step = 0.1; % [deg C]
    else % p_T_step < 0.05
        p_T_step = 0.05; % [deg C]
    end
    
    % Adjust temperature variable extremes depending on their occurances
    if min(p_T2m_cpgn) == p_T_min || min(p_T29m_min) == p_T_min
        % Minimum
        p_T_min = p_T_min - p_T_step; % [deg C]
    end
    if max(p_T2m_cpgn) == p_T_max || max(p_T29m_min) == p_T_max
        % Maximum
        p_T_max = p_T_max + p_T_step; % [deg C]
    end
    
    % Delete unnecessary variable(s)
    clear p_T2m_min p_T2m_max p_T29m_min p_T29m_max
    
    %%% Plot variable data %%%
    % Plot time series data only if more than half days are finite
    if sum(isfinite(p_T2m_cpgn)) > ceil(day_ACLOUD_no/2) && ...
            sum(isfinite(p_T29m_cpgn)) > ceil(day_PASCAL_no/2)
            % More than half days are finite
        %%% Plot variable data %%%
        % Loop over file versions and plot time series data
        for ver = 1:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
            p_crver_name = char(plot_ver(ver)); % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current file version figure path name
            p_crver_fig_path = [p_fig_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
%             % Plot 2-m temperature campaign data as a solid blue graph
%             p_crver_T2m_cpgn = plot(p_T2m_cpgn_t,p_T2m_cpgn,'-b');
            [p_crver_ax,p_crver_T2m_cpgn_l,p_crver_T2m_cpgn_r] = ...
                plotyy(p_T2m_cpgn_t,p_T2m_cpgn,p_T2m_cpgn_t,p_T2m_cpgn,...
                'plot','plot');
            
            % Plot 2-m temperature climatology data as filled blue circles 
            % and vertical blue lines
            p_crver_T2m_clim = ...
                errorbar(p_T2m_clim_t,p_T2m_mean,p_T2m_STD,...
                'o','MarkerSize',3, 'MarkerEdgeColor','b',...
                'MarkerFaceColor','b');
            
            % Plot 29-m temperature campaign data as a solid red graph
            p_crver_T29m_cpgn = plot(p_T29m_cpgn_t,p_T29m_cpgn,'-r');
            
            % Plot melt season campaign data as a vertical black lines
            p_crver_mltsrt_cpgn = ...
                line([p_mlt_cpgn_t(1) p_mlt_cpgn_t(1)],[p_T_min p_T_max+1],...
                'Color','k');
                % Start
            p_crver_mltend_cpgn = ...
                line([p_mlt_cpgn_t(2) p_mlt_cpgn_t(2)],[p_T_min p_T_max+1],...
                'Color','k');
                % End
                
%             % Set 2-m temperature climatology circles and lines to blue
            % Set 2-m temperature campaign graph and climatology circles 
            % and lines to blue
            set(p_crver_T2m_cpgn_l,'Color','b')
                % Left 2-m temperature campaign graph
            set(p_crver_T2m_cpgn_r,'Color','b')
                % Right 2-m temperature campaign graph
            set(p_crver_T2m_clim,'Color','b')
                % 2-m temperature climatology graph
            
            % Plot 0 deg C reference line as a horizontal black line
            p_crver_0degC = ...
                line([p_T2m_cpgn_t(1)-3 p_T2m_cpgn_t(end)+3],[0 0],...
                'Color','k');
            
            % Plot Polarstern ice-locked period as vertical gray lines
            p_crver_PSisrt_cpgn = ...
                line([p_PSi_cpgn_t(1) p_PSi_cpgn_t(1)],[p_T_min p_T_max+1],...
                'LineStyle','--','Color',[.5 .5 .5]);
                % Start
            p_crver_PSiend_cpgn = ...
                line([p_PSi_cpgn_t(2) p_PSi_cpgn_t(2)],[p_T_min p_T_max+1],...
                'LineStyle','--','Color',[.5 .5 .5]);
                % End
            
            % Set y-axes to purple
            p_crver_ax(1).YColor = [.5 0 .5]; % Left
            p_crver_ax(2).YColor = [.5 0 .5]; % Right
            
            % Set 2-m and 29-m temperature graph size
            set(p_crver_T2m_cpgn_l,'LineWidth',plot_line_width);
                % Left 2-m temperature graph
            set(p_crver_T2m_cpgn_r,'LineWidth',plot_line_width);
                % Right 2-m temperature graph
            set(p_crver_T29m_cpgn,'LineWidth',plot_line_width);
                % 29-m temperature graph
                
            % Set x-axis ratio to 2.5 of y-axis
            pbaspect(p_crver_ax(1),[2.5 1 1]) % Left y-axis
            pbaspect(p_crver_ax(2),[2.5 1 1]) % Right y-axis
            
            % Set axes extremes
%             axis([p_T2m_cpgn_t(1)-3 p_T2m_cpgn_t(end)+3 p_T_min p_T_max])
%             p_crver_ax.XLim = [p_T2m_cpgn_t(1)-1 p_T2m_cpgn_t(end)+1];
%                 % x-axis
%             p_crver_ax.YLim = [p_T_min p_T_max+1];
%                 % y-axis
            p_crver_ax(1).XLim = [p_T2m_cpgn_t(1)-1 p_T2m_cpgn_t(end)+1];
                % Bottom x-axis
            p_crver_ax(2).XLim = [p_T2m_cpgn_t(1)-1 p_T2m_cpgn_t(end)+1];
                % Top x-axis
            p_crver_ax(1).YLim = [p_T_min p_T_max+1];
                % Left y-axis
            p_crver_ax(2).YLim = [p_T_min p_T_max+1];
                % Right y-axis
            
%             % Set x-axis ticks to weekly
%             p_crver_axes = gca; % Get axes handle
%             p_crver_axes.XTick = p_T2m_cpgn_t(1):7:p_T2m_cpgn_t(end);
%                 % Set x-axis ticks
                
            % Set x-axis ticks to daily
%             p_crver_ax.XTick = p_T2m_cpgn_t(1):1:p_T2m_cpgn_t(end)+1;
            p_crver_ax(1).XTick = p_T2m_cpgn_t(1):1:p_T2m_cpgn_t(end)+1;
                % Bottom
            p_crver_ax(2).XTick = p_T2m_cpgn_t(1):1:p_T2m_cpgn_t(end)+1;
                % Top
            
            % Set x-axis tick labels to weekly
            p_crver_ax(1).XTickLabel = repmat({''},day_ACLOUD_no+1,1);
                % Remove labels
            p_crver_ax(1).XTickLabel(1:7:end) = ...
                cellstr(datestr(p_T2m_cpgn_t(1):7:p_T2m_cpgn_t(end)+1,'dd/mm'));
                % Every 7th tick
            
%             % Set x-axis to date format
%             datetick('x','dd/mm','keeplimits','keepticks')
            
            % Set y-axes ticks in accordance with parameter steps
%             p_crver_ax.YTick = p_T_min:p_T_step:p_T_max;
            p_crver_ax(1).YTick = p_T_min:2*p_T_step:p_T_max+1; % Left
            p_crver_ax(2).YTick = p_T_min:2*p_T_step:p_T_max+1; % Right
            
            %%% Plot labels %%%
            % Set current file version legend label properties
            p_crver_lgnd_h = ...
                legend(p_crver_ax(1),...
                [p_crver_T2m_cpgn_l p_crver_T29m_cpgn],...
                'NYA 2 m','PS 29 m',...
                'Location','SouthEast');
                % Text and position
            set(p_crver_lgnd_h,'FontName',plot_font_name,...
                'FontSize',plot_size_legend-4)
                % Font
            
            % Set current file version title and axes label properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crver_ttl = title(p_fig_title);
                
                % Title label font
                set(p_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
            end
%             p_crver_x = xlabel('Dates');
                % x-axis label text
            p_crver_y = ...
                ylabel(['Near-surface temperature [' p_param_unit ']']);
                % y-axis label text
%             set([p_crver_x,p_crver_y],...
%                 'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
%                 'FontWeight',plot_font_weight)
            set(p_crver_y,...
                'FontName',plot_font_name,'FontSize',plot_size_legend-2,...
                'FontWeight',plot_font_weight)
                % Axes label font
            p_crver_ax(1).FontSize = plot_size_legend;
            p_crver_ax(2).FontSize = plot_size_legend;
                % Axes ticks size
            
            %%% Save figure %%%
            % Save current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crver_fig_path p_fig_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',[p_crver_fig_path p_fig_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view figure file
                print(gcf,'-dpdf',[p_crver_fig_path p_fig_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current file version data
            clear p_crver_*
        end
    else % At least half days are infinite
        disp(['plot_ACLOUD_AWIPEV_NMI_AWI: ' ...
            'ERROR - ' p_set_title ' ' lower(p_fig_title) ...
            ' data from ' stat_full ' missing'])
    end
        
    %%% Delete data %%%
    % Delete unnecessary data
    clear ver p_*
end
%%
%%% Plot time series of integrated water vapor with precipitation data %%%
% Only plot if asked to
if sum(cell2mat(strfind(plot_typename,'ts-IWV_P'))) > 0
        % Time series of integrated water vapor with precipitation
    disp(['plot_ACLOUD_AWIPEV_NMI_AWI: Plotting time series of ' ...
        'integrated water vapor with precipitation data'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'ts-IWV_P'));
    
    %%% Parameter names and unit %%%
    % Extract parameter MATLAB and title names and unit
    p_param_MATLAB = 'IWV-P';
        % MATLAB name
    p_param_title = 'Integrated water vapor with precipitation';
        % Title name
    p_param_unit = plot_varname(p_type_indx+1:p_type_indx+2,3);
        % Unit
    
    %%% Data set names %%%
    % Extract data set MATLAB and title names
    p_set_MATLAB = ...
        [char(mod_name(1+1,3)) '-' char(mod_name(3+1,3)) '-' ...
        char(mod_name(2+1,3))];
        % MATLAB
    p_set_title = ...
        [char(mod_name(1+1,4)) ', ' char(mod_name(3+1,4)) ' and ' ...
        char(mod_name(2+1,4))];
        % Title
        
    %%% Station names %%%
    p_stat_abbr = [stat_abbr(1,:) '-' stat_abbr(2,1:2)]; % Abbreviation
    p_stat_full = [stat_full(1,:) ' and ' stat_full(2,:)]; % Full
    
    % Diplay plotting choices
    disp(['plot_ACLOUD_AWIPEV_NMI_AWI: ' ...
        'Plotting ' p_set_title ' ' lower(p_param_title) ...
        ' data from ' p_stat_full])
    
    %%% Figure names %%%
    % Set figure path, file and title names
    p_fig_path = [path_fig p_param_MATLAB '/'];
        % Path
    p_fig_file = ...
        [p_param_MATLAB '_' p_stat_abbr '_' ...
        month_ACLOUD_abbr '_' yr_name '_' p_set_MATLAB];
        % File
    p_fig_title = ...
        [{[p_param_title ' during ']}; ...
        {['ACLOUD and PASCAL in ' p_stat_full ' from ' p_set_title]}];
        % Title
    
    %%% Time data %%%
    % Extract integrated water vapor time data
    p_IWV_cpgn_date_NAa = plot_t(p_type_indx,1).mat; % ACLOUD campaign
        % 6-hourly date matrix
        % [6hr*Day_ACLOUD*Month_ACLOUD; Yr : Month : Day : Hr : Min : Sec]
    p_IWV_clim_date_NAa = plot_t(p_type_indx,2).mat; % ACLOUD climatology
        % Daily date matrix
        % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
    p_IWV_cpgn_date_PS = plot_t(p_type_indx,3).mat; % PASCAL campaign
        % 6-hourly date matrix
        % [6hr*Day_PASCAL*Month_PASCAL; Yr : Month : Day : Hr : Min : Sec]
    
    % Extract precipitation time data
    p_P_cpgn_date_NAa = plot_t(p_type_indx,4).mat; % ACLOUD campaign
        % Daily date matrix
        % [Day_ACLOUD*Month_ACLOUD; Yr : Month : Day]
        
    % Set Polarstern ice-locked time data
    p_PSi_cpgn_date = [2017 6 6; 2017 6 16];
        % [Start : End; Yr : Month : Day]
    
    % Convert time data from date matrixes to numerical vectors
    p_IWV_cpgn_t_NAa = datenum(p_IWV_cpgn_date_NAa);
        % Integrated water vapor - ACLOUD campaign
        % [6hr*Day_ACLOUD*Month_ACLOUD]
    p_IWV_clim_t_NAa = datenum(p_IWV_clim_date_NAa);
        % Integrated water vapor - ACLOUD climatology
        % [Day_ACLOUD*Month_ACLOUD]
    p_IWV_cpgn_t_PS = datenum(p_IWV_cpgn_date_PS);
        % Integrated water vapor - PASCAL campaign
        % [6hr*Day_PASCAL*Month_PASCAL]
    p_P_cpgn_t_NAa = datenum(p_P_cpgn_date_NAa);
        % Precipitation - ACLOUD campaign
        % [Day_ACLOUD*Month_ACLOUD]
    p_PSi_cpgn_t = datenum(p_PSi_cpgn_date);
        % Polarstern ice-lock - ACLOUD campaign
        % [Start : End]
    
    %%% Variable data %%%
    % Extract integrated water vapor variable data
    p_IWV_cpgn_NAa = plot_var(p_type_indx,1).mat; % [kg/m^2]
        % ACLOUD campaign
        % 6-hourly over campaign time period
        % [6hr*Day_ACLOUD*Month_ACLOUD]
    p_IWV_mean_NAa = plot_var(p_type_indx,2).mat; % [kg/m^2]
        % ACLOUD climatology
        % Daily averaged annually over time period
        % [Day_ACLOUD*Month_ACLOUD]
    p_IWV_STD_NAa = plot_var(p_type_indx,3).mat; % [kg/m^2]
        % ACLOUD climatology
        % Daily standard-devaited annually over time period
        % [Day_ACLOUD*Month_ACLOUD]
    p_IWV_cpgn_PS = plot_var(p_type_indx,4).mat; % [kg/m^2]
        % PASCAL campaign
        % 6-hourly over campaign time period
        % [6hr*Day_PASCAL*Month_PASCAL]
        
    % Extract precipitation variable data
    p_P_cpgn_NAa = plot_var(p_type_indx,5).mat; % [mm]
        % ACLOUD campaign
        % Daily over time period
        % [Day_ACLOUD*Month_ACLOUD]
    
    % Calculate integrated water vapor variable data extremes using
    % calc_axis_extr.m
    [p_IWV_min_NAa,p_IWV_max_NAa,~,~] = ...
        calc_axis_extr(p_IWV_cpgn_NAa);
        % [kg/m^2], ACLOUD campaign
    [p_IWV_min_PS,p_IWV_max_PS,~,~] = ...
        calc_axis_extr(p_IWV_cpgn_PS);
        % [kg/m^2], PASCAL campaign
        
    % Calculate precipitation variable data extremes using calc_axis_extr.m
    [p_P_min,p_P_max,p_P_step,~] = calc_axis_extr(p_P_cpgn_NAa);
        % [mm/day], minimum and maximum
        
    % Calculate integrated water vapor variable data extremes from station 
    % extremes
    p_IWV_min = min([p_IWV_min_NAa p_IWV_min_PS]); % [kg/m^2], minimum
    p_IWV_max = max([p_IWV_max_NAa p_IWV_max_PS]); % [kg/m^2], maximum
    p_IWV_range = range([p_IWV_min p_IWV_max]); % [kg/m^2], range
    p_IWV_step = p_IWV_range/10; % [kg/m^2], step
    
    % Adjust pressure variable steps depending on their initial size
    if p_IWV_step >= 80
        p_IWV_step = round(p_IWV_step*1e-2)*1e2; % [kg/m^2]
    elseif p_IWV_step > 20 && p_IWV_step < 80
        p_IWV_step = 50; % [kg/m^2]
    elseif p_IWV_step > 5 && p_IWV_step <= 20
        p_IWV_step = round(p_IWV_step/10)*10; % [kg/m^2]
    elseif p_IWV_step >= 1 && p_IWV_step <= 5
        p_IWV_step = floor(p_IWV_step); % [kg/m^2]
    elseif p_IWV_step > 0.25 && p_IWV_step < 1
        p_IWV_step = 0.5; % [kg/m^2]
    elseif p_IWV_step >= 0.15 && p_IWV_step <= 0.25
        p_IWV_step = 0.2; % [kg/m^2]
    elseif p_IWV_step >= 0.05 && p_IWV_step <= 0.15
        p_IWV_step = 0.1; % [kg/m^2]
    else % p_IWV_step < 0.05
        p_IWV_step = 0.05; % [kg/m^2]
    end
    
    % Delete unnecessary variable(s)
    clear p_IWV_min_* p_IWV_max_*
    
    %%% Plot variable data %%%
    % Plot time series data only if more than half days are finite
    if sum(isfinite(p_IWV_cpgn_NAa)) > ceil(day_ACLOUD_no/2) && ...
            sum(isfinite(p_IWV_cpgn_PS)) > ceil(day_PASCAL_no/2)
            % More than half days are finite
        %%% Plot variable data %%%
        % Loop over file versions and plot time series data
        for ver = 1:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
            p_crver_name = char(plot_ver(ver)); % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current file version figure path name
            p_crver_fig_path = [p_fig_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
%             % Plot integrated water vapor ACLOUD campaign data as a solid 
%             % blue graph
%             p_crver_IWV_cpgn_NAa = ...
%                 plot(p_IWV_cpgn_t_NAa,p_IWV_cpgn_NAa,'-b');
            
%             % Plot integrated water vapor ACLOUD campaign data as a filled 
%             % blue bars
%             p_crver_IWV_cpgn_NAa = ...
%                 bar(p_IWV_cpgn_t_NAa,p_IWV_cpgn_NAa,'b');
            
            % Plot integrated water vapor ACLOUD campaign data as a solid 
            % graph and precipitation ACLOUD campaign data as filled bars
            [p_crver_ax,p_crver_IWV_cpgn_NAa,p_crver_P_cpgn_NAa] = ...
                plotyy(p_IWV_cpgn_t_NAa,p_IWV_cpgn_NAa,...
                p_P_cpgn_t_NAa,p_P_cpgn_NAa,...
                'plot','bar');
            
            % Plot integrated water vapor ACLOUD climatology data as filled
            % blue circles and vertical blue lines
            p_crver_IWV_clim_NAa = ...
                errorbar(p_IWV_clim_t_NAa,p_IWV_mean_NAa,p_IWV_STD_NAa,...
                'o','MarkerSize',3, 'MarkerEdgeColor','b',...
                'MarkerFaceColor','b');
            
            % Plot integrated water vapor PASCAL campaign data as a solid 
            % red graph
            p_crver_IWV_cpgn_PS = ...
                plot(p_IWV_cpgn_t_PS,p_IWV_cpgn_PS,'-r');
            
%             % Plot precipitation campaign data as a filled black asterisks
%             p_crver_P_cpgn_NAa = plot(p_P_cpgn_t_NAa,p_P_cpgn_NAa,'*k');
            
%             % Plot precipitation campaign data as a filled black bars
%             p_crver_P_cpgn_NAa = bar(p_P_cpgn_t_NAa,p_P_cpgn_NAa,'k');
            
            % Set integrated water vapor ACLOUD campaign graph and 
            % climatology circles and lines to blue and precipitation 
            % ACLOUD campaign bars to black
            set(p_crver_IWV_cpgn_NAa,'Color','b')
                % Integrated water vapor ACLOUD campaign graph
            set(p_crver_IWV_clim_NAa,'Color','b')
                % Integrated water vapor ACLOUD climatology circles and 
                % lines
            set(p_crver_P_cpgn_NAa,'FaceColor','k')
                % Precipitation ACLOUD campaign bars
                
            % Plot Polarstern ice-locked period as vertical gray lines
            p_crver_PSisrt_cpgn = ...
                line([p_PSi_cpgn_t(1) p_PSi_cpgn_t(1)],...
                [p_IWV_min-10*p_IWV_step p_IWV_max],...
                'LineStyle','--','Color',[.5 .5 .5]);
                % Start
            p_crver_PSiend_cpgn = ...
                line([p_PSi_cpgn_t(2) p_PSi_cpgn_t(2)],...
                [p_IWV_min-10*p_IWV_step p_IWV_max],...
                'LineStyle','--','Color',[.5 .5 .5]);
                % End
                
            % Set humidity y-axis to purple and precipitation y-axis to 
            % black
            p_crver_ax(1).YColor = [.5 0 .5]; % Humidity y-axis
            p_crver_ax(2).YColor = [0 0 0]; % Precipitation y-axis
            
            % Set integrated water vapor graph sizes
            set(p_crver_IWV_cpgn_NAa,'LineWidth',plot_line_width);
                % ACLOUD graph
            set(p_crver_IWV_cpgn_PS,'LineWidth',plot_line_width);
                % PASCAL graph
                
            % Set x-axis ratio to 2.5 of y-axis
            pbaspect(p_crver_ax(1),[2.5 1 1]) % Humidity y-axis
            pbaspect(p_crver_ax(2),[2.5 1 1]) % Precipitation y-axis
            
            % Set axes extremes
%             % NB! Set y-axis min to zero to include precipitation data
%             axis([p_IWV_cpgn_t_NAa(1)-3 p_IWV_cpgn_t_NAa(end)+3 ...
%                 0 p_IWV_max])
            p_crver_ax(1).XLim = ...
                [p_IWV_cpgn_t_NAa(1)-1 p_IWV_cpgn_t_NAa(end)+1];
                % Humidity x-axis
            p_crver_ax(2).XLim = ...
                [p_IWV_cpgn_t_NAa(1)-1 p_IWV_cpgn_t_NAa(end)+1];
                % Precipitation x-axis
            p_crver_ax(1).YLim = [p_IWV_min-10*p_IWV_step p_IWV_max];
                % Humidity y-axis
            p_crver_ax(2).YLim = [0 p_P_max+10*p_P_step];
                % Precipitation y-axis
            
%             % Set x-axis ticks to weekly
%             p_crver_axes = gca; % Get axes handle
%             p_crver_axes.XTick = ...
%                 p_IWV_cpgn_t_NAa(1):7:p_IWV_cpgn_t_NAa(end);
%                 % Set x-axis ticks
                
            % Set x-axis ticks to daily
            p_crver_ax(1).XTick = ...
                p_IWV_cpgn_t_NAa(1):1:p_IWV_cpgn_t_NAa(end)+1;
                % Humidity
            p_crver_ax(2).XTick = ...
                p_IWV_cpgn_t_NAa(1):1:p_IWV_cpgn_t_NAa(end)+1;
                % Precipitation
                
            % Set x-axis tick labels to weekly
            p_crver_ax(1).XTickLabel = repmat({''},day_ACLOUD_no+1,1);
                % Remove labels
            p_crver_ax(1).XTickLabel(1:7:end) = ...
                cellstr(datestr(p_IWV_cpgn_t_NAa(1):7:p_IWV_cpgn_t_NAa(end)+1,'dd/mm'));
                % Every 7th tick
            
%             % Set x-axis to date format
%             datetick('x','dd/mm','keeplimits','keepticks')
            
            % Set y-axis ticks in accordance with parameter steps
%             p_crver_ax(1).YTick = p_IWV_min:p_IWV_step:p_IWV_max;
            p_crver_ax(1).YTick = 0:2*p_IWV_step:p_IWV_max;
                % Humidity
            p_crver_ax(2).YTick = p_P_min:p_P_step:p_P_max;
                % Precipitation
            
            %%% Plot labels %%%
            % Set current file version legend label properties
            p_crver_lgnd_IWV_h = ...
                legend(p_crver_ax(1),...
                [p_crver_IWV_cpgn_NAa p_crver_IWV_cpgn_PS],...
                'NYA','PS','Location','NorthWest');
                % Humidity axes text and position
            p_crver_lgnd_P_h = ...
                legend(p_crver_ax(2),...
                p_crver_P_cpgn_NAa,...
                'NYA','Location','SouthEast');
                % Precipitation axes text
            p_crver_lgnd_P_pos = get(p_crver_lgnd_P_h,'Position');
            set(p_crver_lgnd_P_h,'Position',...
                [p_crver_lgnd_P_pos(1)+0.02 p_crver_lgnd_P_pos(2)+0.05 ...
                p_crver_lgnd_P_pos(3) p_crver_lgnd_P_pos(4)])
                % Precipitation axes position
            set([p_crver_lgnd_IWV_h,p_crver_lgnd_P_h],...
                'FontName',plot_font_name,'FontSize',plot_size_legend-4)
                % Humidity and precipitation axes font
            
            % Set current file version title and axes label properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crver_ttl = title(p_fig_title);
                
                % Title label font
                set(p_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
            end
%             p_crver_x = xlabel('Dates'); % x-axis label text
            p_crver_y_IWV = ...
                ylabel(p_crver_ax(1),...
                ['Integrated water vapor [' char(p_param_unit(1)) ']']);
                % Humidity y-axis label text
            p_crver_y_P = ...
                ylabel(p_crver_ax(2),...
                ['Precipitation [' char(p_param_unit(2)) ']']);
                % Precipitation y-axis label text
            p_crver_y_IWV_pos = get(p_crver_y_IWV,'Position');
                % Humidity y-axis label position
%             set(p_crver_y_IWV,'Position',...
%                 [p_crver_y_IWV_pos(1) p_crver_y_IWV_pos(2)+4*p_IWV_step p_crver_y_IWV_pos(3)])
            set(p_crver_y_IWV,'Position',...
                [p_crver_y_IWV_pos(1) p_crver_y_IWV_pos(2)+0*p_IWV_step p_crver_y_IWV_pos(3)])
                % Humidity y-axis label position
            p_crver_y_P_pos = get(p_crver_y_P,'Position');
                % Precipitation y-axis label position
%             set(p_crver_y_P,'Position',...
%                 [p_crver_y_P_pos(1) p_crver_y_P_pos(2)-3.5*p_P_step p_crver_y_P_pos(3)])
            set(p_crver_y_P,'Rotation',270,'Position',...
                [p_crver_y_P_pos(1)+1 p_crver_y_P_pos(2)-2*p_P_step p_crver_y_P_pos(3)])
                % Precipitation y-axis label position
%             set([p_crver_x,p_crver_y_IWV,p_crver_y_P],...
%                 'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
%                 'FontWeight',plot_font_weight)
            set([p_crver_y_IWV,p_crver_y_P],...
                'FontName',plot_font_name,'FontSize',plot_size_legend-2,...
                'FontWeight',plot_font_weight)
                % Axes label font
            
            %%% Save figure %%%
            % Save current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crver_fig_path p_fig_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',[p_crver_fig_path p_fig_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view figure file
                print(gcf,'-dpdf',[p_crver_fig_path p_fig_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current file version data
            clear p_crver_*
        end
    else % At least half days are infinite
        disp(['plot_ACLOUD_AWIPEV_NMI_AWI: ' ...
            'ERROR - ' p_set_title ' ' lower(p_fig_title) ...
            ' data from ' stat_full ' missing'])
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear ver p_*
end