% PURPOSE
% Load and store 6-hourly atmospheric data from the European Centre for 
% Medium-Range Weather Forecasts (ECMWF) reanalysis interim (ERA-Interim) 
% data set for the Nordic Seas and chosen date and time interval in order 
% to study the synoptic situation during the Arctic CLoud Observations 
% Using airborne measurements during polar Day (ACLOUD) and Physical 
% feedback of Arctic planetary boundary layer, Sea ice, Cloud and AerosoL 
% (PASCAL) field campaigns May 22 - June 28, 2017 on/near Spitsbergen.
%
% The data set choices are:
%   ERA-Int : European Centre for Medium-Range Weather Forecasts (ECMWF) 
%             reanalysis interim
%
% The parameter choices are:
%   Z700hPa : 700-hPa geopotential height (Z_{700hPa})
%   u700hPa : 700-hPa zonal wind (u_{700hPa})
%   v700hPa : 700-hPa meridional wind (v_{700hPa})
%   T700hPa : 700-hPa temperature (T_{700hPa})
%   q700hPa : 700-hPa specific humidity (q_{700hPa})
%   RH700hPa: 700-hPa relative humidity (RH_{700hPa})
%
% The region choices are:
%   NS  : Nordic Seas
%
% NB! Time period start given as 1st year with whole calendar year data.
%
% CHOICES
%   mod_name        : Data set names and time period
%                     [Data set number : File name : MATLAB name : ...
%                      Abbreviated name : Full name : Time period]
%   param_name      : Parameter names and unit of field campaign data
%                     [Parameter number : General name : File name : ...
%                      Data name : MATLAB name : Full name : Unit]
%   path_MATLAB     : MATLAB path
%   path_data       : Data path
%   yr_bnd          : Boundary of chosen year(s) of field campaign data
%   month_bnd       : Boundary of chosen month(s) of field campaign data
%   day_bnd         : Boundary of chosen day(s) of field campaign data
%   hr_bnd          : Boundary of chosen hour(s) of field campaign data
%   mod_indx        : Index(es) of chosen data set(s)
%   param_indx      : Index(es) of chosen parameter(s) of field campaign 
%                     data
%   plot_no         : Number of open plots
%   plot_typename   : MATLAB name of figure type(s) to be plotted
%
% USES
%   plot_ACLOUD_ERA.m
%
% ABBREVIATIONS
%   STD : Standard deviation
%
% MATLAB REQUIREMENTS
%   Charles R. Denham's NetCDF Toolbox
%       (http://crusty.er.usgs.gov/~cdenham/MexCDF/)
%   CSIRO MATLAB/NetCDF Interface
%       (http://www.marine.csiro.au/sw/matlab-netcdf.html)
%
%
% AUTHOR
%   Erlend Moster Knudsen
%   PostDoc
%   Institute for Geophysics and Meteorology, University of Cologne
%   eknudsen@uni-koeln.de
%   November 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% Basic settings %%%%%
%%% Time properties %%%
% Time interval names
tint_name = ...
    [{''} {'Every minute'} {'6-hourly'} {'Day'} {'Month'} ...
    {'Season'} {'Year'} {'Time section'}; ...
    {'n.'} {'min'} {'6hr'} {'day'} {'month'} {'seas'} {'yr'} {'tsec'}; ...
    {'adj./adv.'} {'everymin'} {'6hourly'} {'daily'} {'monthly'} ...
    {'seasonal'} {'annual'} {'time_sectional'}];

% Month names and day numbers
month_name = {'Number' 'Name' 'Abbreviation' 'Initial'};
    % Header of month names table
month_name_full = ...
    {'January'; 'February'; 'March'; 'April'; 'May'; 'June'; ...
    'July'; 'August'; 'September'; 'October'; 'November'; 'December'};
    % Name of all months
for m = 1:size(month_name_full) % m = 1:12 - Loop over number of months
    % Temporary variable
    month_name_tmp = char(month_name_full(m));
    
    % Month names table
    month_name(m+1,:) = ...
        [num2cell(m) month_name_tmp cellstr(month_name_tmp(1:3)) cellstr(month_name_tmp(1))];
end
month_dayno = [31 29 31 30 31 30 31 31 30 31 30 31];
    % Number of days per month, February given as a leap-year
month_daysum = cumsum(month_dayno,2);
    % Number of cumulative days up to the end day per month
    % NB! February given as a leap-year
clear m month_name_* % Delete unnecessary variable(s)

%%% Data sets and variables %%%
% Data set names
mod_name = ...
    [{'      '} {'File name'} {'MATLAB name'} {'Abbreviation'} ...
    {'Full name'} {'Time period'}; ...
    {'Mod 1'} {'ERA_INT'} {'ERA'} {'ERA-Int'} ...
    {'European Centre for Medium-Range Weather Forecasts reanalysis interim'} ...
    {'1979-2017'}];
    % [Data set number : File name : MATLAB name : Abbreviated name : ...
    %  Full name : Time period]
    
% Parameter names
param_name = ...
    [{'      '} {'General name'} {'File name'} {'Data name'} ...
    {'MATLAB name'} {'Full name'} {'Unit'}; ...
    {'Param 1'} {'p'} {'phi700hPa'} {'z'} ...
    {'Z700hPa'} {'700-hPa geopotential height'} {'gpdm'}; ...
    {'Param 2'} {'wind'} {'u700hPa'} {'u'} ...
    {'u700hPa'} {'700-hPa zonal wind'} {'m s^{-1}'}; ...
    {'Param 3'} {'wind'} {'v700hPa'} {'v'} ...
    {'v700hPa'} {'700-hPa meridional wind'} {'m s^{-1}'}; ...
    {'Param 4'} {'T'} {'T700hPa'} {'t'} ...
    {'T700hPa'} {'700-hPa temperature'} {'{\circ}C'}; ...
    {'Param 5'} {'humid'} {'q700hPa'} {'q'} ...
    {'q700hPa'} {'700-hPa specific humidity'} {'kg kg^{-1}'}; ...
    {'Param 6'} {'humid'} {'RH700hPa'} {'r'} ...
    {'RH700hPa'} {'700-hPa relative humidity'} {'%'}];
    % [Parameter number : General name : File name : Data name : ...
    %  MATLAB name : Full name : Unit]
    % NB! Z_{700hPa} given as geopotential (phi; in [m²/s²]) from data, 
    %     conversion to geopotential height (Z; in [m]) in treatment
    % NB! T_{700hPa} given in [K] from data, 
    %     conversion to [deg C] in treatment

%%% Regions and stations %%%
% Region names
reg_name = ...
    [{'      '} {'Abbreviated name'} {'Full name'} ...
    {'Latitudinal start'} {'Latitudinal end'} ...
    {'Longitudinal start'} {'Longitudinal end'}; ...
    {'Reg 1'} {'NS'} {'Nordic Seas'} {'65'} {'85'} {'-30'} {'60'}];
    % [Region number : Abbreviated name : Full name : ...
    %   Latitudinal lower boundary : Latitudinal upper boundary : ...
    %   Longitudinal lower boundary : Longitudinal upper boundary]

%%% Paths %%%
% MATLAB path
path_MATLAB = '/home/eknudsen/MATLAB/ACLOUD/';
    % '/Users/erlendmosterknudsen/Documents/MATLAB/ACLOUD/'
    %       = Mac hard drive path
    % '/home/eknudsen/MATLAB/ACLOUD/'
    %       = Linux hard drive path
    % '/media/backup/eknudsen/Dokumenter/Skole/Geofysikk/
    %   Data/Tools/MATLAB/ACLOUD/'
    %       = UzK hard drive path
    % '/Volumes/UIB-USB/Dokumenter/Skole/Geofysikk/
    %   Data/Tools/MATLAB/ACLOUD/'
    %       = External hard drive path
    
% Data path
path_data = '/media/backup/eknudsen/Dokumenter/Skole/Geofysikk/Data/';
    % '/Users/erlendmosterknudsen/Documents/MATLAB/ACLOUD/'
    %       = Mac hard drive path
    % '/home/eknudsen/MATLAB/ACLOUD/'
    %       = Linux hard drive path
    % '/media/backup/eknudsen/Dokumenter/Skole/Geofysikk/
    %   Data/Tools/MATLAB/ACLOUD/'
    %       = UzK hard drive path
    % '/Volumes/UIB-USB/Dokumenter/Skole/Geofysikk/
    %   Data/Tools/MATLAB/ACLOUD/'
    %       = External hard drive path
    
% Figure path
path_fig = [path_data 'Tools/MATLAB/Figures/AWIPEV-NMI-AWI-ERA_INT/'];

%%%%% Chosen settings %%%%%
%%% Data sets and parameters %%%
% Index(es) and number of chosen parameter(s) in campaign data
param_indx = [4 5]; % Index(es)
    % 1 = Z_{700hPa}
    % 2 = u_{700hPa}
    % 3 = v_{700hPa}
    % 4 = T_{700hPa}
    % 5 = q_{700hPa}
    % 6 = RH_{700hPa}
param_no = length(param_indx); % Number

% Index(es) and number of corresponding data set(s)
if sum(ismember(1:6,param_indx)) > 0 % p, wind, T and/or humid data
    % Index
    %   1 = ERA
    mod_indx = 1;
    
    % Loop over data set parameters and display chosen parameter and 
    % corresponding data set
    for i = 1:6 % Loop over index(es) of ERA parameters
        % Current data set index logical
        param_log = ismember(i,param_indx);
        
        % Display chosen parameter and corresponding data set
        if param_log == 1
            disp(['load_ACLOUD_ERA: ' ...
                'Chosen parameter = ' char(param_name(i+1,6)) ', ' ...
                'chosen data set = ' char(mod_name(1+1,4))])
        end
    end
end
mod_no = length(mod_indx); % Number
clear i param_log % Delete unnecessary variable(s)

%%% Time settings %%%
% Data set time period name, boundary, vector and number
yr_mod_name = char(mod_name(mod_indx+1,6)); % Name
yr_mod_bnd = [str2double(yr_mod_name(1:4)) str2double(yr_mod_name(6:end))];
    % Boundary, [Start : End]
yr_mod_vec = [yr_mod_bnd(1):yr_mod_bnd(2)]'; % Vector, [Yr_Mod]
yr_mod_no = length(yr_mod_vec); % Number

% Chosen year(s) boundary, vector, indexes, number and name of campaign 
% data
yr_cpgn_bnd = [yr_mod_bnd(2) yr_mod_bnd(2)]; % Boundary, [Start : End]
yr_cpgn_vec = [yr_cpgn_bnd(1):yr_cpgn_bnd(2)]'; % Vector, [Yr_Cpgn]
[~,yr_cpgn_indx] = intersect(yr_mod_vec,yr_cpgn_vec);
    % Indexes of years within data set time period, [Yr_Cpgn]
yr_cpgn_no = length(yr_cpgn_vec); % Number
if yr_cpgn_no == 1 % Only 1 year
    % Name
    yr_cpgn_name = num2str(yr_cpgn_bnd(1));
else % Several years
    % Name
    yr_cpgn_name = [num2str(yr_cpgn_bnd(1)) '-' num2str(yr_cpgn_bnd(2))];
end

% Chosen year(s) boundary, vector, indexes, number and name of climatology 
% data
yr_clim_bnd = [yr_mod_bnd(1) yr_mod_bnd(2)-1];
    % Boundary, [Start : End]
yr_clim_vec = [yr_clim_bnd(1):yr_clim_bnd(2)]'; % Vector, [Yr_Clim]
[~,yr_clim_indx] = intersect(yr_mod_vec,yr_clim_vec);
    % Indexes of years within data set time period, [Yr_Clim]
yr_clim_no = length(yr_clim_vec); % Number
yr_clim_name = [num2str(yr_clim_bnd(1)) '-' num2str(yr_clim_bnd(2))];

% Chosen month(s) boundary, vector, number and name of campaign data
month_bnd = [5 6]; % Boundary, [Start : End]
month_vec = month_bnd(1):month_bnd(2); % Vector, [Month]
month_no = length(month_vec); % Number
if month_no == 1 % Only 1 month
    % Name
    month_abbr = char(month_name(month_vec+1,3));
else % Several months
    % Name
    month_abbr = permute(char(month_name(month_vec+1,4)),[2 1]);
end

% Chosen day(s) boundary, vector and number of campaign data
day_bnd = [143 177]; % Boundary, [Start : End]
    % NB! Must account for leap-year possibility
day_vec = [day_bnd(1):day_bnd(2)]'; % Vector, [Day]
day_no = length(day_vec); % Number

% Chosen 6-hour(s) boundary, vectors and number of campaign data
hr_bnd = [0 18]; % Boundary, [Start : End]
hr_vec = [hr_bnd(1):24/4:hr_bnd(2)]'; % Vector, [Hr]
hr_no = length(hr_vec); % Number

% Chosen time period boundary names of campaign data
tper_txt = ...
    [datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)-month_daysum(month_bnd(1)-1)+1,0,0,0]) ...
    ' - ' ...
    datestr([yr_cpgn_bnd(2),month_bnd(2),day_bnd(2)-month_daysum(month_bnd(2)-1)+1,0,0,0])];
    % Text
tper_num = ....
    [datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)-month_daysum(month_bnd(1)-1)+1,0,0,0],...
    'yyyymmdd') ...
    '-' ...
    datestr([yr_cpgn_bnd(2),month_bnd(2),day_bnd(2)-month_daysum(month_bnd(2)-1)+1,0,0,0],...
    'yyyymmdd')];
    % Numerical

% Chosen key period boundaries, number and names
kper_bnd = [1 7; 8 21; 22 35]; % Boundary, [Kp; Start : End]
    % NB! Referring to campaign time period day indexes, not year indexes
kper_no = size(kper_bnd,1); % Number
kper_txt = ...
    [datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(1,1)-month_daysum(month_bnd(1)-1),...
    0,0,0]) ...
    ' - ' ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(1,2)-month_daysum(month_bnd(1)-1),...
    0,0,0]); ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(2,1)-month_daysum(month_bnd(1)-1),...
    0,0,0]) ...
    ' - ' ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(2,2)-month_daysum(month_bnd(1)-1),...
    0,0,0]); ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(3,1)-month_daysum(month_bnd(1)-1),...
    0,0,0]) ...
    ' - ' ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(3,2)-month_daysum(month_bnd(1)-1),...
    0,0,0])];
    % [Kp], text name
kper_num = ....
    [datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(1,1)-month_daysum(month_bnd(1)-1),...
    0,0,0],'yyyymmdd') ...
    '-' ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(1,2)-month_daysum(month_bnd(1)-1),...
    0,0,0],'yyyymmdd'); ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(2,1)-month_daysum(month_bnd(1)-1),...
    0,0,0],'yyyymmdd') ...
    '-' ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(2,2)-month_daysum(month_bnd(1)-1),...
    0,0,0],'yyyymmdd'); ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(3,1)-month_daysum(month_bnd(1)-1),...
    0,0,0],'yyyymmdd') ...
    '-' ...
    datestr([yr_cpgn_bnd(1),month_bnd(1),day_bnd(1)+kper_bnd(3,2)-month_daysum(month_bnd(1)-1),...
    0,0,0],'yyyymmdd')];
    % [Kp], numerical name

% Display chosen time properties of campaign data
disp(['load_ACLOUD_ERA: Chosen time period = ' tper_txt])
for kp = 1:kper_no % Loop over number of key periods
    disp(['load_ACLOUD_ERA: Chosen key period = ' kper_txt(kp,:)])
end
clear kp % Delete unnecessary variable(s)

%%% Region(s) %%%
% Chosen region(s) index, number and names
reg_indx = 1; % Index(es)
    % 1 : Nordic Seas
reg_no = length(reg_indx); % Number
reg_abbr = char(reg_name(reg_indx+1,2)); % Abbreviated name(s)
reg_full = char(reg_name(reg_indx+1,3)); % Full name(s)

% Chosen region(s) boundary latitudes and longitudes
reg_lat_bnd = ...
    [str2double(char(reg_name(reg_indx+1,4))) ...
    str2double(char(reg_name(reg_indx+1,5)))];
    % [deg N], latitude, [Start : End]
reg_lon_bnd = ...
    [str2double(char(reg_name(reg_indx+1,6))) ...
    str2double(char(reg_name(reg_indx+1,7)))];
    % [deg E], longitude, [Start : End]

%%%%% Store basic data %%%%%
%%% Store basic variables %%%
% Data set MATLAB names
mod_MATLAB = char(mod_name(1+1,3)); % 1st data set
for s = 2:size(mod_name,1) - 1 % Loop over number of data sets
    % Other data sets
    mod_MATLAB = [mod_MATLAB '-' char(mod_name(s+1,3))];
end
clear s % Delete unnecessary variable(s)

% Parameter path and file names
param_path = char(param_name(1+1,2)); % 1st parameter, path
param_file = param_path; % 1st parameter, file
for p = 2:size(param_name,1) - 1 % Loop over number of parameters
    % Other parameters
    if isempty(strfind(param_path,char(param_name(p+1,2))))
            % General name non-existent
        % Path
        param_path = [param_path '_' char(param_name(p+1,2))];
        
        % File
        param_file = [param_file '-' char(param_name(p+1,2))];
    end
end
clear p % Delete unnecessary variable(s)

% Path and file name for variable storage
path_store = [path_MATLAB param_path '_data/']; % Path
file_store = [param_file '_' mod_MATLAB '_' yr_cpgn_name '.mat']; % File

% Store basic variables
save([path_store file_store],...
    'tint_name','yr_*','month_*','day_*','hr_*','kper_*',...
    'path_*','mod_*','param_*','reg_name')

%%% Delete data %%%
% Delete unnecessary variable(s)
clear file_store
%%
%%%%%%%% Load data %%%%%%%%
%%%%% p data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
p_name_all = param_name(1+1,5); % Name(s)
p_indx_all = find(strcmp(param_name(2:end,5),p_name_all(1)));
    % Index(es)

% Load p data only if chosen
if sum(ismember(p_indx_all,param_indx)) > 0 % p data chosen
    %%% Basic parameter settings %%%
    % Set time step names
    p_tstep_abbr = char(tint_name(1+1,2+1)); % Abbreviated
    p_tstep_full = char(tint_name(2+1,2+1)); % Full
    
    % Set data set names
    p_set_file = char(mod_name(1+1,2)); % File
    p_set_MATLAB = char(mod_name(1+1,3)); % MATLAB
    p_set_tper = char(mod_name(1+1,6)); % Time period
    
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    p_name_chos = p_name_all(ismember(p_indx_all,param_indx)); % Name(s)
    p_indx_chos = p_indx_all(ismember(p_indx_all,param_indx)); % Index(es)
    p_no_chos = length(p_indx_chos); % Number
    
    % Loop over chosen p variables and load p data
    for p = 1:p_no_chos % Loop over number of chosen p parameters
        %%% Parameter and data set names %%%
        % Extract current chosen parameter names
        crp_name_gen = char(param_name(p_indx_chos(p)+1,2));
            % General
        crp_name_file = char(param_name(p_indx_chos(p)+1,3));
            % File
        crp_name_data = char(param_name(p_indx_chos(p)+1,4));
            % Data
        crp_name_MATLAB = char(param_name(p_indx_chos(p)+1,5));
            % MATLAB
        crp_name_full = char(param_name(p_indx_chos(p)+1,6));
            % Full
            
        % Extract current chosen parameter unit
        crp_unit = char(param_name(p_indx_chos(p)+1,7));
        
        % Set current chosen parameter storage path and file names
        crp_store_path = path_store; % Path
        crp_store_file = ...
            [crp_name_MATLAB '_' reg_abbr '_' ...
            month_abbr '_' yr_cpgn_name '_' p_set_MATLAB '.mat'];
            % File
            
        % Display current chosen parameter loading conditions
        disp(['load_ACLOUD_ERA: Loading ' crp_name_MATLAB ...
            ' data from the ' p_set_MATLAB ' data set'])
        
        %%% Variables in storage file %%%
        % Set current chosen parameter time variables names
        crp_store_t_name = ...
            [{[crp_name_MATLAB '_date_6hrdaymonth_' p_set_MATLAB]}; ...
            {[crp_name_MATLAB '_date_daymonth_' p_set_MATLAB]}];
            % [6-hourly date matrix; ...
            %  Daily date matrix]
            
        % Set current chosen parameter location variables names
        crp_store_loc_name = ...
            [{[crp_name_MATLAB '_lat_' p_set_MATLAB]}; ...
            {[crp_name_MATLAB '_lon_' p_set_MATLAB]}];
            % [Latitudinal grid point vector; ...
            %  Longitudinal grid point vector]
        
        % Set current chosen parameter campaign variable names
        crp_store_cpgn_name = ...
            [{[crp_name_MATLAB '_cpgn_6hrdaymonth_lat_lon_' p_set_MATLAB]}; ...
            {[crp_name_MATLAB '_cpgn_daymonth_6hr_lat_lon_' p_set_MATLAB]}; ...
            {[crp_name_MATLAB '_cpgn_daymonth_lat_lon_' p_set_MATLAB]}];
            % [6-hourly over time period per latitude per longitude; ...
            %  6-hourly per day over time period per latitude per 
            %   longitude; ...
            %  Daily averaged daily over time period per latitude per 
            %   longitude]
            
        % Set current chosen parameter climatology variable names
        crp_store_clim_name = ...
            [{[crp_name_MATLAB '_clim_mean_daymonth_lat_lon_' p_set_MATLAB]}; ...
            {[crp_name_MATLAB '_clim_STD_daymonth_lat_lon_' p_set_MATLAB]}];
            % [Daily averaged annually over time period per latitude per 
            %   longitude; ...
            %  Daily standard-deviated annually over time period per 
            %   latitude per longitude]
        
        %%% Variables to load from storage files %%%
        % Check existence of current chosen parameter variable in storage 
        % file
        if exist([crp_store_path crp_store_file],'file')
                % File existent
            % Find current chosen parameter file variable names
            crp_store_var_file = ...
                whos('-file',[crp_store_path crp_store_file]);
            
            % Check existence of current chosen parameter variables in 
            % storage file
            crp_store_cpgn_exist = ...
                ismember(crp_store_cpgn_name,{crp_store_var_file.name});
                % Campaign variables
            crp_store_clim_exist = ...
                ismember(crp_store_clim_name,{crp_store_var_file.name});
                % Climatology variables
        else % File non-existent
            % Set current chosen parameter logical variable to zero
            crp_store_cpgn_exist = 0; % Campaign variables
            crp_store_clim_exist = 0; % Climatology variables
        end
        
        % Load current chosen parameter data only if variables are 
        % non-existent
        if sum(crp_store_cpgn_exist) == length(crp_store_cpgn_exist) && ...
                sum(crp_store_clim_exist) == length(crp_store_clim_exist)
                % Variables existent
            disp('load_ACLOUD_ERA: Existent variables:')
            disp(crp_store_t_name)
            disp(crp_store_loc_name)
            disp(crp_store_cpgn_name)
            disp(crp_store_clim_name)
            
            %%% Load data %%%
            % Load current chosen parameter data from .mat file
            load([crp_store_path crp_store_file],...
                crp_store_t_name{:},crp_store_loc_name{:},...
                crp_store_cpgn_name{:},crp_store_clim_name{:})
            
            %%% Rename data %%%
            % Rename current chosen parameter time variables
            crp_date_6hrdaymonth = eval(char(crp_store_t_name(1)));
                % 6-hourly date matrix
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
            crp_date_daymonth = eval(char(crp_store_t_name(2)));
                % Daily date matrix
                % [Day*Month; Yr : Month : Day]
                
            % Rename current chosen parameter location variables
            crp_lat = eval(char(crp_store_loc_name(1)));
                % [deg N]
                % Latitudinal grid point vector
                % [Lat]
            crp_lon = eval(char(crp_store_loc_name(2)));
                % [deg E]
                % Longitudinal grid point vector
                % [Lon]
            
            % Rename current chosen parameter campaign variables
            crp_cpgn_6hrdaymonth_lat_lon = ...
                eval(char(crp_store_cpgn_name(1)));
                % [m]
                % 6-hourly over time period per latitude per longitude
                % [6hr*Day*Month; Lat; Lon]
            crp_cpgn_daymonth_6hr_lat_lon = ...
                eval(char(crp_store_cpgn_name(2)));
                % [m]
                % 6-hourly per day over time period per latitude per 
                % longitude
                % [Day*Month; 6hr; Lat; Lon]
            crp_cpgn_daymonth_lat_lon = eval(char(crp_store_cpgn_name(3)));
                % [m]
                % Daily averaged daily over time period per latitude per 
                % longitude
                % [Day*Month; Lat; Lon]
                
            % Rename current chosen parameter climatology variables
            crp_clim_mean_daymonth_lat_lon = ...
                eval(char(crp_store_clim_name(1)));
                % [m]
                % Daily averaged annually over time period per latitude per
                % longitude
                % [Day*Month; Lat; Lon]
            crp_clim_STD_daymonth_lat_lon = ...
                eval(char(crp_store_clim_name(2)));
                % [m]
                % Daily standard-deviated annually over time period per 
                % latitude per longitude
                % [Day*Month; Lat; Lon]
        else % File non-existent
            disp('load_ACLOUD_ERA: Loading variables:')
            disp(crp_store_t_name)
            disp(crp_store_loc_name)
            disp(crp_store_cpgn_name)
            disp(crp_store_clim_name)
            
            %%% Load location data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Loading ' p_set_MATLAB ' ' crp_name_MATLAB ...
                ' location data'])
            
            % Set current chosen parameter loading path and data names
            crp_load_path = ...
                [path_data 'Reanalyses/' upper(p_tstep_full) '/'];
                % Path
            crp_load_data = crp_name_data;
                % Data
                
            % Set current chosen parameter campaign loading file name
            crp_cpgn_load_file = ...
                [p_set_file '_' crp_name_file '_' ...
                p_tstep_full '_' month_abbr '_' yr_cpgn_name '.nc'];
                
            % Load current chosen parameter location data
            crp_lat = ...
                getnc([crp_load_path crp_cpgn_load_file],'latitude');
                % [deg N], latitude, [Lat_All]
            crp_lon = ...
                getnc([crp_load_path crp_cpgn_load_file],'longitude');
                % [deg E], longitude, [Lon_All]
                
            % Calculate current chosen parameter location grid point
            % numbers
            crp_lat_no = length(crp_lat); % Latitude
            crp_lon_no = length(crp_lon); % Longitude
            
            %%% Find location boundary data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Extracting ' p_set_MATLAB ' ' crp_name_MATLAB ...
                ' location data over chosen region'])
            
            % Find current chosen parameter chosen region boundary indexes 
            % in latitude data
            crp_lat_bnd_indx_srt = find(crp_lat == reg_lat_bnd(1),1);
                % Start - Exact longitudinal grid point
            if isempty(crp_lat_bnd_indx_srt) % No location point equality
                % Closest latitudinal grid point
                [~,crp_lat_bnd_indx_srt] = ...
                    min(abs(crp_lat - reg_lat_bnd(1)));
                    % Start
            end
            crp_lat_bnd_indx_end = find(crp_lat == reg_lat_bnd(2),1);
                % End - Exact longitudinal grid point
            if isempty(crp_lat_bnd_indx_end) % No location point equality
                % Closest latitudinal grid point
                [~,crp_lat_bnd_indx_end] = ...
                    min(abs(crp_lat - reg_lat_bnd(2)));
                    % End
            end
            
            % Merge current chosen parameter chosen region boundary indexes 
            % in latitude data
            crp_lat_bnd_indx = [crp_lat_bnd_indx_srt crp_lat_bnd_indx_end];
                % Unsorted, [Start : End]
            crp_lat_bnd_indx = sort(crp_lat_bnd_indx);
                % Sorted, [Start : End]
            
            % Find and merge current chosen parameter chosen region 
            % boundary indexes in longitude data
            if max(max(crp_lon)) > 180 % Format = [0,360] deg E
                % Find boundary index(es) in Eastern Hemisphere
                crp_lon_bnd_indx_EH = ...
                    [1 find(crp_lon == reg_lon_bnd(2),1)];
                    % Exact longitudinal grid points, [Start : End]
                if length(crp_lon_bnd_indx_EH) == 1
                        % Only one location point equality
                    % Closest longitudinal end grid point
                    [~,crp_lon_bnd_indx_EH(2)] = ...
                        min(abs(crp_lon - reg_lon_bnd(2)));
                end
                
                % Find boundary index(es) in Western Hemisphere
                crp_lon_bnd_indx_WH = ...
                    [find(crp_lon == reg_lon_bnd(1) + 360,1) crp_lon_no];
                    % Exact longitudinal grid points, [Start : End]
                if length(crp_lon_bnd_indx_WH) == 1
                        % Only one location point equality
                    % Closest longitudinal start grid point
                    crp_lon_bnd_indx_WH = ...
                        [min(abs(crp_lon - reg_lon_bnd(1) + 360)) ...
                        crp_lon_bnd_indx_WH];
                        % [Start : End]
                end
                
                % Merge boundary indexes
                crp_lon_bnd_indx = ...
                    [crp_lon_bnd_indx_EH; crp_lon_bnd_indx_WH];
                    % [EH : WH; Start : End]
            else % Format = [-180,180] deg E
                % Find start index
                crp_lon_bnd_indx_srt = find(crp_lon == reg_lon_bnd(1),1);
                    % Exact longitudinal grid point
                if isempty(crp_lon_bnd_indx_srt)
                        % No location point equality
                    % Closest longitudinal grid point
                    [~,crp_lon_bnd_indx_srt] = ...
                        min(abs(crp_lon - reg_lon_bnd(1)));
                end
                
                % Find end index
                crp_lon_bnd_indx_end = find(crp_lon == reg_lon_bnd(2),1);
                    % Exact longitudinal grid point
                if isempty(crp_lon_bnd_indx_end)
                        % No location point equality
                    % Closest longitudinal grid point
                    [~,crp_lon_bnd_indx_end] = ...
                        min(abs(crp_lon - reg_lon_bnd(2)));
                end
                
                % Merge boundary indexes
                crp_lon_bnd_indx = ...
                    [crp_lon_bnd_indx_srt crp_lon_bnd_indx_end];
                    % Unsorted, [Start : End]
                crp_lon_bnd_indx = sort(crp_lon_bnd_indx);
                    % Sorted, [Start : End]
            end
            
            % Delete unnecessary variable(s)
            clear crp_lat_bnd_indx_* crp_lon_bnd_indx_*
            
            %%% Extract location data %%%
            % Extract current chosen parameter location data over chosen 
            % region
            crp_lat = crp_lat(crp_lat_bnd_indx(1):crp_lat_bnd_indx(2));
                % [deg N], latitude, [Lat]
            if size(crp_lon_bnd_indx,1) == 2 % Format = [0,360] deg E
                % Longitude
                crp_lon = ...
                    [crp_lon(crp_lon_bnd_indx(2,1):crp_lon_bnd_indx(2,2)); ...
                    crp_lon(crp_lon_bnd_indx(1,1):crp_lon_bnd_indx(1,2))];
                    % [deg E], [Lon]
            else % Format = [-180,180] deg E
                % Longitude
                crp_lon = crp_lon(crp_lon_bnd_indx(1):crp_lon_bnd_indx(2));
                    % [deg E], [Lon]
            end
            
            % Calculate current chosen parameter location grid point
            % numbers
            crp_lat_no = length(crp_lat); % Latitude
            crp_lon_no = length(crp_lon); % Longitude
            
            %%% Load, find boundary and extract time and variable data %%%
            % Loop over data set years and load current chosen parameter
            % time and variable data
            for y = 1:yr_mod_no % Loop over number of data set years
                % Extract current data set year name
                cryr_name = num2str(yr_mod_vec(y));
                disp(['load_ACLOUD_ERA: ' ...
                    'Loading and extracting ' p_set_MATLAB ' ' ...
                    crp_name_MATLAB ' data for ' cryr_name])
                
                % Set current chosen parameter current climatology year 
                % loading file name
                crp_cryr_load_file = ...
                    [p_set_file '_' crp_name_file '_' ...
                    p_tstep_full '_' month_abbr '_' cryr_name '.nc'];
                
                % Load current chosen parameter current climatology year 
                % time data
                crp_cryr_date_6hrdaymonth = ...
                    timenc([crp_load_path crp_cryr_load_file],'time');
                    % [6hr_All*Day_All*Month_All; ...
                    %  Yr : Month : Day : Hr : Min : Sec]
                
                % Load current chosen parameter current climatology year 
                % variable data
                crp_cryr_6hrdaymonth_lat_lon = ...
                    getnc([crp_load_path crp_cryr_load_file],...
                    crp_load_data);
                    % [m²/s²]
                    % [6hr_All*Day_All*Month_All; Lat_All; Lon_All]
                
                % Convert current chosen parameter current climatology year
                % variable data
                if strcmp(crp_name_MATLAB(1),'Z')
                        % Geopotential height data
                    % Convert from geopotential [m²/s²] to geopotential 
                    % height [m] by dividing by the World Meteolorogial 
                    % Organization (WMO) defined gravity constant 
                    % 9.80665 m/s²
                    crp_cryr_6hrdaymonth_lat_lon = ...
                        crp_cryr_6hrdaymonth_lat_lon/9.80665;
                        % [m]
                        % [6hr_All*Day_All*Month_All; Lat_All; Lon_All]
                end
                
                % Find current chosen parameter current climatology year 
                % chosen time period boundary indexes in time data
                crp_cryr_date_bnd_indx_srt = ...
                    find(crp_cryr_date_6hrdaymonth(:,2) == month_bnd(1) ...
                    & crp_cryr_date_6hrdaymonth(:,3) == ...
                    day_bnd(1) - month_daysum(month_bnd(1)-1) + 1,...
                    1,'first');
                    % Start
                crp_cryr_date_bnd_indx_end = ...
                    find(crp_cryr_date_6hrdaymonth(:,2) == month_bnd(2) ...
                    & crp_cryr_date_6hrdaymonth(:,3) == ...
                    day_bnd(2) - month_daysum(month_bnd(2)-1) + 1,...
                    1,'last');
                    % End
                    
                % Merge current chosen parameter current climatology year 
                % chosen time period boundary indexes in time data
                crp_cryr_date_bnd_indx = ...
                    [crp_cryr_date_bnd_indx_srt ...
                    crp_cryr_date_bnd_indx_end];
                    % [Start : End]
                
                % Extract current chosen parameter current climatology year
                % time data over chosen time period
                crp_cryr_date_6hrdaymonth = ...
                    crp_cryr_date_6hrdaymonth(...
                    crp_cryr_date_bnd_indx(1):crp_cryr_date_bnd_indx(2),:);
                    % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
                    
                % Extract current chosen parameter current climatology year
                % variable data over chosen time period
                crp_cryr_6hrdaymonth_lat_lon = ...
                    crp_cryr_6hrdaymonth_lat_lon(...
                    crp_cryr_date_bnd_indx(1):crp_cryr_date_bnd_indx(2),:,:);
                    % [m], [6hr*Day*Month; Lat_All; Lon_All]
                
                % Extract current chosen parameter current climatology year
                % variable data over chosen region
                if size(crp_lon_bnd_indx,1) == 2 % Format = [0,360] deg E
                    crp_cryr_6hrdaymonth_lat_lon = ...
                        cat(3,...
                        crp_cryr_6hrdaymonth_lat_lon(:,...
                        crp_lat_bnd_indx(1):crp_lat_bnd_indx(2),...
                        crp_lon_bnd_indx(2,1):crp_lon_bnd_indx(2,2)),...
                        crp_cryr_6hrdaymonth_lat_lon(:,...
                        crp_lat_bnd_indx(1):crp_lat_bnd_indx(2),...
                        crp_lon_bnd_indx(1,1):crp_lon_bnd_indx(1,2)));
                        % [m], [6hr*Day*Month; Lat; Lon]
                else % Format = [-180,180] deg E
                    crp_cryr_6hrdaymonth_lat_lon = ...
                        crp_cryr_6hrdaymonth_lat_lon(:,...
                        crp_lat_bnd_indx(1):crp_lat_bnd_indx(2),...
                        crp_lon_bnd_indx(1):crp_lon_bnd_indx(2));
                        % [m], [6hr*Day*Month; Lat; Lon]
                end
                
                % Store current chosen parameter current climatology year 
                % time data in 6-hourly matrix over chosen time period 
                % per climatology year
                crp_date_6hrdaymonthyr(hr_no*day_no*(y-1)+1:hr_no*day_no*y,:) = ...
                    crp_cryr_date_6hrdaymonth;
                    % [6hr*Day*Month*Yr; Yr : Month : Day : Hr : Min : Sec]
                
                % Store current chosen parameter current climatology year 
                % variable data in 6-hourly matrix over chosen time period 
                % per climatology year per latitude per longitude
                crp_yr_6hrdaymonth_lat_lon(y,:,:,:) = ...
                    crp_cryr_6hrdaymonth_lat_lon;
                    % [m], [Yr; 6hr*Day*Month; Lat; Lon]
                
                % Delete current chosen parameter current climatology year
                % data
                clear crp_cryr_*
            end
            
            %%% Calculate data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Calculating ' p_set_MATLAB ' ' crp_name_MATLAB ...
                ' average data'])
            
            % Loop over time period days and calculate current chosen 
            % parameter daily means over time period per climatology year 
            % per latitude per longitude
            for d = 1:day_no % Loop over number of time period days
                crp_yr_daymonth_lat_lon(:,d,:,:) = ...
                    nanmean(crp_yr_6hrdaymonth_lat_lon(:,4*(d-1)+1:4*d,:,:),2);
                    % [m], [Yr; Day*Month; Lat; Lon]
            end
            
            % Calculate current chosen parameter daily mean averaged 
            % annually over climatology time period per latitude per 
            % longitude
            crp_clim_mean_daymonth_lat_lon = ...
                squeeze(nanmean(crp_yr_daymonth_lat_lon(yr_clim_indx,:,:,:),1));
                % [m], [Day*Month; Lat; Lon]
                
            % Calculate current chosen parameter daily mean 
            % standard-deviated annually over climatology time period per 
            % latitude per longitude
            crp_clim_STD_daymonth_lat_lon = ...
                squeeze(nanstd(crp_yr_daymonth_lat_lon(yr_clim_indx,:,:,:),0,1));
                % [m], [Day*Month; Lat; Lon]
                
            % Delete unnecessary variable(s)
            clear d
            
            %%% Extract data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Extracting ' p_set_MATLAB ' ' crp_name_MATLAB ...
                ' data over chosen time period'])
            
            % Extract current chosen parameter 6-hourly time data over 
            % campaign time period
            crp_date_6hrdaymonth = ...
                crp_date_6hrdaymonthyr(hr_no*day_no*yr_clim_no+1:end,:);
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
                
            % Extract current chosen parameter daily time data over 
            % campaign time period
            crp_date_daymonth = ...
                crp_date_6hrdaymonth(1:hr_no:end,1:3);
                % [Day*Month; Yr : Month : Day]
            
            % Extract current chosen parameter 6-hourly variable data over 
            % campaign time period per latitude per longitude
            crp_cpgn_6hrdaymonth_lat_lon = ...
                squeeze(crp_yr_6hrdaymonth_lat_lon(end,:,:,:));
                % [m], [6hr*Day*Month; Lat; Lon]
            
            % Extract current chosen parameter daily mean variable data 
            % over campaign time period per latitude per longitude
            crp_cpgn_daymonth_lat_lon = ...
                squeeze(crp_yr_daymonth_lat_lon(end,:,:,:));
                % [m], [Day*Month; Lat; Lon]
            
            %%% Rearrange data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Rearranging ' p_set_MATLAB ' ' crp_name_MATLAB ...
                ' data over chosen time period'])
            
            % Rearrange current chosen parameter 6-hourly variable data 
            % over campaign time period per latitude per longitude from 3D 
            % to 4D
            crp_cpgn_6hr_daymonth_lat_lon = ...
                reshape(crp_cpgn_6hrdaymonth_lat_lon,...
                hr_no,day_no,crp_lat_no,crp_lon_no);
                % [m], [6hr; Day*Month; Lat; Lon]
            crp_cpgn_daymonth_6hr_lat_lon = ...
                permute(crp_cpgn_6hr_daymonth_lat_lon,[2,1,3,4]);
                % [m], [Day*Month; 6hr; Lat; Lon]
                
            % Delete unnecessary variable(s)
            clear crp_cpgn_6hr_daymonth_lat_lon
            
            %%% Rename data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Renaming ' p_set_MATLAB ' ' crp_name_MATLAB ' data'])
            
            % Rename current chosen parameter time variables
            eval([char(crp_store_t_name(1)) ' = crp_date_6hrdaymonth;'])
                % 6-hourly date matrix
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
            eval([char(crp_store_t_name(2)) ' = crp_date_daymonth;'])
                % Daily date matrix
                % [Day*Month; Yr : Month : Day]
                
            % Rename current chosen parameter location variables
            eval([char(crp_store_loc_name(1)) ' = crp_lat;']);
                % [deg N]
                % Latitudinal grid point vector
                % [Lat]
            eval([char(crp_store_loc_name(2)) ' = crp_lon;']);
                % [deg E]
                % Longitudinal grid point vector
                % [Lon]
            
            % Rename current chosen parameter campaign variables
            eval([char(crp_store_cpgn_name(1)) ' = ' ...
                'crp_cpgn_6hrdaymonth_lat_lon;']);
                % [m]
                % 6-hourly over time period per latitude per longitude
                % [6hr*Day*Month; Lat; Lon]
            eval([char(crp_store_cpgn_name(2)) ' = ' ...
                'crp_cpgn_daymonth_6hr_lat_lon;']);
                % [m]
                % 6-hourly per day over time period per latitude per 
                % longitude
                % [Day*Month; 6hr; Lat; Lon]
            eval([char(crp_store_cpgn_name(3)) ' = ' ...
                'crp_cpgn_daymonth_lat_lon;']);
                % [m]
                % Daily averaged daily over time period per latitude per 
                % longitude
                % [Day*Month; Lat; Lon]
                
            % Rename current chosen parameter climatology variables
            eval([char(crp_store_clim_name(1)) ' = ' ...
                'crp_clim_mean_daymonth_lat_lon;']);
                % [m]
                % Daily averaged annually over time period per latitude per
                % longitude
                % [Day*Month; Lat; Lon]
            eval([char(crp_store_clim_name(2)) ' = ' ...
                'crp_clim_STD_daymonth_lat_lon;']);
                % [m]
                % Daily standard-deviated annually over time period per 
                % latitude per longitude
                % [Day*Month; Lat; Lon]
            
            %%% Store data %%%
            % Store current chosen parameter time and campaign data
            disp(['load_ACLOUD_ERA: ' ...
                'Storing ' p_set_MATLAB ' ' crp_name_MATLAB ' data'])
            save([crp_store_path crp_store_file],...
                [crp_name_MATLAB '_*_' p_set_MATLAB])
                % Store time and campaign variables
        end
        
        %%% Rename data %%%
        % Rename current chosen parameter time variables
        eval([crp_name_MATLAB '_date_6hrdaymonth = ' ...
            'crp_date_6hrdaymonth;'])
            % 6-hourly date matrix
            % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
        eval([crp_name_MATLAB '_date_daymonth = ' ...
            'crp_date_daymonth;'])
            % Daily date matrix
            % [Day*Month; Yr : Month : Day]
            
        % Rename current chosen parameter location variables
        eval([crp_name_MATLAB '_lat = crp_lat;'])
            % [deg N]
            % Latitudinal grid point vector
            % [Lat]
        eval([crp_name_MATLAB '_lon = crp_lon;'])
            % [deg E]
            % Longitudinal grid point vector
            % [Lon]
        
        % Rename current chosen parameter campaign variables
        eval([crp_name_MATLAB '_cpgn_6hrdaymonth_lat_lon = ' ...
            'crp_cpgn_6hrdaymonth_lat_lon;']);
            % [m]
            % 6-hourly over time period per latitude per longitude
            % [6hr*Day*Month; Lat; Lon]
        eval([crp_name_MATLAB '_cpgn_daymonth_6hr_lat_lon = ' ...
            'crp_cpgn_daymonth_6hr_lat_lon;']);
            % [m]
            % 6-hourly per day over time period per latitude per longitude
            % [Day*Month; 6hr; Lat; Lon]
        eval([crp_name_MATLAB '_cpgn_daymonth_lat_lon = ' ...
            'crp_cpgn_daymonth_lat_lon;']);
            % [m]
            % Daily averaged daily over time period per latitude per 
            % longitude
            % [Day*Month; Lat; Lon]
            
        % Rename current chosen parameter climatology variables
        eval([crp_name_MATLAB '_clim_mean_daymonth_lat_lon = ' ...
            'crp_clim_mean_daymonth_lat_lon;']);
            % [m]
            % Daily averaged annually over time period per latitude per
            % longitude
            % [Day*Month; Lat; Lon]
        eval([crp_name_MATLAB '_clim_STD_daymonth_lat_lon = ' ...
            'crp_clim_STD_daymonth_lat_lon;']);
            % [m]
            % Daily standard-deviated annually over time period per 
            % latitude per longitude
            % [Day*Month; Lat; Lon]
        
        %%% Delete data %%%
        % Delete unnecessary variable(s)
        clear(crp_store_t_name{:},crp_store_loc_name{:},...
            crp_store_cpgn_name{:},crp_store_clim_name{:})
        
        % Delete current chosen parameter data
        clear crp_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars p p_*
else % p data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear p_name_all p_indx_all
end
%%
%%%%% wind data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
wind_name_all = param_name(2+1:3+1,5); % Name(s)
wind_indx_all = ...
    [find(strcmp(param_name(2:end,5),wind_name_all(1))) ...
    find(strcmp(param_name(2:end,5),wind_name_all(2)))];
    % Index(es)

% Load wind data only if chosen
if sum(ismember(wind_indx_all,param_indx)) > 0 % wind data chosen
    %%% Basic parameter settings %%%
    % Set time step names
    wind_tstep_abbr = char(tint_name(1+1,2+1)); % Abbreviated
    wind_tstep_full = char(tint_name(2+1,2+1)); % Full
    
    % Set data set names
    wind_set_file = char(mod_name(1+1,2)); % File
    wind_set_MATLAB = char(mod_name(1+1,3)); % MATLAB
    wind_set_tper = char(mod_name(1+1,6)); % Time period
    
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    wind_name_chos = wind_name_all(ismember(wind_indx_all,param_indx));
        % Name(s)
    wind_indx_chos = wind_indx_all(ismember(wind_indx_all,param_indx));
        % Index(es)
    wind_no_chos = length(wind_indx_chos); % Number
    
    % Loop over chosen wind variables and load wind data
    for p = 1:wind_no_chos % Loop over number of chosen wind parameters
        %%% Parameter and data set names %%%
        % Extract current chosen parameter names
        crwind_name_gen = char(param_name(wind_indx_chos(p)+1,2));
            % General
        crwind_name_file = char(param_name(wind_indx_chos(p)+1,3));
            % File
        crwind_name_data = char(param_name(wind_indx_chos(p)+1,4));
            % Data
        crwind_name_MATLAB = char(param_name(wind_indx_chos(p)+1,5));
            % MATLAB
        crwind_name_full = char(param_name(wind_indx_chos(p)+1,6));
            % Full
            
        % Extract current chosen parameter unit
        crwind_unit = char(param_name(wind_indx_chos(p)+1,7));
        
        % Set current chosen parameter storage path and file names
        crwind_store_path = path_store; % Path
        crwind_store_file = ...
            [crwind_name_MATLAB '_' reg_abbr '_' ...
            month_abbr '_' yr_cpgn_name '_' wind_set_MATLAB '.mat'];
            % File
            
        % Display current chosen parameter loading conditions
        disp(['load_ACLOUD_ERA: Loading ' crwind_name_MATLAB ...
            ' data from the ' wind_set_MATLAB ' data set'])
        
        %%% Variables in storage file %%%
        % Set current chosen parameter time variables names
        crwind_store_t_name = ...
            [{[crwind_name_MATLAB '_date_6hrdaymonth_' wind_set_MATLAB]}; ...
            {[crwind_name_MATLAB '_date_daymonth_' wind_set_MATLAB]}];
            % [6-hourly date matrix; ...
            %  Daily date matrix]
            
        % Set current chosen parameter location variables names
        crwind_store_loc_name = ...
            [{[crwind_name_MATLAB '_lat_' wind_set_MATLAB]}; ...
            {[crwind_name_MATLAB '_lon_' wind_set_MATLAB]}];
            % [Latitudinal grid point vector; ...
            %  Longitudinal grid point vector]
        
        % Set current chosen parameter campaign variable names
        crwind_store_cpgn_name = ...
            [{[crwind_name_MATLAB '_cpgn_6hrdaymonth_lat_lon_' wind_set_MATLAB]}; ...
            {[crwind_name_MATLAB '_cpgn_daymonth_6hr_lat_lon_' wind_set_MATLAB]}; ...
            {[crwind_name_MATLAB '_cpgn_daymonth_lat_lon_' wind_set_MATLAB]}];
            % [6-hourly over time period per latitude per longitude; ...
            %  6-hourly per day over time period per latitude per 
            %   longitude; ...
            %  Daily averaged daily over time period per latitude per 
            %   longitude]
            
        % Set current chosen parameter climatology variable names
        crwind_store_clim_name = ...
            [{[crwind_name_MATLAB '_clim_mean_daymonth_lat_lon_' wind_set_MATLAB]}; ...
            {[crwind_name_MATLAB '_clim_STD_daymonth_lat_lon_' wind_set_MATLAB]}];
            % [Daily averaged annually over time period per latitude per 
            %   longitude; ...
            %  Daily standard-deviated annually over time period per 
            %   latitude per longitude]
        
        %%% Variables to load from storage files %%%
        % Check existence of current chosen parameter variable in storage 
        % file
        if exist([crwind_store_path crwind_store_file],'file')
                % File existent
            % Find current chosen parameter file variable names
            crwind_store_var_file = ...
                whos('-file',[crwind_store_path crwind_store_file]);
            
            % Check existence of current chosen parameter variables in 
            % storage file
            crwind_store_cpgn_exist = ...
                ismember(crwind_store_cpgn_name,...
                {crwind_store_var_file.name});
                % Campaign variables
            crwind_store_clim_exist = ...
                ismember(crwind_store_clim_name,...
                {crwind_store_var_file.name});
                % Climatology variables
        else % File non-existent
            % Set current chosen parameter logical variable to zero
            crwind_store_cpgn_exist = 0; % Campaign variables
            crwind_store_clim_exist = 0; % Climatology variables
        end
        
        % Load current chosen parameter data only if variables are 
        % non-existent
        if sum(crwind_store_cpgn_exist) == length(crwind_store_cpgn_exist) && ...
                sum(crwind_store_clim_exist) == length(crwind_store_clim_exist)
                % Variables existent
            disp('load_ACLOUD_ERA: Existent variables:')
            disp(crwind_store_t_name)
            disp(crwind_store_loc_name)
            disp(crwind_store_cpgn_name)
            disp(crwind_store_clim_name)
            
            %%% Load data %%%
            % Load current chosen parameter data from .mat file
            load([crwind_store_path crwind_store_file],...
                crwind_store_t_name{:},crwind_store_loc_name{:},...
                crwind_store_cpgn_name{:},crwind_store_clim_name{:})
            
            %%% Rename data %%%
            % Rename current chosen parameter time variables
            crwind_date_6hrdaymonth = eval(char(crwind_store_t_name(1)));
                % 6-hourly date matrix
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
            crwind_date_daymonth = eval(char(crwind_store_t_name(2)));
                % Daily date matrix
                % [Day*Month; Yr : Month : Day]
                
            % Rename current chosen parameter location variables
            crwind_lat = eval(char(crwind_store_loc_name(1)));
                % [deg N]
                % Latitudinal grid point vector
                % [Lat]
            crwind_lon = eval(char(crwind_store_loc_name(2)));
                % [deg E]
                % Longitudinal grid point vector
                % [Lon]
            
            % Rename current chosen parameter campaign variables
            crwind_cpgn_6hrdaymonth_lat_lon = ...
                eval(char(crwind_store_cpgn_name(1)));
                % [m/s]
                % 6-hourly over time period per latitude per longitude
                % [6hr*Day*Month; Lat; Lon]
            crwind_cpgn_daymonth_6hr_lat_lon = ...
                eval(char(crwind_store_cpgn_name(2)));
                % [m/s]
                % 6-hourly per day over time period per latitude per 
                % longitude
                % [Day*Month; 6hr; Lat; Lon]
            crwind_cpgn_daymonth_lat_lon = ...
                eval(char(crwind_store_cpgn_name(3)));
                % [m/s]
                % Daily averaged daily over time period per latitude per 
                % longitude
                % [Day*Month; Lat; Lon]
                
            % Rename current chosen parameter climatology variables
            crwind_clim_mean_daymonth_lat_lon = ...
                eval(char(crwind_store_clim_name(1)));
                % [m/s]
                % Daily averaged annually over time period per latitude per
                % longitude
                % [Day*Month; Lat; Lon]
            crwind_clim_STD_daymonth_lat_lon = ...
                eval(char(crwind_store_clim_name(2)));
                % [m/s]
                % Daily standard-deviated annually over time period per 
                % latitude per longitude
                % [Day*Month; Lat; Lon]
        else % File non-existent
            disp('load_ACLOUD_ERA: Loading variables:')
            disp(crwind_store_t_name)
            disp(crwind_store_loc_name)
            disp(crwind_store_cpgn_name)
            disp(crwind_store_clim_name)
            
            %%% Load location data %%%
            % Set current chosen parameter loading path and data names
            crwind_load_path = ...
                [path_data 'Reanalyses/' upper(wind_tstep_full) '/'];
                % Path
            crwind_load_data = crwind_name_data;
                % Data
                
            % Set current chosen parameter campaign loading file name
            crwind_cpgn_load_file = ...
                [wind_set_file '_' crwind_name_file '_' ...
                wind_tstep_full '_' month_abbr '_' yr_cpgn_name '.nc'];
                
            % Load current chosen parameter location data
            crwind_lat = ...
                getnc([crwind_load_path crwind_cpgn_load_file],...
                'latitude');
                % [deg N], latitude, [Lat_All]
            crwind_lon = ...
                getnc([crwind_load_path crwind_cpgn_load_file],...
                'longitude');
                % [deg E], longitude, [Lon_All]
                
            % Calculate current chosen parameter location grid point
            % numbers
            crwind_lat_no = length(crwind_lat); % Latitude
            crwind_lon_no = length(crwind_lon); % Longitude
            
            %%% Find location boundary data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Extracting ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' location data over chosen region'])
            
            % Find current chosen parameter chosen region boundary indexes 
            % in latitude data
            crwind_lat_bnd_indx_srt = find(crwind_lat == reg_lat_bnd(1),1);
                % Start - Exact longitudinal grid point
            if isempty(crwind_lat_bnd_indx_srt)
                    % No location point equality
                % Closest latitudinal grid point
                [~,crwind_lat_bnd_indx_srt] = ...
                    min(abs(crwind_lat - reg_lat_bnd(1)));
                    % Start
            end
            crwind_lat_bnd_indx_end = find(crwind_lat == reg_lat_bnd(2),1);
                % End - Exact longitudinal grid point
            if isempty(crwind_lat_bnd_indx_end)
                    % No location point equality
                % Closest latitudinal grid point
                [~,crwind_lat_bnd_indx_end] = ...
                    min(abs(crwind_lat - reg_lat_bnd(2)));
                    % End
            end
            
            % Merge current chosen parameter chosen region boundary indexes 
            % in latitude data
            crwind_lat_bnd_indx = ...
                [crwind_lat_bnd_indx_srt crwind_lat_bnd_indx_end];
                % Unsorted, [Start : End]
            crwind_lat_bnd_indx = sort(crwind_lat_bnd_indx);
                % Sorted, [Start : End]
            
            % Find and merge current chosen parameter chosen region 
            % boundary indexes in longitude data
            if max(max(crwind_lon)) > 180 % Format = [0,360] deg E
                % Find boundary index(es) in Eastern Hemisphere
                crwind_lon_bnd_indx_EH = ...
                    [1 find(crwind_lon == reg_lon_bnd(2),1)];
                    % Exact longitudinal grid points, [Start : End]
                if length(crwind_lon_bnd_indx_EH) == 1
                        % Only one location point equality
                    % Closest longitudinal end grid point
                    [~,crwind_lon_bnd_indx_EH(2)] = ...
                        min(abs(crwind_lon - reg_lon_bnd(2)));
                end
                
                % Find boundary index(es) in Western Hemisphere
                crwind_lon_bnd_indx_WH = ...
                    [find(crwind_lon == reg_lon_bnd(1) + 360,1) ...
                    crwind_lon_no];
                    % Exact longitudinal grid points, [Start : End]
                if length(crwind_lon_bnd_indx_WH) == 1
                        % Only one location point equality
                    % Closest longitudinal start grid point
                    crwind_lon_bnd_indx_WH = ...
                        [min(abs(crwind_lon - reg_lon_bnd(1) + 360)) ...
                        crwind_lon_bnd_indx_WH];
                        % [Start : End]
                end
                
                % Merge boundary indexes
                crwind_lon_bnd_indx = ...
                    [crwind_lon_bnd_indx_EH; crwind_lon_bnd_indx_WH];
                    % [EH : WH; Start : End]
            else % Format = [-180,180] deg E
                % Find start index
                crwind_lon_bnd_indx_srt = ...
                    find(crwind_lon == reg_lon_bnd(1),1);
                    % Exact longitudinal grid point
                if isempty(crwind_lon_bnd_indx_srt)
                        % No location point equality
                    % Closest longitudinal grid point
                    [~,crwind_lon_bnd_indx_srt] = ...
                        min(abs(crwind_lon - reg_lon_bnd(1)));
                end
                
                % Find end index
                crwind_lon_bnd_indx_end = ...
                    find(crwind_lon == reg_lon_bnd(2),1);
                    % Exact longitudinal grid point
                if isempty(crwind_lon_bnd_indx_end)
                        % No location point equality
                    % Closest longitudinal grid point
                    [~,crwind_lon_bnd_indx_end] = ...
                        min(abs(crwind_lon - reg_lon_bnd(2)));
                end
                
                % Merge boundary indexes
                crwind_lon_bnd_indx = ...
                    [crwind_lon_bnd_indx_srt crwind_lon_bnd_indx_end];
                    % Unsorted, [Start : End]
                crwind_lon_bnd_indx = sort(crwind_lon_bnd_indx);
                    % Sorted, [Start : End]
            end
            
            % Delete unnecessary variable(s)
            clear crwind_lat_bnd_indx_* crwind_lon_bnd_indx_*
            
            %%% Extract location data %%%
            % Extract current chosen parameter location data over chosen 
            % region
            crwind_lat = ...
                crwind_lat(crwind_lat_bnd_indx(1):crwind_lat_bnd_indx(2));
                % [deg N], latitude, [Lat]
            if size(crwind_lon_bnd_indx,1) == 2 % Format = [0,360] deg E
                % Longitude
                crwind_lon = ...
                    [crwind_lon(crwind_lon_bnd_indx(2,1):crwind_lon_bnd_indx(2,2)); ...
                    crwind_lon(crwind_lon_bnd_indx(1,1):crwind_lon_bnd_indx(1,2))];
                    % [deg E], [Lon]
            else % Format = [-180,180] deg E
                % Longitude
                crwind_lon = ...
                    crwind_lon(crwind_lon_bnd_indx(1):crwind_lon_bnd_indx(2));
                    % [deg E], [Lon]
            end
            
            % Calculate current chosen parameter location grid point
            % numbers
            crwind_lat_no = length(crwind_lat); % Latitude
            crwind_lon_no = length(crwind_lon); % Longitude
            
            %%% Load, find boundary and extract time and variable data %%%
            % Loop over data set years and load current chosen parameter
            % time and variable data
            for y = 1:yr_mod_no % Loop over number of data set years
                % Extract current data set year name
                cryr_name = num2str(yr_mod_vec(y));
                disp(['load_ACLOUD_ERA: ' ...
                    'Loading and extracting ' wind_set_MATLAB ' ' ...
                    crwind_name_MATLAB ' data for ' cryr_name])
                
                % Set current chosen parameter current climatology year 
                % loading file name
                crwind_cryr_load_file = ...
                    [wind_set_file '_' crwind_name_file '_' ...
                    wind_tstep_full '_' month_abbr '_' cryr_name '.nc'];
                
                % Load current chosen parameter current climatology year 
                % time data
                crwind_cryr_date_6hrdaymonth = ...
                    timenc([crwind_load_path crwind_cryr_load_file],...
                    'time');
                    % [6hr_All*Day_All*Month_All; ...
                    %  Yr : Month : Day : Hr : Min : Sec]
                
                % Load current chosen parameter current climatology year 
                % variable data
                crwind_cryr_6hrdaymonth_lat_lon = ...
                    getnc([crwind_load_path crwind_cryr_load_file],...
                    crwind_load_data);
                    % [m/s]
                    % [6hr_All*Day_All*Month_All; Lat_All; Lon_All]
                
                % Find current chosen parameter current climatology year 
                % chosen time period boundary indexes in time data
                crwind_cryr_date_bnd_indx_srt = ...
                    find(...
                    crwind_cryr_date_6hrdaymonth(:,2) == month_bnd(1) ...
                    & crwind_cryr_date_6hrdaymonth(:,3) == ...
                    day_bnd(1) - month_daysum(month_bnd(1)-1) + 1,...
                    1,'first');
                    % Start
                crwind_cryr_date_bnd_indx_end = ...
                    find(...
                    crwind_cryr_date_6hrdaymonth(:,2) == month_bnd(2) ...
                    & crwind_cryr_date_6hrdaymonth(:,3) == ...
                    day_bnd(2) - month_daysum(month_bnd(2)-1) + 1,...
                    1,'last');
                    % End
                    
                % Merge current chosen parameter current climatology year 
                % chosen time period boundary indexes in time data
                crwind_cryr_date_bnd_indx = ...
                    [crwind_cryr_date_bnd_indx_srt ...
                    crwind_cryr_date_bnd_indx_end];
                    % [Start : End]
                
                % Extract current chosen parameter current climatology year
                % time data over chosen time period
                crwind_cryr_date_6hrdaymonth = ...
                    crwind_cryr_date_6hrdaymonth(...
                    crwind_cryr_date_bnd_indx(1):crwind_cryr_date_bnd_indx(2),:);
                    % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
                    
                % Extract current chosen parameter current climatology year
                % variable data over chosen time period
                crwind_cryr_6hrdaymonth_lat_lon = ...
                    crwind_cryr_6hrdaymonth_lat_lon(...
                    crwind_cryr_date_bnd_indx(1):crwind_cryr_date_bnd_indx(2),:,:);
                    % [m], [6hr*Day*Month; Lat_All; Lon_All]
                
                % Extract current chosen parameter current climatology year
                % variable data over chosen region
                if size(crwind_lon_bnd_indx,1) == 2
                        % Format = [0,360] deg E
                    crwind_cryr_6hrdaymonth_lat_lon = ...
                        cat(3,...
                        crwind_cryr_6hrdaymonth_lat_lon(:,...
                        crwind_lat_bnd_indx(1):crwind_lat_bnd_indx(2),...
                        crwind_lon_bnd_indx(2,1):crwind_lon_bnd_indx(2,2)),...
                        crwind_cryr_6hrdaymonth_lat_lon(:,...
                        crwind_lat_bnd_indx(1):crwind_lat_bnd_indx(2),...
                        crwind_lon_bnd_indx(1,1):crwind_lon_bnd_indx(1,2)));
                        % [m], [6hr*Day*Month; Lat; Lon]
                else % Format = [-180,180] deg E
                    crwind_cryr_6hrdaymonth_lat_lon = ...
                        crwind_cryr_6hrdaymonth_lat_lon(:,...
                        crwind_lat_bnd_indx(1):crwind_lat_bnd_indx(2),...
                        crwind_lon_bnd_indx(1):crwind_lon_bnd_indx(2));
                        % [m], [6hr*Day*Month; Lat; Lon]
                end
                
                % Store current chosen parameter current climatology year 
                % time data in 6-hourly matrix over chosen time period 
                % per climatology year
                crwind_date_6hrdaymonthyr(hr_no*day_no*(y-1)+1:hr_no*day_no*y,:) = ...
                    crwind_cryr_date_6hrdaymonth;
                    % [6hr*Day*Month*Yr; Yr : Month : Day : Hr : Min : Sec]
                
                % Store current chosen parameter current climatology year 
                % variable data in 6-hourly matrix over chosen time period 
                % per climatology year per latitude per longitude
                crwind_yr_6hrdaymonth_lat_lon(y,:,:,:) = ...
                    crwind_cryr_6hrdaymonth_lat_lon;
                    % [m/s], [Yr; 6hr*Day*Month; Lat; Lon]
                
                % Delete current chosen parameter current climatology year
                % data
                clear crwind_cryr_*
            end
            
            %%% Calculate data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Calculating ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' average data'])
            
            % Loop over time period days and calculate current chosen 
            % parameter daily means over time period per climatology year 
            % per latitude per longitude
            for d = 1:day_no % Loop over number of time period days
                crwind_yr_daymonth_lat_lon(:,d,:,:) = ...
                    nanmean(crwind_yr_6hrdaymonth_lat_lon(:,4*(d-1)+1:4*d,:,:),2);
                    % [m/s], [Yr; Day*Month; Lat; Lon]
            end
            
            % Calculate current chosen parameter daily mean averaged 
            % annually over climatology time period per latitude per 
            % longitude
            crwind_clim_mean_daymonth_lat_lon = ...
                squeeze(nanmean(crwind_yr_daymonth_lat_lon(yr_clim_indx,:,:,:),1));
                % [m/s], [Day*Month; Lat; Lon]
                
            % Calculate current chosen parameter daily mean 
            % standard-deviated annually over climatology time period per 
            % latitude per longitude
            crwind_clim_STD_daymonth_lat_lon = ...
                squeeze(nanstd(crwind_yr_daymonth_lat_lon(yr_clim_indx,:,:,:),0,1));
                % [m/s], [Day*Month; Lat; Lon]
                
            % Delete unnecessary variable(s)
            clear d
            
            %%% Extract data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Extracting ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' data over chosen time period'])
            
            % Extract current chosen parameter 6-hourly time data over 
            % campaign time period
            crwind_date_6hrdaymonth = ...
                crwind_date_6hrdaymonthyr(hr_no*day_no*yr_clim_no+1:end,:);
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
                
            % Extract current chosen parameter daily time data over 
            % campaign time period
            crwind_date_daymonth = ...
                crwind_date_6hrdaymonth(1:hr_no:end,1:3);
                % [Day*Month; Yr : Month : Day]
            
            % Extract current chosen parameter 6-hourly variable data over 
            % campaign time period per latitude per longitude
            crwind_cpgn_6hrdaymonth_lat_lon = ...
                squeeze(crwind_yr_6hrdaymonth_lat_lon(end,:,:,:));
                % [m/s], [6hr*Day*Month; Lat; Lon]
            
            % Extract current chosen parameter daily mean variable data 
            % over campaign time period per latitude per longitude
            crwind_cpgn_daymonth_lat_lon = ...
                squeeze(crwind_yr_daymonth_lat_lon(end,:,:,:));
                % [m/s], [Day*Month; Lat; Lon]
            
            %%% Rearrange data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Rearranging ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' data over chosen time period'])
            
            % Rearrange current chosen parameter 6-hourly variable data 
            % over campaign time period per latitude per longitude from 3D 
            % to 4D
            crwind_cpgn_6hr_daymonth_lat_lon = ...
                reshape(crwind_cpgn_6hrdaymonth_lat_lon,...
                hr_no,day_no,crwind_lat_no,crwind_lon_no);
                % [m/s], [6hr; Day*Month; Lat; Lon]
            crwind_cpgn_daymonth_6hr_lat_lon = ...
                permute(crwind_cpgn_6hr_daymonth_lat_lon,[2,1,3,4]);
                % [m/s], [Day*Month; 6hr; Lat; Lon]
                
            % Delete unnecessary variable(s)
            clear crwind_cpgn_6hr_daymonth_lat_lon
            
            %%% Rename data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Renaming ' wind_set_MATLAB ' ' crwind_name_MATLAB ...
                ' data'])
            
            % Rename current chosen parameter time variables
            eval([char(crwind_store_t_name(1)) ' = ' ...
                'crwind_date_6hrdaymonth;'])
                % 6-hourly date matrix
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
            eval([char(crwind_store_t_name(2)) ' = ' ...
                'crwind_date_daymonth;'])
                % Daily date matrix
                % [Day*Month; Yr : Month : Day]
                
            % Rename current chosen parameter location variables
            eval([char(crwind_store_loc_name(1)) ' = crwind_lat;']);
                % [deg N]
                % Latitudinal grid point vector
                % [Lat]
            eval([char(crwind_store_loc_name(2)) ' = crwind_lon;']);
                % [deg E]
                % Longitudinal grid point vector
                % [Lon]
            
            % Rename current chosen parameter campaign variables
            eval([char(crwind_store_cpgn_name(1)) ' = ' ...
                'crwind_cpgn_6hrdaymonth_lat_lon;']);
                % [m/s]
                % 6-hourly over time period per latitude per longitude
                % [6hr*Day*Month; Lat; Lon]
            eval([char(crwind_store_cpgn_name(2)) ' = ' ...
                'crwind_cpgn_daymonth_6hr_lat_lon;']);
                % [m/s]
                % 6-hourly per day over time period per latitude per 
                % longitude
                % [Day*Month; 6hr; Lat; Lon]
            eval([char(crwind_store_cpgn_name(3)) ' = ' ...
                'crwind_cpgn_daymonth_lat_lon;']);
                % [m/s]
                % Daily averaged daily over time period per latitude per 
                % longitude
                % [Day*Month; Lat; Lon]
                
            % Rename current chosen parameter climatology variables
            eval([char(crwind_store_clim_name(1)) ' = ' ...
                'crwind_clim_mean_daymonth_lat_lon;']);
                % [m/s]
                % Daily averaged annually over time period per latitude per
                % longitude
                % [Day*Month; Lat; Lon]
            eval([char(crwind_store_clim_name(2)) ' = ' ...
                'crwind_clim_STD_daymonth_lat_lon;']);
                % [m/s]
                % Daily standard-deviated annually over time period per 
                % latitude per longitude
                % [Day*Month; Lat; Lon]
            
            %%% Store data %%%
            % Store current chosen parameter time and campaign data
            disp(['load_ACLOUD_ERA: ' ...
                'Storing ' wind_set_MATLAB ' ' crwind_name_MATLAB ' data'])
            save([crwind_store_path crwind_store_file],...
                [crwind_name_MATLAB '_*_' wind_set_MATLAB])
                % Store time and campaign variables
        end
        
        %%% Rename data %%%
        % Rename current chosen parameter time variables
        eval([crwind_name_MATLAB '_date_6hrdaymonth = ' ...
            'crwind_date_6hrdaymonth;'])
            % 6-hourly date matrix
            % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
        eval([crwind_name_MATLAB '_date_daymonth = ' ...
            'crwind_date_daymonth;'])
            % Daily date matrix
            % [Day*Month; Yr : Month : Day]
            
        % Rename current chosen parameter location variables
        eval([crwind_name_MATLAB '_lat = crwind_lat;'])
            % [deg N]
            % Latitudinal grid point vector
            % [Lat]
        eval([crwind_name_MATLAB '_lon = crwind_lon;'])
            % [deg E]
            % Longitudinal grid point vector
            % [Lon]
        
        % Rename current chosen parameter campaign variables
        eval([crwind_name_MATLAB '_cpgn_6hrdaymonth_lat_lon = ' ...
            'crwind_cpgn_6hrdaymonth_lat_lon;']);
            % [m/s]
            % 6-hourly over time period per latitude per longitude
            % [6hr*Day*Month; Lat; Lon]
        eval([crwind_name_MATLAB '_cpgn_daymonth_6hr_lat_lon = ' ...
            'crwind_cpgn_daymonth_6hr_lat_lon;']);
            % [m/s]
            % 6-hourly per day over time period per latitude per longitude
            % [Day*Month; 6hr; Lat; Lon]
        eval([crwind_name_MATLAB '_cpgn_daymonth_lat_lon = ' ...
            'crwind_cpgn_daymonth_lat_lon;']);
            % [m/s]
            % Daily averaged daily over time period per latitude per 
            % longitude
            % [Day*Month; Lat; Lon]
            
        % Rename current chosen parameter climatology variables
        eval([crwind_name_MATLAB '_clim_mean_daymonth_lat_lon = ' ...
            'crwind_clim_mean_daymonth_lat_lon;']);
            % [m/s]
            % Daily averaged annually over time period per latitude per
            % longitude
            % [Day*Month; Lat; Lon]
        eval([crwind_name_MATLAB '_clim_STD_daymonth_lat_lon = ' ...
            'crwind_clim_STD_daymonth_lat_lon;']);
            % [m/s]
            % Daily standard-deviated annually over time period per 
            % latitude per longitude
            % [Day*Month; Lat; Lon]
        
        %%% Delete data %%%
        % Delete unnecessary variable(s)
        clear(crwind_store_t_name{:},crwind_store_loc_name{:},...
            crwind_store_cpgn_name{:},crwind_store_clim_name{:})
        
        % Delete current chosen parameter data
        clear crwind_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars p wind_*
else % wind data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear wind_name_all wind_indx_all
end
%%
%%%%% T data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
T_name_all = param_name(4+1,5); % Name(s)
T_indx_all = find(strcmp(param_name(2:end,5),T_name_all(1)));
    % Index(es)

% Load T data only if chosen
if sum(ismember(T_indx_all,param_indx)) > 0 % T data chosen
    %%% Basic parameter settings %%%
    % Set time step names
    T_tstep_abbr = char(tint_name(1+1,2+1)); % Abbreviated
    T_tstep_full = char(tint_name(2+1,2+1)); % Full
    
    % Set data set names
    T_set_file = char(mod_name(1+1,2)); % File
    T_set_MATLAB = char(mod_name(1+1,3)); % MATLAB
    T_set_tper = char(mod_name(1+1,6)); % Time period
    
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    T_name_chos = T_name_all(ismember(T_indx_all,param_indx)); % Name(s)
    T_indx_chos = T_indx_all(ismember(T_indx_all,param_indx)); % Index(es)
    T_no_chos = length(T_indx_chos); % Number
    
    % Loop over chosen T variables and load T data
    for p = 1:T_no_chos % Loop over number of chosen T parameters
        %%% Parameter and data set names %%%
        % Extract current chosen parameter names
        crT_name_gen = char(param_name(T_indx_chos(p)+1,2));
            % General
        crT_name_file = char(param_name(T_indx_chos(p)+1,3));
            % File
        crT_name_data = char(param_name(T_indx_chos(p)+1,4));
            % Data
        crT_name_MATLAB = char(param_name(T_indx_chos(p)+1,5));
            % MATLAB
        crT_name_full = char(param_name(T_indx_chos(p)+1,6));
            % Full
            
        % Extract current chosen parameter unit
        crT_unit = char(param_name(T_indx_chos(p)+1,7));
        
        % Set current chosen parameter storage path and file names
        crT_store_path = path_store; % Path
        crT_store_file = ...
            [crT_name_MATLAB '_' reg_abbr '_' ...
            month_abbr '_' yr_cpgn_name '_' T_set_MATLAB '.mat'];
            % File
            
        % Display current chosen parameter loading conditions
        disp(['load_ACLOUD_ERA: Loading ' crT_name_MATLAB ...
            ' data from the ' T_set_MATLAB ' data set'])
        
        %%% Variables in storage file %%%
        % Set current chosen parameter time variables names
        crT_store_t_name = ...
            [{[crT_name_MATLAB '_date_6hrdaymonth_' T_set_MATLAB]}; ...
            {[crT_name_MATLAB '_date_daymonth_' T_set_MATLAB]}];
            % [6-hourly date matrix; ...
            %  Daily date matrix]
            
        % Set current chosen parameter location variables names
        crT_store_loc_name = ...
            [{[crT_name_MATLAB '_lat_' T_set_MATLAB]}; ...
            {[crT_name_MATLAB '_lon_' T_set_MATLAB]}];
            % [Latitudinal grid point vector; ...
            %  Longitudinal grid point vector]
        
        % Set current chosen parameter campaign variable names
        crT_store_cpgn_name = ...
            [{[crT_name_MATLAB '_cpgn_6hrdaymonth_lat_lon_' T_set_MATLAB]}; ...
            {[crT_name_MATLAB '_cpgn_daymonth_6hr_lat_lon_' T_set_MATLAB]}; ...
            {[crT_name_MATLAB '_cpgn_daymonth_lat_lon_' T_set_MATLAB]}];
            % [6-hourly over time period per latitude per longitude; ...
            %  6-hourly per day over time period per latitude per 
            %   longitude; ...
            %  Daily averaged daily over time period per latitude per 
            %   longitude]
            
        % Set current chosen parameter climatology variable names
        crT_store_clim_name = ...
            [{[crT_name_MATLAB '_clim_mean_daymonth_lat_lon_' T_set_MATLAB]}; ...
            {[crT_name_MATLAB '_clim_STD_daymonth_lat_lon_' T_set_MATLAB]}];
            % [Daily averaged annually over time period per latitude per 
            %   longitude; ...
            %  Daily standard-deviated annually over time period per 
            %   latitude per longitude]
        
        %%% Variables to load from storage files %%%
        % Check existence of current chosen parameter variable in storage 
        % file
        if exist([crT_store_path crT_store_file],'file')
                % File existent
            % Find current chosen parameter file variable names
            crT_store_var_file = ...
                whos('-file',[crT_store_path crT_store_file]);
            
            % Check existence of current chosen parameter variables in 
            % storage file
            crT_store_cpgn_exist = ...
                ismember(crT_store_cpgn_name,{crT_store_var_file.name});
                % Campaign variables
            crT_store_clim_exist = ...
                ismember(crT_store_clim_name,{crT_store_var_file.name});
                % Climatology variables
        else % File non-existent
            % Set current chosen parameter logical variable to zero
            crT_store_cpgn_exist = 0; % Campaign variables
            crT_store_clim_exist = 0; % Climatology variables
        end
        
        % Load current chosen parameter data only if variables are 
        % non-existent
        if sum(crT_store_cpgn_exist) == length(crT_store_cpgn_exist) && ...
                sum(crT_store_clim_exist) == length(crT_store_clim_exist)
                % Variables existent
            disp('load_ACLOUD_ERA: Existent variables:')
            disp(crT_store_t_name)
            disp(crT_store_loc_name)
            disp(crT_store_cpgn_name)
            disp(crT_store_clim_name)
            
            %%% Load data %%%
            % Load current chosen parameter data from .mat file
            load([crT_store_path crT_store_file],...
                crT_store_t_name{:},crT_store_loc_name{:},...
                crT_store_cpgn_name{:},crT_store_clim_name{:})
            
            %%% Rename data %%%
            % Rename current chosen parameter time variables
            crT_date_6hrdaymonth = eval(char(crT_store_t_name(1)));
                % 6-hourly date matrix
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
            crT_date_daymonth = eval(char(crT_store_t_name(2)));
                % Daily date matrix
                % [Day*Month; Yr : Month : Day]
                
            % Rename current chosen parameter location variables
            crT_lat = eval(char(crT_store_loc_name(1)));
                % [deg N]
                % Latitudinal grid point vector
                % [Lat]
            crT_lon = eval(char(crT_store_loc_name(2)));
                % [deg E]
                % Longitudinal grid point vector
                % [Lon]
            
            % Rename current chosen parameter campaign variables
            crT_cpgn_6hrdaymonth_lat_lon = ...
                eval(char(crT_store_cpgn_name(1)));
                % [deg C]
                % 6-hourly over time period per latitude per longitude
                % [6hr*Day*Month; Lat; Lon]
            crT_cpgn_daymonth_6hr_lat_lon = ...
                eval(char(crT_store_cpgn_name(2)));
                % [deg C]
                % 6-hourly per day over time period per latitude per 
                % longitude
                % [Day*Month; 6hr; Lat; Lon]
            crT_cpgn_daymonth_lat_lon = eval(char(crT_store_cpgn_name(3)));
                % [deg C]
                % Daily averaged daily over time period per latitude per 
                % longitude
                % [Day*Month; Lat; Lon]
                
            % Rename current chosen parameter climatology variables
            crT_clim_mean_daymonth_lat_lon = ...
                eval(char(crT_store_clim_name(1)));
                % [deg C]
                % Daily averaged annually over time period per latitude per
                % longitude
                % [Day*Month; Lat; Lon]
            crT_clim_STD_daymonth_lat_lon = ...
                eval(char(crT_store_clim_name(2)));
                % [deg C]
                % Daily standard-deviated annually over time period per 
                % latitude per longitude
                % [Day*Month; Lat; Lon]
        else % File non-existent
            disp('load_ACLOUD_ERA: Loading variables:')
            disp(crT_store_t_name)
            disp(crT_store_loc_name)
            disp(crT_store_cpgn_name)
            disp(crT_store_clim_name)
            
            %%% Load location data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Loading ' T_set_MATLAB ' ' crT_name_MATLAB ...
                ' location data'])
            
            % Set current chosen parameter loading path and data names
            crT_load_path = ...
                [path_data 'Reanalyses/' upper(T_tstep_full) '/'];
                % Path
            crT_load_data = crT_name_data;
                % Data
                
            % Set current chosen parameter campaign loading file name
            crT_cpgn_load_file = ...
                [T_set_file '_' crT_name_file '_' ...
                T_tstep_full '_' month_abbr '_' yr_cpgn_name '.nc'];
                
            % Load current chosen parameter location data
            crT_lat = ...
                getnc([crT_load_path crT_cpgn_load_file],'latitude');
                % [deg N], latitude, [Lat_All]
            crT_lon = ...
                getnc([crT_load_path crT_cpgn_load_file],'longitude');
                % [deg E], longitude, [Lon_All]
                
            % Calculate current chosen parameter location grid point
            % numbers
            crT_lat_no = length(crT_lat); % Latitude
            crT_lon_no = length(crT_lon); % Longitude
            
            %%% Find location boundary data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Extracting ' T_set_MATLAB ' ' crT_name_MATLAB ...
                ' location data over chosen region'])
            
            % Find current chosen parameter chosen region boundary indexes 
            % in latitude data
            crT_lat_bnd_indx_srt = find(crT_lat == reg_lat_bnd(1),1);
                % Start - Exact longitudinal grid point
            if isempty(crT_lat_bnd_indx_srt) % No location point equality
                % Closest latitudinal grid point
                [~,crT_lat_bnd_indx_srt] = ...
                    min(abs(crT_lat - reg_lat_bnd(1)));
                    % Start
            end
            crT_lat_bnd_indx_end = find(crT_lat == reg_lat_bnd(2),1);
                % End - Exact longitudinal grid point
            if isempty(crT_lat_bnd_indx_end) % No location point equality
                % Closest latitudinal grid point
                [~,crT_lat_bnd_indx_end] = ...
                    min(abs(crT_lat - reg_lat_bnd(2)));
                    % End
            end
            
            % Merge current chosen parameter chosen region boundary indexes 
            % in latitude data
            crT_lat_bnd_indx = [crT_lat_bnd_indx_srt crT_lat_bnd_indx_end];
                % Unsorted, [Start : End]
            crT_lat_bnd_indx = sort(crT_lat_bnd_indx);
                % Sorted, [Start : End]
            
            % Find and merge current chosen parameter chosen region 
            % boundary indexes in longitude data
            if max(max(crT_lon)) > 180 % Format = [0,360] deg E
                % Find boundary index(es) in Eastern Hemisphere
                crT_lon_bnd_indx_EH = ...
                    [1 find(crT_lon == reg_lon_bnd(2),1)];
                    % Exact longitudinal grid points, [Start : End]
                if length(crT_lon_bnd_indx_EH) == 1
                        % Only one location point equality
                    % Closest longitudinal end grid point
                    [~,crT_lon_bnd_indx_EH(2)] = ...
                        min(abs(crT_lon - reg_lon_bnd(2)));
                end
                
                % Find boundary index(es) in Western Hemisphere
                crT_lon_bnd_indx_WH = ...
                    [find(crT_lon == reg_lon_bnd(1) + 360,1) crT_lon_no];
                    % Exact longitudinal grid points, [Start : End]
                if length(crT_lon_bnd_indx_WH) == 1
                        % Only one location point equality
                    % Closest longitudinal start grid point
                    crT_lon_bnd_indx_WH = ...
                        [min(abs(crT_lon - reg_lon_bnd(1) + 360)) ...
                        crT_lon_bnd_indx_WH];
                        % [Start : End]
                end
                
                % Merge boundary indexes
                crT_lon_bnd_indx = ...
                    [crT_lon_bnd_indx_EH; crT_lon_bnd_indx_WH];
                    % [EH : WH; Start : End]
            else % Format = [-180,180] deg E
                % Find start index
                crT_lon_bnd_indx_srt = find(crT_lon == reg_lon_bnd(1),1);
                    % Exact longitudinal grid point
                if isempty(crT_lon_bnd_indx_srt)
                        % No location point equality
                    % Closest longitudinal grid point
                    [~,crT_lon_bnd_indx_srt] = ...
                        min(abs(crT_lon - reg_lon_bnd(1)));
                end
                
                % Find end index
                crT_lon_bnd_indx_end = find(crT_lon == reg_lon_bnd(2),1);
                    % Exact longitudinal grid point
                if isempty(crT_lon_bnd_indx_end)
                        % No location point equality
                    % Closest longitudinal grid point
                    [~,crT_lon_bnd_indx_end] = ...
                        min(abs(crT_lon - reg_lon_bnd(2)));
                end
                
                % Merge boundary indexes
                crT_lon_bnd_indx = ...
                    [crT_lon_bnd_indx_srt crT_lon_bnd_indx_end];
                    % Unsorted, [Start : End]
                crT_lon_bnd_indx = sort(crT_lon_bnd_indx);
                    % Sorted, [Start : End]
            end
            
            % Delete unnecessary variable(s)
            clear crT_lat_bnd_indx_* crT_lon_bnd_indx_*
            
            %%% Extract location data %%%
            % Extract current chosen parameter location data over chosen 
            % region
            crT_lat = crT_lat(crT_lat_bnd_indx(1):crT_lat_bnd_indx(2));
                % [deg N], latitude, [Lat]
            if size(crT_lon_bnd_indx,1) == 2 % Format = [0,360] deg E
                % Longitude
                crT_lon = ...
                    [crT_lon(crT_lon_bnd_indx(2,1):crT_lon_bnd_indx(2,2)); ...
                    crT_lon(crT_lon_bnd_indx(1,1):crT_lon_bnd_indx(1,2))];
                    % [deg E], [Lon]
            else % Format = [-180,180] deg E
                % Longitude
                crT_lon = crT_lon(crT_lon_bnd_indx(1):crT_lon_bnd_indx(2));
                    % [deg E], [Lon]
            end
            
            % Calculate current chosen parameter location grid point
            % numbers
            crT_lat_no = length(crT_lat); % Latitude
            crT_lon_no = length(crT_lon); % Longitude
            
            %%% Load, find boundary and extract time and variable data %%%
            % Loop over data set years and load current chosen parameter
            % time and variable data
            for y = 1:yr_mod_no % Loop over number of data set years
                % Extract current data set year name
                cryr_name = num2str(yr_mod_vec(y));
                disp(['load_ACLOUD_ERA: ' ...
                    'Loading and extracting ' T_set_MATLAB ' ' ...
                    crT_name_MATLAB ' data for ' cryr_name])
                
                % Set current chosen parameter current climatology year 
                % loading file name
                crT_cryr_load_file = ...
                    [T_set_file '_' crT_name_file '_' ...
                    T_tstep_full '_' month_abbr '_' cryr_name '.nc'];
                
                % Load current chosen parameter current climatology year 
                % time data
                crT_cryr_date_6hrdaymonth = ...
                    timenc([crT_load_path crT_cryr_load_file],'time');
                    % [6hr_All*Day_All*Month_All; ...
                    %  Yr : Month : Day : Hr : Min : Sec]
                
                % Load current chosen parameter current climatology year 
                % variable data
                crT_cryr_6hrdaymonth_lat_lon = ...
                    getnc([crT_load_path crT_cryr_load_file],...
                    crT_load_data);
                    % [K], [6hr_All*Day_All*Month_All; Lat_All; Lon_All]
                
                % Convert current chosen parameter current climatology year
                % variable data from [K] to [deg C]
                crT_cryr_6hrdaymonth_lat_lon = ...
                    crT_cryr_6hrdaymonth_lat_lon - 273.15;
                    % [deg C]
                    % [6hr_All*Day_All*Month_All; Lat_All; Lon_All]
                
                % Find current chosen parameter current climatology year 
                % chosen time period boundary indexes in time data
                crT_cryr_date_bnd_indx_srt = ...
                    find(crT_cryr_date_6hrdaymonth(:,2) == month_bnd(1) ...
                    & crT_cryr_date_6hrdaymonth(:,3) == ...
                    day_bnd(1) - month_daysum(month_bnd(1)-1) + 1,...
                    1,'first');
                    % Start
                crT_cryr_date_bnd_indx_end = ...
                    find(crT_cryr_date_6hrdaymonth(:,2) == month_bnd(2) ...
                    & crT_cryr_date_6hrdaymonth(:,3) == ...
                    day_bnd(2) - month_daysum(month_bnd(2)-1) + 1,...
                    1,'last');
                    % End
                    
                % Merge current chosen parameter current climatology year 
                % chosen time period boundary indexes in time data
                crT_cryr_date_bnd_indx = ...
                    [crT_cryr_date_bnd_indx_srt ...
                    crT_cryr_date_bnd_indx_end];
                    % [Start : End]
                
                % Extract current chosen parameter current climatology year
                % time data over chosen time period
                crT_cryr_date_6hrdaymonth = ...
                    crT_cryr_date_6hrdaymonth(...
                    crT_cryr_date_bnd_indx(1):crT_cryr_date_bnd_indx(2),:);
                    % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
                    
                % Extract current chosen parameter current climatology year
                % variable data over chosen time period
                crT_cryr_6hrdaymonth_lat_lon = ...
                    crT_cryr_6hrdaymonth_lat_lon(...
                    crT_cryr_date_bnd_indx(1):crT_cryr_date_bnd_indx(2),:,:);
                    % [deg C], [6hr*Day*Month; Lat_All; Lon_All]
                
                % Extract current chosen parameter current climatology year
                % variable data over chosen region
                if size(crT_lon_bnd_indx,1) == 2 % Format = [0,360] deg E
                    crT_cryr_6hrdaymonth_lat_lon = ...
                        cat(3,...
                        crT_cryr_6hrdaymonth_lat_lon(:,...
                        crT_lat_bnd_indx(1):crT_lat_bnd_indx(2),...
                        crT_lon_bnd_indx(2,1):crT_lon_bnd_indx(2,2)),...
                        crT_cryr_6hrdaymonth_lat_lon(:,...
                        crT_lat_bnd_indx(1):crT_lat_bnd_indx(2),...
                        crT_lon_bnd_indx(1,1):crT_lon_bnd_indx(1,2)));
                        % [deg C], [6hr*Day*Month; Lat; Lon]
                else % Format = [-180,180] deg E
                    crT_cryr_6hrdaymonth_lat_lon = ...
                        crT_cryr_6hrdaymonth_lat_lon(:,...
                        crT_lat_bnd_indx(1):crT_lat_bnd_indx(2),...
                        crT_lon_bnd_indx(1):crT_lon_bnd_indx(2));
                        % [deg C], [6hr*Day*Month; Lat; Lon]
                end
                
                % Store current chosen parameter current climatology year 
                % time data in 6-hourly matrix over chosen time period 
                % per climatology year
                crT_date_6hrdaymonthyr(hr_no*day_no*(y-1)+1:hr_no*day_no*y,:) = ...
                    crT_cryr_date_6hrdaymonth;
                    % [6hr*Day*Month*Yr; Yr : Month : Day : Hr : Min : Sec]
                
                % Store current chosen parameter current climatology year 
                % variable data in 6-hourly matrix over chosen time period 
                % per climatology year per latitude per longitude
                crT_yr_6hrdaymonth_lat_lon(y,:,:,:) = ...
                    crT_cryr_6hrdaymonth_lat_lon;
                    % [deg C], [Yr; 6hr*Day*Month; Lat; Lon]
                
                % Delete current chosen parameter current climatology year
                % data
                clear crT_cryr_*
            end
            
            %%% Calculate data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Calculating ' T_set_MATLAB ' ' crT_name_MATLAB ...
                ' average data'])
            
            % Loop over time period days and calculate current chosen 
            % parameter daily means over time period per climatology year 
            % per latitude per longitude
            for d = 1:day_no % Loop over number of time period days
                crT_yr_daymonth_lat_lon(:,d,:,:) = ...
                    nanmean(crT_yr_6hrdaymonth_lat_lon(:,4*(d-1)+1:4*d,:,:),2);
                    % [deg C], [Yr; Day*Month; Lat; Lon]
            end
            
            % Calculate current chosen parameter daily mean averaged 
            % annually over climatology time period per latitude per 
            % longitude
            crT_clim_mean_daymonth_lat_lon = ...
                squeeze(nanmean(crT_yr_daymonth_lat_lon(yr_clim_indx,:,:,:),1));
                % [deg C], [Day*Month; Lat; Lon]
                
            % Calculate current chosen parameter daily mean 
            % standard-deviated annually over climatology time period per 
            % latitude per longitude
            crT_clim_STD_daymonth_lat_lon = ...
                squeeze(nanstd(crT_yr_daymonth_lat_lon(yr_clim_indx,:,:,:),0,1));
                % [deg C], [Day*Month; Lat; Lon]
                
            % Delete unnecessary variable(s)
            clear d
            
            %%% Extract data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Extracting ' T_set_MATLAB ' ' crT_name_MATLAB ...
                ' data over chosen time period'])
            
            % Extract current chosen parameter 6-hourly time data over 
            % campaign time period
            crT_date_6hrdaymonth = ...
                crT_date_6hrdaymonthyr(hr_no*day_no*yr_clim_no+1:end,:);
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
                
            % Extract current chosen parameter daily time data over 
            % campaign time period
            crT_date_daymonth = ...
                crT_date_6hrdaymonth(1:hr_no:end,1:3);
                % [Day*Month; Yr : Month : Day]
            
            % Extract current chosen parameter 6-hourly variable data over 
            % campaign time period per latitude per longitude
            crT_cpgn_6hrdaymonth_lat_lon = ...
                squeeze(crT_yr_6hrdaymonth_lat_lon(end,:,:,:));
                % [deg C], [6hr*Day*Month; Lat; Lon]
            
            % Extract current chosen parameter daily mean variable data 
            % over campaign time period per latitude per longitude
            crT_cpgn_daymonth_lat_lon = ...
                squeeze(crT_yr_daymonth_lat_lon(end,:,:,:));
                % [deg C], [Day*Month; Lat; Lon]
            
            %%% Rearrange data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Rearranging ' T_set_MATLAB ' ' crT_name_MATLAB ...
                ' data over chosen time period'])
            
            % Rearrange current chosen parameter 6-hourly variable data 
            % over campaign time period per latitude per longitude from 3D 
            % to 4D
            crT_cpgn_6hr_daymonth_lat_lon = ...
                reshape(crT_cpgn_6hrdaymonth_lat_lon,...
                hr_no,day_no,crT_lat_no,crT_lon_no);
                % [deg C], [6hr; Day*Month; Lat; Lon]
            crT_cpgn_daymonth_6hr_lat_lon = ...
                permute(crT_cpgn_6hr_daymonth_lat_lon,[2,1,3,4]);
                % [deg C], [Day*Month; 6hr; Lat; Lon]
                
            % Delete unnecessary variable(s)
            clear crT_cpgn_6hr_daymonth_lat_lon
            
            %%% Rename data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Renaming ' T_set_MATLAB ' ' crT_name_MATLAB ' data'])
            
            % Rename current chosen parameter time variables
            eval([char(crT_store_t_name(1)) ' = crT_date_6hrdaymonth;'])
                % 6-hourly date matrix
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
            eval([char(crT_store_t_name(2)) ' = crT_date_daymonth;'])
                % Daily date matrix
                % [Day*Month; Yr : Month : Day]
                
            % Rename current chosen parameter location variables
            eval([char(crT_store_loc_name(1)) ' = crT_lat;']);
                % [deg N]
                % Latitudinal grid point vector
                % [Lat]
            eval([char(crT_store_loc_name(2)) ' = crT_lon;']);
                % [deg E]
                % Longitudinal grid point vector
                % [Lon]
            
            % Rename current chosen parameter campaign variables
            eval([char(crT_store_cpgn_name(1)) ' = ' ...
                'crT_cpgn_6hrdaymonth_lat_lon;']);
                % [deg C]
                % 6-hourly over time period per latitude per longitude
                % [6hr*Day*Month; Lat; Lon]
            eval([char(crT_store_cpgn_name(2)) ' = ' ...
                'crT_cpgn_daymonth_6hr_lat_lon;']);
                % [deg C]
                % 6-hourly per day over time period per latitude per 
                % longitude
                % [Day*Month; 6hr; Lat; Lon]
            eval([char(crT_store_cpgn_name(3)) ' = ' ...
                'crT_cpgn_daymonth_lat_lon;']);
                % [deg C]
                % Daily averaged daily over time period per latitude per 
                % longitude
                % [Day*Month; Lat; Lon]
                
            % Rename current chosen parameter climatology variables
            eval([char(crT_store_clim_name(1)) ' = ' ...
                'crT_clim_mean_daymonth_lat_lon;']);
                % [deg C]
                % Daily averaged annually over time period per latitude per
                % longitude
                % [Day*Month; Lat; Lon]
            eval([char(crT_store_clim_name(2)) ' = ' ...
                'crT_clim_STD_daymonth_lat_lon;']);
                % [deg C]
                % Daily standard-deviated annually over time period per 
                % latitude per longitude
                % [Day*Month; Lat; Lon]
            
            %%% Store data %%%
            % Store current chosen parameter time and campaign data
            disp(['load_ACLOUD_ERA: ' ...
                'Storing ' T_set_MATLAB ' ' crT_name_MATLAB ' data'])
            save([crT_store_path crT_store_file],...
                [crT_name_MATLAB '_*_' T_set_MATLAB])
                % Store time and campaign variables
        end
        
        %%% Rename data %%%
        % Rename current chosen parameter time variables
        eval([crT_name_MATLAB '_date_6hrdaymonth = ' ...
            'crT_date_6hrdaymonth;'])
            % 6-hourly date matrix
            % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
        eval([crT_name_MATLAB '_date_daymonth = ' ...
            'crT_date_daymonth;'])
            % Daily date matrix
            % [Day*Month; Yr : Month : Day]
            
        % Rename current chosen parameter location variables
        eval([crT_name_MATLAB '_lat = crT_lat;'])
            % [deg N]
            % Latitudinal grid point vector
            % [Lat]
        eval([crT_name_MATLAB '_lon = crT_lon;'])
            % [deg E]
            % Longitudinal grid point vector
            % [Lon]
        
        % Rename current chosen parameter campaign variables
        eval([crT_name_MATLAB '_cpgn_6hrdaymonth_lat_lon = ' ...
            'crT_cpgn_6hrdaymonth_lat_lon;']);
            % [deg C]
            % 6-hourly over time period per latitude per longitude
            % [6hr*Day*Month; Lat; Lon]
        eval([crT_name_MATLAB '_cpgn_daymonth_6hr_lat_lon = ' ...
            'crT_cpgn_daymonth_6hr_lat_lon;']);
            % [deg C]
            % 6-hourly per day over time period per latitude per longitude
            % [Day*Month; 6hr; Lat; Lon]
        eval([crT_name_MATLAB '_cpgn_daymonth_lat_lon = ' ...
            'crT_cpgn_daymonth_lat_lon;']);
            % [deg C]
            % Daily averaged daily over time period per latitude per 
            % longitude
            % [Day*Month; Lat; Lon]
            
        % Rename current chosen parameter climatology variables
        eval([crT_name_MATLAB '_clim_mean_daymonth_lat_lon = ' ...
            'crT_clim_mean_daymonth_lat_lon;']);
            % [deg C]
            % Daily averaged annually over time period per latitude per
            % longitude
            % [Day*Month; Lat; Lon]
        eval([crT_name_MATLAB '_clim_STD_daymonth_lat_lon = ' ...
            'crT_clim_STD_daymonth_lat_lon;']);
            % [deg C]
            % Daily standard-deviated annually over time period per 
            % latitude per longitude
            % [Day*Month; Lat; Lon]
        
        %%% Delete data %%%
        % Delete unnecessary variable(s)
        clear(crT_store_t_name{:},crT_store_loc_name{:},...
            crT_store_cpgn_name{:},crT_store_clim_name{:})
        
        % Delete current chosen parameter data
        clear crT_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars p T_*
else % T data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear T_name_all T_indx_all
end
%%
%%%%% humid data %%%%%
%%% Loading conditions %%%
% Parameter name(s) and index(es)
humid_name_all = param_name(5+1:6+1,5); % Name(s)
humid_indx_all = ...
    [find(strcmp(param_name(2:end,5),humid_name_all(1))) ...
    find(strcmp(param_name(2:end,5),humid_name_all(2)))];
    % Index(es)

% Load humid data only if chosen
if sum(ismember(humid_indx_all,param_indx)) > 0 % humid data chosen
    %%% Basic parameter settings %%%
    % Set campaign time step names
    humid_tstep_abbr = char(tint_name(1+1,2+1)); % Abbreviated
    humid_tstep_full = char(tint_name(2+1,2+1)); % Full
    
    % Set data set names
    humid_set_file = char(mod_name(1+1,2)); % File
    humid_set_MATLAB = char(mod_name(1+1,3)); % MATLAB
    humid_set_tper = char(mod_name(1+1,6)); % Time period
    
    %%% Chosen parameter settings %%%
    % Extract parameter name(s), index(es) and number
    humid_name_chos = humid_name_all(ismember(humid_indx_all,param_indx));
        % Name(s)
    humid_indx_chos = humid_indx_all(ismember(humid_indx_all,param_indx));
        % Index(es)
    humid_no_chos = length(humid_indx_chos); % Number
    
    % Loop over chosen humid variables and load humid data
    for p = 1:humid_no_chos % Loop over number of chosen humid parameters
        %%% Parameter and data set names %%%
        % Extract current chosen parameter names
        crhumid_name_gen = char(param_name(humid_indx_chos(p)+1,2));
            % General
        crhumid_name_file = char(param_name(humid_indx_chos(p)+1,3));
            % File
        crhumid_name_data = char(param_name(humid_indx_chos(p)+1,4));
            % Data
        crhumid_name_MATLAB = ...
            char(param_name(humid_indx_chos(p)+1,5));
            % MATLAB
        crhumid_name_full = char(param_name(humid_indx_chos(p)+1,6));
            % Full
            
        % Extract current chosen parameter unit
        crhumid_unit = char(param_name(humid_indx_chos(p)+1,7));
        
        % Set current chosen parameter storage path and file names
        crhumid_store_path = path_store; % Path
        crhumid_store_file = ...
            [crhumid_name_MATLAB '_' reg_abbr '_' ...
            month_abbr '_' yr_cpgn_name '_' humid_set_MATLAB '.mat'];
            % File
            
        % Display current chosen parameter loading conditions
        disp(['load_ACLOUD_ERA: Loading ' crhumid_name_MATLAB ...
            ' data from the ' humid_set_MATLAB ' data set'])
        
        %%% Variables in storage file %%%
        % Set current chosen parameter time variables names
        crhumid_store_t_name = ...
            [{[crhumid_name_MATLAB '_date_6hrdaymonth_' humid_set_MATLAB]}; ...
            {[crhumid_name_MATLAB '_date_daymonth_' humid_set_MATLAB]}];
            % [6-hourly date matrix; ...
            %  Daily date matrix]
        
        % Set current chosen parameter location variables names
        crhumid_store_loc_name = ...
            [{[crhumid_name_MATLAB '_lat_' humid_set_MATLAB]}; ...
            {[crhumid_name_MATLAB '_lon_' humid_set_MATLAB]}];
            % [Latitudinal grid point vector; ...
            %  Longitudinal grid point vector]
            
        % Set current chosen parameter campaign variable names
        crhumid_store_cpgn_name = ...
            [{[crhumid_name_MATLAB '_cpgn_6hrdaymonth_' humid_set_MATLAB]}; ...
            {[crhumid_name_MATLAB '_cpgn_daymonth_6hr_' humid_set_MATLAB]}; ...
            {[crhumid_name_MATLAB '_cpgn_daymonth_' humid_set_MATLAB]}];
            % [6-hourly over time period; ...
            %  6-hourly per day over time period; ...
            %  Daily averaged daily over time period]
            
        % Set current chosen parameter climatology variable names
        crhumid_store_clim_name = ...
            [{[crhumid_name_MATLAB '_clim_mean_daymonth_lat_lon_' humid_set_MATLAB]}; ...
            {[crhumid_name_MATLAB '_clim_STD_daymonth_lat_lon_' humid_set_MATLAB]}];
            % [Daily averaged annually over time period per latitude per 
            %   longitude; ...
            %  Daily standard-deviated annually over time period per 
            %   latitude per longitude]
        
        %%% Variables to load from storage files %%%
        % Check existence of current chosen parameter variable in storage 
        % file
        if exist([crhumid_store_path crhumid_store_file],'file')
                % File existent
            % Find current chosen parameter file variable names
            crhumid_store_var_file = ...
                whos('-file',[crhumid_store_path crhumid_store_file]);
            
            % Check existence of current chosen parameter variables in 
            % storage file
            crhumid_store_cpgn_exist = ...
                ismember(crhumid_store_cpgn_name,...
                {crhumid_store_var_file.name});
                % Campaign variables
            crhumid_store_clim_exist = ...
                ismember(crhumid_store_clim_name,...
                {crhumid_store_var_file.name});
                % Climatology variables
        else % File non-existent
            % Set current chosen parameter logical variable to zero
            crhumid_store_cpgn_exist = 0; % Campaign variables
            crhumid_store_clim_exist = 0; % Climatology variables
        end
        
        % Load current chosen parameter data only if variables are 
        % non-existent
        if sum(crhumid_store_cpgn_exist) == length(crhumid_store_cpgn_exist) && ...
                sum(crhumid_store_clim_exist) == length(crhumid_store_clim_exist)
                % Variables existent
            disp('load_ACLOUD_ERA: Existent variables:')
            disp(crhumid_store_t_name)
            disp(crhumid_store_loc_name)
            disp(crhumid_store_cpgn_name)
            disp(crhumid_store_clim_name)
            
            %%% Load data %%%
            % Load current chosen parameter data from .mat file
            load([crhumid_store_path crhumid_store_file],...
                crhumid_store_t_name{:},crhumid_store_loc_name{:},...
                crhumid_store_cpgn_name{:},crhumid_store_clim_name{:})
            
            %%% Rename data %%%
            % Rename current chosen parameter time variables
            crhumid_date_6hrdaymonth = eval(char(crhumid_store_t_name(1)));
                % 6-hourly date matrix
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
            crhumid_date_daymonth = eval(char(crhumid_store_t_name(2)));
                % Daily date matrix
                % [Day*Month; Yr : Month : Day]
                
            % Rename current chosen parameter location variables
            crhumid_lat = eval(char(crhumid_store_loc_name(1)));
                % [deg N]
                % Latitudinal grid point vector
                % [Lat]
            crhumid_lon = eval(char(crhumid_store_loc_name(2)));
                % [deg E]
                % Longitudinal grid point vector
                % [Lon]
            
            % Rename current chosen parameter campaign variables
            crhumid_cpgn_6hrdaymonth_lat_lon = ...
                eval(char(crhumid_store_cpgn_name(1)));
                % [kg/kg] / [%]
                % 6-hourly over time period per latitude per longitude
                % [6hr*Day*Month; Lat; Lon]
            crhumid_cpgn_daymonth_6hr_lat_lon = ...
                eval(char(crhumid_store_cpgn_name(2)));
                % [kg/kg] / [%]
                % 6-hourly per day over time period per latitude per 
                % longitude
                % [Day*Month; 6hr; Lat; Lon]
            crhumid_cpgn_daymonth_lat_lon = ...
                eval(char(crhumid_store_cpgn_name(3)));
                % [kg/kg] / [%]
                % Daily averaged daily over time period per latitude per 
                % longitude
                % [Day*Month; Lat; Lon]
                
            % Rename current chosen parameter climatology variables
            crhumid_clim_mean_daymonth_lat_lon = ...
                eval(char(crhumid_store_clim_name(1)));
                % [kg/kg] / [%]
                % Daily averaged annually over time period per latitude per
                % longitude
                % [Day*Month; Lat; Lon]
            crhumid_clim_STD_daymonth_lat_lon = ...
                eval(char(crhumid_store_clim_name(2)));
                % [kg/kg] / [%]
                % Daily standard-deviated annually over time period per 
                % latitude per longitude
                % [Day*Month; Lat; Lon]
        else % File non-existent
            disp('load_ACLOUD_ERA: Loading variables:')
            disp(crhumid_store_t_name)
            disp(crhumid_store_loc_name)
            disp(crhumid_store_cpgn_name)
            disp(crhumid_store_clim_name)
            
            %%% Load location data %%%
            % Set current chosen parameter loading path and data names
            crhumid_load_path = ...
                [path_data 'Reanalyses/' upper(humid_tstep_full) '/'];
                % Path
            crhumid_load_data = crhumid_name_data;
                % Data
                
            % Set current chosen parameter campaign loading file name
            crhumid_cpgn_load_file = ...
                [humid_set_file '_' crhumid_name_file '_' ...
                humid_tstep_full '_' month_abbr '_' yr_cpgn_name '.nc'];
                
            % Load current chosen parameter location data
            crhumid_lat = ...
                getnc([crhumid_load_path crhumid_cpgn_load_file],...
                'latitude');
                % [deg N], latitude, [Lat_All]
            crhumid_lon = ...
                getnc([crhumid_load_path crhumid_cpgn_load_file],...
                'longitude');
                % [deg E], longitude, [Lon_All]
                
            % Calculate current chosen parameter location grid point
            % numbers
            crhumid_lat_no = length(crhumid_lat); % Latitude
            crhumid_lon_no = length(crhumid_lon); % Longitude
            
            %%% Find location boundary data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Extracting ' humid_set_file ' ' crhumid_name_MATLAB ...
                ' location data over chosen region'])
            
            % Find current chosen parameter chosen region boundary indexes 
            % in latitude data
            crhumid_lat_bnd_indx_srt = ...
                find(crhumid_lat == reg_lat_bnd(1),1);
                % Start - Exact longitudinal grid point
            if isempty(crhumid_lat_bnd_indx_srt)
                    % No location point equality
                % Closest latitudinal grid point
                [~,crhumid_lat_bnd_indx_srt] = ...
                    min(abs(crhumid_lat - reg_lat_bnd(1)));
                    % Start
            end
            crhumid_lat_bnd_indx_end = ...
                find(crhumid_lat == reg_lat_bnd(2),1);
                % End - Exact longitudinal grid point
            if isempty(crhumid_lat_bnd_indx_end)
                    % No location point equality
                % Closest latitudinal grid point
                [~,crhumid_lat_bnd_indx_end] = ...
                    min(abs(crhumid_lat - reg_lat_bnd(2)));
                    % End
            end
            
            % Merge current chosen parameter chosen region boundary indexes 
            % in latitude data
            crhumid_lat_bnd_indx = ...
                [crhumid_lat_bnd_indx_srt crhumid_lat_bnd_indx_end];
                % Unsorted, [Start : End]
            crhumid_lat_bnd_indx = sort(crhumid_lat_bnd_indx);
                % Sorted, [Start : End]
            
            % Find and merge current chosen parameter chosen region 
            % boundary indexes in longitude data
            if max(max(crhumid_lon)) > 180 % Format = [0,360] deg E
                % Find boundary index(es) in Eastern Hemisphere
                crhumid_lon_bnd_indx_EH = ...
                    [1 find(crhumid_lon == reg_lon_bnd(2),1)];
                    % Exact longitudinal grid points, [Start : End]
                if length(crhumid_lon_bnd_indx_EH) == 1
                        % Only one location point equality
                    % Closest longitudinal end grid point
                    [~,crhumid_lon_bnd_indx_EH(2)] = ...
                        min(abs(crhumid_lon - reg_lon_bnd(2)));
                end
                
                % Find boundary index(es) in Western Hemisphere
                crhumid_lon_bnd_indx_WH = ...
                    [find(crhumid_lon == reg_lon_bnd(1) + 360,1) ...
                    crhumid_lon_no];
                    % Exact longitudinal grid points, [Start : End]
                if length(crhumid_lon_bnd_indx_WH) == 1
                        % Only one location point equality
                    % Closest longitudinal start grid point
                    crhumid_lon_bnd_indx_WH = ...
                        [min(abs(crhumid_lon - reg_lon_bnd(1) + 360)) ...
                        crhumid_lon_bnd_indx_WH];
                        % [Start : End]
                end
                
                % Merge boundary indexes
                crhumid_lon_bnd_indx = ...
                    [crhumid_lon_bnd_indx_EH; crhumid_lon_bnd_indx_WH];
                    % [EH : WH; Start : End]
            else % Format = [-180,180] deg E
                % Find start index
                crhumid_lon_bnd_indx_srt = ...
                    find(crhumid_lon == reg_lon_bnd(1),1);
                    % Exact longitudinal grid point
                if isempty(crhumid_lon_bnd_indx_srt)
                        % No location point equality
                    % Closest longitudinal grid point
                    [~,crhumid_lon_bnd_indx_srt] = ...
                        min(abs(crhumid_lon - reg_lon_bnd(1)));
                end
                
                % Find end index
                crhumid_lon_bnd_indx_end = ...
                    find(crhumid_lon == reg_lon_bnd(2),1);
                    % Exact longitudinal grid point
                if isempty(crhumid_lon_bnd_indx_end)
                        % No location point equality
                    % Closest longitudinal grid point
                    [~,crhumid_lon_bnd_indx_end] = ...
                        min(abs(crhumid_lon - reg_lon_bnd(2)));
                end
                
                % Merge boundary indexes
                crhumid_lon_bnd_indx = ...
                    [crhumid_lon_bnd_indx_srt crhumid_lon_bnd_indx_end];
                    % Unsorted, [Start : End]
                crhumid_lon_bnd_indx = sort(crhumid_lon_bnd_indx);
                    % Sorted, [Start : End]
            end
            
            % Delete unnecessary variable(s)
            clear crhumid_lat_bnd_indx_* crhumid_lon_bnd_indx_*
            
            %%% Extract location data %%%
            % Extract current chosen parameter location data over chosen 
            % region
            crhumid_lat = ...
                crhumid_lat(crhumid_lat_bnd_indx(1):crhumid_lat_bnd_indx(2));
                % [deg N], latitude, [Lat]
            if size(crhumid_lon_bnd_indx,1) == 2 % Format = [0,360] deg E
                % Longitude
                crhumid_lon = ...
                    [crhumid_lon(crhumid_lon_bnd_indx(2,1):crhumid_lon_bnd_indx(2,2)); ...
                    crhumid_lon(crhumid_lon_bnd_indx(1,1):crhumid_lon_bnd_indx(1,2))];
                    % [deg E], [Lon]
            else % Format = [-180,180] deg E
                % Longitude
                crhumid_lon = ...
                    crhumid_lon(crhumid_lon_bnd_indx(1):crhumid_lon_bnd_indx(2));
                    % [deg E], [Lon]
            end
            
            % Calculate current chosen parameter location grid point
            % numbers
            crhumid_lat_no = length(crhumid_lat); % Latitude
            crhumid_lon_no = length(crhumid_lon); % Longitude
            
            %%% Load, find boundary and extract time and variable data %%%
            % Loop over data set years and load current chosen parameter
            % time and variable data
            for y = 1:yr_mod_no % Loop over number of data set years
                % Extract current data set year name
                cryr_name = num2str(yr_mod_vec(y));
                disp(['load_ACLOUD_ERA: ' ...
                    'Loading and extracting ' humid_set_file ' ' ...
                    crhumid_name_MATLAB ' data for ' cryr_name])
                
                % Set current chosen parameter current climatology year 
                % loading file name
                crhumid_cryr_load_file = ...
                    [humid_set_file '_' crhumid_name_file '_' ...
                    humid_tstep_full '_' month_abbr '_' cryr_name '.nc'];
                
                % Load current chosen parameter current climatology year 
                % time data
                crhumid_cryr_date_6hrdaymonth = ...
                    timenc([crhumid_load_path crhumid_cryr_load_file],...
                    'time');
                    % [6hr_All*Day_All*Month_All; ...
                    %  Yr : Month : Day : Hr : Min : Sec]
                
                % Load current chosen parameter current climatology year 
                % variable data
                crhumid_cryr_6hrdaymonth_lat_lon = ...
                    getnc([crhumid_load_path crhumid_cryr_load_file],...
                    crhumid_load_data);
                    % [kg/kg] / [%]
                    % [6hr_All*Day_All*Month_All; Lat_All; Lon_All]
                
                % Find current chosen parameter current climatology year 
                % chosen time period boundary indexes in time data
                crhumid_cryr_date_bnd_indx_srt = ...
                    find(...
                    crhumid_cryr_date_6hrdaymonth(:,2) == month_bnd(1) ...
                    & crhumid_cryr_date_6hrdaymonth(:,3) == ...
                    day_bnd(1) - month_daysum(month_bnd(1)-1) + 1,...
                    1,'first');
                    % Start
                crhumid_cryr_date_bnd_indx_end = ...
                    find(...
                    crhumid_cryr_date_6hrdaymonth(:,2) == month_bnd(2) ...
                    & crhumid_cryr_date_6hrdaymonth(:,3) == ...
                    day_bnd(2) - month_daysum(month_bnd(2)-1) + 1,...
                    1,'last');
                    % End
                    
                % Merge current chosen parameter current climatology year 
                % chosen time period boundary indexes in time data
                crhumid_cryr_date_bnd_indx = ...
                    [crhumid_cryr_date_bnd_indx_srt ...
                    crhumid_cryr_date_bnd_indx_end];
                    % [Start : End]
                
                % Extract current chosen parameter current climatology year
                % time data over chosen time period
                crhumid_cryr_date_6hrdaymonth = ...
                    crhumid_cryr_date_6hrdaymonth(...
                    crhumid_cryr_date_bnd_indx(1):crhumid_cryr_date_bnd_indx(2),:);
                    % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
                    
                % Extract current chosen parameter current climatology year
                % variable data over chosen time period
                crhumid_cryr_6hrdaymonth_lat_lon = ...
                    crhumid_cryr_6hrdaymonth_lat_lon(...
                    crhumid_cryr_date_bnd_indx(1):crhumid_cryr_date_bnd_indx(2),:,:);
                    % [m], [6hr*Day*Month; Lat_All; Lon_All]
                
                % Extract current chosen parameter current climatology year
                % variable data over chosen region
                if size(crhumid_lon_bnd_indx,1) == 2
                        % Format = [0,360] deg E
                    crhumid_cryr_6hrdaymonth_lat_lon = ...
                        cat(3,...
                        crhumid_cryr_6hrdaymonth_lat_lon(:,...
                        crhumid_lat_bnd_indx(1):crhumid_lat_bnd_indx(2),...
                        crhumid_lon_bnd_indx(2,1):crhumid_lon_bnd_indx(2,2)),...
                        crhumid_cryr_6hrdaymonth_lat_lon(:,...
                        crhumid_lat_bnd_indx(1):crhumid_lat_bnd_indx(2),...
                        crhumid_lon_bnd_indx(1,1):crhumid_lon_bnd_indx(1,2)));
                        % [m], [6hr*Day*Month; Lat; Lon]
                else % Format = [-180,180] deg E
                    crhumid_cryr_6hrdaymonth_lat_lon = ...
                        crhumid_cryr_6hrdaymonth_lat_lon(:,...
                        crhumid_lat_bnd_indx(1):crhumid_lat_bnd_indx(2),...
                        crhumid_lon_bnd_indx(1):crhumid_lon_bnd_indx(2));
                        % [m], [6hr*Day*Month; Lat; Lon]
                end
                
                % Store current chosen parameter current climatology year 
                % time data in 6-hourly matrix over chosen time period 
                % per climatology year
                crhumid_date_6hrdaymonthyr(hr_no*day_no*(y-1)+1:hr_no*day_no*y,:) = ...
                    crhumid_cryr_date_6hrdaymonth;
                    % [6hr*Day*Month*Yr; Yr : Month : Day : Hr : Min : Sec]
                
                % Store current chosen parameter current climatology year 
                % variable data in 6-hourly matrix over chosen time period 
                % per climatology year per latitude per longitude
                crhumid_yr_6hrdaymonth_lat_lon(y,:,:,:) = ...
                    crhumid_cryr_6hrdaymonth_lat_lon;
                    % [kg/kg] / [%], [Yr; 6hr*Day*Month; Lat; Lon]
                
                % Delete current chosen parameter current climatology year
                % data
                clear crhumid_cryr_*
            end
            
            %%% Calculate data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Calculating ' humid_set_file ' ' crhumid_name_MATLAB ...
                ' average data'])
            
            % Loop over time period days and calculate current chosen 
            % parameter daily means over time period per climatology year 
            % per latitude per longitude
            for d = 1:day_no % Loop over number of time period days
                crhumid_yr_daymonth_lat_lon(:,d,:,:) = ...
                    nanmean(crhumid_yr_6hrdaymonth_lat_lon(:,4*(d-1)+1:4*d,:,:),2);
                    % [kg/kg] / [%], [Yr; Day*Month; Lat; Lon]
            end
            
            % Calculate current chosen parameter daily mean averaged 
            % annually over climatology time period per latitude per 
            % longitude
            crhumid_clim_mean_daymonth_lat_lon = ...
                squeeze(nanmean(crhumid_yr_daymonth_lat_lon(yr_clim_indx,:,:,:),1));
                % [kg/kg] / [%], [Day*Month; Lat; Lon]
                
            % Calculate current chosen parameter daily mean 
            % standard-deviated annually over climatology time period per 
            % latitude per longitude
            crhumid_clim_STD_daymonth_lat_lon = ...
                squeeze(nanstd(crhumid_yr_daymonth_lat_lon(yr_clim_indx,:,:,:),0,1));
                % [kg/kg] / [%], [Day*Month; Lat; Lon]
                
            % Delete unnecessary variable(s)
            clear d
            
            %%% Extract data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Extracting ' humid_set_MATLAB ' ' crhumid_name_MATLAB ...
                ' data over chosen time period'])
            
            % Extract current chosen parameter 6-hourly time data over 
            % campaign time period
            crhumid_date_6hrdaymonth = ...
                crhumid_date_6hrdaymonthyr(hr_no*day_no*yr_clim_no+1:end,:);
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
                
            % Extract current chosen parameter daily time data over 
            % campaign time period
            crhumid_date_daymonth = ...
                crhumid_date_6hrdaymonth(1:hr_no:end,1:3);
                % [Day*Month; Yr : Month : Day]
            
            % Extract current chosen parameter 6-hourly variable data over 
            % campaign time period per latitude per longitude
            crhumid_cpgn_6hrdaymonth_lat_lon = ...
                squeeze(crhumid_yr_6hrdaymonth_lat_lon(end,:,:,:));
                % [kg/kg] / [%], [6hr*Day*Month; Lat; Lon]
            
            % Extract current chosen parameter daily mean variable data 
            % over campaign time period per latitude per longitude
            crhumid_cpgn_daymonth_lat_lon = ...
                squeeze(crhumid_yr_daymonth_lat_lon(end,:,:,:));
                % [kg/kg] / [%], [Day*Month; Lat; Lon]
            
            %%% Rearrange data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Rearranging ' humid_set_MATLAB ' ' crhumid_name_MATLAB ...
                ' data over chosen time period'])
            
            % Rearrange current chosen parameter 6-hourly variable data 
            % over campaign time period per latitude per longitude from 3D 
            % to 4D
            crhumid_cpgn_6hr_daymonth_lat_lon = ...
                reshape(crhumid_cpgn_6hrdaymonth_lat_lon,...
                hr_no,day_no,crhumid_lat_no,crhumid_lon_no);
                % [kg/kg] / [%], [6hr; Day*Month; Lat; Lon]
            crhumid_cpgn_daymonth_6hr_lat_lon = ...
                permute(crhumid_cpgn_6hr_daymonth_lat_lon,[2,1,3,4]);
                % [kg/kg] / [%], [Day*Month; 6hr; Lat; Lon]
                
            % Delete unnecessary variable(s)
            clear crhumid_cpgn_6hr_daymonth_lat_lon
            
            %%% Rename data %%%
            disp(['load_ACLOUD_ERA: ' ...
                'Renaming ' humid_set_MATLAB ' ' crhumid_name_MATLAB ...
                ' data'])
            
            % Rename current chosen parameter time variables
            eval([char(crhumid_store_t_name(1)) ' = ' ...
                'crhumid_date_6hrdaymonth;'])
                % 6-hourly date matrix
                % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
            eval([char(crhumid_store_t_name(2)) ' = ' ...
                'crhumid_date_daymonth;'])
                % Daily date matrix
                % [Day*Month; Yr : Month : Day]
                
            % Rename current chosen parameter location variables
            eval([char(crhumid_store_loc_name(1)) ' = crhumid_lat;']);
                % [deg N]
                % Latitudinal grid point vector
                % [Lat]
            eval([char(crhumid_store_loc_name(2)) ' = crhumid_lon;']);
                % [deg E]
                % Longitudinal grid point vector
                % [Lon]
            
            % Rename current chosen parameter campaign variables
            eval([char(crhumid_store_cpgn_name(1)) ' = ' ...
                'crhumid_cpgn_6hrdaymonth_lat_lon;']);
                % [kg/kg] / [%]
                % 6-hourly over time period per latitude per longitude
                % [6hr*Day*Month; Lat; Lon]
            eval([char(crhumid_store_cpgn_name(2)) ' = ' ...
                'crhumid_cpgn_daymonth_6hr_lat_lon;']);
                % [kg/kg] / [%]
                % 6-hourly per day over time period per latitude per 
                % longitude
                % [Day*Month; 6hr; Lat; Lon]
            eval([char(crhumid_store_cpgn_name(3)) ' = ' ...
                'crhumid_cpgn_daymonth_lat_lon;']);
                % [kg/kg] / [%]
                % Daily averaged daily over time period per latitude per 
                % longitude
                % [Day*Month; Lat; Lon]
                
            % Rename current chosen parameter climatology variables
            eval([char(crhumid_store_clim_name(1)) ' = ' ...
                'crhumid_clim_mean_daymonth_lat_lon;']);
                % [kg/kg] / [%]
                % Daily averaged annually over time period per latitude per
                % longitude
                % [Day*Month; Lat; Lon]
            eval([char(crhumid_store_clim_name(2)) ' = ' ...
                'crhumid_clim_STD_daymonth_lat_lon;']);
                % [kg/kg] / [%]
                % Daily standard-deviated annually over time period per 
                % latitude per longitude
                % [Day*Month; Lat; Lon]
            
            %%% Store data %%%
            % Store current chosen parameter time and campaign data
            disp(['load_ACLOUD_ERA: ' ...
                'Storing ' humid_set_MATLAB ' ' crhumid_name_MATLAB ' data'])
            save([crhumid_store_path crhumid_store_file],...
                [crhumid_name_MATLAB '_*_' humid_set_MATLAB])
                % Store time and campaign variables
        end
        
        %%% Rename data %%%
        % Rename current chosen parameter time variables
        eval([crhumid_name_MATLAB '_date_6hrdaymonth = ' ...
            'crhumid_date_6hrdaymonth;'])
            % 6-hourly date matrix
            % [6hr*Day*Month; Yr : Month : Day : Hr : Min : Sec]
        eval([crhumid_name_MATLAB '_date_daymonth = ' ...
            'crhumid_date_daymonth;'])
            % Daily date matrix
            % [Day*Month; Yr : Month : Day]
            
        % Rename current chosen parameter location variables
        eval([crhumid_name_MATLAB '_lat = crhumid_lat;'])
            % [deg N]
            % Latitudinal grid point vector
            % [Lat]
        eval([crhumid_name_MATLAB '_lon = crhumid_lon;'])
            % [deg E]
            % Longitudinal grid point vector
            % [Lon]
        
        % Rename current chosen parameter campaign variables
        eval([crhumid_name_MATLAB '_cpgn_6hrdaymonth_lat_lon = ' ...
            'crhumid_cpgn_6hrdaymonth_lat_lon;']);
            % [kg/kg] / [%]
            % 6-hourly over time period per latitude per longitude
            % [6hr*Day*Month; Lat; Lon]
        eval([crhumid_name_MATLAB '_cpgn_daymonth_6hr_lat_lon = ' ...
            'crhumid_cpgn_daymonth_6hr_lat_lon;']);
            % [kg/kg] / [%]
            % 6-hourly per day over time period per latitude per longitude
            % [Day*Month; 6hr; Lat; Lon]
        eval([crhumid_name_MATLAB '_cpgn_daymonth_lat_lon = ' ...
            'crhumid_cpgn_daymonth_lat_lon;']);
            % [kg/kg] / [%]
            % Daily averaged daily over time period per latitude per 
            % longitude
            % [Day*Month; Lat; Lon]
            
        % Rename current chosen parameter climatology variables
        eval([crhumid_name_MATLAB '_clim_mean_daymonth_lat_lon = ' ...
            'crhumid_clim_mean_daymonth_lat_lon;']);
            % [kg/kg] / [%]
            % Daily averaged annually over time period per latitude per
            % longitude
            % [Day*Month; Lat; Lon]
        eval([crhumid_name_MATLAB '_clim_STD_daymonth_lat_lon = ' ...
            'crhumid_clim_STD_daymonth_lat_lon;']);
            % [kg/kg] / [%]
            % Daily standard-deviated annually over time period per 
            % latitude per longitude
            % [Day*Month; Lat; Lon]
        
        %%% Delete data %%%
        % Delete unnecessary variable(s)
        clear(crhumid_store_t_name{:},crhumid_store_loc_name{:},...
            crhumid_store_cpgn_name{:},crhumid_store_clim_name{:})
        
        % Delete current chosen parameter data
        clear crhumid_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clearvars p humid_*
else % humid data not chosen
    %%% Delete data %%%
    % Delete unnecessary variable(s)
    clear humid_name_all humid_indx_all
end
%%
%%%%%%%% Plot data %%%%%%%%
%%%%% Atmospheric and surface data %%%%%
%%% Figure properties %%%
% Set number of open plots
plot_no = 0;

%%% Set variable properties %%%
% Set MATLAB name of figure type(s) to be plotted
plot_typename = [{'d-clim_anom_700hPa-vpoT'}];
    % 'wk-clim_anom'             = Climatology and anomaly relative to 
    %                              climatology over campaign weeks
    % 'kp-clim_anom'             = Climatology and anomaly relative to 
    %                              climatology over campaign key periods
    % 'tp-clim_anom'             = Climatology and anomaly relative to 
    %                              climatology over campaign time period
    % 'd-clim_anom_700hPa-circ'  = Climatology and anomaly relative to 
    %                              climatology over campaign days of 
    %                              700-hPa circulation
    % 'wk-clim_anom_700hPa-circ' = Climatology and anomaly relative to 
    %                              climatology over campaign weeks of 
    %                              700-hPa circulation
    % 'kp-clim_anom_700hPa-circ' = Climatology and anomaly relative to 
    %                              climatology over campaign key periods of
    %                              700-hPa circulation
    % 'd-clim_anom_700hPa-vpoT'  = Climatology and anomaly relative to 
    %                              climatology over campaign days of
    %                              700-hPa virtual potential temperature
    % 'kp-clim_anom_700hPa-vpoT' = Climatology and anomaly relative to 
    %                              climatology over campaign key periods of
    %                              700-hPa virtual potential temperature
    % 'tp-clim_anom_700hPa-circ' = Climatology and anomaly relative to 
    %                              climatology over campaign time period of
    %                              700-hPa circulation

% Extract names, unit(s), index(es) and variable data of figure type(s) to 
% be plotted
plot_varname = [{'MATLAB name'} {'Title name'} {'Unit'}];
    % Headlines for variable name(s)
for t = 1:length(plot_typename) % Loop over number of plot types
    % Extract current plot type name
    crtype_name = char(plot_typename(t));
    
    % Extract current plot type variable names, unit(s) and data
    if strcmp(crtype_name,'kp-clim_anom')
            % Climatology and anomaly relative to climatology over campaign
            % key periods
        disp(['load_ACLOUD_ERA: Climatology and anomaly ' ...
            'relative to climatology over campaign key periods ' ...
            'chosen for plotting'])
        
        %%% Set variable names %%%
        % Loop over chosen parameters and extract current plot type MATLAB 
        % and title names and unit(s)
        for p = 1:param_no % Loop over number of chosen parameters
            plot_varname = ...
                [plot_varname; ...
                param_name(param_indx(p)+1,5) ...
                param_name(param_indx(p)+1,6) ...
                param_name(param_indx(p)+1,7)];
        end
        
        %%% Calculate variable number %%%
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge location data %%%
        % Loop over chosen parameters and merge current plot type location 
        % data in a structure
        for p = 1:param_no % Loop over number of chosen parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(param_name(param_indx(p)+1,5));
                % MATLAB
            
            % Merge current plot type current parameter location data in a 
            % structure
            plot_loc(plot_var_no+p,1).mat = ...
                eval([crparam_name_MATLAB '_lat;']);
                % [deg N], latitude, [Plot_Type,1].mat -> [Lat]
            plot_loc(plot_var_no+p,2).mat = ...
                eval([crparam_name_MATLAB '_lon;']);
                % [deg E], longitude, [Plot_Type,1].mat -> [Lon]
        end
        
        %%% Merge variable data %%%
        % Loop over chosen parameters and merge current plot type variable  
        % data in a structure
        for p = 1:param_no % Loop over number of chosen parameters
            % Extract current parameter names
            crparam_name_gen = char(param_name(param_indx(p)+1,2));
                % General
            crparam_name_MATLAB = char(param_name(param_indx(p)+1,5));
                % MATLAB
                
            % Rename current plot type current parameter campaign and 
            % climatology variables
            crtype_crparam_cpgn_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_cpgn_daymonth_lat_lon;']);
                % [m] / [m/s] / [deg C] / [kg/kg] / [%], campaign
                % [Day*Month; Lat; Lon]
            crtype_crparam_clim_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_clim_mean_daymonth_lat_lon;']);
                % [m] / [m/s] / [deg C] / [kg/kg] / [%], climatology
                % [Day*Month; Lat; Lon]
                
            % Loop over key periods and calculate current plot type current
            % parameter campaign and climatology means or median over 
            % campaign key periods
            for kp = 1:kper_no % Loop over number of key periods
                % Campaign
                if strcmp(crparam_name_gen,'wind') % Wind data
                    % Median
                    crtype_crparam_cpgn_kp_lat_lon(kp,:,:) = ...
                        nanmedian(crtype_crparam_cpgn_daymonth_lat_lon(...
                        kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                        % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                        % [Kp; Lat; Lon]
                else % All other data
                    % Mean
                    crtype_crparam_cpgn_kp_lat_lon(kp,:,:) = ...
                        nanmean(crtype_crparam_cpgn_daymonth_lat_lon(...
                        kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                        % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                        % [Kp; Lat; Lon]
                end
                
                % Climatology
                if strcmp(crparam_name_gen,'wind') % Wind data
                    % Median
                    crtype_crparam_clim_kp_lat_lon(kp,:,:) = ...
                        nanmedian(crtype_crparam_clim_daymonth_lat_lon(...
                        kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                        % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                        % [Kp; Lat; Lon]
                else % All other data
                    crtype_crparam_clim_kp_lat_lon(kp,:,:) = ...
                        nanmean(crtype_crparam_clim_daymonth_lat_lon(...
                        kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                        % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                        % [Kp; Lat; Lon]
                end
            end
            
            % Calculate current plot type current parameter campaign 
            % anomaly relative to climatology
            crtype_crparam_anom_kp_lat_lon = ...
                crtype_crparam_cpgn_kp_lat_lon - ...
                crtype_crparam_clim_kp_lat_lon;
                % [m] / [m/s] / [deg C] / [kg/kg] / [%], [Kp; Lat; Lon]
            
            % Merge current plot type current parameter climatology data in
            % a structure
            plot_var(plot_var_no+p,1).mat = crtype_crparam_clim_kp_lat_lon;
                % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                % [Plot_Type,1].mat -> [Kp; Lat; Lon]
            
            % Merge current plot type current parameter campaign anomaly 
            % relative to climatology data in a structure
            plot_var(plot_var_no+p,2).mat = crtype_crparam_anom_kp_lat_lon;
                % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                % [Plot_Type,2].mat -> [Kp; Lat; Lon]
            
            % Delete current parameter data
            clear crtype_crparam_* crparam_*
        end
    elseif strcmp(crtype_name,'tp-clim_anom')
            % Climatology and anomaly relative to climatology over campaign
            % time period
        disp(['load_ACLOUD_ERA: Climatology and anomaly ' ...
            'relative to climatology over campaign time period ' ...
            'chosen for plotting'])
        
        %%% Set variable names %%%
        % Loop over chosen parameters and extract current plot type MATLAB 
        % and title names and unit(s)
        for p = 1:param_no % Loop over number of chosen parameters
            plot_varname = ...
                [plot_varname; ...
                param_name(param_indx(p)+1,5) ...
                param_name(param_indx(p)+1,6) ...
                param_name(param_indx(p)+1,7)];
        end
        
        %%% Calculate variable number %%%
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge location data %%%
        % Loop over chosen parameters and merge current plot type location 
        % data in a structure
        for p = 1:param_no % Loop over number of chosen parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(param_name(param_indx(p)+1,5));
                % MATLAB
            
            % Merge current plot type current parameter location data in a 
            % structure
            plot_loc(plot_var_no+t,1).mat = ...
                eval([crparam_name_MATLAB '_lat;']);
                % [deg N], latitude, [Plot_Type,1].mat -> [Lat]
            plot_loc(plot_var_no+t,2).mat = ...
                eval([crparam_name_MATLAB '_lon;']);
                % [deg E], longitude, [Plot_Type,1].mat -> [Lon]
        end
        
        %%% Merge variable data %%%
        % Loop over chosen parameters and merge current plot type variable  
        % data in a structure
        for p = 1:param_no % Loop over number of chosen parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(param_name(param_indx(p)+1,5));
                % MATLAB
                
            % Rename current plot type current parameter campaign and 
            % climatology variables
            crtype_crparam_cpgn_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_cpgn_daymonth_lat_lon;']);
                % [m] / [m/s] / [deg C] / [kg/kg] / [%], campaign
                % [Day*Month; Lat; Lon]
            crtype_crparam_clim_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_clim_mean_daymonth_lat_lon;']);
                % [m] / [m/s] / [deg C] / [kg/kg] / [%], climatology
                % [Day*Month; Lat; Lon]
                
            % Calculate current plot type current parameter campaign and 
            % climatology means over campaign time period
            crtype_crparam_cpgn_lat_lon = ...
                squeeze(nanmean(crtype_crparam_cpgn_daymonth_lat_lon,1));
                % [m] / [m/s] / [deg C] / [kg/kg] / [%], campaign
                % [Lat; Lon]
            crtype_crparam_clim_lat_lon = ...
                squeeze(nanmean(crtype_crparam_clim_daymonth_lat_lon,1));
                % [m] / [m/s] / [deg C] / [kg/kg] / [%], climatology
                % [Lat; Lon]
                
            % Calculate current plot type current parameter campaign 
            % anomaly relative to climatology
            crtype_crparam_anom_lat_lon = ...
                crtype_crparam_cpgn_lat_lon - crtype_crparam_clim_lat_lon;
                % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                % [Lat; Lon]
            
            % Merge current plot type current parameter climatology data in
            % a structure
            plot_var(plot_var_no+t,1).mat = crtype_crparam_clim_lat_lon;
                % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                % [Plot_Type,1].mat -> [Day*Month; Lat; Lon]
            
            % Merge current plot type current parameter campaign anomaly 
            % relative to climatology data in a structure
            plot_var(plot_var_no+t,2).mat = crtype_crparam_anom_lat_lon;
                % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                % [Plot_Type,2].mat -> [Day*Month; Lat; Lon]
            
            % Delete current parameter data
            clear crtype_crparam_* crparam_*
        end
    elseif strcmp(crtype_name,'d-clim_anom_700hPa-circ')
            % Climatology and anomaly relative to climatology over campaign
            % days of 700-hPa circulation
        disp(['load_ACLOUD_ERA: Climatology and anomaly ' ...
            'relative to climatology over campaign days of ' ...
            '700-hPa circulation chosen for plotting'])
        
        %%% Set variable names %%%
        % Set current plot type parameter names
        crtype_paramname = [{'Z700hPa'}; {'u700hPa'}; {'v700hPa'}];
        
        % Calculate number of current plot type parameters
        crtype_paramno = length(crtype_paramname);
        
        % Loop over current plot type parameters and find parameter indexes
        for p = 1:crtype_paramno % Loop over current plot type parameters
            crtype_paramindx(p) = ...
                find(strcmp(param_name(2:end,5),...
                char(crtype_paramname(p))));
        end
        
        % Extract current plot type MATLAB and title names and unit(s)
        plot_varname = ...
            [plot_varname; ...
            param_name(crtype_paramindx+1,5) ...
            param_name(crtype_paramindx+1,6) ...
            param_name(crtype_paramindx+1,7)];
        
        %%% Calculate variable number %%%
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge location data %%%
        % Loop over chosen parameters and merge current plot type location 
        % data in a structure
        for p = 1:crtype_paramno % Loop over current plot type parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname(p));
                % MATLAB
            
            % Merge current plot type current parameter location data in a 
            % structure
            plot_loc(plot_var_no+t,2*(p-1)+1).mat = ...
                eval([crparam_name_MATLAB '_lat;']);
                % [deg N], latitude
                % [Plot_Type,1:2:2*(Plot_Param-1)].mat -> [Lat]
            plot_loc(plot_var_no+t,2*p).mat = ...
                eval([crparam_name_MATLAB '_lon;']);
                % [deg E], longitude
                % [Plot_Type,2:2:2*Plot_Param].mat -> [Lon]
        end
        
        %%% Merge variable data %%%
        % Loop over chosen parameters and merge current plot type variable  
        % data in a structure
        for p = 1:crtype_paramno % Loop over current plot type parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname(p));
                % MATLAB
                
            % Rename current plot type current parameter campaign and 
            % climatology variables
            crtype_crparam_cpgn_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_cpgn_daymonth_lat_lon;']);
                % [m] / [m/s], campaign, [Day*Month; Lat; Lon]
            crtype_crparam_clim_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_clim_mean_daymonth_lat_lon;']);
                % [m] / [m/s], climatology, [Day*Month; Lat; Lon]
            
            % Calculate current plot type current parameter campaign 
            % anomaly relative to climatology
            crtype_crparam_anom_daymonth_lat_lon = ...
                crtype_crparam_cpgn_daymonth_lat_lon - ...
                crtype_crparam_clim_daymonth_lat_lon;
                % [m] / [m/s], [Day*Month; Lat; Lon]
                
            % Merge current plot type current parameter variable data in 
            % matrixes
            crtype_cpgn_param_daymonth_lat_lon(p,:,:,:) = ...
                crtype_crparam_cpgn_daymonth_lat_lon;
                % [m] / [m/s], campaign
                % [Plot_Param; Day*Month; Lat; Lon]
            crtype_clim_param_daymonth_lat_lon(p,:,:,:) = ...
                crtype_crparam_clim_daymonth_lat_lon;
                % [m] / [m/s], climatology
                % [Plot_Param; Day*Month; Lat; Lon]
            crtype_anom_param_daymonth_lat_lon(p,:,:,:) = ...
                crtype_crparam_anom_daymonth_lat_lon;
                % [m] / [m/s], anomaly relative to climatology
                % [Plot_Param; Day*Month; Lat; Lon]
                
            % Delete current parameter data
            clear w crtype_crparam_* crparam_*
        end
        
        % Merge current plot type 700-hPa geopotential height variable data
        % in a structure
        plot_var(plot_var_no+t,1).mat = ...
            squeeze(crtype_clim_param_daymonth_lat_lon(1,:,:,:));
            % [m], climatology
            % [Plot_Type,1].mat -> [Day*Month; Lat; Lon]
        plot_var(plot_var_no+t,2).mat = ...
            squeeze(crtype_anom_param_daymonth_lat_lon(1,:,:,:));
            % [m], anomaly relative to climatology
            % [Plot_Type,2].mat -> [Day*Month; Lat; Lon]
            
        % Merge current plot type 700-hPa zonal wind variable data in a 
        % structure
        plot_var(plot_var_no+t,3).mat = ...
            squeeze(crtype_cpgn_param_daymonth_lat_lon(2,:,:,:));
            % [m/s], campaign
            % [Plot_Type,3].mat -> [Day*Month; Lat; Lon]
            
        % Merge current plot type 700-hPa meridional wind variable data in 
        % a structure
        plot_var(plot_var_no+t,4).mat = ...
            squeeze(crtype_cpgn_param_daymonth_lat_lon(3,:,:,:));
            % [m/s], campaign
            % [Plot_Type,3].mat -> [Day*Month; Lat; Lon]    
    elseif strcmp(crtype_name,'wk-clim_anom_700hPa-circ')
            % Climatology and anomaly relative to climatology over campaign
            % weeks of 700-hPa circulation
        disp(['load_ACLOUD_ERA: Climatology and anomaly ' ...
            'relative to climatology over campaign weeks of ' ...
            '700-hPa circulation chosen for plotting'])
        
        %%% Set variable names %%%
        % Set current plot type parameter names
        crtype_paramname = [{'Z700hPa'}; {'u700hPa'}; {'v700hPa'}];
        
        % Calculate number of current plot type parameters
        crtype_paramno = length(crtype_paramname);
        
        % Loop over current plot type parameters and find parameter indexes
        for p = 1:crtype_paramno % Loop over current plot type parameters
            crtype_paramindx(p) = ...
                find(strcmp(param_name(2:end,5),...
                char(crtype_paramname(p))));
        end
        
        % Extract current plot type MATLAB and title names and unit(s)
        plot_varname = ...
            [plot_varname; ...
            param_name(crtype_paramindx+1,5) ...
            param_name(crtype_paramindx+1,6) ...
            param_name(crtype_paramindx+1,7)];
        
        %%% Calculate variable number %%%
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge location data %%%
        % Loop over chosen parameters and merge current plot type location 
        % data in a structure
        for p = 1:crtype_paramno % Loop over current plot type parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname(p));
                % MATLAB
            
            % Merge current plot type current parameter location data in a 
            % structure
            plot_loc(plot_var_no+t,2*(p-1)+1).mat = ...
                eval([crparam_name_MATLAB '_lat;']);
                % [deg N], latitude
                % [Plot_Type,1:2:2*(Plot_Param-1)].mat -> [Lat]
            plot_loc(plot_var_no+t,2*p).mat = ...
                eval([crparam_name_MATLAB '_lon;']);
                % [deg E], longitude
                % [Plot_Type,2:2:2*Plot_Param].mat -> [Lon]
        end
        
        %%% Merge variable data %%%
        % Loop over chosen parameters and merge current plot type variable  
        % data in a structure
        for p = 1:crtype_paramno % Loop over current plot type parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname(p));
                % MATLAB
                
            % Rename current plot type current parameter campaign and 
            % climatology variables
            crtype_crparam_cpgn_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_cpgn_daymonth_lat_lon;']);
                % [m] / [m/s], campaign, [Day*Month; Lat; Lon]
            crtype_crparam_clim_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_clim_mean_daymonth_lat_lon;']);
                % [m] / [m/s], climatology, [Day*Month; Lat; Lon]
                
            % Loop over time period weeks and calculate current plot type 
            % current parameter campaign and climatology means over 
            % campaign weeks
            for w = 1:ceil((day_no-3)/7)
                    % Loop over number of time period weeks
                % Campaign
                crtype_crparam_cpgn_wk_lat_lon(w,:,:) = ...
                    nanmean(crtype_crparam_cpgn_daymonth_lat_lon(7*(w-1)+1:7*w,:,:),1);
                    % [m] / [m/s], [Wk; Lat; Lon]
                    
                % Climatology
                crtype_crparam_clim_wk_lat_lon(w,:,:) = ...
                    nanmean(crtype_crparam_clim_daymonth_lat_lon(7*(w-1)+1:7*w,:,:),1);
                    % [m] / [m/s], [Wk; Lat; Lon]
            end
            
            % Calculate current plot type current parameter campaign 
            % anomaly relative to climatology
            crtype_crparam_anom_wk_lat_lon = ...
                crtype_crparam_cpgn_wk_lat_lon - ...
                crtype_crparam_clim_wk_lat_lon;
                % [m] / [m/s], [Wk; Lat; Lon]
                
            % Merge current plot type current parameter variable data in 
            % matrixes
            crtype_cpgn_param_wk_lat_lon(p,:,:,:) = ...
                crtype_crparam_cpgn_wk_lat_lon;
                % [m] / [m/s], campaign
                % [Plot_Param; Wk; Lat; Lon]
            crtype_clim_param_wk_lat_lon(p,:,:,:) = ...
                crtype_crparam_clim_wk_lat_lon;
                % [m] / [m/s], climatology
                % [Plot_Param; Wk; Lat; Lon]
            crtype_anom_param_wk_lat_lon(p,:,:,:) = ...
                crtype_crparam_anom_wk_lat_lon;
                % [m] / [m/s], anomaly relative to climatology
                % [Plot_Param; Wk; Lat; Lon]
                
            % Delete current parameter data
            clear w crtype_crparam_* crparam_*
        end
        
        % Merge current plot type 700-hPa geopotential height variable data
        % in a structure
        plot_var(plot_var_no+t,1).mat = ...
            squeeze(crtype_clim_param_wk_lat_lon(1,:,:,:));
            % [m], climatology
            % [Plot_Type,1].mat -> [Wk; Lat; Lon]
        plot_var(plot_var_no+t,2).mat = ...
            squeeze(crtype_anom_param_wk_lat_lon(1,:,:,:));
            % [m], anomaly relative to climatology
            % [Plot_Type,2].mat -> [Wk; Lat; Lon]
            
        % Merge current plot type 700-hPa zonal wind variable data in a 
        % structure
        plot_var(plot_var_no+t,3).mat = ...
            squeeze(crtype_cpgn_param_wk_lat_lon(2,:,:,:));
            % [m/s], campaign
            % [Plot_Type,3].mat -> [Wk; Lat; Lon]
            
        % Merge current plot type 700-hPa meridional wind variable data in 
        % a structure
        plot_var(plot_var_no+t,4).mat = ...
            squeeze(crtype_cpgn_param_wk_lat_lon(3,:,:,:));
            % [m/s], campaign
            % [Plot_Type,3].mat -> [Wk; Lat; Lon]
    elseif strcmp(crtype_name,'kp-clim_anom_700hPa-circ')
            % Climatology and anomaly relative to climatology over campaign
            % key periods of 700-hPa circulation
        disp(['load_ACLOUD_ERA: Climatology and anomaly ' ...
            'relative to climatology over campaign key periods of ' ...
            '700-hPa circulation chosen for plotting'])
        
        %%% Set variable names %%%
        % Set current plot type parameter names
        crtype_paramname = [{'Z700hPa'}; {'u700hPa'}; {'v700hPa'}];
        
        % Calculate number of current plot type parameters
        crtype_paramno = length(crtype_paramname);
        
        % Loop over current plot type parameters and find parameter indexes
        for p = 1:crtype_paramno % Loop over current plot type parameters
            crtype_paramindx(p) = ...
                find(strcmp(param_name(2:end,5),...
                char(crtype_paramname(p))));
        end
        
        % Extract current plot type MATLAB and title names and unit(s)
        plot_varname = ...
            [plot_varname; ...
            param_name(crtype_paramindx+1,5) ...
            param_name(crtype_paramindx+1,6) ...
            param_name(crtype_paramindx+1,7)];
        
        %%% Calculate variable number %%%
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge location data %%%
        % Loop over chosen parameters and merge current plot type location 
        % data in a structure
        for p = 1:crtype_paramno % Loop over current plot type parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname(p));
                % MATLAB
            
            % Merge current plot type current parameter location data in a 
            % structure
            plot_loc(plot_var_no+t,2*(p-1)+1).mat = ...
                eval([crparam_name_MATLAB '_lat;']);
                % [deg N], latitude
                % [Plot_Type,1:2:2*(Plot_Param-1)].mat -> [Lat]
            plot_loc(plot_var_no+t,2*p).mat = ...
                eval([crparam_name_MATLAB '_lon;']);
                % [deg E], longitude
                % [Plot_Type,2:2:2*Plot_Param].mat -> [Lon]
        end
        
        %%% Merge variable data %%%
        % Loop over chosen parameters and merge current plot type variable  
        % data in a structure
        for p = 1:crtype_paramno % Loop over current plot type parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname(p));
                % MATLAB
                
            % Rename current plot type current parameter campaign and 
            % climatology variables
            crtype_crparam_cpgn_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_cpgn_daymonth_lat_lon;']);
                % [m] / [m/s], campaign, [Day*Month; Lat; Lon]
            crtype_crparam_clim_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_clim_mean_daymonth_lat_lon;']);
                % [m] / [m/s], climatology, [Day*Month; Lat; Lon]
            
            % Loop over key periods and calculate current plot type current
            % parameter campaign and climatology means or median over 
            % campaign key periods
            for kp = 1:kper_no % Loop over number of key periods
                % Campaign
                if strcmp(crparam_name_MATLAB,'Z700hPa')
                        % 700-hPa geopotential height data
                    % Mean
                    crtype_crparam_cpgn_kp_lat_lon(kp,:,:) = ...
                        nanmean(crtype_crparam_cpgn_daymonth_lat_lon(...
                        kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                        % [m] / [m/s], [Kp; Lat; Lon]
                elseif strcmp(crparam_name_MATLAB,'u700hPa') || ...
                        strcmp(crparam_name_MATLAB,'v700hPa')
                        % 700-hPa zonal or meridional wind data
                    % Median
                    crtype_crparam_cpgn_kp_lat_lon(kp,:,:) = ...
                        nanmedian(crtype_crparam_cpgn_daymonth_lat_lon(...
                        kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                        % [m] / [m/s], [Kp; Lat; Lon]
                end
                
                % Climatology
                if strcmp(crparam_name_MATLAB,'Z700hPa')
                        % 700-hPa geopotential height data
                    % Mean
                    crtype_crparam_clim_kp_lat_lon(kp,:,:) = ...
                        nanmean(crtype_crparam_clim_daymonth_lat_lon(...
                        kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                        % [m] / [m/s], [Kp; Lat; Lon]
                elseif strcmp(crparam_name_MATLAB,'u700hPa') || ...
                        strcmp(crparam_name_MATLAB,'v700hPa')
                        % 700-hPa zonal or meridional wind data
                    % Median
                    crtype_crparam_clim_kp_lat_lon(kp,:,:) = ...
                        nanmedian(crtype_crparam_clim_daymonth_lat_lon(...
                        kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                        % [m] / [m/s], [Kp; Lat; Lon]
                end
            end
            
            % Calculate current plot type current parameter campaign 
            % anomaly relative to climatology
            crtype_crparam_anom_kp_lat_lon = ...
                crtype_crparam_cpgn_kp_lat_lon - ...
                crtype_crparam_clim_kp_lat_lon;
                % [m] / [m/s], [Kp; Lat; Lon]
            
            % Merge current plot type current parameter variable data in 
            % matrixes
            crtype_cpgn_param_kp_lat_lon(p,:,:,:) = ...
                crtype_crparam_cpgn_kp_lat_lon;
                % [m] / [m/s], campaign
                % [Plot_Param; Kp; Lat; Lon]
            crtype_clim_param_kp_lat_lon(p,:,:,:) = ...
                crtype_crparam_clim_kp_lat_lon;
                % [m] / [m/s], climatology
                % [Plot_Param; Kp; Lat; Lon]
            crtype_anom_param_kp_lat_lon(p,:,:,:) = ...
                crtype_crparam_anom_kp_lat_lon;
                % [m] / [m/s], anomaly relative to climatology
                % [Plot_Param; Kp; Lat; Lon]
                
            % Delete current parameter data
            clear kp crtype_crparam_* crparam_*
        end
        
        % Merge current plot type 700-hPa geopotential height variable data
        % in a structure
        plot_var(plot_var_no+t,1).mat = ...
            squeeze(crtype_clim_param_kp_lat_lon(1,:,:,:));
            % [m], climatology
            % [Plot_Type,1].mat -> [Kp; Lat; Lon]
        plot_var(plot_var_no+t,2).mat = ...
            squeeze(crtype_anom_param_kp_lat_lon(1,:,:,:));
            % [m], anomaly relative to climatology
            % [Plot_Type,2].mat -> [Kp; Lat; Lon]
            
        % Merge current plot type 700-hPa zonal wind variable data in a 
        % structure
        plot_var(plot_var_no+t,3).mat = ...
            squeeze(crtype_cpgn_param_kp_lat_lon(2,:,:,:));
            % [m/s], campaign
            % [Plot_Type,3].mat -> [Kp; Lat; Lon]
            
        % Merge current plot type 700-hPa meridional wind variable data in 
        % a structure
        plot_var(plot_var_no+t,4).mat = ...
            squeeze(crtype_cpgn_param_kp_lat_lon(3,:,:,:));
            % [m/s], campaign
            % [Plot_Type,3].mat -> [Kp; Lat; Lon]
    elseif strcmp(crtype_name,'d-clim_anom_700hPa-vpoT')
            % Climatology and anomaly relative to climatology over campaign
            % days of 700-hPa virtual potential temperature
        disp(['load_ACLOUD_ERA: Climatology and anomaly relative to ' ...
            'climatology over campaign days of 700-hPa ' ...
            'virtual potential temperature chosen for plotting'])
        
        %%% Set variable names %%%
        % Set current plot type parameter names
        crtype_paramname_old = [{'T700hPa'}; {'q700hPa'}]; % Pre-converted
        crtype_paramname_new = {'thetav700hPa'}; % Post-converted
        
        % Set current plot type title name
        crtype_titlename_new = '700-hPa virtual potential temperature';
        
        % Set current plot type unit
        crtype_unit_new = 'K';
        
        % Calculate number of current plot type parameters
        crtype_paramno_old = length(crtype_paramname_old); % Pre-converted
        crtype_paramno_new = length(crtype_paramname_new); % Post-converted
        
        % Loop over current plot type pre-converted parameters and find 
        % pre-converted parameter indexes
        for p = 1:crtype_paramno_old
                % Loop over current plot type pre-converted parameters
            crtype_paramindx_old(p) = ...
                find(strcmp(param_name(2:end,5),...
                char(crtype_paramname_old(p))));
        end
        
        % Extract and set current plot type MATLAB and title names and 
        % unit(s)
        plot_varname = ...
            [plot_varname; ...
            crtype_paramname_new {crtype_titlename_new} {crtype_unit_new}];
        
        %%% Calculate variable number %%%
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge location data %%%
        % Loop over chosen pre-converted parameters and merge current plot 
        % type location data in a structure
        for p = 1:crtype_paramno_old
                % Loop over current plot type pre-converted parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname_old(p));
                % MATLAB
            
            % Merge current plot type current parameter location data in a 
            % structure
            crtype_lat_param(p).mat = eval([crparam_name_MATLAB '_lat;']);
                % [deg N], latitude, [Plot_Param].mat -> [Lat]
            crtype_lon_param(p).mat = eval([crparam_name_MATLAB '_lon;']);
                % [deg E], longitude, [Plot_Param].mat -> [Lon]
        end
        
        % Convert current plot type pre-converted parameter location data
        % to post-converted parameter location data
        if isequal(crtype_lat_param(1).mat,crtype_lat_param(1).mat) && ...
                isequal(crtype_lon_param(1).mat,crtype_lon_param(1).mat)
                % Pre-converted latitudinal and longitudinal grid point 
                % vectors equal
            % Set post-converted parameter location data to 1st
            % pre-converted parameter location data
            % NB! Pre-converted latitudinal and longitudinal grid point 
            %     vectors are equal
            crtype_lat = crtype_lat_param(1).mat; % [deg N], latitude
                % [Lat]
            crtype_lon = crtype_lon_param(1).mat; % [deg E], longitude
                % [Lon]
        end
        
        % Merge current plot type post-converted parameter location data in
        % a structure
        plot_loc(plot_var_no+t,1).mat = crtype_lat; % [deg N], latitude
            % [Plot_Type,1].mat -> [Lat]
        plot_loc(plot_var_no+t,2).mat = crtype_lon; % [deg E], longitude
            % [Plot_Type,2].mat -> [Lon]
        
        %%% Merge variable data %%%
        % Loop over chosen pre-converted parameters and merge current plot 
        % type variable data in a structure
        for p = 1:crtype_paramno_old
                % Loop over current plot type pre-converted parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname_old(p));
                % MATLAB
                
            % Rename current plot type current pre-converted parameter 
            % campaign and climatology variables
            crtype_crparam_cpgn_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_cpgn_daymonth_lat_lon;']);
                % [deg C] / [%], campaign, [Day*Month; Lat; Lon]
            crtype_crparam_clim_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_clim_mean_daymonth_lat_lon;']);
                % [deg C] / [%], climatology, [Day*Month; Lat; Lon]
            
            % Merge current plot type current pre-converted parameter 
            % variable data in matrixes
            crtype_cpgn_param_daymonth_lat_lon(p,:,:,:) = ...
                crtype_crparam_cpgn_daymonth_lat_lon;
                % [deg C] / [%], campaign
                % [Plot_Param; Day*Month; Lat; Lon]
            crtype_clim_param_daymonth_lat_lon(p,:,:,:) = ...
                crtype_crparam_clim_daymonth_lat_lon;
                % [deg C] / [%], climatology
                % [Plot_Param; Day*Month; Lat; Lon]
                
            % Delete current parameter data
            clear crtype_crparam_* crparam_*
        end
        
        % Calculate current plot type potential temperature data
        % NB! Using the equation (3.43) for potential temperature theta in 
        %     "Theoretische Meteorologie" by Etling (2008):
        %
        %                 p_{0}
        %       theta = T(-----)^(R_{d}/c_{pd})
        %                   p
        %     
        %     where T is the temperature, 
        %     p_{0} = 101325 Pa the reference pressure,
        %     p = 70000 Pa the pressure at the current pressure level,
        %     R_{d} = 287 J/kgK the gas constant for dry air and
        %     c_{pd} = 1004 J/kgK the heat capacity at constant pressure 
        %                         of dry air
        crtype_cpgn_T_daymonth_lat_lon = ...
            squeeze(crtype_cpgn_param_daymonth_lat_lon(1,:,:,:)) + 273.15;
            % [K], temperature - campaign
            % [Day*Month; Lat; Lon]
        crtype_clim_T_daymonth_lat_lon = ...
            squeeze(crtype_clim_param_daymonth_lat_lon(1,:,:,:)) + 273.15;
            % [K], temperature - climatology
            % [Day*Month; Lat; Lon]
        crtype_p0 = 101325; % [Pa], reference pressure
        crtype_p = 70000; % [Pa], pressure at the current pressure level
        crtype_Rd = 287; % [J/kgK], gas constant for dry air
        crtype_cpd = 1004; % [J/kgK]
            % Heat capacity at constant pressure of dry air
        crtype_cpgn_theta_daymonth_lat_lon = ...
            crtype_cpgn_T_daymonth_lat_lon*...
            (crtype_p0/crtype_p)^(crtype_Rd/crtype_cpd);
            % [K], potential temperature - campaign
            % [Day*Month; Lat; Lon]
        crtype_clim_theta_daymonth_lat_lon = ...
            crtype_clim_T_daymonth_lat_lon*...
            (crtype_p0/crtype_p)^(crtype_Rd/crtype_cpd);
            % [K], potential temperature - climatology
            % [Day*Month; Lat; Lon]
        
        % Calculate current plot type virtual potential temperature data
        % NB! Using the equation (4.19) for virtual temperature T_{v} 
        %     in "Theoretische Meteorologie" by Etling (2008), but with 
        %     theta replacing T and thus virtual potential temperature 
        %     theta_{v} replacing T_{v}:
        %
        %       theta_{v} = theta(1 + 0.608q)
        %     
        %     where q is the specific humidity
        crtype_cpgn_q_daymonth_lat_lon = ...
            squeeze(crtype_cpgn_param_daymonth_lat_lon(2,:,:,:));
            % [kg/kg], specific humidity - campaign
            % [Day*Month; Lat; Lon]
        crtype_clim_q_daymonth_lat_lon = ...
            squeeze(crtype_clim_param_daymonth_lat_lon(2,:,:,:));
            % [kg/kg], specific humidity - climatology
            % [Day*Month; Lat; Lon]
        crtype_cpgn_thetav_daymonth_lat_lon = ...
            crtype_cpgn_theta_daymonth_lat_lon.*...
            (1 + 0.608*crtype_cpgn_q_daymonth_lat_lon);
            % [K]
            % Virtual potential temperature
            %   - campaign
            % [Day*Month; Lat; Lon]
        crtype_clim_thetav_daymonth_lat_lon = ...
            crtype_clim_theta_daymonth_lat_lon.*...
            (1 + 0.608*crtype_clim_q_daymonth_lat_lon);
            % [K]
            % Virtual potential temperature
            %   - climatology
            % [Day*Month; Lat; Lon]
        
        % Calculate current plot type 700-hPa virtual potential temperature
        % campaign anomaly relative to climatology
        crtype_anom_thetav_daymonth_lat_lon = ...
            crtype_cpgn_thetav_daymonth_lat_lon - ...
            crtype_clim_thetav_daymonth_lat_lon;
            % [K], [Day*Month; Lat; Lon]
        
        % Merge current plot type 700-hPa virtual potential temperature 
        % variable data in a structure
        plot_var(plot_var_no+t,1).mat = ...
            crtype_clim_thetav_daymonth_lat_lon;
            % [K], climatology
            % [Plot_Type,1].mat -> [Day*Month; Lat; Lon]
        plot_var(plot_var_no+t,2).mat = ...
            crtype_anom_thetav_daymonth_lat_lon;
            % [K], anomaly relative to climatology
            % [Plot_Type,2].mat -> [Day*Month; Lat; Lon]
    elseif strcmp(crtype_name,'kp-clim_anom_700hPa-vpoT')
            % Climatology and anomaly relative to climatology over campaign
            % key periods of 700-hPa virtual potential temperature
        disp(['load_ACLOUD_ERA: Climatology and anomaly relative to ' ...
            'climatology over campaign key periods of 700-hPa ' ...
            'virtual potential temperature chosen for plotting'])
        
        %%% Set variable names %%%
        % Set current plot type parameter names
        crtype_paramname_old = [{'T700hPa'}; {'q700hPa'}]; % Pre-converted
        crtype_paramname_new = {'thetav700hPa'}; % Post-converted
        
        % Set current plot type title name
        crtype_titlename_new = '700-hPa virtual potential temperature';
        
        % Set current plot type unit
        crtype_unit_new = 'K';
        
        % Calculate number of current plot type parameters
        crtype_paramno_old = length(crtype_paramname_old); % Pre-converted
        crtype_paramno_new = length(crtype_paramname_new); % Post-converted
        
        % Loop over current plot type pre-converted parameters and find 
        % pre-converted parameter indexes
        for p = 1:crtype_paramno_old
                % Loop over current plot type pre-converted parameters
            crtype_paramindx_old(p) = ...
                find(strcmp(param_name(2:end,5),...
                char(crtype_paramname_old(p))));
        end
        
        % Extract and set current plot type MATLAB and title names and 
        % unit(s)
        plot_varname = ...
            [plot_varname; ...
            crtype_paramname_new {crtype_titlename_new} {crtype_unit_new}];
        
        %%% Calculate variable number %%%
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge location data %%%
        % Loop over chosen pre-converted parameters and merge current plot 
        % type location data in a structure
        for p = 1:crtype_paramno_old
                % Loop over current plot type pre-converted parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname_old(p));
                % MATLAB
            
            % Merge current plot type current parameter location data in a 
            % structure
            crtype_lat_param(p).mat = eval([crparam_name_MATLAB '_lat;']);
                % [deg N], latitude, [Plot_Param].mat -> [Lat]
            crtype_lon_param(p).mat = eval([crparam_name_MATLAB '_lon;']);
                % [deg E], longitude, [Plot_Param].mat -> [Lon]
        end
        
        % Convert current plot type pre-converted parameter location data
        % to post-converted parameter location data
        if isequal(crtype_lat_param(1).mat,crtype_lat_param(1).mat) && ...
                isequal(crtype_lon_param(1).mat,crtype_lon_param(1).mat)
                % Pre-converted latitudinal and longitudinal grid point 
                % vectors equal
            % Set post-converted parameter location data to 1st
            % pre-converted parameter location data
            % NB! Pre-converted latitudinal and longitudinal grid point 
            %     vectors are equal
            crtype_lat = crtype_lat_param(1).mat; % [deg N], latitude
                % [Lat]
            crtype_lon = crtype_lon_param(1).mat; % [deg E], longitude
                % [Lon]
        end
        
        % Merge current plot type post-converted parameter location data in
        % a structure
        plot_loc(plot_var_no+t,1).mat = crtype_lat; % [deg N], latitude
            % [Plot_Type,1].mat -> [Lat]
        plot_loc(plot_var_no+t,2).mat = crtype_lon; % [deg E], longitude
            % [Plot_Type,2].mat -> [Lon]
        
        %%% Merge variable data %%%
        % Loop over chosen pre-converted parameters and merge current plot 
        % type variable data in a structure
        for p = 1:crtype_paramno_old
                % Loop over current plot type pre-converted parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname_old(p));
                % MATLAB
                
            % Rename current plot type current pre-converted parameter 
            % campaign and climatology variables
            crtype_crparam_cpgn_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_cpgn_daymonth_lat_lon;']);
                % [deg C] / [%], campaign, [Day*Month; Lat; Lon]
            crtype_crparam_clim_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_clim_mean_daymonth_lat_lon;']);
                % [deg C] / [%], climatology, [Day*Month; Lat; Lon]
            
            % Loop over key periods and calculate current plot type current
            % pre-converted parameter campaign and climatology means over 
            % campaign key periods
            for kp = 1:kper_no % Loop over number of key periods
                % Campaign
                crtype_crparam_cpgn_kp_lat_lon(kp,:,:) = ...
                    nanmean(crtype_crparam_cpgn_daymonth_lat_lon(...
                    kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                    % [deg C] / [%], [Kp; Lat; Lon]
                
                % Climatology
                crtype_crparam_clim_kp_lat_lon(kp,:,:) = ...
                    nanmean(crtype_crparam_clim_daymonth_lat_lon(...
                    kper_bnd(kp,1):kper_bnd(kp,2),:,:),1);
                    % [deg C] / [%], [Kp; Lat; Lon]
            end
            
            % Merge current plot type current pre-converted parameter 
            % variable data in matrixes
            crtype_cpgn_param_kp_lat_lon(p,:,:,:) = ...
                crtype_crparam_cpgn_kp_lat_lon;
                % [deg C] / [%], campaign
                % [Plot_Param; Kp; Lat; Lon]
            crtype_clim_param_kp_lat_lon(p,:,:,:) = ...
                crtype_crparam_clim_kp_lat_lon;
                % [deg C] / [%], climatology
                % [Plot_Param; Kp; Lat; Lon]
                
            % Delete current parameter data
            clear kp crtype_crparam_* crparam_*
        end
        
        % Calculate current plot type potential temperature data
        % NB! Using the equation (3.43) for potential temperature theta in 
        %     "Theoretische Meteorologie" by Etling (2008):
        %
        %                 p_{0}
        %       theta = T(-----)^(R_{d}/c_{pd})
        %                   p
        %     
        %     where T is the temperature, 
        %     p_{0} = 101325 Pa the reference pressure,
        %     p = 70000 Pa the pressure at the current pressure level,
        %     R_{d} = 287 J/kgK the gas constant for dry air and
        %     c_{pd} = 1004 J/kgK the heat capacity at constant pressure 
        %                         of dry air
        crtype_cpgn_T_kp_lat_lon = ...
            squeeze(crtype_cpgn_param_kp_lat_lon(1,:,:,:)) + 273.15;
            % [K], temperature - campaign
            % [Kp; Lat; Lon]
        crtype_clim_T_kp_lat_lon = ...
            squeeze(crtype_clim_param_kp_lat_lon(1,:,:,:)) + 273.15;
            % [K], temperature - climatology
            % [Kp; Lat; Lon]
        crtype_p0 = 101325; % [Pa], reference pressure
        crtype_p = 70000; % [Pa], pressure at the current pressure level
        crtype_Rd = 287; % [J/kgK], gas constant for dry air
        crtype_cpd = 1004; % [J/kgK]
            % Heat capacity at constant pressure of dry air
        crtype_cpgn_theta_kp_lat_lon = ...
            crtype_cpgn_T_kp_lat_lon*...
            (crtype_p0/crtype_p)^(crtype_Rd/crtype_cpd);
            % [K], potential temperature - campaign
            % [Kp; Lat; Lon]
        crtype_clim_theta_kp_lat_lon = ...
            crtype_clim_T_kp_lat_lon*...
            (crtype_p0/crtype_p)^(crtype_Rd/crtype_cpd);
            % [K], potential temperature - climatology
            % [Kp; Lat; Lon]
        
        % Calculate current plot type virtual potential temperature data
        % NB! Using the equation (4.19) for virtual temperature T_{v} 
        %     in "Theoretische Meteorologie" by Etling (2008), but with 
        %     theta replacing T and thus virtual potential temperature 
        %     theta_{v} replacing T_{v}:
        %
        %       theta_{v} = theta(1 + 0.608q)
        %     
        %     where q is the specific humidity
        crtype_cpgn_q_kp_lat_lon = ...
            squeeze(crtype_cpgn_param_kp_lat_lon(2,:,:,:));
            % [kg/kg], specific humidity - campaign
            % [Kp; Lat; Lon]
        crtype_clim_q_kp_lat_lon = ...
            squeeze(crtype_clim_param_kp_lat_lon(2,:,:,:));
            % [kg/kg], specific humidity - climatology
            % [Kp; Lat; Lon]
        crtype_cpgn_thetav_kp_lat_lon = ...
            crtype_cpgn_theta_kp_lat_lon.*...
            (1 + 0.608*crtype_cpgn_q_kp_lat_lon);
            % [K]
            % Virtual potential temperature
            %   - campaign
            % [Kp; Lat; Lon]
        crtype_clim_thetav_kp_lat_lon = ...
            crtype_clim_theta_kp_lat_lon.*...
            (1 + 0.608*crtype_clim_q_kp_lat_lon);
            % [K]
            % Virtual potential temperature
            %   - climatology
            % [Kp; Lat; Lon]
        
        % Calculate current plot type 700-hPa virtual potential temperature
        % campaign anomaly relative to climatology
        crtype_anom_thetav_kp_lat_lon = ...
            crtype_cpgn_thetav_kp_lat_lon - crtype_clim_thetav_kp_lat_lon;
            % [K], [Kp; Lat; Lon]
        
        % Merge current plot type 700-hPa virtual potential temperature 
        % variable data in a structure
        plot_var(plot_var_no+t,1).mat = crtype_clim_thetav_kp_lat_lon;
            % [K], climatology
            % [Plot_Type,1].mat -> [Kp; Lat; Lon]
        plot_var(plot_var_no+t,2).mat = crtype_anom_thetav_kp_lat_lon;
            % [K], anomaly relative to climatology
            % [Plot_Type,2].mat -> [Kp; Lat; Lon]
    elseif strcmp(crtype_name,'tp-clim_anom_700hPa-circ')
            % Climatology and anomaly relative to climatology over campaign
            % time period of 700-hPa circulation
        disp(['load_ACLOUD_ERA: Climatology and anomaly ' ...
            'relative to climatology over campaign time period of ' ...
            '700-hPa circulation chosen for plotting'])
        
        %%% Set variable names %%%
        % Set current plot type parameter names
        crtype_paramname = [{'Z700hPa'}; {'u700hPa'}; {'v700hPa'}];
        
        % Calculate number of current plot type parameters
        crtype_paramno = length(crtype_paramname);
        
        % Loop over current plot type parameters and find parameter indexes
        for p = 1:crtype_paramno % Loop over current plot type parameters
            crtype_paramindx(p) = ...
                find(strcmp(param_name(2:end,5),...vpoT
                char(crtype_paramname(p))));
        end
        
        % Extract current plot type MATLAB and title names and unit(s)
        plot_varname = ...
            [plot_varname; ...
            param_name(crtype_paramindx+1,5) ...
            param_name(crtype_paramindx+1,6) ...
            param_name(crtype_paramindx+1,7)];
        
        %%% Calculate variable number %%%
        % Calculate number of variables in 'plot_var.mat'
        if exist('plot_var','var') % Variable existent
            plot_var_no = size(plot_var,1);
        else % Variable non-existent
            plot_var_no = 0;
        end
        
        %%% Merge location data %%%
        % Loop over chosen parameters and merge current plot type location 
        % data in a structure
        for p = 1:crtype_paramno % Loop over current plot type parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname(p));
                % MATLAB
            
            % Merge current plot type current parameter location data in a 
            % structure
            plot_loc(plot_var_no+t,2*(p-1)+1).mat = ...
                eval([crparam_name_MATLAB '_lat;']);
                % [deg N], latitude, [1:2:2*(Plot_Param-1)].mat -> [Lat]
            plot_loc(plot_var_no+t,2*p).mat = ...
                eval([crparam_name_MATLAB '_lon;']);
                % [deg E], longitude, [2:2:2*Plot_Param].mat -> [Lon]
        end
        
        %%% Merge variable data %%%
        % Loop over chosen parameters and merge current plot type variable  
        % data in a structure
        for p = 1:crtype_paramno % Loop over current plot type parameters
            % Extract current parameter names
            crparam_name_MATLAB = char(crtype_paramname(p));
                % MATLAB
                
            % Rename current plot type current parameter campaign and 
            % climatology variables
            crtype_crparam_cpgn_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_cpgn_daymonth_lat_lon;']);
                % [m] / [m/s], campaign
                % [Day*Month; Lat; Lon]
            crtype_crparam_clim_daymonth_lat_lon = ...
                eval([crparam_name_MATLAB '_clim_mean_daymonth_lat_lon;']);
                % [m] / [m/s], climatology
                % [Day*Month; Lat; Lon]
                
            % Calculate current plot type current parameter campaign and 
            % climatology means over campaign time period
            crtype_crparam_cpgn_lat_lon = ...
                squeeze(nanmean(crtype_crparam_cpgn_daymonth_lat_lon,1));
                % [m] / [m/s], campaign
                % [Lat; Lon]
            crtype_crparam_clim_lat_lon = ...
                squeeze(nanmean(crtype_crparam_clim_daymonth_lat_lon,1));
                % [m] / [m/s], climatology
                % [Lat; Lon]
                
            % Calculate current plot type current parameter campaign 
            % anomaly relative to climatology
            crtype_crparam_anom_lat_lon = ...
                crtype_crparam_cpgn_lat_lon - crtype_crparam_clim_lat_lon;
                % [m] / [m/s]
                % [Lat; Lon]
                
            % Merge current plot type current parameter variable data in 
            % matrixes
            crtype_cpgn_param_lat_lon(p,:,:) = ...
                crtype_crparam_cpgn_lat_lon;
                % [m] / [m/s], campaign
                % [Plot_Param; Lat; Lon]
            crtype_clim_param_lat_lon(p,:,:) = ...
                crtype_crparam_clim_lat_lon;
                % [m] / [m/s], climatology
                % [Plot_Param; Lat; Lon]
            crtype_anom_param_lat_lon(p,:,:) = ...
                crtype_crparam_anom_lat_lon;
                % [m] / [m/s], anomaly relative to climatology
                % [Plot_Param; Lat; Lon]
            
            % Delete current parameter data
            clear crtype_crparam_* crparam_*
        end
        
        % Merge current plot type 700-hPa geopotential height variable data
        % in a structure
        plot_var(plot_var_no+t,1).mat = ...
            squeeze(crtype_clim_param_lat_lon(1,:,:));
            % [m], climatology
            % [Plot_Type,1].mat -> [Lat; Lon]
        plot_var(plot_var_no+t,2).mat = ...
            squeeze(crtype_anom_param_lat_lon(1,:,:));
            % [m], anomaly relative to climatology
            % [Plot_Type,2].mat -> [Lat; Lon]
            
        % Merge current plot type 700-hPa zonal wind variable data in a 
        % structure
        plot_var(plot_var_no+t,3).mat = ...
            squeeze(crtype_cpgn_param_lat_lon(2,:,:));
            % [m/s], campaign
            % [Plot_Type,3].mat -> [Lat; Lon]
            
        % Merge current plot type 700-hPa meridional wind variable data in 
        % a structure
        plot_var(plot_var_no+t,4).mat = ...
            squeeze(crtype_cpgn_param_lat_lon(3,:,:));
            % [m/s], campaign
            % [Plot_Type,3].mat -> [Lat; Lon]
    end
    
    % Delete current plot type data
    clear p crtype_*
end

% Delete unnecessary variable(s)
clear t plot_var_no
%%
%%% Plot variable data %%%
% Plotatmospheric and surface data using plot_ACLOUD_NMI.m
plot_ACLOUD_ERA(path_fig,yr_cpgn_name,month_abbr,...
    mod_name,param_name,param_indx,param_no,day_no,tper_txt,...
    kper_no,kper_txt,kper_num,reg_full,reg_abbr,reg_lat_bnd,reg_lon_bnd,...
    plot_no,plot_typename,plot_varname,plot_loc,plot_var)