function plot_ACLOUD_ERA(path_fig,yr_cpgn_name,month_abbr,...
    mod_name,param_name,param_indx,param_no,day_no,tper_txt,...
    kper_no,kper_txt,kper_num,reg_full,reg_abbr,reg_lat_bnd,reg_lon_bnd,...
    plot_no,plot_typename,plot_varname,plot_loc,plot_var)

% PURPOSE
% Plot and store 6-hourly atmospheric data from the European Centre for 
% Medium-Range Weather Forecasts (ECMWF) reanalysis interim (ERA-Interim) 
% data set for the Nordic Seas and chosen date and time interval in order 
% to study the synoptic situation during the Arctic CLoud Observations 
% Using airborne measurements during polar Day (ACLOUD) and Physical 
% feedback of Arctic planetary boundary layer, Sea ice, Cloud and AerosoL 
% (PASCAL) field campaigns May 22 - June 28, 2017 on/near Spitsbergen.
%
% The data set choices are:
%   ERA-Int : European Centre for Medium-Range Weather Forecasts (ECMWF) 
%             reanalysis interim
%
% The parameter choices are:
%   Z700hPa : 700-hPa geopotential height (Z_{700hPa})
%   u700hPa : 700-hPa zonal wind (u_{700hPa})
%   v700hPa : 700-hPa meridional wind (v_{700hPa})
%   T700hPa : 700-hPa temperature (T_{700hPa})
%   q700hPa : 700-hPa specific humidity (q_{700hPa})
%   RH700hPa: 700-hPa relative humidity (RH_{700hPa})
%
% The region choices are:
%   NS  : Nordic Seas
%
% INPUT
%   path_fig        : Figure path
%   yr_cpgn_name    : Name of chosen campaign year(s)
%   month_abbr      : Abbreviated name of chosen month(s)
%   mod_name        : Data set names and time period
%                     [Data set number : File name : MATLAB name : ...
%                      Abbreviated name : Full name : Time period]
%   param_name      : Parameter names and unit of field campaign data
%                     [Parameter number : General name : File name : ...
%                      Data name : MATLAB name : Full name : Unit : ...
%                      Start date : End date]
%   param_indx      : Index(es) and number of chosen parameter(s)
%   param_no        : Number of chosen parameter(s)
%   day_no          : Number of chosen day(s)
%   tper_txt        : Time period boundary text name
%   kper_no         : Key periods number
%   kper_txt        : Key periods boundary text names
%   kper_num        : Key periods boundary numerical names
%   reg_full        : Full name(s) of chosen region(s)
%   reg_abbr        : Abbreviated name(s) of chosen region(s)
%   reg_lat_bnd     : Latitudinal boundary(ies) of chosen region(s)
%   reg_lon_bnd     : Longitudinal boundary(ies) of chosen region(s)
%   plot_no         : Number of open plots
%   plot_typename   : MATLAB name of figure type(s) to be plotted
%   plot_varname    : Names and unit(s) of figure type(s) to be plotted
%                     [MATLAB name : Title name : Unit]
%   plot_loc        : Location data to be plotted merged in a structure
%   plot_var        : Variable data to be plotted merged in a structure
%
% CHOICES
%   plot_line_width     : Line width used in plotting
%   plot_font_name      : Font name used in plotting
%   plot_font_weight    : Font weight used in plotting
%   plot_size_label     : Label font size used in plotting
%   plot_size_legend    : Legend font size used in plotting
%   plot_ver            : Figure file versions used in plotting
%   plot_rend           : Figure render names used in plotting
%   plot_paper_type     : Figure paper type name used in plotting
%   plot_paper_orient   : Figure paper orientation name used in plotting
%   plot_paper_pos      : Figure paper position used in plotting
%   plot_proj_name      : Projection name in m_map plots used in plotting
%   plot_proj_lat       : Projection latitude to center projection over in
%                         m_map plots used in plotting
%   plot_proj_lon       : Projection longitude to center projection around 
%                         in m_map plots used in plotting
%   plot_proj_rad       : Projection latitudinal radius to span projection 
%                         over in m_map plots used in plotting
%   plot_col_coast      : Coast line color in m_map plots used in plotting
%   plot_col_land       : Land patch color in m_map plots used in plotting
%
% USES
%   colorbar_col.m
%   calc_map_extr.m
%
%
% AUTHOR
%   Erlend Moster Knudsen
%   PostDoc
%   Institute for Geophysics and Meteorology, University of Cologne
%   eknudsen@uni-koeln.de
%   November 2017
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% Plot settings %%%%%
%%% Figure properties %%%
% Plot line, font and size properties
plot_line_width = 2; % Line width
plot_font_name = 'Helvetica'; % Font name
plot_font_weight = 'bold'; % Font weight
plot_size_label = 16; % Label font size
plot_size_legend = 12; % Legend font size

% Plot figure file versions and renderer names
plot_ver = [{'fig'}; {'eps'}; {'pdf'}]; % Figure file versions
    % 'fig' = MATLAB file
    % 'eps' = Article file
    % 'pdf' = View file
plot_rend = [{'OpenGL'}; {'OpenGL'}; {'OpenGL'}]; % Renderer names
    % NB! Referes to distribution given by 'plot_ver'
    % 'OpenGL'   = Draws figures using bitmap graphics -> .fig files
    %              NB! Default
    % 'zbuffer'  = Draws figures using bitmap graphics -> .fig files
    %              NB! No longer available from MATLAB R2014b
    % 'none'     = Draws no figures -> display files
    %              NB! No longer available from MATLAB R2014b
    % 'painters' = Sorts graphic objects by child order (2D) or front to
    %               back order (3D)
    %              NB! Available from MATLAB R2014b
    
% Plot paper properties
plot_paper_type = 'A4'; % Type
plot_paper_orient = 'landscape'; % Orientation
    % 'landscape' = longer horizontally than vertically
    % 'portrait'  = longer vertically than horizontally
plot_paper_pos = [-2.0 -0.9 33 22]; % Paper position
    % [Left Top Width Height]
    
%%%%% m_map properties %%%%%
% Plot m_map projections and colors
if strcmp(reg_abbr,'NS') % Nordic Seas
    % Name of projection
    plot_proj_name = 'lambert';
end
plot_lat_lim = reg_lat_bnd; % [deg N], latitudinal boundaries
    % [Start : End]
plot_lon_lim = reg_lon_bnd; % [deg E], longitudinal boundaries
    % [Start : End]
plot_lat_step = range(plot_lat_lim)/100*10; % [deg N], latitudinal steps
plot_lon_step = range(plot_lon_lim)/100*10; % [deg E], longitudinal steps
plot_col_coast = [.7 .7 .7]; % Coast line color
plot_col_land = [.9 .9 .9]; % Land patch color

%%% Color bar properties %%%
% Get blue-red color bar using colorbar_col.m
[plot_bar_BR_gno,plot_bar_BR_gindx,plot_bar_BR_sgnno,plot_bar_BR] = ...
    colorbar_col('BR');
%%
%%%%% Plot data %%%%%
%%% Plot climatology and anomaly relative to climatology %%%
%%%            over campaign key periods data            %%%
% Only plot if asked to
if strcmp(plot_typename,'kp-clim_anom') > 0
        % Climatology and anomaly relative to climatology over campaign 
        % key periods
    disp(['plot_ACLOUD_ERA: Climatology and anomaly ' ...
        'relative to climatology over campaign key periods ' ...
        'chosen for plotting'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'kp-clim_anom'));
    
    %%% Parameter settings and data %%%
    % Set plot parameter threshold value for occurance frequency of extreme
    % values
    p_extr_thres = 0.005;
        % 0.005 -> < 0.5 % extreme value occurance
        % 0.01  -> < 1.0 % extreme value occurance
        % 0.05  -> < 5.0 % extreme value occurance
    
    %%% Plot variable data %%%
    % Loop over chosen parameters and plot climatology and anomaly relative
    % to climatology key periodic data
    for p = 1:param_no % Loop over number of chosen parameters
        %%% Parameter names, unit and indexes %%%
        % Extract current parameter MATLAB and full names and unit
        p_crparam_MATLAB = char(plot_varname(p_type_indx+p,1));
            % MATLAB name
        p_crparam_full = char(plot_varname(p_type_indx+p,2));
            % Full name
        p_crparam_unit = char(plot_varname(p_type_indx+p,3));
            % Unit
        
        % Find current parameter variable indexes
        p_crparam_indx = param_indx(p);
        
        % Extract current parameter general name
        p_crparam_gen = char(param_name(p_crparam_indx+1,2));
        
        %%% Data set index and name %%%
        % Extract current parameter data set name
        p_crparam_set = char(mod_name(1+1,3));
        
        % Diplay current parameter plotting choices
        disp(['plot_ACLOUD_ERA: ' ...
            'Plotting ' p_crparam_set ' ' p_crparam_full ...
            ' data over the ' reg_full])
        
        %%% Figure names %%%
        % Set current parameter figure path name
        p_crparam_path = [path_fig p_crparam_MATLAB '/'];
        
        %%% Location data %%%
        % Extract current parameter location data
        p_crparam_lat = plot_loc(p_type_indx+p-1,1).mat; % [deg N]
            % Latitude, [Lat]
        p_crparam_lon = plot_loc(p_type_indx+p-1,2).mat; % [deg E]
            % Longitude, [Lon]
            
        % Adjust current parameter location data in accordance with plot
        % set-up
        if min(plot_lon_lim) < 0 % Longitudinal format = [-180,180] deg E
            % Longitudinal grid points in Western Hemisphere
            p_crparam_lon(p_crparam_lon > 180) = ...
                p_crparam_lon(p_crparam_lon > 180) - 360;
                % [deg E], [Lon]
        end
        
        %%% Variable data %%%
        % Extract current parameter variable climatology data
        p_crparam_clim_kp_lat_lon = plot_var(p_type_indx+p-1,1).mat;
            % [m] / [m/s] / [deg C] / [kg/kg] / [%]
            % Key periodic averaged per latitude per longitude
            % [Kp; Lat; Lon]
            
        % Extract current parameter variable campaign anomaly relative to 
        % climatology data
        p_crparam_anom_kp_lat_lon = plot_var(p_type_indx+p-1,2).mat;
            % [m] / [m/s] / [deg C] / [kg/kg] / [%]
            % Key periodic averaged per latitude per longitude
            % [Kp; Lat; Lon]
            
        % Calculate current parameter variable climatology data extremes 
        % using calc_map_extr.m
        [p_crparam_clim_min,p_crparam_clim_max,...
            p_crparam_clim_range,p_crparam_clim_step,~,~] = ...
            calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'mean',...
            p_crparam_clim_kp_lat_lon,p_extr_thres);
            % Minimum, maximum, range and steps
        
        % Calculate current parameter variable campaign anomaly relative to
        % climatology data extremes using calc_map_extr.m
        [p_crparam_anom_min,p_crparam_anom_max,...
            p_crparam_anom_range,p_crparam_anom_step,~,~] = ...
            calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'anom',...
            p_crparam_anom_kp_lat_lon,p_extr_thres);
            % Minimum, maximum, range and steps
        
        % Calculate current parameter variable campaign anomaly relative to
        % climatology color bar value steps relative to default color bar
        p_crparam_anom_fbar = p_crparam_anom_range/p_crparam_anom_step;
        
        % Adjust current parameter variable campaign anomaly relative to
        % climatology variable steps according to color bar
        if p_crparam_anom_fbar > plot_bar_BR_gno
                % Color bar groups exceeding default color bar groups
            % Round variable step up
            p_crparam_anom_step = round((p_crparam_anom_range/10)*2)/2;
            
            % Adjust variable extremes according to variable step
            p_crparam_anom_min = ...
                floor(p_crparam_anom_min/p_crparam_anom_step)*...
                p_crparam_anom_step;
                % Minimum
            p_crparam_anom_max = ...
                ceil(p_crparam_anom_max/p_crparam_anom_step)*...
                p_crparam_anom_step;
                % Maximum
            p_crparam_anom_range = ...
                range([p_crparam_anom_min p_crparam_anom_max]);
                % Range
            
            % Adjust color bar step according to variable step
            p_crparam_anom_fbar = p_crparam_anom_range/p_crparam_anom_step;
        end
        
        % Set current parameter anomaly color bar according to campaign 
        % anomaly relative to climatology data extremes
        p_crparam_anom_cbar = ...
            plot_bar_BR(((plot_bar_BR_gno-p_crparam_anom_fbar)/2)*plot_bar_BR_gindx+1:...
            end-((plot_bar_BR_gno-p_crparam_anom_fbar)/2)*plot_bar_BR_gindx,:);
        
        %%% Plot variable data %%%
        % Loop over key periods and plot climatology and anomaly relative 
        % to climatology key periodic data
        for kp = 1:kper_no % Loop over number of key periods
            %%% Key period names %%%
            % Extract current key period names
            p_crkp_file = kper_num(kp,:); % File
            p_crkp_title = kper_txt(kp,:); % Title
            
            %%% Figure names %%%
            % Set current parameter current key period figure file and 
            % title names
            p_crparam_crkp_file = ...
                [p_crparam_MATLAB '_' reg_abbr '_' p_crkp_file '_' ...
                p_crparam_set];
                % File
            p_crparam_crkp_title = ...
                [p_crparam_full ' during ' p_crkp_title ' over the ' ...
                reg_full ' from ' p_crparam_set];
                % Title
            
            %%% Variable data %%%
            % Extract current parameter current key period variable data
            p_crparam_crkp_clim_lat_lon = ...
                squeeze(p_crparam_clim_kp_lat_lon(kp,:,:));
                % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                % Climatology, [Lat; Lon]
            p_crparam_crkp_anom_lat_lon = ...
                squeeze(p_crparam_anom_kp_lat_lon(kp,:,:));
                % [m] / [m/s] / [deg C] / [kg/kg] / [%]
                % Campaign anomaly relative to climatology, [Lat; Lon]
            
            %%% Plot variable data %%%
            % Loop over file versions and plot climatology and anomaly 
            % relative to climatology key periodic data
            for ver = 1:length(plot_ver)
                    % Loop over number of file versions
                %%% File version names %%%
                % Extract current file version and corresponding renderer 
                % names
                p_crver_name = char(plot_ver(ver)); % File version
                p_crver_rend = char(plot_rend(ver)); % Renderer
                
                %%% Figure names %%%
                % Set current parameter current file version figure path 
                % name
                p_crparam_crver_path = [p_crparam_path p_crver_name '/'];
                
                %%% Plot set-up and data %%%
                % Set figure number and renderer
                figure(plot_no+1) % Number
                set(gcf,'Renderer',p_crver_rend) % Renderer
                hold on % Hold figure open for several plots
                
                % Set plot projection
                m_proj(plot_proj_name,...
                    'long',plot_lon_lim,'lat',plot_lat_lim);
                
                % Plot current parameter current key period campaign 
                % anomaly relative to climatology data as a 
                % blue-white-red-shaded map
                p_crparam_crkp_crver_anom = ...
                    m_pcolor(p_crparam_lon,p_crparam_lat,...
                    p_crparam_crkp_anom_lat_lon);
                    % Data
                set(p_crparam_crkp_crver_anom,'LineStyle','none');
                    % Set no data boundaries
                
                % Plot current parameter current key period climatology 
                % data as a black-contoured map
%                 if p_crparam_anom_fbar < 5 % Maximum 5 contours
%                     [p_crparam_crkp_crver_clim,h_crparam_crkp_crver_clim] = ...
%                         m_contour(p_crparam_lon,p_crparam_lat,...
%                         p_crparam_crkp_clim_lat_lon,...
%                         [p_crparam_clim_min:p_crparam_clim_step:p_crparam_clim_max],...
%                         '-','Color','k','LineWidth',2);
%                 else % More than 5 contours
                    [p_crparam_crkp_crver_clim,h_crparam_crkp_crver_clim] = ...
                        m_contour(p_crparam_lon,p_crparam_lat,...
                        p_crparam_crkp_clim_lat_lon,...
                        [p_crparam_clim_min:2*p_crparam_clim_step:p_crparam_clim_max],...
                        '-','Color','k','LineWidth',2);
%                 end
                
                % Set plot grid and land contours
                m_grid('XTick',plot_lon_lim(1):15:plot_lon_lim(2),...
                    'YTick',plot_lat_lim(1):5:plot_lat_lim(2));
                    % Set grid
                m_coast('line','LineWidth',plot_line_width,...
                    'color',plot_col_coast-.3);
                    % Add land contours as grey-lined coasts
                
                % Map color scheme and bar
                p_crparam_crkp_crver_bar = colorbar; % Handle
                set(gca,'CLim',[p_crparam_anom_min p_crparam_anom_max],...
                    'FontSize',plot_size_legend)
                    % Limits
                colormap(p_crparam_anom_cbar); % Set map colors
                set(p_crparam_crkp_crver_bar,...
                    'YLim',[p_crparam_anom_min p_crparam_anom_max],...
                    'YTick',...
                    p_crparam_anom_min:p_crparam_anom_step:p_crparam_anom_max)
                    % Ticks
                p_crparam_crkp_crver_bar_pos = ...
                    get(p_crparam_crkp_crver_bar,'Position');
                    % Get position
                set(p_crparam_crkp_crver_bar,'Position',...
                    [p_crparam_crkp_crver_bar_pos(1)+.04 p_crparam_crkp_crver_bar_pos(2:4)]);
                    % Set position
                
                %%% Plot labels %%%
                % Set plot contour labels
                % NB! Setting text properties (name, size and weight) is 
                %     only possible without the 'h_crparam_crkp_crver_clim'
                %     argument
                clabel(p_crparam_crkp_crver_clim,...
                    h_crparam_crkp_crver_clim,...
                    p_crparam_clim_min:p_crparam_clim_step:p_crparam_clim_max,...
                    'LabelSpacing',100);
                
%                 % Set plot contour and shading labels
%                 p_crparam_crkp_crver_lgnd = ...
%                     legend([p_crparam_crkp_crver_anom h_crparam_crkp_crver_clim],...
%                     'Anomaly','Climatology');
%                     % Text
%                 set(p_crparam_crkp_crver_lgnd,...
%                     'FontName',plot_font_name,...
%                     'FontSize',plot_size_legend,...
%                     'FontWeight',plot_font_weight);
%                     % Font
                
                % Set current parameter current key period current file 
                % version title and color bar labels properties
                if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                        % MATLAB or view file
                    % Title label text
                    p_crparam_crkp_crver_ttl = title(p_crparam_crkp_title);
                    
                    % Title label font
                    set(p_crparam_crkp_crver_ttl,...
                        'FontName',plot_font_name,...
                        'FontSize',plot_size_label+4,...
                        'FontWeight',plot_font_weight)
                end
                p_crparam_crkp_crver_x = ...
                    xlabel(p_crparam_crkp_crver_bar,p_crparam_unit);
                    % Color bar label text
                set(p_crparam_crkp_crver_x,...
                    'Rotation',0,'Position',...
                    [1.5 p_crparam_anom_min-p_crparam_anom_step/2 0],...
                    'HorizontalAlignment','right',...
                    'VerticalAlignment','middle',...
                    'FontName',plot_font_name,...
                    'FontSize',plot_size_legend+2,...
                    'FontWeight',plot_font_weight)
                    % Color bar label rotation, position, alignment and 
                    % font
                
                %%% Save figure %%%
                % Save current parameter current key period current file 
                % version figure
                if strcmp(p_crver_name,'fig') % MATLAB file
                    % Save MATLAB figure file
                    saveas(gcf,...
                        [p_crparam_crver_path p_crparam_crkp_file],'fig')
                elseif strcmp(p_crver_name,'eps') % Article file
                    % Save article figure file
                    print(gcf,'-depsc',...
                        [p_crparam_crver_path p_crparam_crkp_file])
                elseif strcmp(p_crver_name,'pdf') % View file
                    % Set file paper properties
                    set(gcf,'PaperType',plot_paper_type,...
                        'PaperOrientation',plot_paper_orient,...
                        'PaperUnits','centimeters',...
                        'PaperPosition',plot_paper_pos);
                    
                    % Save view figure file
                    print(gcf,'-dpdf',...
                        [p_crparam_crver_path p_crparam_crkp_file])
                end
                
                % Update number of open figures
                p_crver_fig = gcf;
                    % Get current file version figure handle
                plot_no = p_crver_fig.Number;
                    % Get current file version figure number
                
                %%% Delete data %%%
                % Delete current parameter current key period current file 
                % version data
                clear p_crparam_crkp_crver_* p_crkp_crver_* p_crver_*
            end
            
            %%% Delete data %%%
            % Delete current parameter current key period data
            clear ver p_crparam_crkp_* p_crkp_*
        end
        
        %%% Delete data %%%
        % Delete current parameter data
        clear kp p_crparam_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear p
end
%%
%%% Plot climatology and anomaly relative to climatology %%%
%%%            over campaign time period data            %%%
% Only plot if asked to
if strcmp(plot_typename,'tp-clim_anom') > 0
        % Climatology and anomaly relative to climatology over campaign 
        % time period
    disp(['plot_ACLOUD_ERA: Climatology and anomaly ' ...
        'relative to climatology over campaign time period ' ...
        'chosen for plotting'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'tp-clim_anom'));
    
    %%% Parameter settings and data %%%
    % Set plot parameter threshold value for occurance frequency of extreme
    % values
    p_extr_thres = 0.005;
        % 0.005 -> < 0.5 % extreme value occurance
        % 0.01  -> < 1.0 % extreme value occurance
        % 0.05  -> < 5.0 % extreme value occurance
    
    %%% Plot variable data %%%
    % Loop over chosen parameters and plot climatology and anomaly relative
    % to climatology time periodic data
    for p = 1:param_no % Loop over number of chosen parameters
        %%% Parameter names, unit and indexes %%%
        % Extract current parameter MATLAB and full names and unit
        p_crparam_MATLAB = char(plot_varname(p_type_indx+p,1));
            % MATLAB name
        p_crparam_full = char(plot_varname(p_type_indx+p,2));
            % Full name
        p_crparam_unit = char(plot_varname(p_type_indx+p,3));
            % Unit
        
        % Find current parameter variable indexes
        p_crparam_indx = param_indx(p);
        
        % Extract current parameter general name
        p_crparam_gen = char(param_name(p_crparam_indx+1,2));
        
        %%% Data set index and name %%%
        % Extract current parameter data set name
        p_crparam_set = char(mod_name(1+1,3));
        
        % Diplay current parameter plotting choices
        disp(['plot_ACLOUD_ERA: ' ...
            'Plotting ' p_crparam_set ' ' p_crparam_full ...
            ' data over the ' reg_full])
        
        %%% Figure names %%%
        % Set current parameter figure path, file and title names
        p_crparam_path = [path_fig p_crparam_MATLAB '/'];
            % Path
        p_crparam_file = ...
            [p_crparam_MATLAB '_' reg_abbr '_' ...
            month_abbr '_' yr_cpgn_name '_' p_crparam_set];
            % File
        p_crparam_title = ...
            [p_crparam_full ' during ACLOUD over the ' reg_full ...
            ' from ' p_crparam_set];
            % Title
        
        %%% Location data %%%
        % Extract current parameter location data
        p_crparam_lat = plot_loc(p_type_indx+p-1,1).mat; % [deg N]
            % Latitude, [Lat]
        p_crparam_lon = plot_loc(p_type_indx+p-1,2).mat; % [deg E]
            % Longitude, [Lon]
            
        % Adjust current parameter location data in accordance with plot
        % set-up
        if min(plot_lon_lim) < 0 % Longitudinal format = [-180,180] deg E
            % Longitudinal grid points in Western Hemisphere
            p_crparam_lon(p_crparam_lon > 180) = ...
                p_crparam_lon(p_crparam_lon > 180) - 360;
                % [deg E], [Lon]
        end
        
        %%% Variable data %%%
        % Extract current parameter variable climatology data
        p_crparam_clim_lat_lon = plot_var(p_type_indx+p-1,1).mat;
            % [m] / [m/s] / [deg C] / [kg/kg] / [%]
            % Time periodic averaged per latitude per longitude
            % [Lat; Lon]
            
        % Extract current parameter variable campaign anomaly relative to 
        % climatology data
        p_crparam_anom_lat_lon = plot_var(p_type_indx+p-1,2).mat;
            % [m] / [m/s] / [deg C] / [kg/kg] / [%]
            % Time periodic averaged per latitude per longitude
            % [Lat; Lon]
            
        % Calculate current parameter variable climatology data extremes 
        % using calc_map_extr.m
        [p_crparam_clim_min,p_crparam_clim_max,...
            p_crparam_clim_range,p_crparam_clim_step,~,~] = ...
            calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'mean',...
            p_crparam_clim_lat_lon,p_extr_thres);
            % Minimum, maximum, range and steps
        
        % Calculate current parameter variable campaign anomaly relative to
        % climatology data extremes using calc_map_extr.m
        [p_crparam_anom_min,p_crparam_anom_max,...
            p_crparam_anom_range,p_crparam_anom_step,~,~] = ...
            calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'anom',...
            p_crparam_anom_lat_lon,p_extr_thres);
            % Minimum, maximum, range and steps
        
        % Calculate current parameter variable campaign anomaly relative to
        % climatology color bar value steps relative to default color bar
        p_crparam_anom_fbar = p_crparam_anom_range/p_crparam_anom_step;
        
        % Adjust current parameter variable campaign anomaly relative to
        % climatology variable steps according to color bar
        if p_crparam_anom_fbar > plot_bar_BR_gno
                % Color bar groups exceeding default color bar groups
            % Round variable step up
            p_crparam_anom_step = round((p_crparam_anom_range/10)*2)/2;
            
            % Adjust variable extremes according to variable step
            p_crparam_anom_min = ...
                floor(p_crparam_anom_min/p_crparam_anom_step)*...
                p_crparam_anom_step;
                % Minimum
            p_crparam_anom_max = ...
                ceil(p_crparam_anom_max/p_crparam_anom_step)*...
                p_crparam_anom_step;
                % Maximum
            p_crparam_anom_range = ...
                range([p_crparam_anom_min p_crparam_anom_max]);
                % Range
            
            % Adjust color bar step according to variable step
            p_crparam_anom_fbar = p_crparam_anom_range/p_crparam_anom_step;
        end
        
        % Set current parameter anomaly color bar according to campaign 
        % anomaly relative to climatology data extremes
        p_crparam_anom_cbar = ...
            plot_bar_BR(((plot_bar_BR_gno-p_crparam_anom_fbar)/2)*plot_bar_BR_gindx+1:...
            end-((plot_bar_BR_gno-p_crparam_anom_fbar)/2)*plot_bar_BR_gindx,:);
        
        %%% Plot variable data %%%
        % Loop over file versions and plot climatology and anomaly relative
        % to climatology time periodic data
        for ver = 1:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
            p_crver_name = char(plot_ver(ver)); % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current parameter current file version figure path name
            p_crparam_crver_path = [p_crparam_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
            % Set plot projection
            m_proj(plot_proj_name,'long',plot_lon_lim,'lat',plot_lat_lim);
            
            % Plot current parameter campaign anomaly relative to
            % climatology data as a blue-white-red-shaded map
            p_crparam_crver_anom = ...
                m_pcolor(p_crparam_lon,p_crparam_lat,...
                p_crparam_anom_lat_lon);
                % Data
            set(p_crparam_crver_anom,'LineStyle','none');
                % Set no data boundaries
            
            % Plot current parameter climatology data as a
            % black-contoured map
%             if p_crparam_anom_fbar < 5 % Maximum 5 contours
%                 [p_crparam_crver_clim,h_crparam_crver_clim] = ...
%                     m_contour(p_crparam_lon,p_crparam_lat,...
%                     p_crparam_clim_lat_lon,...
%                     [p_crparam_clim_min:p_crparam_clim_step:p_crparam_clim_max],...
%                     '-','Color','k','LineWidth',2);
%             else % More than 5 contours
                [p_crparam_crver_clim,h_crparam_crver_clim] = ...
                    m_contour(p_crparam_lon,p_crparam_lat,...
                    p_crparam_clim_lat_lon,...
                    [p_crparam_clim_min:2*p_crparam_clim_step:p_crparam_clim_max],...
                    '-','Color','k','LineWidth',2);
%             end
            
            % Set plot grid and land contours
            m_grid('XTick',plot_lon_lim(1):15:plot_lon_lim(2),...
                'YTick',plot_lat_lim(1):5:plot_lat_lim(2));
                % Set grid
            m_coast('line','LineWidth',plot_line_width,...
                'color',plot_col_coast-.3);
                % Add land contours as grey-lined coasts
            
            % Map color scheme and bar
            p_crparam_crver_bar = colorbar; % Handle
            set(gca,'CLim',[p_crparam_anom_min p_crparam_anom_max],...
                'FontSize',plot_size_legend)
                % Limits
            colormap(p_crparam_anom_cbar); % Set map colors
            set(p_crparam_crver_bar,...
                'YLim',[p_crparam_anom_min p_crparam_anom_max],...
                'YTick',...
                p_crparam_anom_min:p_crparam_anom_step:p_crparam_anom_max)
                % Ticks
%             p_crparam_crver_bar_pos = ...
%                 get(p_crparam_crver_bar,'Position');
%                 % Get position
%             set(p_crparam_crver_bar,'Position',...
%                 [p_crparam_crver_bar_pos(1)+.04 p_crparam_crver_bar_pos(2:4)]);
%                 % Set position
            
            %%% Plot labels %%%
            % Set plot contour labels
            % NB! Setting text properties (name, size and weight) is only 
            %     possible without the 'h_crparam_crver_clim' argument
            clabel(p_crparam_crver_clim,h_crparam_crver_clim,...
                p_crparam_clim_min:p_crparam_clim_step:p_crparam_clim_max,...
                'LabelSpacing',100);
            
            % Set plot contour and shading labels
            p_crparam_crver_lgnd = ...
                legend([p_crparam_crver_anom h_crparam_crver_clim],...
                'Anomaly','Climatology');
                % Text
            set(p_crparam_crver_lgnd,...
                'FontName',plot_font_name,...
                'FontSize',plot_size_legend,...
                'FontWeight',plot_font_weight);
                % Font
            
            % Set current parameter current file version title and color 
            % bar labels properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crparam_crver_ttl = title(p_crparam_title);
                
                % Title label font
                set(p_crparam_crver_ttl,...
                    'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
            end
            p_crparam_crver_x = ...
                xlabel(p_crparam_crver_bar,p_crparam_unit);
                % Color bar label text
            set(p_crparam_crver_x,...
                'Rotation',0,'Position',...
                [1.5 p_crparam_anom_min-p_crparam_anom_step/2 0],...
                'HorizontalAlignment','right',...
                'VerticalAlignment','middle',...
                'FontName',plot_font_name,...
                'FontSize',plot_size_legend+2,...
                'FontWeight',plot_font_weight)
                % Color bar label rotation, position, alignment and font
            
            %%% Save figure %%%
            % Save current parameter current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crparam_crver_path p_crparam_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',[p_crparam_crver_path p_crparam_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view figure file
                print(gcf,'-dpdf',...
                    [p_crparam_crver_path p_crparam_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current parameter current file version data
            clear p_crparam_crver_* p_crver_*
        end
        
        %%% Delete data %%%
        % Delete current parameter data
        clear ver p_crparam_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear p
end
%%
%%% Plot climatology and anomaly relative to climatology  %%%
%%%    over campaign days of 700-hPa circulation data     %%%
% Only plot if asked to
if strcmp(plot_typename,'d-clim_anom_700hPa-circ') > 0
        % Climatology and anomaly relative to climatology over campaign
        % days of 700-hPa circulation
    disp(['plot_ACLOUD_ERA: Climatology and anomaly ' ...
        'relative to climatology over campaign days of ' ...
        '700-hPa circulation chosen for plotting'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'d-clim_anom_700hPa-circ'));
    
    %%% Parameter settings and data %%%
    % Set plot parameter threshold value for occurance frequency of extreme
    % values
    p_extr_thres = 0.005;
        % 0.005 -> < 0.5 % extreme value occurance
        % 0.01  -> < 1.0 % extreme value occurance
        % 0.05  -> < 5.0 % extreme value occurance
    
    %%% Parameter names, unit and indexes %%%
    % Set parameter MATLAB and full names and unit
    p_param_MATLAB = 'Z700hPa-u700hPa-v700hPa';
        % MATLAB name
    p_param_full = '700-hPa geopotential height with horizontal wind';
        % Full name
    p_param_unit = char(plot_varname(p_type_indx+1,3));
        % Unit
    
    %%% Data set index and name %%%
    % Extract data set name
    p_set_MATLAB = char(mod_name(1+1,3));
    
    % Diplay current parameter plotting choices
    disp(['plot_ACLOUD_ERA: ' ...
        'Plotting ' p_set_MATLAB ' ' p_param_full ...
        ' data over the ' reg_full])
    
    %%% Figure names %%%
    % Set figure path name
    p_fig_path = [path_fig p_param_MATLAB '/'];
    
    %%% Location data %%%
    % Extract 700-hPa geopotential height location data
    p_Z700hPa_lat = plot_loc(p_type_indx,1).mat; % [deg N]
        % Latitude, [Lat]
    p_Z700hPa_lon = plot_loc(p_type_indx,2).mat; % [deg E]
        % Longitude, [Lon]
        
    % Extract 700-hPa zonal wind location data
    p_u700hPa_lat = plot_loc(p_type_indx,3).mat; % [deg N]
        % Latitude, [Lat]
    p_u700hPa_lon = plot_loc(p_type_indx,4).mat; % [deg E]
        % Longitude, [Lon]
        
    % Extract 700-hPa meridional wind location data
    p_v700hPa_lat = plot_loc(p_type_indx,5).mat; % [deg N]
        % Latitude, [Lat]
    p_v700hPa_lon = plot_loc(p_type_indx,6).mat; % [deg E]
        % Longitude, [Lon]
    
    % Adjust 700-hPa geopotential height, zonal and meridional wind 
    % longitude data in accordance with plot set-up
    if min(plot_lon_lim) < 0 % Longitudinal format = [-180,180] deg E
        % Longitudinal grid points in Western Hemisphere
        p_Z700hPa_lon(p_Z700hPa_lon > 180) = ...
            p_Z700hPa_lon(p_Z700hPa_lon > 180) - 360;
            % [deg E], geopotential height, [Lon]
        p_u700hPa_lon(p_u700hPa_lon > 180) = ...
            p_u700hPa_lon(p_u700hPa_lon > 180) - 360;
            % [deg E], zonal wind, [Lon]
        p_v700hPa_lon(p_v700hPa_lon > 180) = ...
            p_v700hPa_lon(p_v700hPa_lon > 180) - 360;
            % [deg E], meridional wind, [Lon]
    end
    
    % Merge 700-hPa zonal and meridional wind location data
    if isequal(p_u700hPa_lat,p_v700hPa_lat) && ...
            isequal(p_u700hPa_lon,p_v700hPa_lon)
            % Latitudinal and longitudinal grid point vectors equal
        % Set 700-hPa horizontal wind location data to 700-hPa zonal wind 
        % location data
        % NB! Latitudinal and longitudinal grid point vectors of 700-hPa
        %     zonal and meridional wind are equal
        p_wnd700hPa_lat = p_u700hPa_lat; % [deg N], latitude, [Lat]
        p_wnd700hPa_lon = p_u700hPa_lon; % [deg E], longitude, [Lon]
    end
    
    %%% Variable data %%%
    % Extract 700-hPa geopotential height variable data
    p_Z700hPa_clim_daymonth_lat_lon = plot_var(p_type_indx,1).mat; % [m]
        % Climatology
        % Weekly averaged per latitude per longitude
        % [Day*Month; Lat; Lon]
    p_Z700hPa_anom_daymonth_lat_lon = plot_var(p_type_indx,2).mat; % [m]
        % Campaign anomaly relative to climatology
        % Weekly averaged per latitude per longitude
        % [Day*Month; Lat; Lon]
        
    % Extract 700-hPa zonal wind variable data
    p_u700hPa_cpgn_daymonth_lat_lon = plot_var(p_type_indx,3).mat; % [m/s]
        % Campaign
        % Weekly averaged per latitude per longitude
        % [Day*Month; Lat; Lon]
        
    % Extract 700-hPa meridional wind variable data
    p_v700hPa_cpgn_daymonth_lat_lon = plot_var(p_type_indx,4).mat; % [m/s]
        % Campaign
        % Weekly averaged per latitude per longitude
        % [Day*Month; Lat; Lon]
    
    % Calculate 700-hPa geopotential height variable climatology data 
    % extremes using calc_map_extr.m
    [p_Z700hPa_clim_min,p_Z700hPa_clim_max,...
        p_Z700hPa_clim_range,p_Z700hPa_clim_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'mean',...
        p_Z700hPa_clim_daymonth_lat_lon,p_extr_thres);
        % [m], minimum, maximum, range and steps
    
    % Calculate 700-hPa geopotential height variable campaign anomaly 
    % relative to climatology data extremes using calc_map_extr.m
    [p_Z700hPa_anom_min,p_Z700hPa_anom_max,...
        p_Z700hPa_anom_range,p_Z700hPa_anom_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'anom',...
        p_Z700hPa_anom_daymonth_lat_lon,p_extr_thres);
        % [m], minimum, maximum, range and steps
    
    % Calculate 700-hPa geopotential height variable campaign anomaly 
    % relative to climatology color bar value steps relative to default 
    % color bar
    p_Z700hPa_anom_fbar = p_Z700hPa_anom_range/p_Z700hPa_anom_step;
    
    % Adjust 700-hPa geopotential height variable campaign anomaly relative
    % to climatology variable steps according to color bar
    if p_Z700hPa_anom_fbar > plot_bar_BR_gno
            % Color bar groups exceeding default color bar groups
        % Round variable step up
        p_Z700hPa_anom_step = round((p_Z700hPa_anom_range/10)*2)/2; % [m]
        
        % Adjust variable extremes according to variable step
        p_Z700hPa_anom_min = ...
            floor(p_Z700hPa_anom_min/p_Z700hPa_anom_step)*...
            p_Z700hPa_anom_step;
            % [m], minimum
        p_Z700hPa_anom_max = ...
            ceil(p_Z700hPa_anom_max/p_Z700hPa_anom_step)*...
            p_Z700hPa_anom_step;
            % [m], maximum
        p_Z700hPa_anom_range = ...
            range([p_Z700hPa_anom_min p_Z700hPa_anom_max]);
            % [m], range
        
        % Adjust color bar step according to variable step
        p_Z700hPa_anom_fbar = p_Z700hPa_anom_range/p_Z700hPa_anom_step;
    end
    
    % Set 700-hPa geopotential height anomaly color bar according to 
    % campaign anomaly relative to climatology data extremes
    p_Z700hPa_anom_cbar = ...
        plot_bar_BR(((plot_bar_BR_gno-p_Z700hPa_anom_fbar)/2)*plot_bar_BR_gindx+1:...
        end-((plot_bar_BR_gno-p_Z700hPa_anom_fbar)/2)*plot_bar_BR_gindx,:);
    
    %%% Plot variable color bar %%%
    % Loop over file versions and plot climatology and anomaly relative
    % to climatology daily color bar
    for ver = 1:length(plot_ver) % Loop over number of file versions
        %%% File version names %%%
        % Extract current file version and corresponding renderer names
        p_crver_name = char(plot_ver(ver)); % File version
        p_crver_rend = char(plot_rend(ver)); % Renderer
        
        %%% Figure names %%%
        % Set current file version figure path and file names
        p_crver_fig_path = [p_fig_path p_crver_name '/']; % Path
        p_crver_fig_file = ...
            [p_param_MATLAB '_cbar_hor_' reg_abbr '_daymonth_' ...
            p_set_MATLAB];
            % File
        
        %%% Plot set-up and data %%%
        % Set figure number and renderer
        figure(plot_no+1) % Number
        set(gcf,'Renderer',p_crver_rend) % Renderer
        
        % Plot color bar
        p_crver_Z700hPa_bar = colorbar('SouthOutside'); % Handle
        axis off % Remove axes
        set(gca,'CLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
            'FontSize',plot_size_legend+2)
            % Limits
        colormap(p_Z700hPa_anom_cbar) % Set map colors
        set(p_crver_Z700hPa_bar,'XLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
            'XTick',p_Z700hPa_anom_min:p_Z700hPa_anom_step:p_Z700hPa_anom_max)
            % Ticks
            
        % Add color bar label
        p_crdaymonth_crver_y = ...
            ylabel(p_crver_Z700hPa_bar,...
            ['Geopoential height [' p_param_unit ']']);
            % Set label text
        set(p_crdaymonth_crver_y,'Rotation',0,...
            'HorizontalAlignment','Center','VerticalAlignment','Top',...
            'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
            'FontWeight',plot_font_weight)
            % Set label rotation, alignment and font
        
        %%% Save figure %%%
        % Save current file version figure
        if strcmp(p_crver_name,'fig') % MATLAB file
            % Save MATLAB figure file
            saveas(gcf,[p_crver_fig_path p_crver_fig_file],'fig')
        elseif strcmp(p_crver_name,'eps') % Article file
            % Save article figure file
            print(gcf,'-depsc',...
                [p_crver_fig_path p_crver_fig_file])
        elseif strcmp(p_crver_name,'pdf') % View file
            % Set file paper properties
            set(gcf,'PaperType',plot_paper_type,...
                'PaperOrientation',plot_paper_orient,...
                'PaperUnits','centimeters',...
                'PaperPosition',plot_paper_pos);
            
            % Save view figure file
            print(gcf,'-dpdf',[p_crver_fig_path p_crver_fig_file])
        end
            
        % Update number of open figures
        p_crver_fig = gcf;
            % Get current file version figure handle
        plot_no = p_crver_fig.Number;
            % Get current file version figure number
        
        %%% Delete data %%%
        % Delete current file version data
        clear p_crver_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear ver
    
    %%% Plot variable data %%%
    % Loop over days and plot climatology and anomaly relative to 
    % climatology daily data
    for d = 1:day_no % Loop over number of time period days
        %%% Week names %%%
        % Extract current day names
        p_crdaymonth_file = ...
            datestr(datenum(tper_txt(1:11))+d-1,'yyyymmdd');
            % File
        p_crdaymonth_title = datestr(datenum(tper_txt(1:11))+d-1);
            % Title
            
        %%% Figure names %%%
        % Set current day figure file and title names
        p_crdaymonth_fig_file = ...
            [p_param_MATLAB '_' reg_abbr '_' p_crdaymonth_file '_' ...
            p_set_MATLAB];
            % File
        p_crdaymonth_fig_title = ...
            [p_param_full ' during ' p_crdaymonth_title ' over the ' ...
            reg_full ' from ' p_set_MATLAB];
            % Title
            
        %%% Variable data %%%
        % Extract current day 700-hPa geopotential height variable data
        p_crdaymonth_Z700hPa_clim_lat_lon = ...
            squeeze(p_Z700hPa_clim_daymonth_lat_lon(d,:,:));
            % [m], climatology, [Lat; Lon]
        p_crdaymonth_Z700hPa_anom_lat_lon = ...
            squeeze(p_Z700hPa_anom_daymonth_lat_lon(d,:,:));
            % [m], campaign anomaly relative to climatology, [Lat; Lon]
        
        % Extract current day 700-hPa zonal wind variable data
        p_crdaymonth_u700hPa_cpgn_lat_lon = ...
            squeeze(p_u700hPa_cpgn_daymonth_lat_lon(d,:,:));
            % [m/s], campaign, [Lat; Lon]
        
        % Extract current day 700-hPa meridional wind variable data
        p_crdaymonth_v700hPa_cpgn_lat_lon = ...
            squeeze(p_v700hPa_cpgn_daymonth_lat_lon(d,:,:));
            % [m/s], campaign, [Lat; Lon]
        
        %%% Plot variable data %%%
        % Loop over file versions and plot climatology and anomaly relative
        % to climatology daily data
        for ver = 1%:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
%             p_crver_name = char(plot_ver(ver)); % File version
            p_crver_name = 'png'; % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current file version figure path name
            p_crver_fig_path = [p_fig_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
            % Set plot projection
            m_proj(plot_proj_name,'long',plot_lon_lim,'lat',plot_lat_lim);
            
            % Plot 700-hPa geopotential height campaign anomaly relative to
            % climatology data as a blue-white-red-shaded map
            p_crdaymonth_crver_Z700hPa_anom = ...
                m_pcolor(p_Z700hPa_lon,p_Z700hPa_lat,...
                p_crdaymonth_Z700hPa_anom_lat_lon);
                % Data
            set(p_crdaymonth_crver_Z700hPa_anom,'LineStyle','none');
                % Set no data boundaries
            
            % Plot 700-hPa geopotential height climatology data as a
            % black-contoured map
            [p_crdaymonth_crver_Z700hPa_clim,...
                h_crdaymonth_crver_Z700hPa_clim] = ...
                m_contour(p_Z700hPa_lon,p_Z700hPa_lat,...
                p_crdaymonth_Z700hPa_clim_lat_lon,...
                [p_Z700hPa_clim_min:p_Z700hPa_clim_step:p_Z700hPa_clim_max],...
                '-','Color','k','LineWidth',2);
            
            % Plot 700-hPa horizontal wind campaign data as a 
            % green-vectored map
%             p_crdaymonth_crver_wnd700hPa_cpgn = ...
%                 m_quiver(...
%                 repmat(p_wnd700hPa_lon(1:8:end)',ceil(length(p_wnd700hPa_lat)/2),1),...
%                 repmat(p_wnd700hPa_lat(1:2:end),1,ceil(length(p_wnd700hPa_lon)/8)),...
%                 p_crdaymonth_u700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
%                 p_crdaymonth_v700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
%                 1,'Color',[0 .5 0],'LineWidth',1);
            [p_crdaymonth_crver_wnd700hPa_cpgn,~] = ...
                m_vec(20,...
                repmat(p_wnd700hPa_lon(1:8:end)',ceil(length(p_wnd700hPa_lat)/2),1),...
                repmat(p_wnd700hPa_lat(1:2:end),1,ceil(length(p_wnd700hPa_lon)/8)),...
                p_crdaymonth_u700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
                p_crdaymonth_v700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
                'centered','yes');
                % Data
            p_crdaymonth_crver_wnd700hPa_scl = ...
                m_vec(20,80,80,10,0,'key','10 m s^{-1}','centered','yes');
                % Scale
            
            % Set plot grid and land contours
            m_grid('XTick',plot_lon_lim(1):15:plot_lon_lim(2),...
                'YTick',plot_lat_lim(1):5:plot_lat_lim(2));
                % Set grid
            m_coast('line','LineWidth',plot_line_width,...
                'color',plot_col_coast-.3);
                % Add land contours as grey-lined coasts
            
            % Map color scheme and bar
            p_crdaymonth_crver_Z700hPa_bar = colorbar; % Get bar handle
            set(gca,'CLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
                'FontSize',plot_size_legend+2)
                % Set bar limits
            colormap(p_Z700hPa_anom_cbar); % Set map colors
            set([p_crdaymonth_crver_wnd700hPa_cpgn,...
                p_crdaymonth_crver_wnd700hPa_scl],...
                'FaceColor',[0 .5 0],'EdgeColor',[0 .5 0])
                % Set arrow colors
            set(p_crdaymonth_crver_Z700hPa_bar,...
                'YLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
                'YTick',...
                p_Z700hPa_anom_min:p_Z700hPa_anom_step:p_Z700hPa_anom_max)
                % Set bar ticks
%             p_crdaymonth_crver_Z700hPa_bar_pos = ...
%                 get(p_crdaymonth_crver_Z700hPa_bar,'Position');
%             set(p_crdaymonth_crver_Z700hPa_bar,'Position',...
%                 [p_crdaymonth_crver_Z700hPa_bar_pos(1)+0.15 ...
%                 p_crdaymonth_crver_Z700hPa_bar_pos(2) ...
%                 p_crdaymonth_crver_Z700hPa_bar_pos(3) ...
%                 p_crdaymonth_crver_Z700hPa_bar_pos(4)])
%                 % Set bar position
            if strcmp(p_crver_name,'eps')
                % Hide bar
                colorbar('hide');
            end
            
            %%% Plot labels %%%
            % Set plot contour labels
            % NB! Setting text properties (name, size and weight) is only
            %     possible without the 'h_crdaymonth_crver_Z700hPa_clim' 
            %     argument
            clabel(p_crdaymonth_crver_Z700hPa_clim,...
                h_crdaymonth_crver_Z700hPa_clim,...
                p_Z700hPa_clim_min:p_Z700hPa_clim_step:p_Z700hPa_clim_max,...
                'LabelSpacing',150);
            
            % Set plot axes labels
            set(findall(gcf,'-property','FontName'),...
                'FontName',plot_font_name)
                % Type
            set(findall(gcf,'-property','FontSize'),...
                'FontSize',plot_size_legend+2)
                % Size
            
            % Set current file version title and color bar labels 
            % properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crdaymonth_crver_ttl = title(p_crdaymonth_fig_title);
                
                % Title label font
                set(p_crdaymonth_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
            
                % Color bar label text
                p_crdaymonth_crver_x = ...
                    xlabel(p_crdaymonth_crver_Z700hPa_bar,...
                    ['Geopoential height [' p_param_unit ']']);
                
                % Color bar label rotation, position, alignment and font
                set(p_crdaymonth_crver_x,'Rotation',0,'Position',...
                    [1.5 p_Z700hPa_anom_min-p_Z700hPa_anom_step/2 0],...
                    'HorizontalAlignment','right',...
                    'VerticalAlignment','middle',...
                    'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
                    'FontWeight',plot_font_weight)
            elseif strcmp(p_crver_name,'png') % Graphic file
                % Title label text
                p_crdaymonth_crver_ttl = ...
                    title(...
                    {'700 hPa geopotential height '; ...
                    '(contours = 1979-2016, shading = 2017 minus 1979-2016)'; ...
                    'and horizontal wind (vectors = 2017):'; ...
                    p_crdaymonth_title});
                
                % Title label position
                p_crdaymonth_crver_ttl_pos = ...
                    get(p_crdaymonth_crver_ttl,'Position');
                    % Get
                set(p_crdaymonth_crver_ttl,'Position',...
                    [p_crdaymonth_crver_ttl_pos(1) ...
                    p_crdaymonth_crver_ttl_pos(2)+0.01 ...
                    p_crdaymonth_crver_ttl_pos(3)])
                    % Set
                
                % Title label font
                set(p_crdaymonth_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label,...
                    'FontWeight',plot_font_weight)
            
                % Color bar label text
                p_crdaymonth_crver_x = ...
                    xlabel(p_crdaymonth_crver_Z700hPa_bar,...
                    {'Geopoential height'; ['[' p_param_unit ']']});
                
                % Color bar label rotation, position, alignment and font
                set(p_crdaymonth_crver_x,'Rotation',0,'Position',...
                    [1.5 p_Z700hPa_anom_min-p_Z700hPa_anom_step/2 0],...
                    'HorizontalAlignment','right',...
                    'VerticalAlignment','top',...
                    'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
                    'FontWeight',plot_font_weight)
            end
            
            %%% Save figure %%%
            % Save current parameter current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crver_fig_path p_crdaymonth_fig_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',...
                    [p_crver_fig_path p_crdaymonth_fig_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view or graphic figure file
                print(gcf,'-dpdf',[p_crver_fig_path p_crdaymonth_fig_file])
            elseif strcmp(p_crver_name,'png') % Graphic file
                % Save view or graphic figure file
                pause(1)
                print(gcf,'-dpng',[p_crver_fig_path p_crdaymonth_fig_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current day current file version data
            clear p_crdaymonth_crver_* p_crver_*
        end
        
        %%% Delete data %%%
        % Delete current day data
        clear ver p_crdaymonth_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear d
end
%%
%%% Plot climatology and anomaly relative to climatology  %%%
%%%    over campaign weeks of 700-hPa circulation data    %%%
% Only plot if asked to
if strcmp(plot_typename,'wk-clim_anom_700hPa-circ') > 0
        % Climatology and anomaly relative to climatology over campaign
        % weeks of 700-hPa circulation
    disp(['plot_ACLOUD_ERA: Climatology and anomaly ' ...
        'relative to climatology over campaign weeks of ' ...
        '700-hPa circulation chosen for plotting'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'wk-clim_anom_700hPa-circ'));
    
    %%% Parameter settings and data %%%
    % Set plot parameter threshold value for occurance frequency of extreme
    % values
    p_extr_thres = 0.005;
        % 0.005 -> < 0.5 % extreme value occurance
        % 0.01  -> < 1.0 % extreme value occurance
        % 0.05  -> < 5.0 % extreme value occurance
    
    %%% Parameter names, unit and indexes %%%
    % Set parameter MATLAB and full names and unit
    p_param_MATLAB = 'Z700hPa-u700hPa-v700hPa';
        % MATLAB name
    p_param_full = '700-hPa geopotential height with horizontal wind';
        % Full name
    p_param_unit = char(plot_varname(p_type_indx+1,3));
        % Unit
    
    %%% Data set index and name %%%
    % Extract data set name
    p_set_MATLAB = char(mod_name(1+1,3));
    
    % Diplay current parameter plotting choices
    disp(['plot_ACLOUD_ERA: ' ...
        'Plotting ' p_set_MATLAB ' ' p_param_full ...
        ' data over the ' reg_full])
    
    %%% Figure names %%%
    % Set figure path name
    p_fig_path = [path_fig p_param_MATLAB '/'];
    
    %%% Location data %%%
    % Extract 700-hPa geopotential height location data
    p_Z700hPa_lat = plot_loc(p_type_indx,1).mat; % [deg N]
        % Latitude, [Lat]
    p_Z700hPa_lon = plot_loc(p_type_indx,2).mat; % [deg E]
        % Longitude, [Lon]
        
    % Extract 700-hPa zonal wind location data
    p_u700hPa_lat = plot_loc(p_type_indx,3).mat; % [deg N]
        % Latitude, [Lat]
    p_u700hPa_lon = plot_loc(p_type_indx,4).mat; % [deg E]
        % Longitude, [Lon]
        
    % Extract 700-hPa meridional wind location data
    p_v700hPa_lat = plot_loc(p_type_indx,5).mat; % [deg N]
        % Latitude, [Lat]
    p_v700hPa_lon = plot_loc(p_type_indx,6).mat; % [deg E]
        % Longitude, [Lon]
    
    % Adjust 700-hPa geopotential height, zonal and meridional wind 
    % longitude data in accordance with plot set-up
    if min(plot_lon_lim) < 0 % Longitudinal format = [-180,180] deg E
        % Longitudinal grid points in Western Hemisphere
        p_Z700hPa_lon(p_Z700hPa_lon > 180) = ...
            p_Z700hPa_lon(p_Z700hPa_lon > 180) - 360;
            % [deg E], geopotential height, [Lon]
        p_u700hPa_lon(p_u700hPa_lon > 180) = ...
            p_u700hPa_lon(p_u700hPa_lon > 180) - 360;
            % [deg E], zonal wind, [Lon]
        p_v700hPa_lon(p_v700hPa_lon > 180) = ...
            p_v700hPa_lon(p_v700hPa_lon > 180) - 360;
            % [deg E], meridional wind, [Lon]
    end
    
    % Merge 700-hPa zonal and meridional wind location data
    if isequal(p_u700hPa_lat,p_v700hPa_lat) && ...
            isequal(p_u700hPa_lon,p_v700hPa_lon)
            % Latitudinal and longitudinal grid point vectors equal
        % Set 700-hPa horizontal wind location data to 700-hPa zonal wind 
        % location data
        % NB! Latitudinal and longitudinal grid point vectors of 700-hPa
        %     zonal and meridional wind are equal
        p_wnd700hPa_lat = p_u700hPa_lat; % [deg N], latitude, [Lat]
        p_wnd700hPa_lon = p_u700hPa_lon; % [deg E], longitude, [Lon]
    end
    
    %%% Variable data %%%
    % Extract 700-hPa geopotential height variable data
    p_Z700hPa_clim_wk_lat_lon = plot_var(p_type_indx,1).mat; % [m]
        % Climatology
        % Weekly averaged per latitude per longitude
        % [Wk; Lat; Lon]
    p_Z700hPa_anom_wk_lat_lon = plot_var(p_type_indx,2).mat; % [m]
        % Campaign anomaly relative to climatology
        % Weekly averaged per latitude per longitude
        % [Wk; Lat; Lon]
        
    % Extract 700-hPa zonal wind variable data
    p_u700hPa_cpgn_wk_lat_lon = plot_var(p_type_indx,3).mat; % [m/s]
        % Campaign
        % Weekly averaged per latitude per longitude
        % [Wk; Lat; Lon]
        
    % Extract 700-hPa meridional wind variable data
    p_v700hPa_cpgn_wk_lat_lon = plot_var(p_type_indx,4).mat; % [m/s]
        % Campaign
        % Weekly averaged per latitude per longitude
        % [Wk; Lat; Lon]
    
    % Calculate 700-hPa geopotential height variable climatology data 
    % extremes using calc_map_extr.m
    [p_Z700hPa_clim_min,p_Z700hPa_clim_max,...
        p_Z700hPa_clim_range,p_Z700hPa_clim_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'mean',...
        p_Z700hPa_clim_wk_lat_lon,p_extr_thres);
        % [m], minimum, maximum, range and steps
    
    % Calculate 700-hPa geopotential height variable campaign anomaly 
    % relative to climatology data extremes using calc_map_extr.m
    [p_Z700hPa_anom_min,p_Z700hPa_anom_max,...
        p_Z700hPa_anom_range,p_Z700hPa_anom_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'anom',...
        p_Z700hPa_anom_wk_lat_lon,p_extr_thres);
        % [m], minimum, maximum, range and steps
    
    % Calculate 700-hPa geopotential height variable campaign anomaly 
    % relative to climatology color bar value steps relative to default 
    % color bar
    p_Z700hPa_anom_fbar = p_Z700hPa_anom_range/p_Z700hPa_anom_step;
    
    % Adjust 700-hPa geopotential height variable campaign anomaly relative
    % to climatology variable steps according to color bar
    if p_Z700hPa_anom_fbar > plot_bar_BR_gno
            % Color bar groups exceeding default color bar groups
        % Round variable step up
        p_Z700hPa_anom_step = round((p_Z700hPa_anom_range/10)*2)/2; % [m]
        
        % Adjust variable extremes according to variable step
        p_Z700hPa_anom_min = ...
            floor(p_Z700hPa_anom_min/p_Z700hPa_anom_step)*...
            p_Z700hPa_anom_step;
            % [m], minimum
        p_Z700hPa_anom_max = ...
            ceil(p_Z700hPa_anom_max/p_Z700hPa_anom_step)*...
            p_Z700hPa_anom_step;
            % [m], maximum
        p_Z700hPa_anom_range = ...
            range([p_Z700hPa_anom_min p_Z700hPa_anom_max]);
            % [m], range
        
        % Adjust color bar step according to variable step
        p_Z700hPa_anom_fbar = p_Z700hPa_anom_range/p_Z700hPa_anom_step;
    end
    
    % Set 700-hPa geopotential height anomaly color bar according to 
    % campaign anomaly relative to climatology data extremes
    p_Z700hPa_anom_cbar = ...
        plot_bar_BR(((plot_bar_BR_gno-p_Z700hPa_anom_fbar)/2)*plot_bar_BR_gindx+1:...
        end-((plot_bar_BR_gno-p_Z700hPa_anom_fbar)/2)*plot_bar_BR_gindx,:);
    
    %%% Plot variable data %%%
    % Loop over weeks and plot climatology and anomaly relative to 
    % climatology weekly data
    for w = 1:ceil((day_no-3)/7) % Loop over number of time period weeks
        %%% Week names %%%
        % Extract current week names
        p_crwk_file = ...
            [datestr(datenum(tper_txt(1:11))+7*(w-1),'yyyymmdd') '-' ...
            datestr(datenum(tper_txt(1:11))+7*w-1,'yyyymmdd')];
            % File
        p_crwk_title = ...
            [datestr(datenum(tper_txt(1:11))+7*(w-1)) ' - ' ...
            datestr(datenum(tper_txt(1:11))+7*w-1)];
            % Title
            
        %%% Figure names %%%
        % Set current week figure file and title names
        p_crwk_fig_file = ...
            [p_param_MATLAB '_' reg_abbr '_' p_crwk_file '_' p_set_MATLAB];
            % File
        p_crwk_fig_title = ...
            [p_param_full ' during ' p_crwk_title ' over the ' reg_full ...
            ' from ' p_set_MATLAB];
            % Title
            
        %%% Variable data %%%
        % Extract current week 700-hPa geopotential height variable data
        p_crwk_Z700hPa_clim_lat_lon = ...
            squeeze(p_Z700hPa_clim_wk_lat_lon(w,:,:));
            % [m], climatology, [Lat; Lon]
        p_crwk_Z700hPa_anom_lat_lon = ...
            squeeze(p_Z700hPa_anom_wk_lat_lon(w,:,:));
            % [m], campaign anomaly relative to climatology, [Lat; Lon]
        
        % Extract current week 700-hPa zonal wind variable data
        p_crwk_u700hPa_cpgn_lat_lon = ...
            squeeze(p_u700hPa_cpgn_wk_lat_lon(w,:,:));
            % [m/s], campaign, [Lat; Lon]
        
        % Extract current week 700-hPa meridional wind variable data
        p_crwk_v700hPa_cpgn_lat_lon = ...
            squeeze(p_v700hPa_cpgn_wk_lat_lon(w,:,:));
            % [m/s], campaign, [Lat; Lon]
        
        %%% Plot variable data %%%
        % Loop over file versions and plot climatology and anomaly relative
        % to climatology weekly data
        for ver = 1:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
            p_crver_name = char(plot_ver(ver)); % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current file version figure path name
            p_crver_fig_path = [p_fig_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
            % Set plot projection
            m_proj(plot_proj_name,'long',plot_lon_lim,'lat',plot_lat_lim);
            
            % Plot 700-hPa geopotential height campaign anomaly relative to
            % climatology data as a blue-white-red-shaded map
            p_crwk_crver_Z700hPa_anom = ...
                m_pcolor(p_Z700hPa_lon,p_Z700hPa_lat,...
                p_crwk_Z700hPa_anom_lat_lon);
                % Data
            set(p_crwk_crver_Z700hPa_anom,'LineStyle','none');
                % Set no data boundaries
            
            % Plot 700-hPa geopotential height climatology data as a
            % black-contoured map
            [p_crwk_crver_Z700hPa_clim,h_crwk_crver_Z700hPa_clim] = ...
                m_contour(p_Z700hPa_lon,p_Z700hPa_lat,...
                p_crwk_Z700hPa_clim_lat_lon,...
                [p_Z700hPa_clim_min:p_Z700hPa_clim_step:p_Z700hPa_clim_max],...
                '-','Color','k','LineWidth',2);
            
            % Plot 700-hPa horizontal wind campaign data as a 
            % green-vectored map
            p_crwk_crver_wnd700hPa_cpgn = ...
                m_quiver(...
                repmat(p_wnd700hPa_lon(1:8:end)',ceil(length(p_wnd700hPa_lat)/2),1),...
                repmat(p_wnd700hPa_lat(1:2:end),1,ceil(length(p_wnd700hPa_lon)/8)),...
                p_crwk_u700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
                p_crwk_v700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
                1,'Color',[0 .5 0],'LineWidth',1);
            
            % Set plot grid and land contours
            m_grid('XTick',plot_lon_lim(1):15:plot_lon_lim(2),...
                'YTick',plot_lat_lim(1):5:plot_lat_lim(2));
                % Set grid
            m_coast('line','LineWidth',plot_line_width,...
                'color',plot_col_coast-.3);
                % Add land contours as grey-lined coasts
            
            % Map color scheme and bar
            p_crwk_crver_Z700hPa_bar = colorbar; % Handle
            set(gca,'CLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
                'FontSize',plot_size_legend)
                % Limits
            colormap(p_Z700hPa_anom_cbar); % Set map colors
            set(p_crwk_crver_Z700hPa_bar,...
                'YLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
                'YTick',...
                p_Z700hPa_anom_min:p_Z700hPa_anom_step:p_Z700hPa_anom_max)
                % Ticks
            
            %%% Plot labels %%%
            % Set plot contour labels
            % NB! Setting text properties (name, size and weight) is only
            %     possible without the 'h_crwk_crver_Z700hPa_clim' argument
            clabel(p_crwk_crver_Z700hPa_clim,h_crwk_crver_Z700hPa_clim,...
                p_Z700hPa_clim_min:p_Z700hPa_clim_step:p_Z700hPa_clim_max,...
                'LabelSpacing',100);
            
%             % Set plot contour and shading labels
%             p_crwk_crver_Z700hPa_lgnd = ...
%                 legend([p_crwk_crver_Z700hPa_anom h_crwk_crver_Z700hPa_clim],...
%                 'Anomaly','Climatology');
%                 % Text
%             set(p_crwk_crver_Z700hPa_lgnd,'FontName',plot_font_name,...
%                 'FontSize',plot_size_legend,'FontWeight',plot_font_weight);
%                 % Font
            
            % Set current file version title and color bar labels 
            % properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crwk_crver_ttl = title(p_crwk_fig_title);
                
                % Title label font
                set(p_crwk_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
            end
            p_crwk_crver_x = xlabel(p_crwk_crver_Z700hPa_bar,p_param_unit);
                % Color bar label text
            set(p_crwk_crver_x,'Rotation',0,'Position',...
                [1.5 p_Z700hPa_anom_min-p_Z700hPa_anom_step/2 0],...
                'HorizontalAlignment','right',...
                'VerticalAlignment','middle',...
                'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
                'FontWeight',plot_font_weight)
                % Color bar label rotation, position, alignment and font
            
            %%% Save figure %%%
            % Save current parameter current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crver_fig_path p_crwk_fig_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',[p_crver_fig_path p_crwk_fig_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view figure file
                print(gcf,'-dpdf',[p_crver_fig_path p_crwk_fig_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current week current file version data
            clear p_crwk_crver_* p_crver_*
        end
        
        %%% Delete data %%%
        % Delete current week data
        clear ver p_crwk_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear w
end
%%
%%% Plot climatology and anomaly relative to climatology  %%%
%%% over campaign key periods of 700-hPa circulation data %%%
% Only plot if asked to
if strcmp(plot_typename,'kp-clim_anom_700hPa-circ') > 0
        % Climatology and anomaly relative to climatology over campaign
        % key periods of 700-hPa circulation
    disp(['plot_ACLOUD_ERA: Climatology and anomaly ' ...
        'relative to climatology over campaign key periods of ' ...
        '700-hPa circulation chosen for plotting'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'kp-clim_anom_700hPa-circ'));
    
    %%% Parameter settings and data %%%
    % Set plot parameter threshold value for occurance frequency of extreme
    % values
    p_extr_thres = 0.005;
        % 0.005 -> < 0.5 % extreme value occurance
        % 0.01  -> < 1.0 % extreme value occurance
        % 0.05  -> < 5.0 % extreme value occurance
    
    %%% Parameter names, unit and indexes %%%
    % Set parameter MATLAB and full names and unit
    p_param_MATLAB = 'Z700hPa-u700hPa-v700hPa';
        % MATLAB name
    p_param_full = '700-hPa geopotential height with horizontal wind';
        % Full name
    p_param_unit = char(plot_varname(p_type_indx+1,3));
        % Unit
    
    %%% Data set index and name %%%
    % Extract data set name
    p_set_MATLAB = char(mod_name(1+1,3));
    
    % Diplay current parameter plotting choices
    disp(['plot_ACLOUD_ERA: ' ...
        'Plotting ' p_set_MATLAB ' ' p_param_full ...
        ' data over the ' reg_full])
    
    %%% Figure names %%%
    % Set figure path name
    p_fig_path = [path_fig p_param_MATLAB '/'];
    
    %%% Location data %%%
    % Extract 700-hPa geopotential height location data
    p_Z700hPa_lat = plot_loc(p_type_indx,1).mat; % [deg N]
        % Latitude, [Lat]
    p_Z700hPa_lon = plot_loc(p_type_indx,2).mat; % [deg E]
        % Longitude, [Lon]
        
    % Extract 700-hPa zonal wind location data
    p_u700hPa_lat = plot_loc(p_type_indx,3).mat; % [deg N]
        % Latitude, [Lat]
    p_u700hPa_lon = plot_loc(p_type_indx,4).mat; % [deg E]
        % Longitude, [Lon]
        
    % Extract 700-hPa meridional wind location data
    p_v700hPa_lat = plot_loc(p_type_indx,5).mat; % [deg N]
        % Latitude, [Lat]
    p_v700hPa_lon = plot_loc(p_type_indx,6).mat; % [deg E]
        % Longitude, [Lon]
    
    % Adjust 700-hPa geopotential height, zonal and meridional wind 
    % longitude data in accordance with plot set-up
    if min(plot_lon_lim) < 0 % Longitudinal format = [-180,180] deg E
        % Longitudinal grid points in Western Hemisphere
        p_Z700hPa_lon(p_Z700hPa_lon > 180) = ...
            p_Z700hPa_lon(p_Z700hPa_lon > 180) - 360;
            % [deg E], geopotential height, [Lon]
        p_u700hPa_lon(p_u700hPa_lon > 180) = ...
            p_u700hPa_lon(p_u700hPa_lon > 180) - 360;
            % [deg E], zonal wind, [Lon]
        p_v700hPa_lon(p_v700hPa_lon > 180) = ...
            p_v700hPa_lon(p_v700hPa_lon > 180) - 360;
            % [deg E], meridional wind, [Lon]
    end
    
    % Merge 700-hPa zonal and meridional wind location data
    if isequal(p_u700hPa_lat,p_v700hPa_lat) && ...
            isequal(p_u700hPa_lon,p_v700hPa_lon)
            % Latitudinal and longitudinal grid point vectors equal
        % Set 700-hPa horizontal wind location data to 700-hPa zonal wind 
        % location data
        % NB! Latitudinal and longitudinal grid point vectors of 700-hPa
        %     zonal and meridional wind are equal
        p_wnd700hPa_lat = p_u700hPa_lat; % [deg N], latitude, [Lat]
        p_wnd700hPa_lon = p_u700hPa_lon; % [deg E], longitude, [Lon]
    end
    
    %%% Variable data %%%
    % Extract 700-hPa geopotential height variable data
    p_Z700hPa_clim_kp_lat_lon = plot_var(p_type_indx,1).mat; % [m]
        % Climatology
        % Key periodic averaged per latitude per longitude
        % [Kp; Lat; Lon]
    p_Z700hPa_anom_kp_lat_lon = plot_var(p_type_indx,2).mat; % [m]
        % Campaign anomaly relative to climatology
        % Key periodic averaged per latitude per longitude
        % [Kp; Lat; Lon]
        
    % Extract 700-hPa zonal wind variable data
    p_u700hPa_cpgn_kp_lat_lon = plot_var(p_type_indx,3).mat; % [m/s]
        % Campaign
        % Key periodic medianed per latitude per longitude
        % [Kp; Lat; Lon]
        
    % Extract 700-hPa meridional wind variable data
    p_v700hPa_cpgn_kp_lat_lon = plot_var(p_type_indx,4).mat; % [m/s]
        % Campaign
        % Key periodic medianed per latitude per longitude
        % [Kp; Lat; Lon]
    
    % Calculate 700-hPa geopotential height variable climatology data 
    % extremes using calc_map_extr.m
    [p_Z700hPa_clim_min,p_Z700hPa_clim_max,...
        p_Z700hPa_clim_range,p_Z700hPa_clim_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'mean',...
        p_Z700hPa_clim_kp_lat_lon,p_extr_thres);
        % [m], minimum, maximum, range and steps
    
    % Calculate 700-hPa geopotential height variable campaign anomaly 
    % relative to climatology data extremes using calc_map_extr.m
    [p_Z700hPa_anom_min,p_Z700hPa_anom_max,...
        p_Z700hPa_anom_range,p_Z700hPa_anom_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'anom',...
        p_Z700hPa_anom_kp_lat_lon,p_extr_thres);
        % [m], minimum, maximum, range and steps
    
    % Calculate 700-hPa geopotential height variable campaign anomaly 
    % relative to climatology color bar value steps relative to default 
    % color bar
    p_Z700hPa_anom_fbar = p_Z700hPa_anom_range/p_Z700hPa_anom_step;
    
    % Adjust 700-hPa geopotential height variable campaign anomaly relative
    % to climatology variable steps according to color bar
    if p_Z700hPa_anom_fbar > plot_bar_BR_gno
            % Color bar groups exceeding default color bar groups
        % Round variable step up
        p_Z700hPa_anom_step = round((p_Z700hPa_anom_range/10)*2)/2; % [m]
        
        % Adjust variable extremes according to variable step
        p_Z700hPa_anom_min = ...
            floor(p_Z700hPa_anom_min/p_Z700hPa_anom_step)*...
            p_Z700hPa_anom_step;
            % [m], minimum
        p_Z700hPa_anom_max = ...
            ceil(p_Z700hPa_anom_max/p_Z700hPa_anom_step)*...
            p_Z700hPa_anom_step;
            % [m], maximum
        p_Z700hPa_anom_range = ...
            range([p_Z700hPa_anom_min p_Z700hPa_anom_max]);
            % [m], range
        
        % Adjust color bar step according to variable step
        p_Z700hPa_anom_fbar = p_Z700hPa_anom_range/p_Z700hPa_anom_step;
    end
    
    % Set 700-hPa geopotential height anomaly color bar according to 
    % campaign anomaly relative to climatology data extremes
    p_Z700hPa_anom_cbar = ...
        plot_bar_BR(((plot_bar_BR_gno-p_Z700hPa_anom_fbar)/2)*plot_bar_BR_gindx+1:...
        end-((plot_bar_BR_gno-p_Z700hPa_anom_fbar)/2)*plot_bar_BR_gindx,:);
    
    %%% Plot variable color bar %%%
    % Loop over file versions and plot climatology and anomaly relative
    % to climatology key periodic color bar
    for ver = 1:length(plot_ver) % Loop over number of file versions
        %%% File version names %%%
        % Extract current file version and corresponding renderer names
        p_crver_name = char(plot_ver(ver)); % File version
        p_crver_rend = char(plot_rend(ver)); % Renderer
        
        %%% Figure names %%%
        % Set current file version figure path and file names
        p_crver_fig_path = [p_fig_path p_crver_name '/']; % Path
        p_crver_fig_file = ...
            [p_param_MATLAB '_cbar_hor_' reg_abbr '_kp_' ...
            p_set_MATLAB];
            % File
        
        %%% Plot set-up and data %%%
        % Set figure number and renderer
        figure(plot_no+1) % Number
        set(gcf,'Renderer',p_crver_rend) % Renderer
        
        % Plot color bar
        p_crver_Z700hPa_bar = colorbar('SouthOutside'); % Handle
        axis off % Remove axes
        set(gca,'CLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
            'FontSize',plot_size_legend+2)
            % Limits
        colormap(p_Z700hPa_anom_cbar) % Set map colors
        set(p_crver_Z700hPa_bar,'XLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
            'XTick',p_Z700hPa_anom_min:p_Z700hPa_anom_step:p_Z700hPa_anom_max)
            % Ticks
            
        % Add color bar label
        p_crdaymonth_crver_y = ...
            ylabel(p_crver_Z700hPa_bar,...
            ['Geopoential height [' p_param_unit ']']);
            % Set label text
        set(p_crdaymonth_crver_y,'Rotation',0,...
            'HorizontalAlignment','Center','VerticalAlignment','Top',...
            'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
            'FontWeight',plot_font_weight)
            % Set label rotation, alignment and font
        
        %%% Save figure %%%
        % Save current file version figure
        if strcmp(p_crver_name,'fig') % MATLAB file
            % Save MATLAB figure file
            saveas(gcf,[p_crver_fig_path p_crver_fig_file],'fig')
        elseif strcmp(p_crver_name,'eps') % Article file
            % Save article figure file
            print(gcf,'-depsc',...
                [p_crver_fig_path p_crver_fig_file])
        elseif strcmp(p_crver_name,'pdf') % View file
            % Set file paper properties
            set(gcf,'PaperType',plot_paper_type,...
                'PaperOrientation',plot_paper_orient,...
                'PaperUnits','centimeters',...
                'PaperPosition',plot_paper_pos);
            
            % Save view figure file
            print(gcf,'-dpdf',[p_crver_fig_path p_crver_fig_file])
        end
            
        % Update number of open figures
        p_crver_fig = gcf;
            % Get current file version figure handle
        plot_no = p_crver_fig.Number;
            % Get current file version figure number
        
        %%% Delete data %%%
        % Delete current file version data
        clear p_crver_*
    end
    
    %%% Plot variable data %%%
    % Loop over key periods and plot climatology and anomaly relative to 
    % climatology key periodic data
    for kp = 1:kper_no % Loop over number of key periods
        %%% Key period names %%%
        % Extract current key period names
        p_crkp_file = kper_num(kp,:); % File
        p_crkp_title = kper_txt(kp,:); % Title
            
        %%% Figure names %%%
        % Set current key period figure file and title names
        p_crkp_fig_file = ...
            [p_param_MATLAB '_' reg_abbr '_' p_crkp_file '_' p_set_MATLAB];
            % File
        p_crkp_fig_title = ...
            [p_param_full ' during ' p_crkp_title ' over the ' reg_full ...
            ' from ' p_set_MATLAB];
            % Title
            
        %%% Variable data %%%
        % Extract current key period 700-hPa geopotential height variable 
        % data
        p_crkp_Z700hPa_clim_lat_lon = ...
            squeeze(p_Z700hPa_clim_kp_lat_lon(kp,:,:));
            % [m], climatology, [Lat; Lon]
        p_crkp_Z700hPa_anom_lat_lon = ...
            squeeze(p_Z700hPa_anom_kp_lat_lon(kp,:,:));
            % [m], campaign anomaly relative to climatology, [Lat; Lon]
        
        % Extract current key period 700-hPa zonal wind variable data
        p_crkp_u700hPa_cpgn_lat_lon = ...
            squeeze(p_u700hPa_cpgn_kp_lat_lon(kp,:,:));
            % [m/s], campaign, [Lat; Lon]
        
        % Extract current key period 700-hPa meridional wind variable data
        p_crkp_v700hPa_cpgn_lat_lon = ...
            squeeze(p_v700hPa_cpgn_kp_lat_lon(kp,:,:));
            % [m/s], campaign, [Lat; Lon]
        
        %%% Plot variable data %%%
        % Loop over file versions and plot climatology and anomaly relative
        % to climatology key periodic data
        for ver = 1:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
            p_crver_name = char(plot_ver(ver)); % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current file version figure path name
            p_crver_fig_path = [p_fig_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
            % Set plot projection
            m_proj(plot_proj_name,'long',plot_lon_lim,'lat',plot_lat_lim);
            
            % Plot 700-hPa geopotential height campaign anomaly relative to
            % climatology data as a blue-white-red-shaded map
            p_crkp_crver_Z700hPa_anom = ...
                m_pcolor(p_Z700hPa_lon,p_Z700hPa_lat,...
                p_crkp_Z700hPa_anom_lat_lon);
                % Data
            set(p_crkp_crver_Z700hPa_anom,'LineStyle','none');
                % Set no data boundaries
            
            % Plot 700-hPa geopotential height climatology data as a
            % black-contoured map
            [p_crkp_crver_Z700hPa_clim,h_crkp_crver_Z700hPa_clim] = ...
                m_contour(p_Z700hPa_lon,p_Z700hPa_lat,...
                p_crkp_Z700hPa_clim_lat_lon,...
                [p_Z700hPa_clim_min:p_Z700hPa_clim_step:p_Z700hPa_clim_max],...
                '-','Color','k','LineWidth',2);
            
            % Plot 700-hPa horizontal wind campaign data as a 
            % green-vectored map
%             p_crkp_crver_wnd700hPa_cpgn = ...
%                 m_quiver(...
%                 repmat(p_wnd700hPa_lon(1:8:end)',ceil(length(p_wnd700hPa_lat)/2),1),...
%                 repmat(p_wnd700hPa_lat(1:2:end),1,ceil(length(p_wnd700hPa_lon)/8)),...
%                 p_crkp_u700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
%                 p_crkp_v700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
%                 1,'Color',[0 .5 0],'LineWidth',1);
%             p_crkp_crver_wnd700hPa_cpgn = ...
%                 m_quiver(...
%                 p_wnd700hPa_lon(1),p_wnd700hPa_lat(1),...
%                 p_crkp_u700hPa_cpgn_lat_lon(1,1),...
%                 p_crkp_v700hPa_cpgn_lat_lon(1,1),...
%                 1,'Color',[0 .5 0],'LineWidth',1);
            [p_crkp_crver_wnd700hPa_cpgn,~] = ...
                m_vec(20,...
                repmat(p_wnd700hPa_lon(1:8:end)',ceil(length(p_wnd700hPa_lat)/2),1),...
                repmat(p_wnd700hPa_lat(1:2:end),1,ceil(length(p_wnd700hPa_lon)/8)),...
                p_crkp_u700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
                p_crkp_v700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
                'centered','yes');
                % Data
            p_crkp_crver_wnd700hPa_scl = ...
                m_vec(20,80,80,10,0,'key','10 m s^{-1}','centered','yes');
                % Scale
            
            % Set plot grid and land contours
            m_grid('XTick',plot_lon_lim(1):15:plot_lon_lim(2),...
                'YTick',plot_lat_lim(1):5:plot_lat_lim(2));
                % Set grid
            m_coast('line','LineWidth',plot_line_width,...
                'color',plot_col_coast-.3);
                % Add land contours as grey-lined coasts
            
            % Map color scheme and bar
            p_crkp_crver_Z700hPa_bar = colorbar; % Get bar handle
            set(gca,'CLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
                'FontSize',plot_size_legend+2)
                % Set bar limits
            colormap(p_Z700hPa_anom_cbar); % Set map colors
            set([p_crkp_crver_wnd700hPa_cpgn,p_crkp_crver_wnd700hPa_scl],...
                'FaceColor',[0 .5 0],'EdgeColor',[0 .5 0])
                % Set arrow colors
            set(p_crkp_crver_Z700hPa_bar,...
                'YLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
                'YTick',...
                p_Z700hPa_anom_min:p_Z700hPa_anom_step:p_Z700hPa_anom_max)
                % Set bar ticks
            if strcmp(p_crver_name,'eps')
                % Hide bar
                colorbar('hide');
            end
            
%             % Plot 700-hPa horizontal wind campaign data scale
%             p_crkp_crver_wnd700hPa_scl = ...
%                  m_vec(100,80,80,50,0,'key','50 m s^{-1}');
%             p_crkp_crver_wnd700hPa_scl.FaceColor = [0 .5 0];
            
            %%% Plot labels %%%
            % Set plot contour labels
            % NB! Setting text properties (name, size and weight) is only
            %     possible without the 'h_crkp_crver_Z700hPa_clim' argument
            % NB! Setting labels manually seemingly the only option if
            %     wanting to increase the label size
            clabel(p_crkp_crver_Z700hPa_clim,h_crkp_crver_Z700hPa_clim,...
                'manual','FontSize',plot_size_legend+2);
%             clabel(p_crkp_crver_Z700hPa_clim,h_crkp_crver_Z700hPa_clim,...
%                 p_Z700hPa_clim_min:p_Z700hPa_clim_step:p_Z700hPa_clim_max,...
%                 'LabelSpacing',150);
%             clabel(p_crkp_crver_Z700hPa_clim,...
%                 'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
%                 'FontWeight',plot_font_weight);
            
%             % Set plot contour and shading labels
%             p_crkp_crver_Z700hPa_lgnd = ...
%                 legend([p_crkp_crver_Z700hPa_anom h_crkp_crver_Z700hPa_clim],...
%                 'Anomaly','Climatology');
%                 % Text
%             set(p_crkp_crver_Z700hPa_lgnd,'FontName',plot_font_name,...
%                 'FontSize',plot_size_legend+2,'FontWeight',plot_font_weight);
%                 % Font

            % Set plot axes labels
            set(findall(gcf,'-property','FontName'),...
                'FontName',plot_font_name)
                % Type
            set(findall(gcf,'-property','FontSize'),...
                'FontSize',plot_size_legend+2)
                % Size
            
            % Set current file version title and color bar labels 
            % properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crkp_crver_ttl = title(p_crkp_fig_title);
                
                % Title label font
                set(p_crkp_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
                
                % Color bar label text
                p_crkp_crver_x = ...
                    xlabel(p_crkp_crver_Z700hPa_bar,...
                    ['Geopoential height [' p_param_unit ']']);
                
                % Color bar label rotation, position, alignment and font
                set(p_crkp_crver_x,'Rotation',0,'Position',...
                    [1.5 p_Z700hPa_anom_min-p_Z700hPa_anom_step/2 0],...
                    'HorizontalAlignment','right',...
                    'VerticalAlignment','middle',...
                    'FontName',plot_font_name,...
                    'FontSize',plot_size_legend+2,...
                    'FontWeight',plot_font_weight)
            end
            
            %%% Save figure %%%
            % Save current parameter current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crver_fig_path p_crkp_fig_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',[p_crver_fig_path p_crkp_fig_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view figure file
                print(gcf,'-dpdf',[p_crver_fig_path p_crkp_fig_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current key period current file version data
            clear p_crkp_crver_* p_crver_*
        end
        
        %%% Delete data %%%
        % Delete current key period data
        clear ver p_crkp_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear kp
end
%%
%%% Plot climatology and anomaly relative to climatology over campaign %%%
%%%         days of 700-hPa virtual potential temperature data         %%%
% Only plot if asked to
if strcmp(plot_typename,'d-clim_anom_700hPa-vpoT') > 0
        % Climatology and anomaly relative to climatology over campaign
        % days of 700-hPa virtual potential temperature
    disp(['plot_ACLOUD_ERA: Climatology and anomaly ' ...
        'relative to climatology over campaign days of ' ...
        '700-hPa virtual potential temperature chosen for plotting'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'d-clim_anom_700hPa-vpoT'));
    
    %%% Parameter settings and data %%%
    % Set plot parameter threshold value for occurance frequency of extreme
    % values
    p_extr_thres = 0.005;
        % 0.005 -> < 0.5 % extreme value occurance
        % 0.01  -> < 1.0 % extreme value occurance
        % 0.05  -> < 5.0 % extreme value occurance
    
    %%% Parameter names, unit and indexes %%%
    % Set parameter MATLAB and full names and unit
    p_param_MATLAB = 'thetav700hPa'; % MATLAB name
    p_param_full = '700-hPa virtual potential temperature'; % Full name
    p_param_unit = 'K'; % Unit
    
    %%% Data set index and name %%%
    % Extract data set name
    p_set_MATLAB = char(mod_name(1+1,3));
    
    % Diplay current parameter plotting choices
    disp(['plot_ACLOUD_ERA: ' ...
        'Plotting ' p_set_MATLAB ' ' p_param_full ...
        ' data over the ' reg_full])
    
    %%% Figure names %%%
    % Set figure path name
    p_fig_path = [path_fig p_param_MATLAB '/'];
    
    %%% Location data %%%
    % Extract 700-hPa virtual potential temperature location data
    p_thetav700hPa_lat = plot_loc(p_type_indx,1).mat; % [deg N]
        % Latitude, [Lat]
    p_thetav700hPa_lon = plot_loc(p_type_indx,2).mat; % [deg E]
        % Longitude, [Lon]
    
    % Adjust 700-hPa virtual potential temperature longitude data in 
    % accordance with plot set-up
    if min(plot_lon_lim) < 0 % Longitudinal format = [-180,180] deg E
        % Longitudinal grid points in Western Hemisphere
        p_thetav700hPa_lon(p_thetav700hPa_lon > 180) = ...
            p_thetav700hPa_lon(p_thetav700hPa_lon > 180) - 360;
            % [deg E], [Lon]
    end
    
    %%% Variable data %%%
    % Extract 700-hPa virtual potential temperature variable data
    % NB! Climatology data are absolute values and thus converted from K to
    %     deg C by subtracting 273.15 K.
    % NB! Campaign anomaly relative to climatology data are relevant values
    %     and thus equal in K and deg C.
    p_thetav700hPa_clim_daymonth_lat_lon = ...
        plot_var(p_type_indx,1).mat - 273.15;
        % [deg C]
        % Climatology
        % Daily averaged per latitude per longitude
        % [Day*Month; Lat; Lon]
    p_thetav700hPa_anom_daymonth_lat_lon = plot_var(p_type_indx,2).mat;
        % [deg C]
        % Campaign anomaly relative to climatology
        % Daily averaged per latitude per longitude
        % [Day*Month; Lat; Lon]
    
    % Calculate 700-hPa virtual potential temperature variable climatology 
    % data extremes using calc_map_extr.m
    [p_thetav700hPa_clim_min,p_thetav700hPa_clim_max,...
        p_thetav700hPa_clim_range,p_thetav700hPa_clim_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'mean',...
        p_thetav700hPa_clim_daymonth_lat_lon,p_extr_thres);
        % [deg C], minimum, maximum, range and steps
    
    % Calculate 700-hPa virtual potential temperature variable campaign 
    % anomaly relative to climatology data extremes using calc_map_extr.m
    [p_thetav700hPa_anom_min,p_thetav700hPa_anom_max,...
        p_thetav700hPa_anom_range,p_thetav700hPa_anom_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'anom',...
        p_thetav700hPa_anom_daymonth_lat_lon,p_extr_thres);
        % [deg C], minimum, maximum, range and steps
    
    % Calculate 700-hPa virtual potential temperature variable campaign 
    % anomaly relative to climatology color bar value steps relative to 
    % default color bar
    p_thetav700hPa_anom_fbar = ...
        p_thetav700hPa_anom_range/p_thetav700hPa_anom_step;
    
    % Adjust 700-hPa virtual potential temperature variable campaign 
    % anomaly relative to climatology variable steps according to color bar
    if p_thetav700hPa_anom_fbar > plot_bar_BR_gno
            % Color bar groups exceeding default color bar groups
        % Round variable step up
        p_thetav700hPa_anom_step = ...
            round((p_thetav700hPa_anom_range/10)*2)/2;
            % [deg C]
        
        % Adjust variable extremes according to variable step
        p_thetav700hPa_anom_min = ...
            floor(p_thetav700hPa_anom_min/p_thetav700hPa_anom_step)*...
            p_thetav700hPa_anom_step;
            % [deg C], minimum
        p_thetav700hPa_anom_max = ...
            ceil(p_thetav700hPa_anom_max/p_thetav700hPa_anom_step)*...
            p_thetav700hPa_anom_step;
            % [deg C], maximum
        p_thetav700hPa_anom_range = ...
            range([p_thetav700hPa_anom_min p_thetav700hPa_anom_max]);
            % [deg C], range
        
        % Adjust color bar step according to variable step
        p_thetav700hPa_anom_fbar = ...
            p_thetav700hPa_anom_range/p_thetav700hPa_anom_step;
    end
    
    % Set 700-hPa virtual potential temperatureanomaly color bar according 
    % to campaign anomaly relative to climatology data extremes
    p_thetav700hPa_anom_cbar = ...
        plot_bar_BR(((plot_bar_BR_gno-p_thetav700hPa_anom_fbar)/2)*plot_bar_BR_gindx+1:...
        end-((plot_bar_BR_gno-p_thetav700hPa_anom_fbar)/2)*plot_bar_BR_gindx,:);
    
    %%% Plot variable color bar %%%
    % Loop over file versions and plot climatology and anomaly relative
    % to climatology key periodic color bar
    for ver = 1:length(plot_ver) % Loop over number of file versions
        %%% File version names %%%
        % Extract current file version and corresponding renderer names
        p_crver_name = char(plot_ver(ver)); % File version
        p_crver_rend = char(plot_rend(ver)); % Renderer
        
        %%% Figure names %%%
        % Set current file version figure path and file names
        p_crver_fig_path = [p_fig_path p_crver_name '/']; % Path
        p_crver_fig_file = ...
            [p_param_MATLAB '_cbar_hor_' reg_abbr '_daymonth_' ...
            p_set_MATLAB];
            % File
        
        %%% Plot set-up and data %%%
        % Set figure number and renderer
        figure(plot_no+1) % Number
        set(gcf,'Renderer',p_crver_rend) % Renderer
        
        % Plot color bar
        p_crver_thetav700hPa_bar = colorbar('SouthOutside'); % Handle
        axis off % Remove axes
        set(gca,'CLim',[p_thetav700hPa_anom_min p_thetav700hPa_anom_max],...
            'FontSize',plot_size_legend+2)
            % Limits
        colormap(p_thetav700hPa_anom_cbar) % Set map colors
        set(p_crver_thetav700hPa_bar,...
            'XLim',[p_thetav700hPa_anom_min p_thetav700hPa_anom_max],...
            'XTick',p_thetav700hPa_anom_min:p_thetav700hPa_anom_step:p_thetav700hPa_anom_max)
            % Ticks
            
        % Add color bar label
        p_crdaymonth_crver_y = ...
            ylabel(p_crver_thetav700hPa_bar,...
            ['Virtual poential temperature [' p_param_unit ']']);
            % Set label text
        set(p_crdaymonth_crver_y,'Rotation',0,...
            'HorizontalAlignment','Center','VerticalAlignment','Top',...
            'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
            'FontWeight',plot_font_weight)
            % Set label rotation, alignment and font
        
        %%% Save figure %%%
        % Save current file version figure
        if strcmp(p_crver_name,'fig') % MATLAB file
            % Save MATLAB figure file
            saveas(gcf,[p_crver_fig_path p_crver_fig_file],'fig')
        elseif strcmp(p_crver_name,'eps') % Article file
            % Save article figure file
            print(gcf,'-depsc',...
                [p_crver_fig_path p_crver_fig_file])
        elseif strcmp(p_crver_name,'pdf') % View file
            % Set file paper properties
            set(gcf,'PaperType',plot_paper_type,...
                'PaperOrientation',plot_paper_orient,...
                'PaperUnits','centimeters',...
                'PaperPosition',plot_paper_pos);
            
            % Save view figure file
            print(gcf,'-dpdf',[p_crver_fig_path p_crver_fig_file])
        end
            
        % Update number of open figures
        p_crver_fig = gcf;
            % Get current file version figure handle
        plot_no = p_crver_fig.Number;
            % Get current file version figure number
        
        %%% Delete data %%%
        % Delete current file version data
        clear p_crver_*
    end
    
    %%% Plot variable data %%%
    % Loop over days and plot climatology and anomaly relative to 
    % climatology daily data
    for d = 1:day_no % Loop over number of time period days
        %%% Key period names %%%
        % Extract current day names
        p_crdaymonth_file = ...
            datestr(datenum(tper_txt(1:11))+d-1,'yyyymmdd');
            % File
        p_crdaymonth_title = datestr(datenum(tper_txt(1:11))+d-1);
            % Title
            
        %%% Figure names %%%
        % Set current day figure file and title names
        p_crdaymonth_fig_file = ...
            [p_param_MATLAB '_' reg_abbr '_' p_crdaymonth_file '_' ...
            p_set_MATLAB];
            % File
        p_crdaymonth_fig_title = ...
            [p_param_full ' during ' p_crdaymonth_title ' over the ' ...
            reg_full ' from ' p_set_MATLAB];
            % Title
            
        %%% Variable data %%%
        % Extract current day 700-hPa virtual potential temperature 
        % variable data
        p_crdaymonth_thetav700hPa_clim_lat_lon = ...
            squeeze(p_thetav700hPa_clim_daymonth_lat_lon(d,:,:));
            % [deg C], climatology, [Lat; Lon]
        p_crdaymonth_thetav700hPa_anom_lat_lon = ...
            squeeze(p_thetav700hPa_anom_daymonth_lat_lon(d,:,:));
            % [deg C], campaign anomaly relative to climatology, [Lat; Lon]
        
        %%% Plot variable data %%%
        % Loop over file versions and plot climatology and anomaly relative
        % to climatology daily data
        for ver = 1%:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
%             p_crver_name = char(plot_ver(ver)); % File version
            p_crver_name = 'png'; % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current file version figure path name
            p_crver_fig_path = [p_fig_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
            % Set plot projection
            m_proj(plot_proj_name,'long',plot_lon_lim,'lat',plot_lat_lim);
            
            % Plot 700-hPa virtual potential temperature campaign anomaly 
            % relative to climatology data as a blue-white-red-shaded map
            p_crdaymonth_crver_thetav700hPa_anom = ...
                m_pcolor(p_thetav700hPa_lon,p_thetav700hPa_lat,...
                p_crdaymonth_thetav700hPa_anom_lat_lon);
                % Data
            set(p_crdaymonth_crver_thetav700hPa_anom,'LineStyle','none');
                % Set no data boundaries
            
            % Plot 700-hPa virtual potential temperature climatology data 
            % as a black-contoured map
            [p_crdaymonth_crver_thetav700hPa_clim,...
                h_crdaymonth_crver_thetav700hPa_clim] = ...
                m_contour(p_thetav700hPa_lon,p_thetav700hPa_lat,...
                p_crdaymonth_thetav700hPa_clim_lat_lon,...
                [p_thetav700hPa_clim_min:2*p_thetav700hPa_clim_step:p_thetav700hPa_clim_max],...
                '-','Color','k','LineWidth',2);
            
            % Set plot grid and land contours
            m_grid('XTick',plot_lon_lim(1):15:plot_lon_lim(2),...
                'YTick',plot_lat_lim(1):5:plot_lat_lim(2));
                % Set grid
            m_coast('line','LineWidth',plot_line_width,...
                'color',plot_col_coast-.3);
                % Add land contours as grey-lined coasts
            
            % Map color scheme and bar
            p_crdaymonth_crver_thetav700hPa_bar = colorbar;
                % Get bar handle
            set(gca,...
                'CLim',...
                [p_thetav700hPa_anom_min p_thetav700hPa_anom_max],...
                'FontSize',plot_size_legend+2)
                % Set bar limits
            colormap(p_thetav700hPa_anom_cbar); % Set map colors
            set(p_crdaymonth_crver_thetav700hPa_bar,...
                'YLim',...
                [p_thetav700hPa_anom_min p_thetav700hPa_anom_max],...
                'YTick',...
                p_thetav700hPa_anom_min:p_thetav700hPa_anom_step:p_thetav700hPa_anom_max)
                % Set bar ticks
            if strcmp(p_crver_name,'eps')
                % Hide bar
                colorbar('hide');
            end
            
            %%% Plot labels %%%
            % Set plot contour labels
            % NB! Setting text properties (name, size and weight) is only
            %     possible without the 'h_crkp_crver_thetav700hPa_clim' 
            %     argument
            clabel(p_crdaymonth_crver_thetav700hPa_clim,...
                h_crdaymonth_crver_thetav700hPa_clim,...
                p_thetav700hPa_clim_min:p_thetav700hPa_clim_step:p_thetav700hPa_clim_max,...
                'LabelSpacing',150);
            
            % Set current file version title and color bar labels 
            % properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crdaymonth_crver_ttl = title(p_crdaymonth_fig_title);
                
                % Title label font
                set(p_crdaymonth_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
            
                % Color bar label text
                p_crdaymonth_crver_x = ...
                    xlabel(p_crdaymonth_crver_thetav700hPa_bar,p_param_unit);
                
                % Color bar label rotation, position, alignment and font
                set(p_crdaymonth_crver_x,'Rotation',0,'Position',...
                    [1.5 p_thetav700hPa_anom_min-p_thetav700hPa_anom_step/2 0],...
                    'HorizontalAlignment','right',...
                    'VerticalAlignment','middle',...
                    'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
                    'FontWeight',plot_font_weight)
            elseif strcmp(p_crver_name,'png') % Graphic file
                % Title label text
                p_crdaymonth_crver_ttl = ...
                    title({'700 hPa virtual potential temperature'; ...
                    '(contours = 1979-2016, shading = 2017 minus 1979-2016):'; ...
                    p_crdaymonth_title});
                
                % Title label position
                p_crdaymonth_crver_ttl_pos = ...
                    get(p_crdaymonth_crver_ttl,'Position');
                    % Get
                set(p_crdaymonth_crver_ttl,'Position',...
                    [p_crdaymonth_crver_ttl_pos(1) ...
                    p_crdaymonth_crver_ttl_pos(2)+0.03 ...
                    p_crdaymonth_crver_ttl_pos(3)])
                    % Set
                
                % Title label font
                set(p_crdaymonth_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label,...
                    'FontWeight',plot_font_weight)
            
                % Color bar label text
                p_crdaymonth_crver_x = ...
                    xlabel(p_crdaymonth_crver_thetav700hPa_bar,...
                    {'Virtual potential'; ...
                    ['temperature [' p_param_unit ']']});
                
                % Color bar label rotation, position, alignment and font
                set(p_crdaymonth_crver_x,'Rotation',0,'Position',...
                    [1.5 p_thetav700hPa_anom_min-p_thetav700hPa_anom_step/2 0],...
                    'HorizontalAlignment','right',...
                    'VerticalAlignment','top',...
                    'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
                    'FontWeight',plot_font_weight)
            end
            
            %%% Save figure %%%
            % Save current parameter current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crver_fig_path p_crdaymonth_fig_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',...
                    [p_crver_fig_path p_crdaymonth_fig_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view figure file
                print(gcf,'-dpdf',[p_crver_fig_path p_crdaymonth_fig_file])
            elseif strcmp(p_crver_name,'png') % Graphic file
                % Save view figure file
                pause(1)
                print(gcf,'-dpng',[p_crver_fig_path p_crdaymonth_fig_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current day current file version data
            clear p_crdaymonth_crver_* h_crdaymonth_crver_* p_crver_*
        end
        
        %%% Delete data %%%
        % Delete current day data
        clear ver p_crdaymonth_* h_crdaymonth_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear d
end
%%
%%% Plot climatology and anomaly relative to climatology over campaign %%%
%%%     key periods of 700-hPa virtual potential temperature data      %%%
% Only plot if asked to
if strcmp(plot_typename,'kp-clim_anom_700hPa-vpoT') > 0
        % Climatology and anomaly relative to climatology over campaign
        % key periods of 700-hPa virtual potential temperature
    disp(['plot_ACLOUD_ERA: Climatology and anomaly ' ...
        'relative to climatology over campaign key periods of ' ...
        '700-hPa virtual potential temperature chosen for plotting'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'kp-clim_anom_700hPa-vpoT'));
    
    %%% Parameter settings and data %%%
    % Set plot parameter threshold value for occurance frequency of extreme
    % values
    p_extr_thres = 0.005;
        % 0.005 -> < 0.5 % extreme value occurance
        % 0.01  -> < 1.0 % extreme value occurance
        % 0.05  -> < 5.0 % extreme value occurance
    
    %%% Parameter names, unit and indexes %%%
    % Set parameter MATLAB and full names and unit
    p_param_MATLAB = 'thetav700hPa'; % MATLAB name
    p_param_full = '700-hPa virtual potential temperature'; % Full name
    p_param_unit = 'K'; % Unit
    
    %%% Data set index and name %%%
    % Extract data set name
    p_set_MATLAB = char(mod_name(1+1,3));
    
    % Diplay current parameter plotting choices
    disp(['plot_ACLOUD_ERA: ' ...
        'Plotting ' p_set_MATLAB ' ' p_param_full ...
        ' data over the ' reg_full])
    
    %%% Figure names %%%
    % Set figure path name
    p_fig_path = [path_fig p_param_MATLAB '/'];
    
    %%% Location data %%%
    % Extract 700-hPa virtual potential temperature location data
    p_thetav700hPa_lat = plot_loc(p_type_indx,1).mat; % [deg N]
        % Latitude, [Lat]
    p_thetav700hPa_lon = plot_loc(p_type_indx,2).mat; % [deg E]
        % Longitude, [Lon]
    
    % Adjust 700-hPa virtual potential temperature longitude data in 
    % accordance with plot set-up
    if min(plot_lon_lim) < 0 % Longitudinal format = [-180,180] deg E
        % Longitudinal grid points in Western Hemisphere
        p_thetav700hPa_lon(p_thetav700hPa_lon > 180) = ...
            p_thetav700hPa_lon(p_thetav700hPa_lon > 180) - 360;
            % [deg E], [Lon]
    end
    
    %%% Variable data %%%
    % Extract 700-hPa virtual potential temperature variable data
    % NB! Climatology data are absolute values and thus converted from K to
    %     deg C by subtracting 273.15 K.
    % NB! Campaign anomaly relative to climatology data are relevant values
    %     and thus equal in K and deg C.
    p_thetav700hPa_clim_kp_lat_lon = plot_var(p_type_indx,1).mat - 273.15;
        % [deg C]
        % Climatology
        % Key periodic averaged per latitude per longitude
        % [Kp; Lat; Lon]
    p_thetav700hPa_anom_kp_lat_lon = plot_var(p_type_indx,2).mat;
        % [deg C]
        % Campaign anomaly relative to climatology
        % Key periodic averaged per latitude per longitude
        % [Kp; Lat; Lon]
    
    % Calculate 700-hPa virtual potential temperature variable climatology 
    % data extremes using calc_map_extr.m
    [p_thetav700hPa_clim_min,p_thetav700hPa_clim_max,...
        p_thetav700hPa_clim_range,p_thetav700hPa_clim_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'mean',...
        p_thetav700hPa_clim_kp_lat_lon,p_extr_thres);
        % [deg C], minimum, maximum, range and steps
    
    % Calculate 700-hPa virtual potential temperature variable campaign 
    % anomaly relative to climatology data extremes using calc_map_extr.m
    [p_thetav700hPa_anom_min,p_thetav700hPa_anom_max,...
        p_thetav700hPa_anom_range,p_thetav700hPa_anom_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'anom',...
        p_thetav700hPa_anom_kp_lat_lon,p_extr_thres);
        % [deg C], minimum, maximum, range and steps
    
    % Calculate 700-hPa virtual potential temperature variable campaign 
    % anomaly relative to climatology color bar value steps relative to 
    % default color bar
    p_thetav700hPa_anom_fbar = ...
        p_thetav700hPa_anom_range/p_thetav700hPa_anom_step;
    
    % Adjust 700-hPa virtual potential temperature variable campaign 
    % anomaly relative to climatology variable steps according to color bar
    if p_thetav700hPa_anom_fbar > plot_bar_BR_gno
            % Color bar groups exceeding default color bar groups
        % Round variable step up
        p_thetav700hPa_anom_step = ...
            round((p_thetav700hPa_anom_range/10)*2)/2;
            % [deg C]
        
        % Adjust variable extremes according to variable step
        p_thetav700hPa_anom_min = ...
            floor(p_thetav700hPa_anom_min/p_thetav700hPa_anom_step)*...
            p_thetav700hPa_anom_step;
            % [deg C], minimum
        p_thetav700hPa_anom_max = ...
            ceil(p_thetav700hPa_anom_max/p_thetav700hPa_anom_step)*...
            p_thetav700hPa_anom_step;
            % [deg C], maximum
        p_thetav700hPa_anom_range = ...
            range([p_thetav700hPa_anom_min p_thetav700hPa_anom_max]);
            % [deg C], range
        
        % Adjust color bar step according to variable step
        p_thetav700hPa_anom_fbar = ...
            p_thetav700hPa_anom_range/p_thetav700hPa_anom_step;
    end
    
    % Set 700-hPa virtual potential temperatureanomaly color bar according 
    % to campaign anomaly relative to climatology data extremes
    p_thetav700hPa_anom_cbar = ...
        plot_bar_BR(((plot_bar_BR_gno-p_thetav700hPa_anom_fbar)/2)*plot_bar_BR_gindx+1:...
        end-((plot_bar_BR_gno-p_thetav700hPa_anom_fbar)/2)*plot_bar_BR_gindx,:);
    
    %%% Plot variable color bar %%%
    % Loop over file versions and plot climatology and anomaly relative
    % to climatology key periodic color bar
    for ver = 1:length(plot_ver) % Loop over number of file versions
        %%% File version names %%%
        % Extract current file version and corresponding renderer names
        p_crver_name = char(plot_ver(ver)); % File version
        p_crver_rend = char(plot_rend(ver)); % Renderer
        
        %%% Figure names %%%
        % Set current file version figure path and file names
        p_crver_fig_path = [p_fig_path p_crver_name '/']; % Path
        p_crver_fig_file = ...
            [p_param_MATLAB '_cbar_hor_' reg_abbr '_kp_' ...
            p_set_MATLAB];
            % File
        
        %%% Plot set-up and data %%%
        % Set figure number and renderer
        figure(plot_no+1) % Number
        set(gcf,'Renderer',p_crver_rend) % Renderer
        
        % Plot color bar
        p_crver_thetav700hPa_bar = colorbar('SouthOutside'); % Handle
        axis off % Remove axes
        set(gca,'CLim',[p_thetav700hPa_anom_min p_thetav700hPa_anom_max],...
            'FontSize',plot_size_legend+2)
            % Limits
        colormap(p_thetav700hPa_anom_cbar) % Set map colors
        set(p_crver_thetav700hPa_bar,...
            'XLim',[p_thetav700hPa_anom_min p_thetav700hPa_anom_max],...
            'XTick',p_thetav700hPa_anom_min:p_thetav700hPa_anom_step:p_thetav700hPa_anom_max)
            % Ticks
            
        % Add color bar label
        p_crdaymonth_crver_y = ...
            ylabel(p_crver_thetav700hPa_bar,...
            ['Virtual potential temperature [' p_param_unit ']']);
            % Set label text
        set(p_crdaymonth_crver_y,'Rotation',0,...
            'HorizontalAlignment','Center','VerticalAlignment','Top',...
            'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
            'FontWeight',plot_font_weight)
            % Set label rotation, alignment and font
        
        %%% Save figure %%%
        % Save current file version figure
        if strcmp(p_crver_name,'fig') % MATLAB file
            % Save MATLAB figure file
            saveas(gcf,[p_crver_fig_path p_crver_fig_file],'fig')
        elseif strcmp(p_crver_name,'eps') % Article file
            % Save article figure file
            print(gcf,'-depsc',...
                [p_crver_fig_path p_crver_fig_file])
        elseif strcmp(p_crver_name,'pdf') % View file
            % Set file paper properties
            set(gcf,'PaperType',plot_paper_type,...
                'PaperOrientation',plot_paper_orient,...
                'PaperUnits','centimeters',...
                'PaperPosition',plot_paper_pos);
            
            % Save view figure file
            print(gcf,'-dpdf',[p_crver_fig_path p_crver_fig_file])
        end
            
        % Update number of open figures
        p_crver_fig = gcf;
            % Get current file version figure handle
        plot_no = p_crver_fig.Number;
            % Get current file version figure number
        
        %%% Delete data %%%
        % Delete current file version data
        clear p_crver_*
    end
    
    %%% Plot variable data %%%
    % Loop over key periods and plot climatology and anomaly relative to 
    % climatology key periodic data
    for kp = 1:kper_no % Loop over number of key periods
        %%% Key period names %%%
        % Extract current key period names
        p_crkp_file = kper_num(kp,:); % File
        p_crkp_title = kper_txt(kp,:); % Title
            
        %%% Figure names %%%
        % Set current key period figure file and title names
        p_crkp_fig_file = ...
            [p_param_MATLAB '_' reg_abbr '_' p_crkp_file '_' p_set_MATLAB];
            % File
        p_crkp_fig_title = ...
            [p_param_full ' during ' p_crkp_title ' over the ' reg_full ...
            ' from ' p_set_MATLAB];
            % Title
            
        %%% Variable data %%%
        % Extract current key period 700-hPa virtual potential temperature 
        % variable data
        p_crkp_thetav700hPa_clim_lat_lon = ...
            squeeze(p_thetav700hPa_clim_kp_lat_lon(kp,:,:));
            % [deg C], climatology, [Lat; Lon]
        p_crkp_thetav700hPa_anom_lat_lon = ...
            squeeze(p_thetav700hPa_anom_kp_lat_lon(kp,:,:));
            % [deg C], campaign anomaly relative to climatology, [Lat; Lon]
        
        %%% Plot variable data %%%
        % Loop over file versions and plot climatology and anomaly relative
        % to climatology key periodic data
        for ver = 1:length(plot_ver) % Loop over number of file versions
            %%% File version names %%%
            % Extract current file version and corresponding renderer names
            p_crver_name = char(plot_ver(ver)); % File version
            p_crver_rend = char(plot_rend(ver)); % Renderer
            
            %%% Figure names %%%
            % Set current file version figure path name
            p_crver_fig_path = [p_fig_path p_crver_name '/'];
            
            %%% Plot set-up and data %%%
            % Set figure number and renderer
            figure(plot_no+1) % Number
            set(gcf,'Renderer',p_crver_rend) % Renderer
            hold on % Hold figure open for several plots
            
            % Set plot projection
            m_proj(plot_proj_name,'long',plot_lon_lim,'lat',plot_lat_lim);
            
            % Plot 700-hPa virtual potential temperature campaign anomaly 
            % relative to climatology data as a blue-white-red-shaded map
            p_crkp_crver_thetav700hPa_anom = ...
                m_pcolor(p_thetav700hPa_lon,p_thetav700hPa_lat,...
                p_crkp_thetav700hPa_anom_lat_lon);
                % Data
            set(p_crkp_crver_thetav700hPa_anom,'LineStyle','none');
                % Set no data boundaries
            
            % Plot 700-hPa virtual potential temperature climatology data 
            % as a black-contoured map
            [p_crkp_crver_thetav700hPa_clim,h_crkp_crver_thetav700hPa_clim] = ...
                m_contour(p_thetav700hPa_lon,p_thetav700hPa_lat,...
                p_crkp_thetav700hPa_clim_lat_lon,...
                [p_thetav700hPa_clim_min:2*p_thetav700hPa_clim_step:p_thetav700hPa_clim_max],...
                '-','Color','k','LineWidth',2);
            
            % Set plot grid and land contours
            m_grid('XTick',plot_lon_lim(1):15:plot_lon_lim(2),...
                'YTick',plot_lat_lim(1):5:plot_lat_lim(2));
                % Set grid
            m_coast('line','LineWidth',plot_line_width,...
                'color',plot_col_coast-.3);
                % Add land contours as grey-lined coasts
            
            % Map color scheme and bar
            p_crkp_crver_thetav700hPa_bar = colorbar; % Get bar handle
            set(gca,...
                'CLim',...
                [p_thetav700hPa_anom_min p_thetav700hPa_anom_max],...
                'FontSize',plot_size_legend+2)
                % Set bar limits
            colormap(p_thetav700hPa_anom_cbar); % Set map colors
            set(p_crkp_crver_thetav700hPa_bar,...
                'YLim',...
                [p_thetav700hPa_anom_min p_thetav700hPa_anom_max],...
                'YTick',...
                p_thetav700hPa_anom_min:p_thetav700hPa_anom_step:p_thetav700hPa_anom_max)
                % Set bar ticks
            if strcmp(p_crver_name,'eps')
                % Hide bar
                colorbar('hide');
            end
            
            %%% Plot labels %%%
            % Set plot contour labels
            % NB! Setting text properties (name, size and weight) is only
            %     possible without the 'h_crkp_crver_thetav700hPa_clim' 
            %     argument
            % NB! Setting labels manually seemingly the only option if
            %     wanting to increase the label size
            clabel(p_crkp_crver_thetav700hPa_clim,...
                h_crkp_crver_thetav700hPa_clim,...
                'manual','FontSize',plot_size_legend+2);
%             clabel(p_crkp_crver_thetav700hPa_clim,h_crkp_crver_thetav700hPa_clim,...
%                 p_thetav700hPa_clim_min:p_thetav700hPa_clim_step:p_thetav700hPa_clim_max,...
%                 'LabelSpacing',100);
            
%             % Set plot contour and shading labels
%             p_crkp_crver_thetav700hPa_lgnd = ...
%                 legend([p_crkp_crver_thetav700hPa_anom h_crkp_crver_thetav700hPa_clim],...
%                 'Anomaly','Climatology');
%                 % Text
%             set(p_crkp_crver_thetav700hPa_lgnd,'FontName',plot_font_name,...
%                 'FontSize',plot_size_legend,'FontWeight',plot_font_weight);
%                 % Font
            
            % Set plot axes labels
            set(findall(gcf,'-property','FontName'),...
                'FontName',plot_font_name)
                % Type
            set(findall(gcf,'-property','FontSize'),...
                'FontSize',plot_size_legend+2)
                % Size
            
            % Set current file version title and color bar labels 
            % properties
            if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                    % MATLAB or view file
                % Title label text
                p_crkp_crver_ttl = title(p_crkp_fig_title);
                
                % Title label font
                set(p_crkp_crver_ttl,'FontName',plot_font_name,...
                    'FontSize',plot_size_label+4,...
                    'FontWeight',plot_font_weight)
                
                % Color bar label text
                p_crkp_crver_x = ...
                    xlabel(p_crkp_crver_thetav700hPa_bar,...
                    ['Virtual potential temperature [' p_param_unit ']']);
                
                % Color bar label rotation, position, alignment and font
                set(p_crkp_crver_x,'Rotation',0,'Position',...
                    [1.5 p_thetav700hPa_anom_min-p_thetav700hPa_anom_step/2 0],...
                    'HorizontalAlignment','right',...
                    'VerticalAlignment','middle',...
                    'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
                    'FontWeight',plot_font_weight)
            end
            
            %%% Save figure %%%
            % Save current parameter current file version figure
            if strcmp(p_crver_name,'fig') % MATLAB file
                % Save MATLAB figure file
                saveas(gcf,[p_crver_fig_path p_crkp_fig_file],'fig')
            elseif strcmp(p_crver_name,'eps') % Article file
                % Save article figure file
                print(gcf,'-depsc',[p_crver_fig_path p_crkp_fig_file])
            elseif strcmp(p_crver_name,'pdf') % View file
                % Set file paper properties
                set(gcf,'PaperType',plot_paper_type,...
                    'PaperOrientation',plot_paper_orient,...
                    'PaperUnits','centimeters',...
                    'PaperPosition',plot_paper_pos);
                
                % Save view figure file
                print(gcf,'-dpdf',[p_crver_fig_path p_crkp_fig_file])
            end
            
            % Update number of open figures
            p_crver_fig = gcf;
                % Get current file version figure handle
            plot_no = p_crver_fig.Number;
                % Get current file version figure number
            
            %%% Delete data %%%
            % Delete current key period current file version data
            clear p_crkp_crver_* h_crkp_crver_* p_crver_*
        end
        
        %%% Delete data %%%
        % Delete current key period data
        clear ver p_crkp_* h_crkp_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear kp
end
%%
%%% Plot climatology and anomaly relative to climatology  %%%
%%% over campaign time period of 700-hPa circulation data %%%
% Only plot if asked to
if strcmp(plot_typename,'tp-clim_anom_700hPa-circ') > 0
        % Climatology and anomaly relative to climatology over campaign
        % time period of 700-hPa circulation
    disp(['plot_ACLOUD_ERA: Climatology and anomaly ' ...
        'relative to climatology over campaign time period of ' ...
        '700-hPa circulation chosen for plotting'])
    
    %%% Plot type index %%%
    p_type_indx = find(strcmp(plot_typename,'tp-clim_anom_700hPa-circ'));
    
    %%% Parameter settings and data %%%
    % Set plot parameter threshold value for occurance frequency of extreme
    % values
    p_extr_thres = 0.005;
        % 0.005 -> < 0.5 % extreme value occurance
        % 0.01  -> < 1.0 % extreme value occurance
        % 0.05  -> < 5.0 % extreme value occurance
    
    %%% Parameter names, unit and indexes %%%
    % Extract parameter MATLAB and full names and unit
    p_param_MATLAB = 'Z700hPa-u700hPa-v700hPa';
        % MATLAB name
    p_param_full = '700-hPa geopotential height with horizontal wind';
        % Full name
    p_param_unit = char(plot_varname(p_type_indx+1,3));
        % Unit
    
    %%% Data set index and name %%%
    % Extract current parameter data set name
    p_set_MATLAB = char(mod_name(1+1,3));
    
    % Diplay current parameter plotting choices
    disp(['plot_ACLOUD_ERA: ' ...
        'Plotting ' p_set_MATLAB ' ' lower(p_param_full) ...
        ' data over the ' reg_full])
    
    %%% Figure names %%%
    % Set current parameter figure path, file and title names
    p_fig_path = [path_fig p_param_MATLAB '/'];
        % Path
    p_fig_file = ...
        [p_param_MATLAB '_' reg_abbr '_' ...
        month_abbr '_' yr_cpgn_name '_' p_set_MATLAB];
        % File
    p_fig_title = ...
        [p_param_full ' during ACLOUD over the ' reg_full ...
        ' from ' p_set_MATLAB];
        % Title
    
    %%% Location data %%%
    % Extract 700-hPa geopotential height location data
    p_Z700hPa_lat = plot_loc(p_type_indx,1).mat; % [deg N]
        % Latitude, [Lat]
    p_Z700hPa_lon = plot_loc(p_type_indx,2).mat; % [deg E]
        % Longitude, [Lon]
        
    % Extract 700-hPa zonal wind location data
    p_u700hPa_lat = plot_loc(p_type_indx,3).mat; % [deg N]
        % Latitude, [Lat]
    p_u700hPa_lon = plot_loc(p_type_indx,4).mat; % [deg E]
        % Longitude, [Lon]
        
    % Extract 700-hPa meridional wind location data
    p_v700hPa_lat = plot_loc(p_type_indx,5).mat; % [deg N]
        % Latitude, [Lat]
    p_v700hPa_lon = plot_loc(p_type_indx,6).mat; % [deg E]
        % Longitude, [Lon]
    
    % Adjust 700-hPa geopotential height, zonal and meridional wind 
    % longitude data in accordance with plot set-up
    if min(plot_lon_lim) < 0 % Longitudinal format = [-180,180] deg E
        % Longitudinal grid points in Western Hemisphere
        p_Z700hPa_lon(p_Z700hPa_lon > 180) = ...
            p_Z700hPa_lon(p_Z700hPa_lon > 180) - 360;
            % [deg E], geopotential height, [Lon]
        p_u700hPa_lon(p_u700hPa_lon > 180) = ...
            p_u700hPa_lon(p_u700hPa_lon > 180) - 360;
            % [deg E], zonal wind, [Lon]
        p_v700hPa_lon(p_v700hPa_lon > 180) = ...
            p_v700hPa_lon(p_v700hPa_lon > 180) - 360;
            % [deg E], meridional wind, [Lon]
    end
    
    % Merge 700-hPa zonal and meridional wind location data
    if isequal(p_u700hPa_lat,p_v700hPa_lat) && ...
            isequal(p_u700hPa_lon,p_v700hPa_lon)
            % Latitudinal and longitudinal grid point vectors equal
        % Set 700-hPa horizontal wind location data to 700-hPa zonal wind 
        % location data
        % NB! Latitudinal and longitudinal grid point vectors of 700-hPa
        %     zonal and meridional wind are equal
        p_wnd700hPa_lat = p_u700hPa_lat; % [deg N], latitude, [Lat]
        p_wnd700hPa_lon = p_u700hPa_lon; % [deg E], longitude, [Lon]
    end
    
    %%% Variable data %%%
    % Extract 700-hPa geopotential height variable data
    p_Z700hPa_clim_lat_lon = plot_var(p_type_indx,1).mat; % [m]
        % Climatology
        % Time periodic averaged per latitude per longitude
        % [Lat; Lon]
    p_Z700hPa_anom_lat_lon = plot_var(p_type_indx,2).mat; % [m]
        % Campaign anomaly relative to climatology
        % Time periodic averaged per latitude per longitude
        % [Lat; Lon]
        
    % Extract 700-hPa zonal wind variable data
    p_u700hPa_cpgn_lat_lon = plot_var(p_type_indx,3).mat; % [m/s]
        % Campaign
        % Time periodic averaged per latitude per longitude
        % [Lat; Lon]
        
    % Extract 700-hPa meridional wind variable data
    p_v700hPa_cpgn_lat_lon = plot_var(p_type_indx,4).mat; % [m/s]
        % Campaign
        % Time periodic averaged per latitude per longitude
        % [Lat; Lon]
    
    % Calculate 700-hPa geopotential height variable climatology data 
    % extremes using calc_map_extr.m
    [p_Z700hPa_clim_min,p_Z700hPa_clim_max,...
        p_Z700hPa_clim_range,p_Z700hPa_clim_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'mean',...
        p_Z700hPa_clim_lat_lon,p_extr_thres);
        % [m], minimum, maximum, range and steps
    
    % Calculate 700-hPa geopotential height variable campaign anomaly 
    % relative to climatology data extremes using calc_map_extr.m
    [p_Z700hPa_anom_min,p_Z700hPa_anom_max,...
        p_Z700hPa_anom_range,p_Z700hPa_anom_step,~,~] = ...
        calc_map_extr(plot_bar_BR_sgnno,plot_bar_BR,'anom',...
        p_Z700hPa_anom_lat_lon,p_extr_thres);
        % [m], minimum, maximum, range and steps
    
    % Calculate 700-hPa geopotential height variable campaign anomaly 
    % relative to climatology color bar value steps relative to default 
    % color bar
    p_Z700hPa_anom_fbar = p_Z700hPa_anom_range/p_Z700hPa_anom_step;
    
    % Adjust 700-hPa geopotential height variable campaign anomaly relative
    % to climatology variable steps according to color bar
    if p_Z700hPa_anom_fbar > plot_bar_BR_gno
            % Color bar groups exceeding default color bar groups
        % Round variable step up
        p_Z700hPa_anom_step = round((p_Z700hPa_anom_range/10)*2)/2; % [m]
        
        % Adjust variable extremes according to variable step
        p_Z700hPa_anom_min = ...
            floor(p_Z700hPa_anom_min/p_Z700hPa_anom_step)*...
            p_Z700hPa_anom_step;
            % [m], minimum
        p_Z700hPa_anom_max = ...
            ceil(p_Z700hPa_anom_max/p_Z700hPa_anom_step)*...
            p_Z700hPa_anom_step;
            % [m], maximum
        p_Z700hPa_anom_range = ...
            range([p_Z700hPa_anom_min p_Z700hPa_anom_max]);
            % [m], range
        
        % Adjust color bar step according to variable step
        p_Z700hPa_anom_fbar = p_Z700hPa_anom_range/p_Z700hPa_anom_step;
    end
    
    % Set 700-hPa geopotential heightanomaly color bar according to 
    % campaign anomaly relative to climatology data extremes
    p_Z700hPa_anom_cbar = ...
        plot_bar_BR(((plot_bar_BR_gno-p_Z700hPa_anom_fbar)/2)*plot_bar_BR_gindx+1:...
        end-((plot_bar_BR_gno-p_Z700hPa_anom_fbar)/2)*plot_bar_BR_gindx,:);
    
    %%% Plot variable data %%%
    % Loop over file versions and plot climatology and anomaly relative to 
    % climatology time periodic data
    for ver = 1:length(plot_ver) % Loop over number of file versions
        %%% File version names %%%
        % Extract current file version and corresponding renderer names
        p_crver_name = char(plot_ver(ver)); % File version
        p_crver_rend = char(plot_rend(ver)); % Renderer
        
        %%% Figure names %%%
        % Set current file version figure path name
        p_crver_fig_path = [p_fig_path p_crver_name '/'];
        
        %%% Plot set-up and data %%%
        % Set figure number and renderer
        figure(plot_no+1) % Number
        set(gcf,'Renderer',p_crver_rend) % Renderer
        hold on % Hold figure open for several plots
        
        % Set plot projection
        m_proj(plot_proj_name,'long',plot_lon_lim,'lat',plot_lat_lim);
        
        % Plot 700-hPa geopotential height campaign anomaly relative to
        % climatology data as a blue-white-red-shaded map
        p_crver_Z700hPa_anom = ...
            m_pcolor(p_Z700hPa_lon,p_Z700hPa_lat,p_Z700hPa_anom_lat_lon);
            % Data
        set(p_crver_Z700hPa_anom,'LineStyle','none');
            % Set no data boundaries
        
        % Plot 700-hPa geopotential height climatology data as a
        % black-contoured map
        [p_crver_Z700hPa_clim,h_crver_Z700hPa_clim] = ...
            m_contour(p_Z700hPa_lon,p_Z700hPa_lat,...
            p_Z700hPa_clim_lat_lon,...
            [p_Z700hPa_clim_min:p_Z700hPa_clim_step:p_Z700hPa_clim_max],...
            '-','Color','k','LineWidth',2);
        
        % Plot 700-hPa horizontal wind campaign data as a green-vectored 
        % map
        p_crver_u700hPa_v700hPa_cpgn = ...
            m_quiver(...
            repmat(p_wnd700hPa_lon(1:8:end)',ceil(length(p_wnd700hPa_lat)/2),1),...
            repmat(p_wnd700hPa_lat(1:2:end),1,ceil(length(p_wnd700hPa_lon)/8)),...
            p_u700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
            p_v700hPa_cpgn_lat_lon(1:2:end,1:8:end),...
            1,'Color',[0 .5 0],'LineWidth',1);
        
        % Set plot grid and land contours
        m_grid('XTick',plot_lon_lim(1):15:plot_lon_lim(2),...
                'YTick',plot_lat_lim(1):5:plot_lat_lim(2));
            % Set grid
        m_coast('line','LineWidth',plot_line_width,...
            'color',plot_col_coast-.3);
            % Add land contours as grey-lined coasts
        
        % Map color scheme and bar
        p_crver_Z700hPa_bar = colorbar; % Handle
        set(gca,'CLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
            'FontSize',plot_size_legend)
            % Limits
        colormap(p_Z700hPa_anom_cbar); % Set map colors
        set(p_crver_Z700hPa_bar,...
            'YLim',[p_Z700hPa_anom_min p_Z700hPa_anom_max],...
            'YTick',...
            p_Z700hPa_anom_min:p_Z700hPa_anom_step:p_Z700hPa_anom_max)
            % Ticks
        
        %%% Plot labels %%%
        % Set plot contour labels
        % NB! Setting text properties (name, size and weight) is only
        %     possible without the 'h_crver_Z700hPa_clim' argument
        clabel(p_crver_Z700hPa_clim,h_crver_Z700hPa_clim,...
            p_Z700hPa_clim_min:p_Z700hPa_clim_step:p_Z700hPa_clim_max,...
            'LabelSpacing',100);
        
        % Set plot contour and shading labels
        p_crver_Z700hPa_lgnd = ...
            legend([p_crver_Z700hPa_anom h_crver_Z700hPa_clim],...
            'Anomaly','Climatology');
            % Text
        set(p_crver_Z700hPa_lgnd,'FontName',plot_font_name,...
            'FontSize',plot_size_legend,'FontWeight',plot_font_weight);
            % Font
        
        % Set current file version title and color bar labels properties
        if strcmp(p_crver_name,'fig') || strcmp(p_crver_name,'pdf')
                % MATLAB or view file
            % Title label text
            p_crver_ttl = title(p_fig_title);
            
            % Title label font
            set(p_crver_ttl,'FontName',plot_font_name,...
                'FontSize',plot_size_label+4,'FontWeight',plot_font_weight)
        end
        p_crver_x = xlabel(p_crver_Z700hPa_bar,p_param_unit);
            % Color bar label text
        set(p_crver_x,'Rotation',0,'Position',...
            [1.5 p_Z700hPa_anom_min-p_Z700hPa_anom_step/2 0],...
            'HorizontalAlignment','right',...
            'VerticalAlignment','middle',...
            'FontName',plot_font_name,'FontSize',plot_size_legend+2,...
            'FontWeight',plot_font_weight)
            % Color bar label rotation, position, alignment and font
        
        %%% Save figure %%%
        % Save current parameter current file version figure
        if strcmp(p_crver_name,'fig') % MATLAB file
            % Save MATLAB figure file
            saveas(gcf,[p_crver_fig_path p_fig_file],'fig')
        elseif strcmp(p_crver_name,'eps') % Article file
            % Save article figure file
            print(gcf,'-depsc',[p_crver_fig_path p_fig_file])
        elseif strcmp(p_crver_name,'pdf') % View file
            % Set file paper properties
            set(gcf,'PaperType',plot_paper_type,...
                'PaperOrientation',plot_paper_orient,...
                'PaperUnits','centimeters','PaperPosition',plot_paper_pos);
            
            % Save view figure file
            print(gcf,'-dpdf',[p_crver_fig_path p_fig_file])
        end
        
        % Update number of open figures
        p_crver_fig = gcf;
            % Get current file version figure handle
        plot_no = p_crver_fig.Number;
            % Get current file version figure number
        
        %%% Delete data %%%
        % Delete current file version data
        clear p_crver_*
    end
    
    %%% Delete data %%%
    % Delete unnecessary data
    clear ver
end